""" Cisco_IOS_XR_clns_isis_oper 

This module contains a collection of YANG definitions
for Cisco IOS\-XR clns\-isis package operational data.

This module contains definitions
for the following management objects\:
  ocni\-isis\: An OpenConfig description of a network\-instance
  isis\: isis

Copyright (c) 2013\-2018 by Cisco Systems, Inc.
All rights reserved.

"""
from collections import OrderedDict

from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YError, YModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error



class IsisAdjBfdState(Enum):
    """
    IsisAdjBfdState (Enum Class)

    Current BFD state of an adjacency

    .. data:: isis_adj_bfd_no_state = 0

    	No BFD session created

    .. data:: isis_adj_bfd_down_state = 1

    	BFD session is DOWN

    .. data:: isis_adj_bfd_init_state = 2

    	Waiting for BFD session to come UP

    .. data:: isis_adj_bfd_up_state = 3

    	BFD session is UP

    """

    isis_adj_bfd_no_state = Enum.YLeaf(0, "isis-adj-bfd-no-state")

    isis_adj_bfd_down_state = Enum.YLeaf(1, "isis-adj-bfd-down-state")

    isis_adj_bfd_init_state = Enum.YLeaf(2, "isis-adj-bfd-init-state")

    isis_adj_bfd_up_state = Enum.YLeaf(3, "isis-adj-bfd-up-state")


class IsisAdjState(Enum):
    """
    IsisAdjState (Enum Class)

    Isis adj state

    .. data:: isis_adj_up_state = 0

    	Adjacency up

    .. data:: isis_adj_init_state = 1

    	Adjacency initializing

    .. data:: isis_adj_failed_state = 2

    	Adjacency down/failed

    """

    isis_adj_up_state = Enum.YLeaf(0, "isis-adj-up-state")

    isis_adj_init_state = Enum.YLeaf(1, "isis-adj-init-state")

    isis_adj_failed_state = Enum.YLeaf(2, "isis-adj-failed-state")


class IsisAdjStateReason(Enum):
    """
    IsisAdjStateReason (Enum Class)

    Isis adj state reason

    .. data:: isis_adj_up_nsf_restart = 0

    	NSF Restart

    .. data:: isis_adj_up_new_adj = 1

    	New adjacency

    .. data:: isis_adj_up_restarted = 2

    	Restarted

    .. data:: isis_adj_up_nsf_restored = 3

    	Restored during NSF

    .. data:: isis_adj_up_chkpt_restored = 4

    	Restored from checkpoint

    .. data:: isis_adj_init_reason = 5

    	Into INIT

    .. data:: isis_adj_init_neighbor_forgot = 6

    	Neighbor forgot us

    .. data:: isis_adj_down_hold_time = 7

    	Holdtime expired

    .. data:: isis_adj_down_if_down = 8

    	Interface state going down

    .. data:: isis_adj_down_cfg_mismatch = 9

    	Area address/level mismatch

    .. data:: isis_adj_down_circ_id = 10

    	Circuit ID changed

    .. data:: isis_adj_down_nsf_ack_fail = 11

    	NSF could not CSNP Ack P2P adjacency

    .. data:: isis_adj_down_db_clear = 12

    	Clear of the Adjacency DB

    .. data:: isis_adj_down_no_common_topology = 13

    	Neighbors have no common link topology

    .. data:: isis_adj_down_restart_tlv_missing = 14

    	Restart TLV missing during IETF NSF restart

    .. data:: isis_adj_down_bfd_down = 15

    	BFD session has gone DOWN

    .. data:: isis_adj_down_3way_down = 16

    	3-way state down

    """

    isis_adj_up_nsf_restart = Enum.YLeaf(0, "isis-adj-up-nsf-restart")

    isis_adj_up_new_adj = Enum.YLeaf(1, "isis-adj-up-new-adj")

    isis_adj_up_restarted = Enum.YLeaf(2, "isis-adj-up-restarted")

    isis_adj_up_nsf_restored = Enum.YLeaf(3, "isis-adj-up-nsf-restored")

    isis_adj_up_chkpt_restored = Enum.YLeaf(4, "isis-adj-up-chkpt-restored")

    isis_adj_init_reason = Enum.YLeaf(5, "isis-adj-init-reason")

    isis_adj_init_neighbor_forgot = Enum.YLeaf(6, "isis-adj-init-neighbor-forgot")

    isis_adj_down_hold_time = Enum.YLeaf(7, "isis-adj-down-hold-time")

    isis_adj_down_if_down = Enum.YLeaf(8, "isis-adj-down-if-down")

    isis_adj_down_cfg_mismatch = Enum.YLeaf(9, "isis-adj-down-cfg-mismatch")

    isis_adj_down_circ_id = Enum.YLeaf(10, "isis-adj-down-circ-id")

    isis_adj_down_nsf_ack_fail = Enum.YLeaf(11, "isis-adj-down-nsf-ack-fail")

    isis_adj_down_db_clear = Enum.YLeaf(12, "isis-adj-down-db-clear")

    isis_adj_down_no_common_topology = Enum.YLeaf(13, "isis-adj-down-no-common-topology")

    isis_adj_down_restart_tlv_missing = Enum.YLeaf(14, "isis-adj-down-restart-tlv-missing")

    isis_adj_down_bfd_down = Enum.YLeaf(15, "isis-adj-down-bfd-down")

    isis_adj_down_3way_down = Enum.YLeaf(16, "isis-adj-down-3way-down")


class IsisAdjTopoChange(Enum):
    """
    IsisAdjTopoChange (Enum Class)

    Per\-topology change type for an adjacency

    .. data:: isis_adj_topo_up_change = 0

    	Topology up

    .. data:: isis_adj_topo_next_hop_change = 1

    	Topology next-hop changed

    .. data:: isis_adj_topo_down_change = 2

    	Topology down

    """

    isis_adj_topo_up_change = Enum.YLeaf(0, "isis-adj-topo-up-change")

    isis_adj_topo_next_hop_change = Enum.YLeaf(1, "isis-adj-topo-next-hop-change")

    isis_adj_topo_down_change = Enum.YLeaf(2, "isis-adj-topo-down-change")


class IsisAdjTopoStatus(Enum):
    """
    IsisAdjTopoStatus (Enum Class)

    Status of a topology in an adjacency

    .. data:: isis_adj_topo_status_ok = 0

    	Topology is included in adjacency

    .. data:: isis_adj_topo_status_intf_not_configured = 1

    	Topology is not configured on the interface

    .. data:: isis_adj_topo_status_intf_not_running = 2

    	Topology is not running on the interface

    .. data:: isis_adj_topo_status_init_state = 3

    	Adjacency is in INIT state

    .. data:: isis_adj_topo_status_neighbor_doesnt_participate = 4

    	Neighbor doesn't participate in topology

    .. data:: isis_adj_topo_status_ipv4_address_tlv_missing = 5

    	Neighbor IIH doesn't contain IPv4 address TLV

    .. data:: isis_adj_topo_status_ipv4_address_tlv_empty = 6

    	Neighbor's IPv4 address TLV is empty

    .. data:: isis_adj_topo_status_ipv6_address_tlv_missing = 7

    	Neighbor IIH doesn't contain IPv6 address TLV

    .. data:: isis_adj_topo_status_ipv6_address_tlv_empty = 8

    	Neighbor's IPv6 address TLV is empty

    .. data:: isis_adj_topo_status_ipv4_address_matches_ours = 9

    	Neighbor's IPv4 address matches ours

    .. data:: isis_adj_topo_status_ipv6_address_matches_ours = 10

    	Neighbor's IPv6 address matches ours

    .. data:: isis_adj_topo_status_ipv4_address_subnet_mismatch = 11

    	Neighbor's IPv4 address is in a different

    	subnet to ours

    .. data:: isis_adj_topo_status_ipv6_address_not_link_local = 12

    	Neighbor's IPv6 address is not link local

    """

    isis_adj_topo_status_ok = Enum.YLeaf(0, "isis-adj-topo-status-ok")

    isis_adj_topo_status_intf_not_configured = Enum.YLeaf(1, "isis-adj-topo-status-intf-not-configured")

    isis_adj_topo_status_intf_not_running = Enum.YLeaf(2, "isis-adj-topo-status-intf-not-running")

    isis_adj_topo_status_init_state = Enum.YLeaf(3, "isis-adj-topo-status-init-state")

    isis_adj_topo_status_neighbor_doesnt_participate = Enum.YLeaf(4, "isis-adj-topo-status-neighbor-doesnt-participate")

    isis_adj_topo_status_ipv4_address_tlv_missing = Enum.YLeaf(5, "isis-adj-topo-status-ipv4-address-tlv-missing")

    isis_adj_topo_status_ipv4_address_tlv_empty = Enum.YLeaf(6, "isis-adj-topo-status-ipv4-address-tlv-empty")

    isis_adj_topo_status_ipv6_address_tlv_missing = Enum.YLeaf(7, "isis-adj-topo-status-ipv6-address-tlv-missing")

    isis_adj_topo_status_ipv6_address_tlv_empty = Enum.YLeaf(8, "isis-adj-topo-status-ipv6-address-tlv-empty")

    isis_adj_topo_status_ipv4_address_matches_ours = Enum.YLeaf(9, "isis-adj-topo-status-ipv4-address-matches-ours")

    isis_adj_topo_status_ipv6_address_matches_ours = Enum.YLeaf(10, "isis-adj-topo-status-ipv6-address-matches-ours")

    isis_adj_topo_status_ipv4_address_subnet_mismatch = Enum.YLeaf(11, "isis-adj-topo-status-ipv4-address-subnet-mismatch")

    isis_adj_topo_status_ipv6_address_not_link_local = Enum.YLeaf(12, "isis-adj-topo-status-ipv6-address-not-link-local")


class IsisAfId(Enum):
    """
    IsisAfId (Enum Class)

    Isis af id

    .. data:: ipv4 = 0

    	IPv4

    .. data:: ipv6 = 1

    	IPv6

    """

    ipv4 = Enum.YLeaf(0, "ipv4")

    ipv6 = Enum.YLeaf(1, "ipv6")


class IsisEnabled(Enum):
    """
    IsisEnabled (Enum Class)

    Isis enabled

    .. data:: isis_disabled = 0

    	Disabled

    .. data:: isis_enabled = 1

    	Enabled

    """

    isis_disabled = Enum.YLeaf(0, "isis-disabled")

    isis_enabled = Enum.YLeaf(1, "isis-enabled")


class IsisErrLogLevel(Enum):
    """
    IsisErrLogLevel (Enum Class)

    Isis err log level

    .. data:: isis_err_log_level_info = 0

    	isis err log level info

    .. data:: isis_err_log_level_warn = 1

    	isis err log level warn

    .. data:: isis_err_log_level_critical = 2

    	isis err log level critical

    """

    isis_err_log_level_info = Enum.YLeaf(0, "isis-err-log-level-info")

    isis_err_log_level_warn = Enum.YLeaf(1, "isis-err-log-level-warn")

    isis_err_log_level_critical = Enum.YLeaf(2, "isis-err-log-level-critical")


class IsisFrr(Enum):
    """
    IsisFrr (Enum Class)

    Isis frr

    .. data:: isis_frr_type_none = 0

    	Computation disabled

    .. data:: isis_frr_type_per_link = 1

    	Prefix independent per-link computation

    .. data:: isis_frr_type_per_prefix = 2

    	Prefix dependent computation

    .. data:: isis_frr_type_sr_u_loop = 3

    	Segment Routing Microloop Avoidance computation

    """

    isis_frr_type_none = Enum.YLeaf(0, "isis-frr-type-none")

    isis_frr_type_per_link = Enum.YLeaf(1, "isis-frr-type-per-link")

    isis_frr_type_per_prefix = Enum.YLeaf(2, "isis-frr-type-per-prefix")

    isis_frr_type_sr_u_loop = Enum.YLeaf(3, "isis-frr-type-sr-u-loop")


class IsisFrrTiebreaker(Enum):
    """
    IsisFrrTiebreaker (Enum Class)

    Isis frr tiebreaker

    .. data:: isis_frr_tiebreaker_down_stream = 0

    	Backup path is via downstream node

    .. data:: isis_frr_tiebreaker_lc_disjoint = 1

    	Backup path is line card disjoint

    .. data:: isis_frr_tiebreaker_low_est_backup_metric = 2

    	Backup path has lowest metric

    .. data:: isis_frr_tiebreaker_node_protecting = 3

    	Backup path is node protecting

    .. data:: isis_frr_tiebreaker_primary_path = 4

    	Backup path is ECMP

    .. data:: isis_frr_tiebreaker_secondary_path = 5

    	Backup path is not an ECMP

    .. data:: isis_frr_tiebreaker_srlg_disjoint = 6

    	Backup path is SRLG disjoint

    .. data:: isis_frr_tiebreaker_default = 7

    	Backup path is link protecting

    """

    isis_frr_tiebreaker_down_stream = Enum.YLeaf(0, "isis-frr-tiebreaker-down-stream")

    isis_frr_tiebreaker_lc_disjoint = Enum.YLeaf(1, "isis-frr-tiebreaker-lc-disjoint")

    isis_frr_tiebreaker_low_est_backup_metric = Enum.YLeaf(2, "isis-frr-tiebreaker-low-est-backup-metric")

    isis_frr_tiebreaker_node_protecting = Enum.YLeaf(3, "isis-frr-tiebreaker-node-protecting")

    isis_frr_tiebreaker_primary_path = Enum.YLeaf(4, "isis-frr-tiebreaker-primary-path")

    isis_frr_tiebreaker_secondary_path = Enum.YLeaf(5, "isis-frr-tiebreaker-secondary-path")

    isis_frr_tiebreaker_srlg_disjoint = Enum.YLeaf(6, "isis-frr-tiebreaker-srlg-disjoint")

    isis_frr_tiebreaker_default = Enum.YLeaf(7, "isis-frr-tiebreaker-default")


class IsisIfAdjFormDisabledReason(Enum):
    """
    IsisIfAdjFormDisabledReason (Enum Class)

    Isis if adj form disabled reason

    .. data:: isis_intf_adj_form_disabled_cfg_passive = 0

    	isis intf adj form disabled cfg passive

    .. data:: isis_intf_adj_form_disabled_no_topo_participate = 1

    	isis intf adj form disabled no topo participate

    .. data:: isis_intf_adj_form_disabled_add_to_intf_stack_fail = 2

    	isis intf adj form disabled add to intf stack

    	fail

    .. data:: isis_intf_adj_form_disabled_clns_io = 3

    	isis intf adj form disabled clns io

    .. data:: isis_intf_adj_form_disabled_internal_error = 4

    	isis intf adj form disabled internal error

    """

    isis_intf_adj_form_disabled_cfg_passive = Enum.YLeaf(0, "isis-intf-adj-form-disabled-cfg-passive")

    isis_intf_adj_form_disabled_no_topo_participate = Enum.YLeaf(1, "isis-intf-adj-form-disabled-no-topo-participate")

    isis_intf_adj_form_disabled_add_to_intf_stack_fail = Enum.YLeaf(2, "isis-intf-adj-form-disabled-add-to-intf-stack-fail")

    isis_intf_adj_form_disabled_clns_io = Enum.YLeaf(3, "isis-intf-adj-form-disabled-clns-io")

    isis_intf_adj_form_disabled_internal_error = Enum.YLeaf(4, "isis-intf-adj-form-disabled-internal-error")


class IsisIfAdvPrefixDisabledReason(Enum):
    """
    IsisIfAdvPrefixDisabledReason (Enum Class)

    Isis if adv prefix disabled reason

    .. data:: isis_intf_adv_prefix_disabled_if_cfg_suppressed = 0

    	isis intf adv prefix disabled if cfg suppressed

    .. data:: isis_intf_adv_prefix_disabled_no_topo_participate = 1

    	isis intf adv prefix disabled no topo

    	participate

    .. data:: isis_intf_adv_prefix_disabled_internal_error = 2

    	isis intf adv prefix disabled internal error

    """

    isis_intf_adv_prefix_disabled_if_cfg_suppressed = Enum.YLeaf(0, "isis-intf-adv-prefix-disabled-if-cfg-suppressed")

    isis_intf_adv_prefix_disabled_no_topo_participate = Enum.YLeaf(1, "isis-intf-adv-prefix-disabled-no-topo-participate")

    isis_intf_adv_prefix_disabled_internal_error = Enum.YLeaf(2, "isis-intf-adv-prefix-disabled-internal-error")


class IsisIfAfDisabledReason(Enum):
    """
    IsisIfAfDisabledReason (Enum Class)

    Isis if af disabled reason

    .. data:: isis_intf_af_disabled_no_topo_enabled = 0

    	isis intf af disabled no topo enabled

    .. data:: isis_intf_af_disabled_internal_error = 1

    	isis intf af disabled internal error

    """

    isis_intf_af_disabled_no_topo_enabled = Enum.YLeaf(0, "isis-intf-af-disabled-no-topo-enabled")

    isis_intf_af_disabled_internal_error = Enum.YLeaf(1, "isis-intf-af-disabled-internal-error")


class IsisIfAfFwdAddrUnknownReason(Enum):
    """
    IsisIfAfFwdAddrUnknownReason (Enum Class)

    Isis if af fwd addr unknown reason

    .. data:: isis_intf_af_fwd_addr_unknown_cfg_passive = 0

    	isis intf af fwd addr unknown cfg passive

    .. data:: isis_intf_af_fwd_addr_unknown_proto_doesnt_exist = 1

    	isis intf af fwd addr unknown proto doesnt

    	exist

    .. data:: isis_intf_af_fwd_addr_unknown_next_hop_reg_error = 2

    	isis intf af fwd addr unknown next hop reg

    	error

    .. data:: isis_intf_af_fwd_addr_unknown_no_link_local_add = 3

    	isis intf af fwd addr unknown no link local add

    .. data:: isis_intf_af_fwd_addr_unknown_af_not_up = 4

    	isis intf af fwd addr unknown af not up

    .. data:: isis_intf_af_fwd_addr_unknown_vrf_enabled = 5

    	isis intf af fwd addr unknown vrf enabled

    .. data:: isis_intf_af_fwd_addr_unknown_internal_error = 6

    	isis intf af fwd addr unknown internal error

    """

    isis_intf_af_fwd_addr_unknown_cfg_passive = Enum.YLeaf(0, "isis-intf-af-fwd-addr-unknown-cfg-passive")

    isis_intf_af_fwd_addr_unknown_proto_doesnt_exist = Enum.YLeaf(1, "isis-intf-af-fwd-addr-unknown-proto-doesnt-exist")

    isis_intf_af_fwd_addr_unknown_next_hop_reg_error = Enum.YLeaf(2, "isis-intf-af-fwd-addr-unknown-next-hop-reg-error")

    isis_intf_af_fwd_addr_unknown_no_link_local_add = Enum.YLeaf(3, "isis-intf-af-fwd-addr-unknown-no-link-local-add")

    isis_intf_af_fwd_addr_unknown_af_not_up = Enum.YLeaf(4, "isis-intf-af-fwd-addr-unknown-af-not-up")

    isis_intf_af_fwd_addr_unknown_vrf_enabled = Enum.YLeaf(5, "isis-intf-af-fwd-addr-unknown-vrf-enabled")

    isis_intf_af_fwd_addr_unknown_internal_error = Enum.YLeaf(6, "isis-intf-af-fwd-addr-unknown-internal-error")


class IsisIfAfPrefixUnknownReason(Enum):
    """
    IsisIfAfPrefixUnknownReason (Enum Class)

    Isis if af prefix unknown reason

    .. data:: isis_intf_af_prefix_unknown_adv_suppressed = 0

    	isis intf af prefix unknown adv suppressed

    .. data:: isis_intf_af_prefix_unknown_global_addr_reg_error = 1

    	isis intf af prefix unknown global addr reg

    	error

    .. data:: isis_intf_af_prefix_unknown_internal_error = 2

    	isis intf af prefix unknown internal error

    """

    isis_intf_af_prefix_unknown_adv_suppressed = Enum.YLeaf(0, "isis-intf-af-prefix-unknown-adv-suppressed")

    isis_intf_af_prefix_unknown_global_addr_reg_error = Enum.YLeaf(1, "isis-intf-af-prefix-unknown-global-addr-reg-error")

    isis_intf_af_prefix_unknown_internal_error = Enum.YLeaf(2, "isis-intf-af-prefix-unknown-internal-error")


class IsisIfAfProtoDownReason(Enum):
    """
    IsisIfAfProtoDownReason (Enum Class)

    Isis if af proto down reason

    .. data:: isis_intf_af_proto_down_imd_conn_fail = 0

    	isis intf af proto down imd conn fail

    .. data:: isis_intf_af_proto_down_imd_node_doesnt_exist = 1

    	isis intf af proto down imd node doesnt exist

    .. data:: isis_intf_af_proto_down_imd_exist_reg_error = 2

    	isis intf af proto down imd exist reg error

    .. data:: isis_intf_af_proto_down_imd_state_reg_error = 3

    	isis intf af proto down imd state reg error

    .. data:: isis_intf_af_proto_down_af_not_up = 4

    	isis intf af proto down af not up

    .. data:: isis_intf_af_proto_down_internal_error = 5

    	isis intf af proto down internal error

    """

    isis_intf_af_proto_down_imd_conn_fail = Enum.YLeaf(0, "isis-intf-af-proto-down-imd-conn-fail")

    isis_intf_af_proto_down_imd_node_doesnt_exist = Enum.YLeaf(1, "isis-intf-af-proto-down-imd-node-doesnt-exist")

    isis_intf_af_proto_down_imd_exist_reg_error = Enum.YLeaf(2, "isis-intf-af-proto-down-imd-exist-reg-error")

    isis_intf_af_proto_down_imd_state_reg_error = Enum.YLeaf(3, "isis-intf-af-proto-down-imd-state-reg-error")

    isis_intf_af_proto_down_af_not_up = Enum.YLeaf(4, "isis-intf-af-proto-down-af-not-up")

    isis_intf_af_proto_down_internal_error = Enum.YLeaf(5, "isis-intf-af-proto-down-internal-error")


class IsisIfClnsMtuInvalidReason(Enum):
    """
    IsisIfClnsMtuInvalidReason (Enum Class)

    Isis if clns mtu invalid reason

    .. data:: isis_intf_clns_mtu_invalid_too_small = 0

    	isis intf clns mtu invalid too small

    .. data:: isis_intf_clns_mtu_invalid_internal_error = 1

    	isis intf clns mtu invalid internal error

    """

    isis_intf_clns_mtu_invalid_too_small = Enum.YLeaf(0, "isis-intf-clns-mtu-invalid-too-small")

    isis_intf_clns_mtu_invalid_internal_error = Enum.YLeaf(1, "isis-intf-clns-mtu-invalid-internal-error")


class IsisIfClnsProtoDownReason(Enum):
    """
    IsisIfClnsProtoDownReason (Enum Class)

    Isis if clns proto down reason

    .. data:: isis_intf_clns_proto_down_add_to_intf_stack_fail = 0

    	isis intf clns proto down add to intf stack

    	fail

    .. data:: isis_intf_clns_proto_down_no_imd_conn = 1

    	isis intf clns proto down no imd conn

    .. data:: isis_intf_clns_proto_down_imd_node_doesnt_exist = 2

    	isis intf clns proto down imd node doesnt exist

    .. data:: isis_intf_clns_proto_down_imd_exist_reg_error = 3

    	isis intf clns proto down imd exist reg error

    .. data:: isis_intf_clns_proto_down_imd_state_reg_error = 4

    	isis intf clns proto down imd state reg error

    .. data:: isis_intf_clns_proto_down_clns_not_up = 5

    	isis intf clns proto down clns not up

    """

    isis_intf_clns_proto_down_add_to_intf_stack_fail = Enum.YLeaf(0, "isis-intf-clns-proto-down-add-to-intf-stack-fail")

    isis_intf_clns_proto_down_no_imd_conn = Enum.YLeaf(1, "isis-intf-clns-proto-down-no-imd-conn")

    isis_intf_clns_proto_down_imd_node_doesnt_exist = Enum.YLeaf(2, "isis-intf-clns-proto-down-imd-node-doesnt-exist")

    isis_intf_clns_proto_down_imd_exist_reg_error = Enum.YLeaf(3, "isis-intf-clns-proto-down-imd-exist-reg-error")

    isis_intf_clns_proto_down_imd_state_reg_error = Enum.YLeaf(4, "isis-intf-clns-proto-down-imd-state-reg-error")

    isis_intf_clns_proto_down_clns_not_up = Enum.YLeaf(5, "isis-intf-clns-proto-down-clns-not-up")


class IsisIfClnsSnpaUnknownReason(Enum):
    """
    IsisIfClnsSnpaUnknownReason (Enum Class)

    Isis if clns snpa unknown reason

    .. data:: isis_intf_clns_snpa_unknown_access_error = 0

    	isis intf clns snpa unknown access error

    .. data:: isis_intf_clns_snpa_unknown_not_lan = 1

    	isis intf clns snpa unknown not lan

    .. data:: isis_intf_clns_snpa_unknown_internal_error = 2

    	isis intf clns snpa unknown internal error

    """

    isis_intf_clns_snpa_unknown_access_error = Enum.YLeaf(0, "isis-intf-clns-snpa-unknown-access-error")

    isis_intf_clns_snpa_unknown_not_lan = Enum.YLeaf(1, "isis-intf-clns-snpa-unknown-not-lan")

    isis_intf_clns_snpa_unknown_internal_error = Enum.YLeaf(2, "isis-intf-clns-snpa-unknown-internal-error")


class IsisIfDisabledReason(Enum):
    """
    IsisIfDisabledReason (Enum Class)

    Isis if disabled reason

    .. data:: isis_intf_disabled_no_net_cfg = 0

    	isis intf disabled no net cfg

    .. data:: isis_intf_disabled_area_missing = 1

    	isis intf disabled area missing

    .. data:: isis_intf_disabled_no_area_running = 2

    	isis intf disabled no area running

    .. data:: isis_intf_disabled_no_topos_cfg = 3

    	isis intf disabled no topos cfg

    .. data:: isis_intf_disabled_no_imd_conn = 4

    	isis intf disabled no imd conn

    .. data:: isis_intf_disabled_imd_reg_error = 5

    	isis intf disabled imd reg error

    .. data:: isis_intf_disabled_level_mismatch = 6

    	isis intf disabled level mismatch

    .. data:: isis_intf_disabled_base_caps_error = 7

    	isis intf disabled base caps error

    .. data:: isis_intf_disabled_intf_doesnt_exist = 8

    	isis intf disabled intf doesnt exist

    .. data:: isis_intf_disabled_intf_shutdown = 9

    	isis intf disabled intf shutdown

    .. data:: isis_intf_disabled_internal_error = 10

    	isis intf disabled internal error

    """

    isis_intf_disabled_no_net_cfg = Enum.YLeaf(0, "isis-intf-disabled-no-net-cfg")

    isis_intf_disabled_area_missing = Enum.YLeaf(1, "isis-intf-disabled-area-missing")

    isis_intf_disabled_no_area_running = Enum.YLeaf(2, "isis-intf-disabled-no-area-running")

    isis_intf_disabled_no_topos_cfg = Enum.YLeaf(3, "isis-intf-disabled-no-topos-cfg")

    isis_intf_disabled_no_imd_conn = Enum.YLeaf(4, "isis-intf-disabled-no-imd-conn")

    isis_intf_disabled_imd_reg_error = Enum.YLeaf(5, "isis-intf-disabled-imd-reg-error")

    isis_intf_disabled_level_mismatch = Enum.YLeaf(6, "isis-intf-disabled-level-mismatch")

    isis_intf_disabled_base_caps_error = Enum.YLeaf(7, "isis-intf-disabled-base-caps-error")

    isis_intf_disabled_intf_doesnt_exist = Enum.YLeaf(8, "isis-intf-disabled-intf-doesnt-exist")

    isis_intf_disabled_intf_shutdown = Enum.YLeaf(9, "isis-intf-disabled-intf-shutdown")

    isis_intf_disabled_internal_error = Enum.YLeaf(10, "isis-intf-disabled-internal-error")


class IsisIfMcastInvalidReason(Enum):
    """
    IsisIfMcastInvalidReason (Enum Class)

    Isis if mcast invalid reason

    .. data:: isis_intf_mcast_invalid_join_error = 0

    	Error when attempting to join this multicast

    	group

    .. data:: isis_intf_mcast_invalid_internal_error = 1

    	Internal error

    .. data:: isis_intf_mcast_invalid_not_yet_needed = 2

    	Multicast group membership not yet requested

    """

    isis_intf_mcast_invalid_join_error = Enum.YLeaf(0, "isis-intf-mcast-invalid-join-error")

    isis_intf_mcast_invalid_internal_error = Enum.YLeaf(1, "isis-intf-mcast-invalid-internal-error")

    isis_intf_mcast_invalid_not_yet_needed = Enum.YLeaf(2, "isis-intf-mcast-invalid-not-yet-needed")


class IsisIfTopoAdjFormDisabledReason(Enum):
    """
    IsisIfTopoAdjFormDisabledReason (Enum Class)

    Isis if topo adj form disabled reason

    .. data:: isis_intf_topo_adj_form_disabled_intf_passive = 0

    	isis intf topo adj form disabled intf passive

    .. data:: isis_intf_topo_adj_form_disabled_af_not_up = 1

    	isis intf topo adj form disabled af not up

    .. data:: isis_intf_topo_adj_form_disabled_af_fwd_addr_unknown = 2

    	isis intf topo adj form disabled af fwd addr

    	unknown

    .. data:: isis_intf_topo_adj_form_disabled_topo_not_cfg = 3

    	isis intf topo adj form disabled topo not cfg

    .. data:: isis_intf_topo_adj_form_disabled_topo_can_not_participate = 4

    	isis intf topo adj form disabled topo can not

    	participate

    .. data:: isis_intf_topo_adj_form_disabled_idle = 5

    	isis intf topo adj form disabled idle

    .. data:: isis_intf_topo_adj_form_disabled_internal_error = 6

    	isis intf topo adj form disabled internal error

    .. data:: isis_intf_topo_adj_form_disabled_mtu = 7

    	isis intf topo adj form disabled mtu

    .. data:: isis_intf_topo_adj_form_disabled_snpa = 8

    	isis intf topo adj form disabled snpa

    .. data:: isis_intf_topo_adj_form_disabled_mcast = 9

    	isis intf topo adj form disabled mcast

    """

    isis_intf_topo_adj_form_disabled_intf_passive = Enum.YLeaf(0, "isis-intf-topo-adj-form-disabled-intf-passive")

    isis_intf_topo_adj_form_disabled_af_not_up = Enum.YLeaf(1, "isis-intf-topo-adj-form-disabled-af-not-up")

    isis_intf_topo_adj_form_disabled_af_fwd_addr_unknown = Enum.YLeaf(2, "isis-intf-topo-adj-form-disabled-af-fwd-addr-unknown")

    isis_intf_topo_adj_form_disabled_topo_not_cfg = Enum.YLeaf(3, "isis-intf-topo-adj-form-disabled-topo-not-cfg")

    isis_intf_topo_adj_form_disabled_topo_can_not_participate = Enum.YLeaf(4, "isis-intf-topo-adj-form-disabled-topo-can-not-participate")

    isis_intf_topo_adj_form_disabled_idle = Enum.YLeaf(5, "isis-intf-topo-adj-form-disabled-idle")

    isis_intf_topo_adj_form_disabled_internal_error = Enum.YLeaf(6, "isis-intf-topo-adj-form-disabled-internal-error")

    isis_intf_topo_adj_form_disabled_mtu = Enum.YLeaf(7, "isis-intf-topo-adj-form-disabled-mtu")

    isis_intf_topo_adj_form_disabled_snpa = Enum.YLeaf(8, "isis-intf-topo-adj-form-disabled-snpa")

    isis_intf_topo_adj_form_disabled_mcast = Enum.YLeaf(9, "isis-intf-topo-adj-form-disabled-mcast")


class IsisIfTopoAdvPrefixDisabledReason(Enum):
    """
    IsisIfTopoAdvPrefixDisabledReason (Enum Class)

    Isis if topo adv prefix disabled reason

    .. data:: isis_intf_topo_adv_prefix_disabled_intf_suppressed = 0

    	isis intf topo adv prefix disabled intf

    	suppressed

    .. data:: isis_intf_topo_adv_prefix_disabled_af_not_up = 1

    	isis intf topo adv prefix disabled af not up

    .. data:: isis_intf_topo_adv_prefix_disabled_af_prefixes_unknown = 2

    	isis intf topo adv prefix disabled af prefixes

    	unknown

    .. data:: isis_intf_topo_adv_prefix_disabled_internal_error = 3

    	isis intf topo adv prefix disabled internal

    	error

    """

    isis_intf_topo_adv_prefix_disabled_intf_suppressed = Enum.YLeaf(0, "isis-intf-topo-adv-prefix-disabled-intf-suppressed")

    isis_intf_topo_adv_prefix_disabled_af_not_up = Enum.YLeaf(1, "isis-intf-topo-adv-prefix-disabled-af-not-up")

    isis_intf_topo_adv_prefix_disabled_af_prefixes_unknown = Enum.YLeaf(2, "isis-intf-topo-adv-prefix-disabled-af-prefixes-unknown")

    isis_intf_topo_adv_prefix_disabled_internal_error = Enum.YLeaf(3, "isis-intf-topo-adv-prefix-disabled-internal-error")


class IsisIfTopoDisabledReason(Enum):
    """
    IsisIfTopoDisabledReason (Enum Class)

    Isis if topo disabled reason

    .. data:: isis_intf_topo_disabled_not_cfg = 0

    	isis intf topo disabled not cfg

    .. data:: isis_intf_topo_disabled_internal_error = 1

    	isis intf topo disabled internal error

    """

    isis_intf_topo_disabled_not_cfg = Enum.YLeaf(0, "isis-intf-topo-disabled-not-cfg")

    isis_intf_topo_disabled_internal_error = Enum.YLeaf(1, "isis-intf-topo-disabled-internal-error")


class IsisKnown(Enum):
    """
    IsisKnown (Enum Class)

    Isis known

    .. data:: isis_unknown = 0

    	Unknown

    .. data:: isis_known = 1

    	Known

    """

    isis_unknown = Enum.YLeaf(0, "isis-unknown")

    isis_known = Enum.YLeaf(1, "isis-known")


class IsisLevel(Enum):
    """
    IsisLevel (Enum Class)

    Isis level

    .. data:: isis_level0 = 0

    	isis level0

    .. data:: isis_level1 = 1

    	isis level1

    .. data:: isis_level2 = 2

    	isis level2

    """

    isis_level0 = Enum.YLeaf(0, "isis-level0")

    isis_level1 = Enum.YLeaf(1, "isis-level1")

    isis_level2 = Enum.YLeaf(2, "isis-level2")


class IsisLevels(Enum):
    """
    IsisLevels (Enum Class)

    Isis levels

    .. data:: isis_levels_none = 0

    	isis levels none

    .. data:: isis_levels_1 = 1

    	isis levels 1

    .. data:: isis_levels_2 = 2

    	isis levels 2

    .. data:: isis_levels_12 = 3

    	isis levels 12

    .. data:: isis_levels_total = 4

    	isis levels total

    """

    isis_levels_none = Enum.YLeaf(0, "isis-levels-none")

    isis_levels_1 = Enum.YLeaf(1, "isis-levels-1")

    isis_levels_2 = Enum.YLeaf(2, "isis-levels-2")

    isis_levels_12 = Enum.YLeaf(3, "isis-levels-12")

    isis_levels_total = Enum.YLeaf(4, "isis-levels-total")


class IsisLspDbOp(Enum):
    """
    IsisLspDbOp (Enum Class)

    Isis lsp db op

    .. data:: isis_lsp_db_clear = 0

    	Clear the LSP database

    .. data:: isis_lsp_db_insert_new_lsp = 1

    	Insertion of new LSP

    .. data:: isis_lsp_db_replace_lsp_with_lsp = 2

    	LSP replacing LSP

    .. data:: isis_lsp_db_purge_lsp = 3

    	LSP purged by the local system

    .. data:: isis_lsp_db_delete_lsp = 4

    	Removal of the LSP from the database

    """

    isis_lsp_db_clear = Enum.YLeaf(0, "isis-lsp-db-clear")

    isis_lsp_db_insert_new_lsp = Enum.YLeaf(1, "isis-lsp-db-insert-new-lsp")

    isis_lsp_db_replace_lsp_with_lsp = Enum.YLeaf(2, "isis-lsp-db-replace-lsp-with-lsp")

    isis_lsp_db_purge_lsp = Enum.YLeaf(3, "isis-lsp-db-purge-lsp")

    isis_lsp_db_delete_lsp = Enum.YLeaf(4, "isis-lsp-db-delete-lsp")


class IsisLspTrigger(Enum):
    """
    IsisLspTrigger (Enum Class)

    Isis lsp trigger

    .. data:: isis_lsp_trig_config = 0

    	Any configuration change

    .. data:: isis_lsp_trig_newadj = 1

    	New adjacency came up

    .. data:: isis_lsp_trig_deladj = 2

    	Adjacency went down

    .. data:: isis_lsp_trig_dr_change = 3

    	DIS changed, or pseudonode changed

    .. data:: isis_lsp_trig_area_set = 4

    	Active area set changed

    .. data:: isis_lsp_trig_attach = 5

    	Attached bit changed state

    .. data:: isis_lsp_trig_hippity = 6

    	LSPDB overload bit changed state

    .. data:: isis_lsp_trig_regen = 7

    	LSP regeneration

    .. data:: isis_lsp_trig_ip_if_up = 8

    	Directly connected IP prefix up

    .. data:: isis_lsp_trig_ip_if_down = 9

    	Directly connected IP prefix down

    .. data:: isis_lsp_trig_ip_inter_area = 10

    	Interarea IP route appeared or gone

    .. data:: isis_lsp_trig_ip_external = 11

    	Redistributed IP route appeared or gone

    .. data:: isis_lsp_trig_ip_external_full = 12

    	Full IP redistribution

    .. data:: isis_lsp_trig_ip_def_orig = 13

    	Default information originate changed

    .. data:: isis_lsp_trig_ip_addr_chg = 14

    	IP interface address changed

    .. data:: isis_lsp_trig_te_info = 15

    	TE bandwidth resource information

    .. data:: isis_lsp_trig_te_pce_info = 16

    	TE PCE information

    .. data:: isis_lsp_trig_te_fa_info = 17

    	TE forwarding adjacency information

    .. data:: isis_lsp_trig_nsr_fo = 18

    	NSR FO is done

    .. data:: isis_lsp_trig_pn_cancel = 19

    	Pseudo-node generation canceled

    .. data:: isis_lsp_trig_lkgp = 20

    	Link-group offset metric change

    .. data:: isis_lsp_trig_pp = 21

    	Proactive Protection metric change

    .. data:: isis_lsp_trig_config_force_send = 22

    	Any configuration change that requires all LSPs

    	to be updated

    .. data:: isis_lsp_trig_config_force_init = 23

    	Any configuration change that requires the LBD

    	database re-init.

    .. data:: isis_lsp_trig_adj_sid_add = 24

    	Adjacency SID added

    .. data:: isis_lsp_trig_adj_sid_delete = 25

    	Adjacency SID deleted

    .. data:: isis_lsp_trig_adj_sid_change = 26

    	Adjacency SIDs added and/or deleted

    .. data:: isis_lsp_trig_msd = 27

    	Maximum SID depth change

    .. data:: isis_lsp_trig_adj_sid_wait_timer = 28

    	Adjacency SID wait timer expired

    .. data:: isis_lsp_trig_direct_gen = 29

    	Direct LSP generation

    .. data:: isis_lsp_trig_flex_algo_enable_disable = 30

    	Flex-Algo Enable/Disable

    .. data:: isis_lsp_trig_pm_delay_loss = 31

    	Link delay/loss changed

    .. data:: isis_lsp_trig_pm_bw_util = 32

    	Link bandwidth utilization changed

    """

    isis_lsp_trig_config = Enum.YLeaf(0, "isis-lsp-trig-config")

    isis_lsp_trig_newadj = Enum.YLeaf(1, "isis-lsp-trig-newadj")

    isis_lsp_trig_deladj = Enum.YLeaf(2, "isis-lsp-trig-deladj")

    isis_lsp_trig_dr_change = Enum.YLeaf(3, "isis-lsp-trig-dr-change")

    isis_lsp_trig_area_set = Enum.YLeaf(4, "isis-lsp-trig-area-set")

    isis_lsp_trig_attach = Enum.YLeaf(5, "isis-lsp-trig-attach")

    isis_lsp_trig_hippity = Enum.YLeaf(6, "isis-lsp-trig-hippity")

    isis_lsp_trig_regen = Enum.YLeaf(7, "isis-lsp-trig-regen")

    isis_lsp_trig_ip_if_up = Enum.YLeaf(8, "isis-lsp-trig-ip-if-up")

    isis_lsp_trig_ip_if_down = Enum.YLeaf(9, "isis-lsp-trig-ip-if-down")

    isis_lsp_trig_ip_inter_area = Enum.YLeaf(10, "isis-lsp-trig-ip-inter-area")

    isis_lsp_trig_ip_external = Enum.YLeaf(11, "isis-lsp-trig-ip-external")

    isis_lsp_trig_ip_external_full = Enum.YLeaf(12, "isis-lsp-trig-ip-external-full")

    isis_lsp_trig_ip_def_orig = Enum.YLeaf(13, "isis-lsp-trig-ip-def-orig")

    isis_lsp_trig_ip_addr_chg = Enum.YLeaf(14, "isis-lsp-trig-ip-addr-chg")

    isis_lsp_trig_te_info = Enum.YLeaf(15, "isis-lsp-trig-te-info")

    isis_lsp_trig_te_pce_info = Enum.YLeaf(16, "isis-lsp-trig-te-pce-info")

    isis_lsp_trig_te_fa_info = Enum.YLeaf(17, "isis-lsp-trig-te-fa-info")

    isis_lsp_trig_nsr_fo = Enum.YLeaf(18, "isis-lsp-trig-nsr-fo")

    isis_lsp_trig_pn_cancel = Enum.YLeaf(19, "isis-lsp-trig-pn-cancel")

    isis_lsp_trig_lkgp = Enum.YLeaf(20, "isis-lsp-trig-lkgp")

    isis_lsp_trig_pp = Enum.YLeaf(21, "isis-lsp-trig-pp")

    isis_lsp_trig_config_force_send = Enum.YLeaf(22, "isis-lsp-trig-config-force-send")

    isis_lsp_trig_config_force_init = Enum.YLeaf(23, "isis-lsp-trig-config-force-init")

    isis_lsp_trig_adj_sid_add = Enum.YLeaf(24, "isis-lsp-trig-adj-sid-add")

    isis_lsp_trig_adj_sid_delete = Enum.YLeaf(25, "isis-lsp-trig-adj-sid-delete")

    isis_lsp_trig_adj_sid_change = Enum.YLeaf(26, "isis-lsp-trig-adj-sid-change")

    isis_lsp_trig_msd = Enum.YLeaf(27, "isis-lsp-trig-msd")

    isis_lsp_trig_adj_sid_wait_timer = Enum.YLeaf(28, "isis-lsp-trig-adj-sid-wait-timer")

    isis_lsp_trig_direct_gen = Enum.YLeaf(29, "isis-lsp-trig-direct-gen")

    isis_lsp_trig_flex_algo_enable_disable = Enum.YLeaf(30, "isis-lsp-trig-flex-algo-enable-disable")

    isis_lsp_trig_pm_delay_loss = Enum.YLeaf(31, "isis-lsp-trig-pm-delay-loss")

    isis_lsp_trig_pm_bw_util = Enum.YLeaf(32, "isis-lsp-trig-pm-bw-util")


class IsisMediaClass(Enum):
    """
    IsisMediaClass (Enum Class)

    Isis media class

    .. data:: isis_media_class_lan = 0

    	LAN

    .. data:: isis_media_class_p2p = 1

    	P2P

    .. data:: isis_media_class_loop_back = 2

    	Loopback

    """

    isis_media_class_lan = Enum.YLeaf(0, "isis-media-class-lan")

    isis_media_class_p2p = Enum.YLeaf(1, "isis-media-class-p2p")

    isis_media_class_loop_back = Enum.YLeaf(2, "isis-media-class-loop-back")


class IsisMetricMode(Enum):
    """
    IsisMetricMode (Enum Class)

    Isis metric mode

    .. data:: isis_metric_mode_fixed = 0

    	Fixed

    .. data:: isis_metric_mode_relative = 1

    	Relative

    .. data:: isis_metric_mode_absolute = 2

    	Absolute

    """

    isis_metric_mode_fixed = Enum.YLeaf(0, "isis-metric-mode-fixed")

    isis_metric_mode_relative = Enum.YLeaf(1, "isis-metric-mode-relative")

    isis_metric_mode_absolute = Enum.YLeaf(2, "isis-metric-mode-absolute")


class IsisMetricStyle(Enum):
    """
    IsisMetricStyle (Enum Class)

    Isis metric style

    .. data:: isis_metric_style_narrow = 0

    	old-style (ISO 10589) metrics

    .. data:: isis_metric_style_wide = 1

    	new-style 32-bit metrics

    .. data:: isis_metric_style_transition = 2

    	send/accept both forms of metric

    .. data:: isis_metric_style_narrow_transition = 3

    	send old-style (ISO 10589) metrics but accept

    	both

    .. data:: isis_metric_style_wide_transition = 4

    	send new-style 32-bit metrics but accept both

    """

    isis_metric_style_narrow = Enum.YLeaf(0, "isis-metric-style-narrow")

    isis_metric_style_wide = Enum.YLeaf(1, "isis-metric-style-wide")

    isis_metric_style_transition = Enum.YLeaf(2, "isis-metric-style-transition")

    isis_metric_style_narrow_transition = Enum.YLeaf(3, "isis-metric-style-narrow-transition")

    isis_metric_style_wide_transition = Enum.YLeaf(4, "isis-metric-style-wide-transition")


class IsisNsfFlavor(Enum):
    """
    IsisNsfFlavor (Enum Class)

    Isis nsf flavor

    .. data:: isis_nsf_flav_or_none = 0

    	NSF not configured

    .. data:: isis_nsf_flav_or_cisco = 1

    	Cisco-proprietary NSF

    .. data:: isis_nsf_flav_or_ietf = 2

    	IETF-standard NSF

    .. data:: isis_nsf_flav_or_nsr = 3

    	Cisco-proprietary NSR

    """

    isis_nsf_flav_or_none = Enum.YLeaf(0, "isis-nsf-flav-or-none")

    isis_nsf_flav_or_cisco = Enum.YLeaf(1, "isis-nsf-flav-or-cisco")

    isis_nsf_flav_or_ietf = Enum.YLeaf(2, "isis-nsf-flav-or-ietf")

    isis_nsf_flav_or_nsr = Enum.YLeaf(3, "isis-nsf-flav-or-nsr")


class IsisPrefixOrigin(Enum):
    """
    IsisPrefixOrigin (Enum Class)

    Isis prefix origin

    .. data:: isis_prefix_origin_l1_summary_null = 0

    	Level 1 Summary Null Route

    .. data:: isis_prefix_origin_l1 = 1

    	Level 1 Route

    .. data:: isis_prefix_origin_l2_summary_null = 2

    	Level 2 Summary Null Route

    .. data:: isis_prefix_origin_l2 = 3

    	Level 2 Route

    .. data:: isis_prefix_origin_inter_area_summary_null = 4

    	Level 1 Interarea Summary Null Route

    .. data:: isis_prefix_origin_inter_area = 5

    	Level 1 Interarea Route

    .. data:: isis_prefix_origin_default_nearest_attached = 6

    	Nearest Attached Default Route

    """

    isis_prefix_origin_l1_summary_null = Enum.YLeaf(0, "isis-prefix-origin-l1-summary-null")

    isis_prefix_origin_l1 = Enum.YLeaf(1, "isis-prefix-origin-l1")

    isis_prefix_origin_l2_summary_null = Enum.YLeaf(2, "isis-prefix-origin-l2-summary-null")

    isis_prefix_origin_l2 = Enum.YLeaf(3, "isis-prefix-origin-l2")

    isis_prefix_origin_inter_area_summary_null = Enum.YLeaf(4, "isis-prefix-origin-inter-area-summary-null")

    isis_prefix_origin_inter_area = Enum.YLeaf(5, "isis-prefix-origin-inter-area")

    isis_prefix_origin_default_nearest_attached = Enum.YLeaf(6, "isis-prefix-origin-default-nearest-attached")


class IsisPrefixPriority(Enum):
    """
    IsisPrefixPriority (Enum Class)

    Isis prefix priority

    .. data:: isis_prefix_priority_critical = 0

    	Critical priority prefixes

    .. data:: isis_prefix_priority_high = 1

    	High priority prefixes

    .. data:: isis_prefix_priority_med = 2

    	Medium priority prefixes

    .. data:: isis_prefix_priority_low = 3

    	Low priority prefixes

    """

    isis_prefix_priority_critical = Enum.YLeaf(0, "isis-prefix-priority-critical")

    isis_prefix_priority_high = Enum.YLeaf(1, "isis-prefix-priority-high")

    isis_prefix_priority_med = Enum.YLeaf(2, "isis-prefix-priority-med")

    isis_prefix_priority_low = Enum.YLeaf(3, "isis-prefix-priority-low")


class IsisReachable(Enum):
    """
    IsisReachable (Enum Class)

    Isis reachable

    .. data:: isis_unreachable = 0

    	Unreachable

    .. data:: isis_reachable = 1

    	Reachable

    """

    isis_unreachable = Enum.YLeaf(0, "isis-unreachable")

    isis_reachable = Enum.YLeaf(1, "isis-reachable")


class IsisRedistProto(Enum):
    """
    IsisRedistProto (Enum Class)

    Isis redist proto

    .. data:: isis_redist_connected = 0

    	Redistributed protocol is Connected

    .. data:: isis_redist_static = 1

    	Redistributed protocol is Static

    .. data:: isis_redist_ospf = 2

    	Redistributed protocol is OSPF

    .. data:: isis_redist_bgp = 3

    	Redistributed protocol is BGP

    .. data:: isis_redist_isis = 4

    	Redistributed protocol is IS-IS

    .. data:: isis_redist_ospfv3 = 5

    	Redistributed protocol is OSPFv3

    .. data:: isis_redist_rip = 6

    	Redistributed protocol is RIP

    .. data:: isis_redist_eigrp = 7

    	Redistributed protocol is EIGRP

    .. data:: isis_redist_subscriber = 8

    	Redistributed protocol is Subscriber

    .. data:: isis_redist_application = 9

    	Redistributed protocol is Application

    .. data:: isis_redist_mobile = 10

    	Redistributed protocol is Mobile

    """

    isis_redist_connected = Enum.YLeaf(0, "isis-redist-connected")

    isis_redist_static = Enum.YLeaf(1, "isis-redist-static")

    isis_redist_ospf = Enum.YLeaf(2, "isis-redist-ospf")

    isis_redist_bgp = Enum.YLeaf(3, "isis-redist-bgp")

    isis_redist_isis = Enum.YLeaf(4, "isis-redist-isis")

    isis_redist_ospfv3 = Enum.YLeaf(5, "isis-redist-ospfv3")

    isis_redist_rip = Enum.YLeaf(6, "isis-redist-rip")

    isis_redist_eigrp = Enum.YLeaf(7, "isis-redist-eigrp")

    isis_redist_subscriber = Enum.YLeaf(8, "isis-redist-subscriber")

    isis_redist_application = Enum.YLeaf(9, "isis-redist-application")

    isis_redist_mobile = Enum.YLeaf(10, "isis-redist-mobile")


class IsisShRouteAdvOrigin(Enum):
    """
    IsisShRouteAdvOrigin (Enum Class)

    Origin of a prefix advertisement

    .. data:: isis_sh_route_adv_origin_interface = 0

    	IS-IS interface prefix

    .. data:: isis_sh_route_adv_origin_redistributed = 1

    	Redistributed prefix

    .. data:: isis_sh_route_adv_origin_native = 2

    	Native prefix

    .. data:: isis_sh_route_adv_origin_summary = 3

    	Summary prefix

    .. data:: isis_sh_route_adv_origin_default = 4

    	Explicit origination of default prefix

    """

    isis_sh_route_adv_origin_interface = Enum.YLeaf(0, "isis-sh-route-adv-origin-interface")

    isis_sh_route_adv_origin_redistributed = Enum.YLeaf(1, "isis-sh-route-adv-origin-redistributed")

    isis_sh_route_adv_origin_native = Enum.YLeaf(2, "isis-sh-route-adv-origin-native")

    isis_sh_route_adv_origin_summary = Enum.YLeaf(3, "isis-sh-route-adv-origin-summary")

    isis_sh_route_adv_origin_default = Enum.YLeaf(4, "isis-sh-route-adv-origin-default")


class IsisShTeLink(Enum):
    """
    IsisShTeLink (Enum Class)

    Isis sh te link

    .. data:: isis_sh_te_link_p2p = 0

    	Tunnel is absolute

    .. data:: isis_sh_te_link_broadcast = 1

    	Broadcast link

    """

    isis_sh_te_link_p2p = Enum.YLeaf(0, "isis-sh-te-link-p2p")

    isis_sh_te_link_broadcast = Enum.YLeaf(1, "isis-sh-te-link-broadcast")


class IsisShTePceFloodingScope(Enum):
    """
    IsisShTePceFloodingScope (Enum Class)

    Isis sh te pce flooding scope

    .. data:: none = 0

    	Flooding is disabled

    .. data:: area = 1

    	Area wide flooding

    .. data:: domain = 2

    	Domain wide flooding

    """

    none = Enum.YLeaf(0, "none")

    area = Enum.YLeaf(1, "area")

    domain = Enum.YLeaf(2, "domain")


class IsisSpfClass(Enum):
    """
    IsisSpfClass (Enum Class)

    Types of route calculation

    .. data:: isis_spf_frr_sr_u_loop = 0

    	Remote microloop avoidance SPF

    .. data:: isis_spf_frr_per_link = 1

    	FRR per-link SPF

    .. data:: isis_spf_partial = 2

    	PRC

    .. data:: isis_spf_frr_per_prefix = 3

    	FRR per-prefix SPF

    .. data:: isis_spf_ucmp_calc = 4

    	UCMP SPF

    .. data:: isis_spf_flex = 5

    	Flex-Algo SPF

    .. data:: isis_spf_next_hop = 6

    	Next Hop

    .. data:: isis_spf_incremental = 7

    	Incremental SPF

    .. data:: isis_spf_full = 8

    	Full SPF

    """

    isis_spf_frr_sr_u_loop = Enum.YLeaf(0, "isis-spf-frr-sr-u-loop")

    isis_spf_frr_per_link = Enum.YLeaf(1, "isis-spf-frr-per-link")

    isis_spf_partial = Enum.YLeaf(2, "isis-spf-partial")

    isis_spf_frr_per_prefix = Enum.YLeaf(3, "isis-spf-frr-per-prefix")

    isis_spf_ucmp_calc = Enum.YLeaf(4, "isis-spf-ucmp-calc")

    isis_spf_flex = Enum.YLeaf(5, "isis-spf-flex")

    isis_spf_next_hop = Enum.YLeaf(6, "isis-spf-next-hop")

    isis_spf_incremental = Enum.YLeaf(7, "isis-spf-incremental")

    isis_spf_full = Enum.YLeaf(8, "isis-spf-full")


class IsisSpfTrigger(Enum):
    """
    IsisSpfTrigger (Enum Class)

    Isis spf trigger

    .. data:: isis_spf_trig_config = 0

    	Configuration change

    .. data:: isis_spf_trig_nsr_fo = 1

    	NSR FO is done

    .. data:: isis_spf_trig_periodic = 2

    	Periodic SPF

    .. data:: isis_spf_trig_clear = 3

    	Cleared route table

    .. data:: isis_spf_trig_newadj = 4

    	New adjacency

    .. data:: isis_spf_trig_deladj = 5

    	Deleted adjacency

    .. data:: isis_spf_trig_next_hop = 6

    	IP nexthop address change

    .. data:: isis_spf_trig_metric = 7

    	Changed interface metric

    .. data:: isis_spf_trig_dis = 8

    	Change to elected DIS

    .. data:: isis_spf_trig_frr_per_link = 9

    	Change to per-link FRR config

    .. data:: isis_spf_trig_frr_per_prefix = 10

    	Change to per-prefix FRR config

    .. data:: isis_spf_trig_ucmp = 11

    	Change to UCMP config/calculation

    .. data:: isis_spf_trig_new_tunnel = 12

    	New TE Autoroute Tunnel

    .. data:: isis_spf_trig_del_tunnel = 13

    	Deleted TE Autoroute Tunnel

    .. data:: isis_spf_trig_chg_tunnel = 14

    	Changed TE Autoroute Tunnel

    .. data:: isis_spf_trig_new_node = 15

    	New LSP zero which participates in topology

    .. data:: isis_spf_trig_del_node = 16

    	New LSP zero which no longer participates in

    	topology

    .. data:: isis_spf_trig_newlsp = 17

    	Previously unseen LSP fragment

    .. data:: isis_spf_trig_lsp_expiry = 18

    	LSP expired

    .. data:: isis_spf_trig_attach_set = 19

    	Attached bit set

    .. data:: isis_spf_trig_attach_clr = 20

    	Attached bit cleared

    .. data:: isis_spf_trig_overload_set = 21

    	Overload bit set

    .. data:: isis_spf_trig_overload_clr = 22

    	Overload bit cleared

    .. data:: isis_spf_trig_link_good = 23

    	Good news link TLV content change

    .. data:: isis_spf_trig_link_bad = 24

    	Bad news link TLV content change

    .. data:: isis_spf_trig_prefix_good = 25

    	Good news prefix TLV content change

    .. data:: isis_spf_trig_prefix_bad = 26

    	Bad news prefix TLV content change

    .. data:: isis_spf_trig_prefix = 27

    	Neutral (neither good nor bad news) prefix TLV

    	content change

    .. data:: isis_spf_trig_area_addr = 28

    	Area address TLV content change

    .. data:: isis_spf_trig_ip_addr = 29

    	IP address TLV content change

    .. data:: isis_spf_trig_rtrid = 30

    	Router id TLV content change

    .. data:: isis_spf_trig_flex_algo = 31

    	Flex-Algo support change

    .. data:: isis_spf_trig_prefix_policy = 32

    	Prefix policy change

    """

    isis_spf_trig_config = Enum.YLeaf(0, "isis-spf-trig-config")

    isis_spf_trig_nsr_fo = Enum.YLeaf(1, "isis-spf-trig-nsr-fo")

    isis_spf_trig_periodic = Enum.YLeaf(2, "isis-spf-trig-periodic")

    isis_spf_trig_clear = Enum.YLeaf(3, "isis-spf-trig-clear")

    isis_spf_trig_newadj = Enum.YLeaf(4, "isis-spf-trig-newadj")

    isis_spf_trig_deladj = Enum.YLeaf(5, "isis-spf-trig-deladj")

    isis_spf_trig_next_hop = Enum.YLeaf(6, "isis-spf-trig-next-hop")

    isis_spf_trig_metric = Enum.YLeaf(7, "isis-spf-trig-metric")

    isis_spf_trig_dis = Enum.YLeaf(8, "isis-spf-trig-dis")

    isis_spf_trig_frr_per_link = Enum.YLeaf(9, "isis-spf-trig-frr-per-link")

    isis_spf_trig_frr_per_prefix = Enum.YLeaf(10, "isis-spf-trig-frr-per-prefix")

    isis_spf_trig_ucmp = Enum.YLeaf(11, "isis-spf-trig-ucmp")

    isis_spf_trig_new_tunnel = Enum.YLeaf(12, "isis-spf-trig-new-tunnel")

    isis_spf_trig_del_tunnel = Enum.YLeaf(13, "isis-spf-trig-del-tunnel")

    isis_spf_trig_chg_tunnel = Enum.YLeaf(14, "isis-spf-trig-chg-tunnel")

    isis_spf_trig_new_node = Enum.YLeaf(15, "isis-spf-trig-new-node")

    isis_spf_trig_del_node = Enum.YLeaf(16, "isis-spf-trig-del-node")

    isis_spf_trig_newlsp = Enum.YLeaf(17, "isis-spf-trig-newlsp")

    isis_spf_trig_lsp_expiry = Enum.YLeaf(18, "isis-spf-trig-lsp-expiry")

    isis_spf_trig_attach_set = Enum.YLeaf(19, "isis-spf-trig-attach-set")

    isis_spf_trig_attach_clr = Enum.YLeaf(20, "isis-spf-trig-attach-clr")

    isis_spf_trig_overload_set = Enum.YLeaf(21, "isis-spf-trig-overload-set")

    isis_spf_trig_overload_clr = Enum.YLeaf(22, "isis-spf-trig-overload-clr")

    isis_spf_trig_link_good = Enum.YLeaf(23, "isis-spf-trig-link-good")

    isis_spf_trig_link_bad = Enum.YLeaf(24, "isis-spf-trig-link-bad")

    isis_spf_trig_prefix_good = Enum.YLeaf(25, "isis-spf-trig-prefix-good")

    isis_spf_trig_prefix_bad = Enum.YLeaf(26, "isis-spf-trig-prefix-bad")

    isis_spf_trig_prefix = Enum.YLeaf(27, "isis-spf-trig-prefix")

    isis_spf_trig_area_addr = Enum.YLeaf(28, "isis-spf-trig-area-addr")

    isis_spf_trig_ip_addr = Enum.YLeaf(29, "isis-spf-trig-ip-addr")

    isis_spf_trig_rtrid = Enum.YLeaf(30, "isis-spf-trig-rtrid")

    isis_spf_trig_flex_algo = Enum.YLeaf(31, "isis-spf-trig-flex-algo")

    isis_spf_trig_prefix_policy = Enum.YLeaf(32, "isis-spf-trig-prefix-policy")


class IsisStartupStatus(Enum):
    """
    IsisStartupStatus (Enum Class)

    Isis startup status

    .. data:: isis_startup_ssm_active = 0

    	Startup-state-machine controlled restart in

    	progress

    .. data:: isis_startup_ssm_complete = 1

    	Startup-state-machine controlled restart

    	complete

    .. data:: isis_startup_ssm_aborted = 2

    	Startup-state-machine controlled restart

    	aborted

    .. data:: isis_startup_ssm_not_run = 3

    	Startup-state-machine controlled not attempted

    """

    isis_startup_ssm_active = Enum.YLeaf(0, "isis-startup-ssm-active")

    isis_startup_ssm_complete = Enum.YLeaf(1, "isis-startup-ssm-complete")

    isis_startup_ssm_aborted = Enum.YLeaf(2, "isis-startup-ssm-aborted")

    isis_startup_ssm_not_run = Enum.YLeaf(3, "isis-startup-ssm-not-run")


class IsisSubAfId(Enum):
    """
    IsisSubAfId (Enum Class)

    Isis sub af id

    .. data:: unicast = 0

    	Unicast

    .. data:: multicast = 1

    	Multicast

    """

    unicast = Enum.YLeaf(0, "unicast")

    multicast = Enum.YLeaf(1, "multicast")


class IsisTilfaComputation(Enum):
    """
    IsisTilfaComputation (Enum Class)

    Isis tilfa computation

    .. data:: isis_tilfa_comp_none = 0

    	isis tilfa comp none

    .. data:: isis_tilfa_comp_link = 1

    	isis tilfa comp link

    .. data:: isis_tilfa_comp_node = 2

    	isis tilfa comp node

    .. data:: isis_tilfa_comp_srlg = 3

    	isis tilfa comp srlg

    .. data:: isis_tilfa_comp_node_srlg = 4

    	isis tilfa comp node srlg

    """

    isis_tilfa_comp_none = Enum.YLeaf(0, "isis-tilfa-comp-none")

    isis_tilfa_comp_link = Enum.YLeaf(1, "isis-tilfa-comp-link")

    isis_tilfa_comp_node = Enum.YLeaf(2, "isis-tilfa-comp-node")

    isis_tilfa_comp_srlg = Enum.YLeaf(3, "isis-tilfa-comp-srlg")

    isis_tilfa_comp_node_srlg = Enum.YLeaf(4, "isis-tilfa-comp-node-srlg")


class IsisUloopAvoidance(Enum):
    """
    IsisUloopAvoidance (Enum Class)

    Isis uloop avoidance

    .. data:: isis_u_loop_avoidance_type_none = 0

    	No MicroLoop avoidance

    .. data:: isis_u_loop_avoidance_type_all = 1

    	Apply MicroLoop avoidance for all prefixes

    .. data:: isis_u_loop_avoidance_type_protected = 2

    	Apply MicroLoop avoidance only for protected

    	prefixes

    .. data:: isis_u_loop_avoidance_type_sr = 3

    	Segment Routing MicroLoop avoidance for All

    	single-link changes

    """

    isis_u_loop_avoidance_type_none = Enum.YLeaf(0, "isis-u-loop-avoidance-type-none")

    isis_u_loop_avoidance_type_all = Enum.YLeaf(1, "isis-u-loop-avoidance-type-all")

    isis_u_loop_avoidance_type_protected = Enum.YLeaf(2, "isis-u-loop-avoidance-type-protected")

    isis_u_loop_avoidance_type_sr = Enum.YLeaf(3, "isis-u-loop-avoidance-type-sr")


class IsisUloopEvent(Enum):
    """
    IsisUloopEvent (Enum Class)

    Isis uloop event

    .. data:: isis_u_loop_event_none = 0

    	isis u loop event none

    .. data:: isis_u_loop_event_link_down = 1

    	isis u loop event link down

    .. data:: isis_u_loop_event_link_up = 2

    	isis u loop event link up

    .. data:: isis_u_loop_event_ol_bit_set = 3

    	isis u loop event ol bit set

    .. data:: isis_u_loop_event_ol_bit_unset = 4

    	isis u loop event ol bit unset

    """

    isis_u_loop_event_none = Enum.YLeaf(0, "isis-u-loop-event-none")

    isis_u_loop_event_link_down = Enum.YLeaf(1, "isis-u-loop-event-link-down")

    isis_u_loop_event_link_up = Enum.YLeaf(2, "isis-u-loop-event-link-up")

    isis_u_loop_event_ol_bit_set = Enum.YLeaf(3, "isis-u-loop-event-ol-bit-set")

    isis_u_loop_event_ol_bit_unset = Enum.YLeaf(4, "isis-u-loop-event-ol-bit-unset")


class IsisUp(Enum):
    """
    IsisUp (Enum Class)

    Isis up

    .. data:: isis_down = 0

    	Down

    .. data:: isis_up = 1

    	Up

    """

    isis_down = Enum.YLeaf(0, "isis-down")

    isis_up = Enum.YLeaf(1, "isis-up")


class IsisValid(Enum):
    """
    IsisValid (Enum Class)

    Isis valid

    .. data:: isis_invalid = 0

    	Invalid

    .. data:: isis_valid = 1

    	Valid

    """

    isis_invalid = Enum.YLeaf(0, "isis-invalid")

    isis_valid = Enum.YLeaf(1, "isis-valid")


class OpenconfigIsisAdjacencyStateNlpidEnum(Enum):
    """
    OpenconfigIsisAdjacencyStateNlpidEnum (Enum Class)

    Openconfig isis adjacency state nlpid enum

    .. data:: ipv4 = 0

    	IPv4 Address family.

    .. data:: ipv6 = 1

    	IPv6 Address family.

    """

    ipv4 = Enum.YLeaf(0, "ipv4")

    ipv6 = Enum.YLeaf(1, "ipv6")


class OpenconfigIsisLspAdjacencySidStateFlagsEnum(Enum):
    """
    OpenconfigIsisLspAdjacencySidStateFlagsEnum (Enum Class)

    Openconfig isis lsp adjacency sid state flags

    enum

    .. data:: address_family = 0

    	Address-family flag. When unset, the Adj-SID

    	refers to an adjacency with outgoing IPv4

    	encapsulation. If set then the Adj-SID refers

    	to an adjacency with outgoing IPv6

    	encapsulation.

    .. data:: backup = 1

    	Backup flag. When set, the Adj-SID refers to an

    	adjacency being protected (e.g.: using IPFRR or

    	MPLS-FRR).

    .. data:: value = 2

    	Value flag. When set, the SID carries a value

    	(instead of an index). By default the flag is

    	SET.

    .. data:: local = 3

    	Local flag. When set, the value/index carried

    	by the SID has local significance. By default

    	the flag is SET.

    .. data:: set = 4

    	Set flag. When set, the S-Flag indicates that

    	the Adj-SID refers to a set of adjacencies.

    """

    address_family = Enum.YLeaf(0, "address-family")

    backup = Enum.YLeaf(1, "backup")

    value = Enum.YLeaf(2, "value")

    local = Enum.YLeaf(3, "local")

    set = Enum.YLeaf(4, "set")


class OpenconfigIsisLspAlgorithmEnum(Enum):
    """
    OpenconfigIsisLspAlgorithmEnum (Enum Class)

    Openconfig isis lsp algorithm enum

    .. data:: spf = 0

    	Shortest Path First (SPF) algorithm based on

    	link metric.  This is the well-known shortest

    	path algorithm as computed by the IS-IS

    	Decision process.  Consistent with the deployed

    	practice for link- state protocols, algorithm 0

    	permits any node to overwrite the SPF path with

    	a different path based on local policy.

    .. data:: strict_spf = 1

    	Strict Shortest Path First (SPF) algorithm

    	based on link metric. The algorithm is

    	identical to algorithm 0 but algorithm 1

    	requires that all nodes along the path will

    	honor the SPF routing decision. Local policy

    	MUST NOT alter the forwarding decision computed

    	by algorithm 1 at the node claiming to support

    	algorithm 1.

    """

    spf = Enum.YLeaf(0, "spf")

    strict_spf = Enum.YLeaf(1, "strict-spf")


class OpenconfigIsisLspAttributesEnum(Enum):
    """
    OpenconfigIsisLspAttributesEnum (Enum Class)

    Openconfig isis lsp attributes enum

    .. data:: overload = 0

    	When set, node is overloaded, still part of the

    	topology but cannot be used for transit.

    .. data:: attached = 1

    	When set, node is attached to another area

    	using the referred metric and can be used as

    	default gateway.

    """

    overload = Enum.YLeaf(0, "overload")

    attached = Enum.YLeaf(1, "attached")


class OpenconfigIsisLspCryptoTypeEnum(Enum):
    """
    OpenconfigIsisLspCryptoTypeEnum (Enum Class)

    Openconfig isis lsp crypto type enum

    .. data:: hmac_md5 = 0

    	HMAC-MD5 Authentication type.

    .. data:: cleartext = 1

    	Cleartext Authentication type.

    """

    hmac_md5 = Enum.YLeaf(0, "hmac-md5")

    cleartext = Enum.YLeaf(1, "cleartext")


class OpenconfigIsisLspDefaultMetricStateFlagsEnum(Enum):
    """
    OpenconfigIsisLspDefaultMetricStateFlagsEnum (Enum Class)

    Openconfig isis lsp default metric state flags

    enum

    .. data:: internal = 0

    	When set to zero, indicates internal metrics.

    """

    internal = Enum.YLeaf(0, "internal")


class OpenconfigIsisLspFlagsEnum(Enum):
    """
    OpenconfigIsisLspFlagsEnum (Enum Class)

    Openconfig isis lsp flags enum

    .. data:: partition_repair = 0

    	When set, the originator supports partition

    	repair.

    .. data:: attached_error = 1

    	When set, the originator is attached to another

    	area using the referred metric.

    .. data:: attached_expense = 2

    	When set, the originator is attached to another

    	area using the referred metric.

    .. data:: attached_delay = 3

    	When set, the originator is attached to another

    	area using the referred metric.

    .. data:: attached_default = 4

    	When set, the originator is attached to another

    	area using the referred metric.

    .. data:: overload = 5

    	When set, the originator is overloaded, and

    	must be avoided in path calculation.

    """

    partition_repair = Enum.YLeaf(0, "partition-repair")

    attached_error = Enum.YLeaf(1, "attached-error")

    attached_expense = Enum.YLeaf(2, "attached-expense")

    attached_delay = Enum.YLeaf(3, "attached-delay")

    attached_default = Enum.YLeaf(4, "attached-default")

    overload = Enum.YLeaf(5, "overload")


class OpenconfigIsisLspFlagsStateFlagsEnum(Enum):
    """
    OpenconfigIsisLspFlagsStateFlagsEnum (Enum Class)

    Openconfig isis lsp flags state flags enum

    .. data:: external_flag = 0

    	External prefix flag. Set if the prefix has

    	been redistributed from another protocol. This

    	includes the case where multiple virtual

    	routers are supported and the source of the

    	redistributed prefix is another IS-IS instance.

    .. data:: readvertisement_flag = 1

    	Readvertisement flag. Set when the prefix has

    	been leaked from one level to another (upwards

    	or downwards).

    .. data:: node_flag = 2

    	Node flag. Set when the prefix identifies the

    	advertising router, i.e., the prefix is a host

    	prefix advertising  a globally reachable

    	address typically associated with a loopback

    	address.

    """

    external_flag = Enum.YLeaf(0, "external-flag")

    readvertisement_flag = Enum.YLeaf(1, "readvertisement-flag")

    node_flag = Enum.YLeaf(2, "node-flag")


class OpenconfigIsisLspIpv6SrlgStateFlagsEnum(Enum):
    """
    OpenconfigIsisLspIpv6SrlgStateFlagsEnum (Enum Class)

    Openconfig isis lsp ipv6 srlg state flags enum

    .. data:: na = 0

    	When set, the IPv6 neighbour address is

    	included, whereas if unset, it is omitted

    """

    na = Enum.YLeaf(0, "na")


class OpenconfigIsisLspIsisMetricFlagsEnum(Enum):
    """
    OpenconfigIsisLspIsisMetricFlagsEnum (Enum Class)

    Openconfig isis lsp isis metric flags enum

    .. data:: internal = 0

    	When this flag is not set, internal metrics are

    	in use.

    .. data:: unsupported = 1

    	When this flag (referred to as the S-bit) is

    	set, then the metric is unsupported.

    """

    internal = Enum.YLeaf(0, "internal")

    unsupported = Enum.YLeaf(1, "unsupported")


class OpenconfigIsisLspLanAdjacencySidStateFlagsEnum(Enum):
    """
    OpenconfigIsisLspLanAdjacencySidStateFlagsEnum (Enum Class)

    Openconfig isis lsp lan adjacency sid state flags

    enum

    .. data:: address_family = 0

    	Address-family flag. When unset, the Adj-SID

    	refers to an adjacency with outgoing IPv4

    	encapsulation. If set then the Adj-SID refers

    	to an adjacency with outgoing IPv6

    	encapsulation.

    .. data:: backup = 1

    	Backup flag. When set, the Adj-SID refers to an

    	adjacency being protected (e.g.: using IPFRR or

    	MPLS-FRR).

    .. data:: value = 2

    	Value flag. When set, the SID carries a value

    	(instead of an index). By default the flag is

    	SET.

    .. data:: local = 3

    	Local flag. When set, the value/index carried

    	by the SID has local significance. By default

    	the flag is SET.

    .. data:: set = 4

    	Set flag. When set, the S-Flag indicates that

    	the Adj-SID refers to a set of adjacencies.

    """

    address_family = Enum.YLeaf(0, "address-family")

    backup = Enum.YLeaf(1, "backup")

    value = Enum.YLeaf(2, "value")

    local = Enum.YLeaf(3, "local")

    set = Enum.YLeaf(4, "set")


class OpenconfigIsisLspNlpidEnum(Enum):
    """
    OpenconfigIsisLspNlpidEnum (Enum Class)

    Openconfig isis lsp nlpid enum

    .. data:: ipv4 = 0

    	IPv4 Address family.

    .. data:: ipv6 = 1

    	IPv6 Address family.

    """

    ipv4 = Enum.YLeaf(0, "ipv4")

    ipv6 = Enum.YLeaf(1, "ipv6")


class OpenconfigIsisLspPduTypeEnum(Enum):
    """
    OpenconfigIsisLspPduTypeEnum (Enum Class)

    Openconfig isis lsp pdu type enum

    .. data:: level1 = 0

    	This enum describes ISIS level 1 PDU.

    .. data:: level2 = 1

    	This enum describes ISIS level 2 PDU.

    """

    level1 = Enum.YLeaf(0, "level1")

    level2 = Enum.YLeaf(1, "level2")


class OpenconfigIsisLspPrefixSidStateFlagsEnum(Enum):
    """
    OpenconfigIsisLspPrefixSidStateFlagsEnum (Enum Class)

    Openconfig isis lsp prefix sid state flags enum

    .. data:: readvertisement = 0

    	Readvertisment flag. When set, the prefix to

    	which this Prefix-SID is attached, has been

    	propagated by the router either from another

    	level or from redistribution.

    .. data:: node = 1

    	Node flag. When set, the Prefix-SID refers to

    	the router identified by the prefix. Typically,

    	the N-Flag is set on Prefix-SIDs attached to a

    	router loopback address.

    .. data:: php = 2

    	Penultimate-Hop-Popping flag. When set, then

    	the penultimate hop MUST NOT pop the Prefix-SID

    	before delivering the packet to the node that

    	advertised the Prefix-SID.

    .. data:: explicit_null = 3

    	Explicit-Null flag. When set, any upstream

    	neighbor of the Prefix-SID originator MUST

    	replace the Prefix-SID with a Prefix-SID having

    	an Explicit-NULL value (0 for IPv4 and 2 for

    	IPv6) before forwarding the packet.

    .. data:: value = 4

    	Value flag. When set, the Prefix-SID carries a

    	value (instead of an index). By default the

    	flag is UNSET.

    .. data:: local = 5

    	Local flag. When set, the value/index carried

    	by the Prefix-SID has local significance. By

    	default the flag is UNSET.

    """

    readvertisement = Enum.YLeaf(0, "readvertisement")

    node = Enum.YLeaf(1, "node")

    php = Enum.YLeaf(2, "php")

    explicit_null = Enum.YLeaf(3, "explicit-null")

    value = Enum.YLeaf(4, "value")

    local = Enum.YLeaf(5, "local")


class OpenconfigIsisLspRouterCapabilityStateFlagsEnum(Enum):
    """
    OpenconfigIsisLspRouterCapabilityStateFlagsEnum (Enum Class)

    Openconfig isis lsp router capability state flags

    enum

    .. data:: flood = 0

    	When the S bit is set(1), the IS - IS Router

    	CAPABILITY TLV MUST be flooded across the

    	entire routing domain. When the S bit is not

    	set(0), the TLV MUST NOT be leaked between

    	levels . This bit MUST NOT be altered during

    	the TLV leaking.

    .. data:: down = 1

    	When the IS-IS Router CAPABILITY TLV is leaked

    	from level - 2 to level-1, the Down bit MUST be

    	set. Otherwise, this bit MUST be clear. IS - IS

    	Router capability TLVs with the Down bit set

    	MUST NOT be leaked from level - 1 to level-2.

    	This is to prevent TLV looping.

    """

    flood = Enum.YLeaf(0, "flood")

    down = Enum.YLeaf(1, "down")


class OpenconfigIsisLspSegmentRoutingCapabilityStateFlagsEnum(Enum):
    """
    OpenconfigIsisLspSegmentRoutingCapabilityStateFlagsEnum (Enum Class)

    Openconfig isis lsp segment routing capability

    state flags enum

    .. data:: ipv4_mpls = 0

    	When set, the router is capable of processing

    	SR MPLS encapsulated IPv4 packets on all

    	interfaces.

    .. data:: ipv6_mpls = 1

    	When set, the router is capable of processing

    	SR MPLS encapsulated IPv6 packets on all

    	interfaces.

    .. data:: ipv6_sr = 2

    	When set, the router is capable of processing

    	the IPv6 Segment Routing Header on all

    	interfaces.

    """

    ipv4_mpls = Enum.YLeaf(0, "ipv4-mpls")

    ipv6_mpls = Enum.YLeaf(1, "ipv6-mpls")

    ipv6_sr = Enum.YLeaf(2, "ipv6-sr")


class OpenconfigIsisLspStateFlagsEnum(Enum):
    """
    OpenconfigIsisLspStateFlagsEnum (Enum Class)

    Openconfig isis lsp state flags enum

    .. data:: numbered = 0

    	When set, the interface is numbered, whereas if

    	unset indicates that the interface is

    	unnumbered.

    """

    numbered = Enum.YLeaf(0, "numbered")


class OpenconfigIsisTypesAdaptiveTimerTypeEnum(Enum):
    """
    OpenconfigIsisTypesAdaptiveTimerTypeEnum (Enum Class)

    Openconfig isis types adaptive timer type enum

    .. data:: linear = 0

    	This enum describes linear algorithm timer

    .. data:: exponential = 1

    	This enum describes exponential algorithm timer

    """

    linear = Enum.YLeaf(0, "linear")

    exponential = Enum.YLeaf(1, "exponential")


class OpenconfigIsisTypesCircuitTypeEnum(Enum):
    """
    OpenconfigIsisTypesCircuitTypeEnum (Enum Class)

    Openconfig isis types circuit type enum

    .. data:: point_to_point = 0

    	This enum describes a point-to-point interface

    .. data:: broadcast = 1

    	This enum describes a broadcast interface

    """

    point_to_point = Enum.YLeaf(0, "point-to-point")

    broadcast = Enum.YLeaf(1, "broadcast")


class OpenconfigIsisTypesHelloPaddingTypeEnum(Enum):
    """
    OpenconfigIsisTypesHelloPaddingTypeEnum (Enum Class)

    Openconfig isis types hello padding type enum

    .. data:: strict = 0

    	This enum describes strict padding

    .. data:: loose = 1

    	This enum describes loose padding

    .. data:: adaptive = 2

    	This enum describes adaptive padding

    .. data:: disable = 3

    	This enum disables padding

    """

    strict = Enum.YLeaf(0, "strict")

    loose = Enum.YLeaf(1, "loose")

    adaptive = Enum.YLeaf(2, "adaptive")

    disable = Enum.YLeaf(3, "disable")


class OpenconfigIsisTypesIsisInterfaceAdjStateEnum(Enum):
    """
    OpenconfigIsisTypesIsisInterfaceAdjStateEnum (Enum Class)

    Openconfig isis types isis interface adj state

    enum

    .. data:: up = 0

    	This state describes that adjacency is

    	established.

    .. data:: down = 1

    	This state describes that adjacency is NOT

    	established.

    .. data:: init = 2

    	This state describes that adjacency is

    	establishing.

    .. data:: failed = 3

    	This state describes that adjacency is failed.

    """

    up = Enum.YLeaf(0, "up")

    down = Enum.YLeaf(1, "down")

    init = Enum.YLeaf(2, "init")

    failed = Enum.YLeaf(3, "failed")


class OpenconfigIsisTypesLevelTypeEnum(Enum):
    """
    OpenconfigIsisTypesLevelTypeEnum (Enum Class)

    Openconfig isis types level type enum

    .. data:: level1 = 0

    	This enum describes ISIS level 1

    .. data:: level2 = 1

    	This enum describes ISIS level 2

    .. data:: level12 = 2

    	This enum describes ISIS level 1-2

    """

    level1 = Enum.YLeaf(0, "level1")

    level2 = Enum.YLeaf(1, "level2")

    level12 = Enum.YLeaf(2, "level12")


class OpenconfigIsisTypesMetricStyleEnum(Enum):
    """
    OpenconfigIsisTypesMetricStyleEnum (Enum Class)

    Openconfig isis types metric style enum

    .. data:: narrow_metric = 0

    	This enum describes narrow metric style

    .. data:: wide_metric = 1

    	This enum describes wide metric style

    """

    narrow_metric = Enum.YLeaf(0, "narrow-metric")

    wide_metric = Enum.YLeaf(1, "wide-metric")


class OpenconfigSegmentRoutingLabelOptionsEnum(Enum):
    """
    OpenconfigSegmentRoutingLabelOptionsEnum (Enum Class)

    Openconfig segment routing label options enum

    .. data:: no_php = 0

    	When this value is specified, the penultimate

    	hop must not pop the Prefix-SID label before

    	forwarding it to the local system.

    .. data:: explicit_null = 1

    	When set, the penultimate hop must swap the

    	prefix SID for the relevant explicit null label

    	before forwarding the packet.

    """

    no_php = Enum.YLeaf(0, "no-php")

    explicit_null = Enum.YLeaf(1, "explicit-null")


class SrmsMiAfEB(Enum):
    """
    SrmsMiAfEB (Enum Class)

    Srms mi af e b

    .. data:: none = 0

    	None

    .. data:: ipv4 = 1

    	IPv4

    .. data:: ipv6 = 2

    	IPv6

    """

    none = Enum.YLeaf(0, "none")

    ipv4 = Enum.YLeaf(1, "ipv4")

    ipv6 = Enum.YLeaf(2, "ipv6")


class SrmsMiFlagEB(Enum):
    """
    SrmsMiFlagEB (Enum Class)

    Srms mi flag e b

    .. data:: false = 0

    	False

    .. data:: true = 1

    	True

    """

    false = Enum.YLeaf(0, "false")

    true = Enum.YLeaf(1, "true")


class SrmsMiSrcEB(Enum):
    """
    SrmsMiSrcEB (Enum Class)

    Srms mi src e b

    .. data:: none = 0

    	None

    .. data:: local = 1

    	Local

    .. data:: remote = 2

    	Remote

    """

    none = Enum.YLeaf(0, "none")

    local = Enum.YLeaf(1, "local")

    remote = Enum.YLeaf(2, "remote")


class Srv6EndFunction(Enum):
    """
    Srv6EndFunction (Enum Class)

    SRv6 End Function Type

    .. data:: unknown = 0

    	Unknown

    .. data:: end = 1

    	End (no PSP/USP)

    .. data:: end_with_psp = 2

    	End with PSP

    .. data:: end_with_usp = 3

    	End with USP

    .. data:: end_with_psp_usp = 4

    	End with PSP/USP

    .. data:: end_x = 5

    	End.X (no PSP/USP)

    .. data:: end_x_with_psp = 6

    	End.X with PSP

    .. data:: end_x_with_usp = 7

    	End.X with USP

    .. data:: end_x_with_psp_usp = 8

    	End.X with PSP/USP

    .. data:: end_tn = 9

    	End.T (no PSP/USP)

    .. data:: end_t_with_psp = 10

    	End.T with PSP

    .. data:: end_t_with_usp = 11

    	End.T with USP

    .. data:: end_t_with_psp_usp = 12

    	End.T with PSP/USP

    .. data:: end_b6 = 13

    	End.B6

    .. data:: end_b6_encaps = 14

    	End.B6.Encaps

    .. data:: end_bm = 15

    	End.BM

    .. data:: end_dx6 = 16

    	End.DX6

    .. data:: end_dx4 = 17

    	End.DX4

    .. data:: end_dt6 = 18

    	End.DT6

    .. data:: end_dt4 = 19

    	End.DT4

    .. data:: end_dt46 = 20

    	End.DT46

    .. data:: end_dx2 = 21

    	End.DX2

    .. data:: end_dx2v = 22

    	End.DX2V

    .. data:: end_dx2u = 23

    	End.DX2U

    .. data:: end_dx2m = 24

    	End.DX2M

    .. data:: end_otp = 25

    	End.OTP

    .. data:: end_s = 26

    	End.S

    """

    unknown = Enum.YLeaf(0, "unknown")

    end = Enum.YLeaf(1, "end")

    end_with_psp = Enum.YLeaf(2, "end-with-psp")

    end_with_usp = Enum.YLeaf(3, "end-with-usp")

    end_with_psp_usp = Enum.YLeaf(4, "end-with-psp-usp")

    end_x = Enum.YLeaf(5, "end-x")

    end_x_with_psp = Enum.YLeaf(6, "end-x-with-psp")

    end_x_with_usp = Enum.YLeaf(7, "end-x-with-usp")

    end_x_with_psp_usp = Enum.YLeaf(8, "end-x-with-psp-usp")

    end_tn = Enum.YLeaf(9, "end-tn")

    end_t_with_psp = Enum.YLeaf(10, "end-t-with-psp")

    end_t_with_usp = Enum.YLeaf(11, "end-t-with-usp")

    end_t_with_psp_usp = Enum.YLeaf(12, "end-t-with-psp-usp")

    end_b6 = Enum.YLeaf(13, "end-b6")

    end_b6_encaps = Enum.YLeaf(14, "end-b6-encaps")

    end_bm = Enum.YLeaf(15, "end-bm")

    end_dx6 = Enum.YLeaf(16, "end-dx6")

    end_dx4 = Enum.YLeaf(17, "end-dx4")

    end_dt6 = Enum.YLeaf(18, "end-dt6")

    end_dt4 = Enum.YLeaf(19, "end-dt4")

    end_dt46 = Enum.YLeaf(20, "end-dt46")

    end_dx2 = Enum.YLeaf(21, "end-dx2")

    end_dx2v = Enum.YLeaf(22, "end-dx2v")

    end_dx2u = Enum.YLeaf(23, "end-dx2u")

    end_dx2m = Enum.YLeaf(24, "end-dx2m")

    end_otp = Enum.YLeaf(25, "end-otp")

    end_s = Enum.YLeaf(26, "end-s")



class OcniIsis(Entity):
    """
    An OpenConfig description of a network\-instance
    
    .. attribute:: network_instances
    
    	Network instances configured on the local system
    	**type**\:  :py:class:`NetworkInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances>`
    
    

    """

    _prefix = 'clns-isis-oper'
    _revision = '2018-04-07'

    def __init__(self):
        super(OcniIsis, self).__init__()
        self._top_entity = None

        self.yang_name = "ocni-isis"
        self.yang_parent_name = "Cisco-IOS-XR-clns-isis-oper"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self.ylist_key_names = []
        self._child_classes = OrderedDict([("network-instances", ("network_instances", OcniIsis.NetworkInstances))])
        self._leafs = OrderedDict()

        self.network_instances = OcniIsis.NetworkInstances()
        self.network_instances.parent = self
        self._children_name_map["network_instances"] = "network-instances"
        self._segment_path = lambda: "Cisco-IOS-XR-clns-isis-oper:ocni-isis"
        self._is_frozen = True

    def __setattr__(self, name, value):
        self._perform_setattr(OcniIsis, [], name, value)


    class NetworkInstances(Entity):
        """
        Network instances configured on the local system
        
        .. attribute:: network_instance
        
        	Network instances configured on the local system
        	**type**\: list of  		 :py:class:`NetworkInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance>`
        
        

        """

        _prefix = 'clns-isis-oper'
        _revision = '2018-04-07'

        def __init__(self):
            super(OcniIsis.NetworkInstances, self).__init__()

            self.yang_name = "network-instances"
            self.yang_parent_name = "ocni-isis"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("network-instance", ("network_instance", OcniIsis.NetworkInstances.NetworkInstance))])
            self._leafs = OrderedDict()

            self.network_instance = YList(self)
            self._segment_path = lambda: "network-instances"
            self._absolute_path = lambda: "Cisco-IOS-XR-clns-isis-oper:ocni-isis/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(OcniIsis.NetworkInstances, [], name, value)


        class NetworkInstance(Entity):
            """
            Network instances configured on the local
            system
            
            .. attribute:: name  (key)
            
            	A unique name identifying the network instance
            	**type**\: str
            
            .. attribute:: interfaces
            
            	An interface associated with the network instance
            	**type**\:  :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Interfaces>`
            
            .. attribute:: protocols
            
            	A process (instance) of a routing protocol
            	**type**\:  :py:class:`Protocols <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols>`
            
            .. attribute:: state
            
            	Operational state parameters relating to a network instance
            	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.State>`
            
            

            """

            _prefix = 'clns-isis-oper'
            _revision = '2018-04-07'

            def __init__(self):
                super(OcniIsis.NetworkInstances.NetworkInstance, self).__init__()

                self.yang_name = "network-instance"
                self.yang_parent_name = "network-instances"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("interfaces", ("interfaces", OcniIsis.NetworkInstances.NetworkInstance.Interfaces)), ("protocols", ("protocols", OcniIsis.NetworkInstances.NetworkInstance.Protocols)), ("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.State))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                ])
                self.name = None

                self.interfaces = OcniIsis.NetworkInstances.NetworkInstance.Interfaces()
                self.interfaces.parent = self
                self._children_name_map["interfaces"] = "interfaces"

                self.protocols = OcniIsis.NetworkInstances.NetworkInstance.Protocols()
                self.protocols.parent = self
                self._children_name_map["protocols"] = "protocols"

                self.state = OcniIsis.NetworkInstances.NetworkInstance.State()
                self.state.parent = self
                self._children_name_map["state"] = "state"
                self._segment_path = lambda: "network-instance" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-clns-isis-oper:ocni-isis/network-instances/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance, ['name'], name, value)


            class Interfaces(Entity):
                """
                An interface associated with the network
                instance
                
                .. attribute:: interface
                
                	An interface associated with the network instance
                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Interfaces.Interface>`
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2018-04-07'

                def __init__(self):
                    super(OcniIsis.NetworkInstances.NetworkInstance.Interfaces, self).__init__()

                    self.yang_name = "interfaces"
                    self.yang_parent_name = "network-instance"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("interface", ("interface", OcniIsis.NetworkInstances.NetworkInstance.Interfaces.Interface))])
                    self._leafs = OrderedDict()

                    self.interface = YList(self)
                    self._segment_path = lambda: "interfaces"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Interfaces, [], name, value)


                class Interface(Entity):
                    """
                    An interface associated with the network
                    instance
                    
                    .. attribute:: id  (key)
                    
                    	A reference to an identifier for this interface which acts as a key for this list
                    	**type**\: str
                    
                    .. attribute:: state
                    
                    	Operational state parameters relating to the associated interface
                    	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Interfaces.Interface.State>`
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2018-04-07'

                    def __init__(self):
                        super(OcniIsis.NetworkInstances.NetworkInstance.Interfaces.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "interfaces"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['id']
                        self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Interfaces.Interface.State))])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                        ])
                        self.id = None

                        self.state = OcniIsis.NetworkInstances.NetworkInstance.Interfaces.Interface.State()
                        self.state.parent = self
                        self._children_name_map["state"] = "state"
                        self._segment_path = lambda: "interface" + "[id='" + str(self.id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Interfaces.Interface, ['id'], name, value)


                    class State(Entity):
                        """
                        Operational state parameters relating to the
                        associated interface
                        
                        .. attribute:: id
                        
                        	A unique identifier for this interface \- this is expressed as a free\-text string
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(OcniIsis.NetworkInstances.NetworkInstance.Interfaces.Interface.State, self).__init__()

                            self.yang_name = "state"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('id', (YLeaf(YType.str, 'id'), ['str'])),
                            ])
                            self.id = None
                            self._segment_path = lambda: "state"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Interfaces.Interface.State, [u'id'], name, value)


            class Protocols(Entity):
                """
                A process (instance) of a routing protocol
                
                .. attribute:: protocol
                
                	A process (instance) of a routing protocol
                	**type**\: list of  		 :py:class:`Protocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol>`
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2018-04-07'

                def __init__(self):
                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols, self).__init__()

                    self.yang_name = "protocols"
                    self.yang_parent_name = "network-instance"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("protocol", ("protocol", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol))])
                    self._leafs = OrderedDict()

                    self.protocol = YList(self)
                    self._segment_path = lambda: "protocols"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols, [], name, value)


                class Protocol(Entity):
                    """
                    A process (instance) of a routing protocol
                    
                    .. attribute:: protocols_state
                    
                    	State parameters relating to the routing protocol instance
                    	**type**\:  :py:class:`ProtocolsState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.ProtocolsState>`
                    
                    .. attribute:: isis
                    
                    	This container defines top\-level ISIS configuration and state information
                    	**type**\:  :py:class:`Isis <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis>`
                    
                    .. attribute:: identifier
                    
                    	The protocol name for the routing or forwarding protocol to be instantiated
                    	**type**\: str
                    
                    .. attribute:: name
                    
                    	An operator\-assigned identifier for the routing or forwarding protocol
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2018-04-07'

                    def __init__(self):
                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol, self).__init__()

                        self.yang_name = "protocol"
                        self.yang_parent_name = "protocols"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("protocols-state", ("protocols_state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.ProtocolsState)), ("isis", ("isis", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis))])
                        self._leafs = OrderedDict([
                            ('identifier', (YLeaf(YType.str, 'identifier'), ['str'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ])
                        self.identifier = None
                        self.name = None

                        self.protocols_state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.ProtocolsState()
                        self.protocols_state.parent = self
                        self._children_name_map["protocols_state"] = "protocols-state"

                        self.isis = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis()
                        self.isis.parent = self
                        self._children_name_map["isis"] = "isis"
                        self._segment_path = lambda: "protocol"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol, ['identifier', 'name'], name, value)


                    class ProtocolsState(Entity):
                        """
                        State parameters relating to the routing
                        protocol instance
                        
                        .. attribute:: identifier
                        
                        	The protocol identifier for the instance
                        	**type**\: str
                        
                        .. attribute:: name
                        
                        	A unique name for the protocol instance
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.ProtocolsState, self).__init__()

                            self.yang_name = "protocols-state"
                            self.yang_parent_name = "protocol"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('identifier', (YLeaf(YType.str, 'identifier'), ['str'])),
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.identifier = None
                            self.name = None
                            self._segment_path = lambda: "protocols-state"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.ProtocolsState, [u'identifier', u'name'], name, value)


                    class Isis(Entity):
                        """
                        This container defines top\-level ISIS
                        configuration and state information
                        
                        .. attribute:: isis_interfaces
                        
                        	This list contains ISIS interfaces
                        	**type**\:  :py:class:`IsisInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces>`
                        
                        .. attribute:: global_
                        
                        	This container defines global ISIS configuration and state information
                        	**type**\:  :py:class:`Global <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global>`
                        
                        .. attribute:: levels
                        
                        	Configuration and operational state parameters related to a particular level within the IS\-IS protocol instance
                        	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis, self).__init__()

                            self.yang_name = "isis"
                            self.yang_parent_name = "protocol"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("isis-interfaces", ("isis_interfaces", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces)), ("global", ("global_", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global)), ("levels", ("levels", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels))])
                            self._leafs = OrderedDict()

                            self.isis_interfaces = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces()
                            self.isis_interfaces.parent = self
                            self._children_name_map["isis_interfaces"] = "isis-interfaces"

                            self.global_ = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global()
                            self.global_.parent = self
                            self._children_name_map["global_"] = "global"

                            self.levels = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels()
                            self.levels.parent = self
                            self._children_name_map["levels"] = "levels"
                            self._segment_path = lambda: "isis"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis, [], name, value)


                        class IsisInterfaces(Entity):
                            """
                            This list contains ISIS interfaces
                            
                            .. attribute:: isis_interface
                            
                            	This list contains ISIS interfaces
                            	**type**\: list of  		 :py:class:`IsisInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces, self).__init__()

                                self.yang_name = "isis-interfaces"
                                self.yang_parent_name = "isis"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("isis-interface", ("isis_interface", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface))])
                                self._leafs = OrderedDict()

                                self.isis_interface = YList(self)
                                self._segment_path = lambda: "isis-interfaces"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces, [], name, value)


                            class IsisInterface(Entity):
                                """
                                This list contains ISIS interfaces
                                
                                .. attribute:: interface_id  (key)
                                
                                	Reference to interface\-id
                                	**type**\: str
                                
                                .. attribute:: interfaces_afi_safis
                                
                                	Address\-family/Subsequent Address\-family list
                                	**type**\:  :py:class:`InterfacesAfiSafis <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesAfiSafis>`
                                
                                .. attribute:: interfaces_state
                                
                                	This container defines state information for ISIS interfaces
                                	**type**\:  :py:class:`InterfacesState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesState>`
                                
                                .. attribute:: interfaces_levels
                                
                                	Configuration and operational state parameters related to a particular level on an IS\-IS enabled interface
                                	**type**\:  :py:class:`InterfacesLevels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels>`
                                
                                .. attribute:: circuit_counters
                                
                                	This container defines state information for ISIS circuit counters
                                	**type**\:  :py:class:`CircuitCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.CircuitCounters>`
                                
                                .. attribute:: interfaces_authentication
                                
                                	This container defines ISIS authentication
                                	**type**\:  :py:class:`InterfacesAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesAuthentication>`
                                
                                .. attribute:: interfaces_timers
                                
                                	This container describes ISIS interface timers configuration
                                	**type**\:  :py:class:`InterfacesTimers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesTimers>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface, self).__init__()

                                    self.yang_name = "isis-interface"
                                    self.yang_parent_name = "isis-interfaces"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['interface_id']
                                    self._child_classes = OrderedDict([("interfaces-afi-safis", ("interfaces_afi_safis", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesAfiSafis)), ("interfaces-state", ("interfaces_state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesState)), ("interfaces-levels", ("interfaces_levels", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels)), ("circuit-counters", ("circuit_counters", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.CircuitCounters)), ("interfaces-authentication", ("interfaces_authentication", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesAuthentication)), ("interfaces-timers", ("interfaces_timers", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesTimers))])
                                    self._leafs = OrderedDict([
                                        ('interface_id', (YLeaf(YType.str, 'interface-id'), ['str'])),
                                    ])
                                    self.interface_id = None

                                    self.interfaces_afi_safis = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesAfiSafis()
                                    self.interfaces_afi_safis.parent = self
                                    self._children_name_map["interfaces_afi_safis"] = "interfaces-afi-safis"

                                    self.interfaces_state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesState()
                                    self.interfaces_state.parent = self
                                    self._children_name_map["interfaces_state"] = "interfaces-state"

                                    self.interfaces_levels = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels()
                                    self.interfaces_levels.parent = self
                                    self._children_name_map["interfaces_levels"] = "interfaces-levels"

                                    self.circuit_counters = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.CircuitCounters()
                                    self.circuit_counters.parent = self
                                    self._children_name_map["circuit_counters"] = "circuit-counters"

                                    self.interfaces_authentication = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesAuthentication()
                                    self.interfaces_authentication.parent = self
                                    self._children_name_map["interfaces_authentication"] = "interfaces-authentication"

                                    self.interfaces_timers = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesTimers()
                                    self.interfaces_timers.parent = self
                                    self._children_name_map["interfaces_timers"] = "interfaces-timers"
                                    self._segment_path = lambda: "isis-interface" + "[interface-id='" + str(self.interface_id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface, ['interface_id'], name, value)


                                class InterfacesAfiSafis(Entity):
                                    """
                                    Address\-family/Subsequent Address\-family
                                    list
                                    
                                    .. attribute:: interfaces_afi_safi
                                    
                                    	Address\-family/Subsequent Address\-family list
                                    	**type**\: list of  		 :py:class:`InterfacesAfiSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesAfiSafis.InterfacesAfiSafi>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesAfiSafis, self).__init__()

                                        self.yang_name = "interfaces-afi-safis"
                                        self.yang_parent_name = "isis-interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interfaces-afi-safi", ("interfaces_afi_safi", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesAfiSafis.InterfacesAfiSafi))])
                                        self._leafs = OrderedDict()

                                        self.interfaces_afi_safi = YList(self)
                                        self._segment_path = lambda: "interfaces-afi-safis"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesAfiSafis, [], name, value)


                                    class InterfacesAfiSafi(Entity):
                                        """
                                        Address\-family/Subsequent Address\-family
                                        list
                                        
                                        .. attribute:: afi_name
                                        
                                        	Reference to address\-family type
                                        	**type**\: str
                                        
                                        .. attribute:: safi_name
                                        
                                        	Reference to subsequent address\-family type
                                        	**type**\: str
                                        
                                        .. attribute:: state
                                        
                                        	This container defines AFI\-SAFI State information
                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesAfiSafis.InterfacesAfiSafi.State>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesAfiSafis.InterfacesAfiSafi, self).__init__()

                                            self.yang_name = "interfaces-afi-safi"
                                            self.yang_parent_name = "interfaces-afi-safis"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesAfiSafis.InterfacesAfiSafi.State))])
                                            self._leafs = OrderedDict([
                                                ('afi_name', (YLeaf(YType.str, 'afi-name'), ['str'])),
                                                ('safi_name', (YLeaf(YType.str, 'safi-name'), ['str'])),
                                            ])
                                            self.afi_name = None
                                            self.safi_name = None

                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesAfiSafis.InterfacesAfiSafi.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._segment_path = lambda: "interfaces-afi-safi"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesAfiSafis.InterfacesAfiSafi, ['afi_name', 'safi_name'], name, value)


                                        class State(Entity):
                                            """
                                            This container defines AFI\-SAFI State
                                            information
                                            
                                            .. attribute:: afi_name
                                            
                                            	Address\-family type
                                            	**type**\: str
                                            
                                            .. attribute:: safi_name
                                            
                                            	Subsequent address\-family type
                                            	**type**\: str
                                            
                                            .. attribute:: enabled
                                            
                                            	When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesAfiSafis.InterfacesAfiSafi.State, self).__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "interfaces-afi-safi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi_name', (YLeaf(YType.str, 'afi-name'), ['str'])),
                                                    ('safi_name', (YLeaf(YType.str, 'safi-name'), ['str'])),
                                                    ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                                ])
                                                self.afi_name = None
                                                self.safi_name = None
                                                self.enabled = None
                                                self._segment_path = lambda: "state"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesAfiSafis.InterfacesAfiSafi.State, [u'afi_name', u'safi_name', u'enabled'], name, value)


                                class InterfacesState(Entity):
                                    """
                                    This container defines state information
                                    for ISIS interfaces
                                    
                                    .. attribute:: enabled
                                    
                                    	When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: interface_id
                                    
                                    	Interface for which ISIS configuration is to be applied
                                    	**type**\: str
                                    
                                    .. attribute:: passive
                                    
                                    	When set to true, the referenced interface is a passive interface such that it is not eligible to establish adjacencies with other systems, but is advertised into the IS\-IS topology
                                    	**type**\: bool
                                    
                                    .. attribute:: hello_padding
                                    
                                    	This leaf controls padding type for IS\-IS Hello PDUs
                                    	**type**\:  :py:class:`OpenconfigIsisTypesHelloPaddingTypeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisTypesHelloPaddingTypeEnum>`
                                    
                                    .. attribute:: circuit_type
                                    
                                    	ISIS circuit type (p2p, broadcast)
                                    	**type**\:  :py:class:`OpenconfigIsisTypesCircuitTypeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisTypesCircuitTypeEnum>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesState, self).__init__()

                                        self.yang_name = "interfaces-state"
                                        self.yang_parent_name = "isis-interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                            ('interface_id', (YLeaf(YType.str, 'interface-id'), ['str'])),
                                            ('passive', (YLeaf(YType.boolean, 'passive'), ['bool'])),
                                            ('hello_padding', (YLeaf(YType.enumeration, 'hello-padding'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisTypesHelloPaddingTypeEnum', '')])),
                                            ('circuit_type', (YLeaf(YType.enumeration, 'circuit-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisTypesCircuitTypeEnum', '')])),
                                        ])
                                        self.enabled = None
                                        self.interface_id = None
                                        self.passive = None
                                        self.hello_padding = None
                                        self.circuit_type = None
                                        self._segment_path = lambda: "interfaces-state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesState, [u'enabled', u'interface_id', u'passive', u'hello_padding', u'circuit_type'], name, value)


                                class InterfacesLevels(Entity):
                                    """
                                    Configuration and operational state
                                    parameters related to a particular level
                                    on an IS\-IS enabled interface
                                    
                                    .. attribute:: interfaces_level
                                    
                                    	Configuration and operational state parameters related to a particular level on an IS\-IS enabled interface
                                    	**type**\: list of  		 :py:class:`InterfacesLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels, self).__init__()

                                        self.yang_name = "interfaces-levels"
                                        self.yang_parent_name = "isis-interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interfaces-level", ("interfaces_level", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel))])
                                        self._leafs = OrderedDict()

                                        self.interfaces_level = YList(self)
                                        self._segment_path = lambda: "interfaces-levels"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels, [], name, value)


                                    class InterfacesLevel(Entity):
                                        """
                                        Configuration and operational state
                                        parameters related to a particular level
                                        on an IS\-IS enabled interface
                                        
                                        .. attribute:: level_number  (key)
                                        
                                        	Reference to ISIS level\-number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: hello_authentication
                                        
                                        	This container defines ISIS authentication
                                        	**type**\:  :py:class:`HelloAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.HelloAuthentication>`
                                        
                                        .. attribute:: interfaces_levels_state
                                        
                                        	This container defines interface ISIS level state information
                                        	**type**\:  :py:class:`InterfacesLevelsState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.InterfacesLevelsState>`
                                        
                                        .. attribute:: packet_counters
                                        
                                        	This container defines ISIS interface packet counters
                                        	**type**\:  :py:class:`PacketCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters>`
                                        
                                        .. attribute:: adjacencies
                                        
                                        	List of the local system's IS\-IS adjacencies
                                        	**type**\:  :py:class:`Adjacencies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.Adjacencies>`
                                        
                                        .. attribute:: levels_timers
                                        
                                        	This container defines ISIS timers
                                        	**type**\:  :py:class:`LevelsTimers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsTimers>`
                                        
                                        .. attribute:: levels_afi_safis
                                        
                                        	Address\-family/Subsequent Address\-family list
                                        	**type**\:  :py:class:`LevelsAfiSafis <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsAfiSafis>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel, self).__init__()

                                            self.yang_name = "interfaces-level"
                                            self.yang_parent_name = "interfaces-levels"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['level_number']
                                            self._child_classes = OrderedDict([("hello-authentication", ("hello_authentication", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.HelloAuthentication)), ("interfaces-levels-state", ("interfaces_levels_state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.InterfacesLevelsState)), ("packet-counters", ("packet_counters", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters)), ("adjacencies", ("adjacencies", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.Adjacencies)), ("levels-timers", ("levels_timers", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsTimers)), ("levels-afi-safis", ("levels_afi_safis", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsAfiSafis))])
                                            self._leafs = OrderedDict([
                                                ('level_number', (YLeaf(YType.uint32, 'level-number'), ['int'])),
                                            ])
                                            self.level_number = None

                                            self.hello_authentication = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.HelloAuthentication()
                                            self.hello_authentication.parent = self
                                            self._children_name_map["hello_authentication"] = "hello-authentication"

                                            self.interfaces_levels_state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.InterfacesLevelsState()
                                            self.interfaces_levels_state.parent = self
                                            self._children_name_map["interfaces_levels_state"] = "interfaces-levels-state"

                                            self.packet_counters = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters()
                                            self.packet_counters.parent = self
                                            self._children_name_map["packet_counters"] = "packet-counters"

                                            self.adjacencies = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.Adjacencies()
                                            self.adjacencies.parent = self
                                            self._children_name_map["adjacencies"] = "adjacencies"

                                            self.levels_timers = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsTimers()
                                            self.levels_timers.parent = self
                                            self._children_name_map["levels_timers"] = "levels-timers"

                                            self.levels_afi_safis = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsAfiSafis()
                                            self.levels_afi_safis.parent = self
                                            self._children_name_map["levels_afi_safis"] = "levels-afi-safis"
                                            self._segment_path = lambda: "interfaces-level" + "[level-number='" + str(self.level_number) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel, ['level_number'], name, value)


                                        class HelloAuthentication(Entity):
                                            """
                                            This container defines ISIS
                                            authentication
                                            
                                            .. attribute:: key
                                            
                                            	This container defines ISIS authentication key
                                            	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.HelloAuthentication.Key>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.HelloAuthentication, self).__init__()

                                                self.yang_name = "hello-authentication"
                                                self.yang_parent_name = "interfaces-level"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("key", ("key", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.HelloAuthentication.Key))])
                                                self._leafs = OrderedDict()

                                                self.key = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.HelloAuthentication.Key()
                                                self.key.parent = self
                                                self._children_name_map["key"] = "key"
                                                self._segment_path = lambda: "hello-authentication"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.HelloAuthentication, [], name, value)


                                            class Key(Entity):
                                                """
                                                This container defines ISIS authentication key
                                                
                                                .. attribute:: state
                                                
                                                	This container defines ISIS authentication key state
                                                	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.HelloAuthentication.Key.State>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.HelloAuthentication.Key, self).__init__()

                                                    self.yang_name = "key"
                                                    self.yang_parent_name = "hello-authentication"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.HelloAuthentication.Key.State))])
                                                    self._leafs = OrderedDict()

                                                    self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.HelloAuthentication.Key.State()
                                                    self.state.parent = self
                                                    self._children_name_map["state"] = "state"
                                                    self._segment_path = lambda: "key"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.HelloAuthentication.Key, [], name, value)


                                                class State(Entity):
                                                    """
                                                    This container defines ISIS authentication key
                                                    state
                                                    
                                                    .. attribute:: auth_password
                                                    
                                                    	Authentication key string
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.HelloAuthentication.Key.State, self).__init__()

                                                        self.yang_name = "state"
                                                        self.yang_parent_name = "key"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('auth_password', (YLeaf(YType.str, 'auth-password'), ['str'])),
                                                        ])
                                                        self.auth_password = None
                                                        self._segment_path = lambda: "state"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.HelloAuthentication.Key.State, [u'auth_password'], name, value)


                                        class InterfacesLevelsState(Entity):
                                            """
                                            This container defines interface ISIS
                                            level state information
                                            
                                            .. attribute:: level_number
                                            
                                            	ISIS level number(level\-1, level\-2)
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	ISIS neighbor priority(LAN hello PDU only)
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.InterfacesLevelsState, self).__init__()

                                                self.yang_name = "interfaces-levels-state"
                                                self.yang_parent_name = "interfaces-level"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('level_number', (YLeaf(YType.uint8, 'level-number'), ['int'])),
                                                    ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                ])
                                                self.level_number = None
                                                self.priority = None
                                                self._segment_path = lambda: "interfaces-levels-state"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.InterfacesLevelsState, [u'level_number', u'priority'], name, value)


                                        class PacketCounters(Entity):
                                            """
                                            This container defines ISIS interface
                                            packet counters
                                            
                                            .. attribute:: lsp
                                            
                                            	This container defines LSP packet counters
                                            	**type**\:  :py:class:`Lsp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Lsp>`
                                            
                                            .. attribute:: iih
                                            
                                            	This container defines IIH packet counters
                                            	**type**\:  :py:class:`Iih <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Iih>`
                                            
                                            .. attribute:: psnp
                                            
                                            	This container defines PSNP packet counters
                                            	**type**\:  :py:class:`Psnp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Psnp>`
                                            
                                            .. attribute:: cnsp
                                            
                                            	Operational state parameters relating to CNSPs
                                            	**type**\:  :py:class:`Cnsp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Cnsp>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters, self).__init__()

                                                self.yang_name = "packet-counters"
                                                self.yang_parent_name = "interfaces-level"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("lsp", ("lsp", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Lsp)), ("iih", ("iih", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Iih)), ("psnp", ("psnp", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Psnp)), ("cnsp", ("cnsp", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Cnsp))])
                                                self._leafs = OrderedDict()

                                                self.lsp = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Lsp()
                                                self.lsp.parent = self
                                                self._children_name_map["lsp"] = "lsp"

                                                self.iih = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Iih()
                                                self.iih.parent = self
                                                self._children_name_map["iih"] = "iih"

                                                self.psnp = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Psnp()
                                                self.psnp.parent = self
                                                self._children_name_map["psnp"] = "psnp"

                                                self.cnsp = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Cnsp()
                                                self.cnsp.parent = self
                                                self._children_name_map["cnsp"] = "cnsp"
                                                self._segment_path = lambda: "packet-counters"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters, [], name, value)


                                            class Lsp(Entity):
                                                """
                                                This container defines LSP packet counters
                                                
                                                .. attribute:: state
                                                
                                                	This container defines LSP PDU counters
                                                	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Lsp.State>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Lsp, self).__init__()

                                                    self.yang_name = "lsp"
                                                    self.yang_parent_name = "packet-counters"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Lsp.State))])
                                                    self._leafs = OrderedDict()

                                                    self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Lsp.State()
                                                    self.state.parent = self
                                                    self._children_name_map["state"] = "state"
                                                    self._segment_path = lambda: "lsp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Lsp, [], name, value)


                                                class State(Entity):
                                                    """
                                                    This container defines LSP PDU counters
                                                    
                                                    .. attribute:: received
                                                    
                                                    	The number of the specified type of PDU received on the interface
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: processed
                                                    
                                                    	The number of the specified type of PDU received on the interface that have been processed by the local system
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sent
                                                    
                                                    	The number of the specified type of PDU that have been sent by the local system on the interface
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Lsp.State, self).__init__()

                                                        self.yang_name = "state"
                                                        self.yang_parent_name = "lsp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('received', (YLeaf(YType.uint32, 'received'), ['int'])),
                                                            ('processed', (YLeaf(YType.uint32, 'processed'), ['int'])),
                                                            ('sent', (YLeaf(YType.uint32, 'sent'), ['int'])),
                                                        ])
                                                        self.received = None
                                                        self.processed = None
                                                        self.sent = None
                                                        self._segment_path = lambda: "state"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Lsp.State, [u'received', u'processed', u'sent'], name, value)


                                            class Iih(Entity):
                                                """
                                                This container defines IIH packet counters
                                                
                                                .. attribute:: state
                                                
                                                	Operational counters relating to IIH PDUs
                                                	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Iih.State>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Iih, self).__init__()

                                                    self.yang_name = "iih"
                                                    self.yang_parent_name = "packet-counters"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Iih.State))])
                                                    self._leafs = OrderedDict()

                                                    self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Iih.State()
                                                    self.state.parent = self
                                                    self._children_name_map["state"] = "state"
                                                    self._segment_path = lambda: "iih"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Iih, [], name, value)


                                                class State(Entity):
                                                    """
                                                    Operational counters relating to IIH PDUs
                                                    
                                                    .. attribute:: received
                                                    
                                                    	The number of the specified type of PDU received on the interface
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: processed
                                                    
                                                    	The number of the specified type of PDU received on the interface that have been processed by the local system
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sent
                                                    
                                                    	The number of the specified type of PDU that have been sent by the local system on the interface
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Iih.State, self).__init__()

                                                        self.yang_name = "state"
                                                        self.yang_parent_name = "iih"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('received', (YLeaf(YType.uint32, 'received'), ['int'])),
                                                            ('processed', (YLeaf(YType.uint32, 'processed'), ['int'])),
                                                            ('sent', (YLeaf(YType.uint32, 'sent'), ['int'])),
                                                        ])
                                                        self.received = None
                                                        self.processed = None
                                                        self.sent = None
                                                        self._segment_path = lambda: "state"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Iih.State, [u'received', u'processed', u'sent'], name, value)


                                            class Psnp(Entity):
                                                """
                                                This container defines PSNP packet counters
                                                
                                                .. attribute:: state
                                                
                                                	Packet counters relating to PSNPs
                                                	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Psnp.State>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Psnp, self).__init__()

                                                    self.yang_name = "psnp"
                                                    self.yang_parent_name = "packet-counters"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Psnp.State))])
                                                    self._leafs = OrderedDict()

                                                    self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Psnp.State()
                                                    self.state.parent = self
                                                    self._children_name_map["state"] = "state"
                                                    self._segment_path = lambda: "psnp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Psnp, [], name, value)


                                                class State(Entity):
                                                    """
                                                    Packet counters relating to PSNPs
                                                    
                                                    .. attribute:: received
                                                    
                                                    	The number of the specified type of PDU received on the interface
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: processed
                                                    
                                                    	The number of the specified type of PDU received on the interface that have been processed by the local system
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sent
                                                    
                                                    	The number of the specified type of PDU that have been sent by the local system on the interface
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Psnp.State, self).__init__()

                                                        self.yang_name = "state"
                                                        self.yang_parent_name = "psnp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('received', (YLeaf(YType.uint32, 'received'), ['int'])),
                                                            ('processed', (YLeaf(YType.uint32, 'processed'), ['int'])),
                                                            ('sent', (YLeaf(YType.uint32, 'sent'), ['int'])),
                                                        ])
                                                        self.received = None
                                                        self.processed = None
                                                        self.sent = None
                                                        self._segment_path = lambda: "state"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Psnp.State, [u'received', u'processed', u'sent'], name, value)


                                            class Cnsp(Entity):
                                                """
                                                Operational state parameters relating to CNSPs
                                                
                                                .. attribute:: state
                                                
                                                	Packet counters relating to CNSPs
                                                	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Cnsp.State>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Cnsp, self).__init__()

                                                    self.yang_name = "cnsp"
                                                    self.yang_parent_name = "packet-counters"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Cnsp.State))])
                                                    self._leafs = OrderedDict()

                                                    self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Cnsp.State()
                                                    self.state.parent = self
                                                    self._children_name_map["state"] = "state"
                                                    self._segment_path = lambda: "cnsp"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Cnsp, [], name, value)


                                                class State(Entity):
                                                    """
                                                    Packet counters relating to CNSPs
                                                    
                                                    .. attribute:: received
                                                    
                                                    	The number of the specified type of PDU received on the interface
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: processed
                                                    
                                                    	The number of the specified type of PDU received on the interface that have been processed by the local system
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: sent
                                                    
                                                    	The number of the specified type of PDU that have been sent by the local system on the interface
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Cnsp.State, self).__init__()

                                                        self.yang_name = "state"
                                                        self.yang_parent_name = "cnsp"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('received', (YLeaf(YType.uint32, 'received'), ['int'])),
                                                            ('processed', (YLeaf(YType.uint32, 'processed'), ['int'])),
                                                            ('sent', (YLeaf(YType.uint32, 'sent'), ['int'])),
                                                        ])
                                                        self.received = None
                                                        self.processed = None
                                                        self.sent = None
                                                        self._segment_path = lambda: "state"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.PacketCounters.Cnsp.State, [u'received', u'processed', u'sent'], name, value)


                                        class Adjacencies(Entity):
                                            """
                                            List of the local system's IS\-IS
                                            adjacencies
                                            
                                            .. attribute:: adjacency
                                            
                                            	List of the local system's IS\-IS adjacencies
                                            	**type**\: list of  		 :py:class:`Adjacency <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.Adjacencies.Adjacency>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.Adjacencies, self).__init__()

                                                self.yang_name = "adjacencies"
                                                self.yang_parent_name = "interfaces-level"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("adjacency", ("adjacency", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.Adjacencies.Adjacency))])
                                                self._leafs = OrderedDict()

                                                self.adjacency = YList(self)
                                                self._segment_path = lambda: "adjacencies"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.Adjacencies, [], name, value)


                                            class Adjacency(Entity):
                                                """
                                                List of the local system's IS\-IS
                                                adjacencies
                                                
                                                .. attribute:: system_id  (key)
                                                
                                                	Reference to the IS neighbor
                                                	**type**\: str
                                                
                                                .. attribute:: state
                                                
                                                	Operational state relating to the IS\-IS adjacency with the remote system
                                                	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.Adjacencies.Adjacency.State>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.Adjacencies.Adjacency, self).__init__()

                                                    self.yang_name = "adjacency"
                                                    self.yang_parent_name = "adjacencies"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['system_id']
                                                    self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.Adjacencies.Adjacency.State))])
                                                    self._leafs = OrderedDict([
                                                        ('system_id', (YLeaf(YType.str, 'system-id'), ['str'])),
                                                    ])
                                                    self.system_id = None

                                                    self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.Adjacencies.Adjacency.State()
                                                    self.state.parent = self
                                                    self._children_name_map["state"] = "state"
                                                    self._segment_path = lambda: "adjacency" + "[system-id='" + str(self.system_id) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.Adjacencies.Adjacency, ['system_id'], name, value)


                                                class State(Entity):
                                                    """
                                                    Operational state relating to the IS\-IS
                                                    adjacency with the remote system
                                                    
                                                    .. attribute:: system_id
                                                    
                                                    	ISIS neighbor system\-id
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_ipv4_address
                                                    
                                                    	ISIS Neighbor IPv4 address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: neighbor_ipv6_address
                                                    
                                                    	ISIS Neighbor IPv6 address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: neighbor_snpa
                                                    
                                                    	ISIS neighbor SNPA
                                                    	**type**\: str
                                                    
                                                    .. attribute:: local_extended_circuit_id
                                                    
                                                    	Local extended circuit ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: neighbor_extended_circuit_id
                                                    
                                                    	ISIS neighbor extended circuit ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: priority
                                                    
                                                    	Priority of the neighboring IS(LAN Hello only)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: dis_system_id
                                                    
                                                    	DIS System ID(LAN hello only)
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_circuit_type
                                                    
                                                    	Received ISIS circuit type (level\-1, level\-2, level\-1\-2)
                                                    	**type**\:  :py:class:`OpenconfigIsisTypesLevelTypeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisTypesLevelTypeEnum>`
                                                    
                                                    .. attribute:: adjacency_type
                                                    
                                                    	Formed ISIS adjacency type(level\-1, level\-2, level\-1\-2)
                                                    	**type**\:  :py:class:`OpenconfigIsisTypesLevelTypeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisTypesLevelTypeEnum>`
                                                    
                                                    .. attribute:: adjacency_state
                                                    
                                                    	P2P 3\-way ISIS adjacency state(up, down, init, failed)
                                                    	**type**\:  :py:class:`OpenconfigIsisTypesIsisInterfaceAdjStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisTypesIsisInterfaceAdjStateEnum>`
                                                    
                                                    .. attribute:: remaining_hold_time
                                                    
                                                    	Holding time in seconds for adjacency
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: second
                                                    
                                                    .. attribute:: up_time
                                                    
                                                    	Adjacency up time
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: restart_support
                                                    
                                                    	When set to true, Graceful\-restart signaling is supported
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: restart_suppress
                                                    
                                                    	When set to true, adjacency is not advertised
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: restart_status
                                                    
                                                    	When set to true, neighbor is being helped
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: topology
                                                    
                                                    	ISIS topology type support(ipv4\-unicast, ipv6\-unicast, ipv4\-multicast, ipv6\-multicast)
                                                    	**type**\: list of str
                                                    
                                                    .. attribute:: area_address
                                                    
                                                    	List of ISIS area\-address(es)
                                                    	**type**\: list of str
                                                    
                                                    .. attribute:: nlpid
                                                    
                                                    	Supported Protocol
                                                    	**type**\: list of   :py:class:`OpenconfigIsisAdjacencyStateNlpidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisAdjacencyStateNlpidEnum>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.Adjacencies.Adjacency.State, self).__init__()

                                                        self.yang_name = "state"
                                                        self.yang_parent_name = "adjacency"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('system_id', (YLeaf(YType.str, 'system-id'), ['str'])),
                                                            ('neighbor_ipv4_address', (YLeaf(YType.str, 'neighbor-ipv4-address'), ['str'])),
                                                            ('neighbor_ipv6_address', (YLeaf(YType.str, 'neighbor-ipv6-address'), ['str'])),
                                                            ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                            ('local_extended_circuit_id', (YLeaf(YType.uint32, 'local-extended-circuit-id'), ['int'])),
                                                            ('neighbor_extended_circuit_id', (YLeaf(YType.uint32, 'neighbor-extended-circuit-id'), ['int'])),
                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                            ('dis_system_id', (YLeaf(YType.str, 'dis-system-id'), ['str'])),
                                                            ('neighbor_circuit_type', (YLeaf(YType.enumeration, 'neighbor-circuit-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisTypesLevelTypeEnum', '')])),
                                                            ('adjacency_type', (YLeaf(YType.enumeration, 'adjacency-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisTypesLevelTypeEnum', '')])),
                                                            ('adjacency_state', (YLeaf(YType.enumeration, 'adjacency-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisTypesIsisInterfaceAdjStateEnum', '')])),
                                                            ('remaining_hold_time', (YLeaf(YType.uint16, 'remaining-hold-time'), ['int'])),
                                                            ('up_time', (YLeaf(YType.uint32, 'up-time'), ['int'])),
                                                            ('restart_support', (YLeaf(YType.boolean, 'restart-support'), ['bool'])),
                                                            ('restart_suppress', (YLeaf(YType.boolean, 'restart-suppress'), ['bool'])),
                                                            ('restart_status', (YLeaf(YType.boolean, 'restart-status'), ['bool'])),
                                                            ('topology', (YLeafList(YType.str, 'topology'), ['str'])),
                                                            ('area_address', (YLeafList(YType.str, 'area-address'), ['str'])),
                                                            ('nlpid', (YLeafList(YType.enumeration, 'nlpid'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisAdjacencyStateNlpidEnum', '')])),
                                                        ])
                                                        self.system_id = None
                                                        self.neighbor_ipv4_address = None
                                                        self.neighbor_ipv6_address = None
                                                        self.neighbor_snpa = None
                                                        self.local_extended_circuit_id = None
                                                        self.neighbor_extended_circuit_id = None
                                                        self.priority = None
                                                        self.dis_system_id = None
                                                        self.neighbor_circuit_type = None
                                                        self.adjacency_type = None
                                                        self.adjacency_state = None
                                                        self.remaining_hold_time = None
                                                        self.up_time = None
                                                        self.restart_support = None
                                                        self.restart_suppress = None
                                                        self.restart_status = None
                                                        self.topology = []
                                                        self.area_address = []
                                                        self.nlpid = []
                                                        self._segment_path = lambda: "state"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.Adjacencies.Adjacency.State, [u'system_id', u'neighbor_ipv4_address', u'neighbor_ipv6_address', u'neighbor_snpa', u'local_extended_circuit_id', u'neighbor_extended_circuit_id', u'priority', u'dis_system_id', u'neighbor_circuit_type', u'adjacency_type', u'adjacency_state', u'remaining_hold_time', u'up_time', u'restart_support', u'restart_suppress', u'restart_status', u'topology', u'area_address', u'nlpid'], name, value)


                                        class LevelsTimers(Entity):
                                            """
                                            This container defines ISIS timers
                                            
                                            .. attribute:: state
                                            
                                            	This container defines ISIS interface hello\-timers state
                                            	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsTimers.State>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsTimers, self).__init__()

                                                self.yang_name = "levels-timers"
                                                self.yang_parent_name = "interfaces-level"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsTimers.State))])
                                                self._leafs = OrderedDict()

                                                self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsTimers.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "levels-timers"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsTimers, [], name, value)


                                            class State(Entity):
                                                """
                                                This container defines ISIS interface
                                                hello\-timers state
                                                
                                                .. attribute:: hello_interval
                                                
                                                	ISIS hello\-interval value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: hello_multiplier
                                                
                                                	ISIS hello\-multiplier value
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsTimers.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "levels-timers"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                                                        ('hello_multiplier', (YLeaf(YType.uint8, 'hello-multiplier'), ['int'])),
                                                    ])
                                                    self.hello_interval = None
                                                    self.hello_multiplier = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsTimers.State, [u'hello_interval', u'hello_multiplier'], name, value)


                                        class LevelsAfiSafis(Entity):
                                            """
                                            Address\-family/Subsequent
                                            Address\-family list
                                            
                                            .. attribute:: levels_afi_safi
                                            
                                            	Address\-family/Subsequent Address\-family list
                                            	**type**\: list of  		 :py:class:`LevelsAfiSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsAfiSafis.LevelsAfiSafi>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsAfiSafis, self).__init__()

                                                self.yang_name = "levels-afi-safis"
                                                self.yang_parent_name = "interfaces-level"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("levels-afi-safi", ("levels_afi_safi", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsAfiSafis.LevelsAfiSafi))])
                                                self._leafs = OrderedDict()

                                                self.levels_afi_safi = YList(self)
                                                self._segment_path = lambda: "levels-afi-safis"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsAfiSafis, [], name, value)


                                            class LevelsAfiSafi(Entity):
                                                """
                                                Address\-family/Subsequent
                                                Address\-family list
                                                
                                                .. attribute:: afi_safi_state
                                                
                                                	This container defines AFI\-SAFI State information
                                                	**type**\:  :py:class:`AfiSafiState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsAfiSafis.LevelsAfiSafi.AfiSafiState>`
                                                
                                                .. attribute:: afi_safi_segment_routing
                                                
                                                	Configuration and operatioanl state parameters relating to segment routing for an interface within the IGP
                                                	**type**\:  :py:class:`AfiSafiSegmentRouting <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsAfiSafis.LevelsAfiSafi.AfiSafiSegmentRouting>`
                                                
                                                .. attribute:: afi_name
                                                
                                                	Reference to address\-family type
                                                	**type**\: str
                                                
                                                .. attribute:: safi_name
                                                
                                                	Reference to subsequent address\-family type
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsAfiSafis.LevelsAfiSafi, self).__init__()

                                                    self.yang_name = "levels-afi-safi"
                                                    self.yang_parent_name = "levels-afi-safis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("afi-safi-state", ("afi_safi_state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsAfiSafis.LevelsAfiSafi.AfiSafiState)), ("afi-safi-segment-routing", ("afi_safi_segment_routing", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsAfiSafis.LevelsAfiSafi.AfiSafiSegmentRouting))])
                                                    self._leafs = OrderedDict([
                                                        ('afi_name', (YLeaf(YType.str, 'afi-name'), ['str'])),
                                                        ('safi_name', (YLeaf(YType.str, 'safi-name'), ['str'])),
                                                    ])
                                                    self.afi_name = None
                                                    self.safi_name = None

                                                    self.afi_safi_state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsAfiSafis.LevelsAfiSafi.AfiSafiState()
                                                    self.afi_safi_state.parent = self
                                                    self._children_name_map["afi_safi_state"] = "afi-safi-state"

                                                    self.afi_safi_segment_routing = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsAfiSafis.LevelsAfiSafi.AfiSafiSegmentRouting()
                                                    self.afi_safi_segment_routing.parent = self
                                                    self._children_name_map["afi_safi_segment_routing"] = "afi-safi-segment-routing"
                                                    self._segment_path = lambda: "levels-afi-safi"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsAfiSafis.LevelsAfiSafi, ['afi_name', 'safi_name'], name, value)


                                                class AfiSafiState(Entity):
                                                    """
                                                    This container defines AFI\-SAFI State
                                                    information
                                                    
                                                    .. attribute:: afi_name
                                                    
                                                    	Address\-family type
                                                    	**type**\: str
                                                    
                                                    .. attribute:: safi_name
                                                    
                                                    	Subsequent address\-family type
                                                    	**type**\: str
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	ISIS metric value(default=10)
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsAfiSafis.LevelsAfiSafi.AfiSafiState, self).__init__()

                                                        self.yang_name = "afi-safi-state"
                                                        self.yang_parent_name = "levels-afi-safi"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('afi_name', (YLeaf(YType.str, 'afi-name'), ['str'])),
                                                            ('safi_name', (YLeaf(YType.str, 'safi-name'), ['str'])),
                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ])
                                                        self.afi_name = None
                                                        self.safi_name = None
                                                        self.metric = None
                                                        self._segment_path = lambda: "afi-safi-state"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsAfiSafis.LevelsAfiSafi.AfiSafiState, [u'afi_name', u'safi_name', u'metric'], name, value)


                                                class AfiSafiSegmentRouting(Entity):
                                                    """
                                                    Configuration and operatioanl state
                                                    parameters relating to segment
                                                    routing for an interface within the
                                                    IGP
                                                    
                                                    .. attribute:: segment_routing_prefix_sids
                                                    
                                                    	An IGP prefix that should have a segment routing IGP\-Prefix SID allocated to it
                                                    	**type**\:  :py:class:`SegmentRoutingPrefixSids <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsAfiSafis.LevelsAfiSafi.AfiSafiSegmentRouting.SegmentRoutingPrefixSids>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsAfiSafis.LevelsAfiSafi.AfiSafiSegmentRouting, self).__init__()

                                                        self.yang_name = "afi-safi-segment-routing"
                                                        self.yang_parent_name = "levels-afi-safi"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("segment-routing-prefix-sids", ("segment_routing_prefix_sids", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsAfiSafis.LevelsAfiSafi.AfiSafiSegmentRouting.SegmentRoutingPrefixSids))])
                                                        self._leafs = OrderedDict()

                                                        self.segment_routing_prefix_sids = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsAfiSafis.LevelsAfiSafi.AfiSafiSegmentRouting.SegmentRoutingPrefixSids()
                                                        self.segment_routing_prefix_sids.parent = self
                                                        self._children_name_map["segment_routing_prefix_sids"] = "segment-routing-prefix-sids"
                                                        self._segment_path = lambda: "afi-safi-segment-routing"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsAfiSafis.LevelsAfiSafi.AfiSafiSegmentRouting, [], name, value)


                                                    class SegmentRoutingPrefixSids(Entity):
                                                        """
                                                        An IGP prefix that should have a
                                                        segment routing IGP\-Prefix SID
                                                        allocated to it
                                                        
                                                        .. attribute:: segment_routing_prefix_sid
                                                        
                                                        	An IGP prefix that should have a segment routing IGP\-Prefix SID allocated to it
                                                        	**type**\: list of  		 :py:class:`SegmentRoutingPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsAfiSafis.LevelsAfiSafi.AfiSafiSegmentRouting.SegmentRoutingPrefixSids.SegmentRoutingPrefixSid>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsAfiSafis.LevelsAfiSafi.AfiSafiSegmentRouting.SegmentRoutingPrefixSids, self).__init__()

                                                            self.yang_name = "segment-routing-prefix-sids"
                                                            self.yang_parent_name = "afi-safi-segment-routing"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("segment-routing-prefix-sid", ("segment_routing_prefix_sid", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsAfiSafis.LevelsAfiSafi.AfiSafiSegmentRouting.SegmentRoutingPrefixSids.SegmentRoutingPrefixSid))])
                                                            self._leafs = OrderedDict()

                                                            self.segment_routing_prefix_sid = YList(self)
                                                            self._segment_path = lambda: "segment-routing-prefix-sids"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsAfiSafis.LevelsAfiSafi.AfiSafiSegmentRouting.SegmentRoutingPrefixSids, [], name, value)


                                                        class SegmentRoutingPrefixSid(Entity):
                                                            """
                                                            An IGP prefix that should have a
                                                            segment routing IGP\-Prefix SID
                                                            allocated to it
                                                            
                                                            .. attribute:: prefix  (key)
                                                            
                                                            	Reference to the prefix for which the IGP\-Prefix SID is to be advertised
                                                            	**type**\: str
                                                            
                                                            .. attribute:: state
                                                            
                                                            	Operational state parameters for the IGP\-Prefix SID
                                                            	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsAfiSafis.LevelsAfiSafi.AfiSafiSegmentRouting.SegmentRoutingPrefixSids.SegmentRoutingPrefixSid.State>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'clns-isis-oper'
                                                            _revision = '2018-04-07'

                                                            def __init__(self):
                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsAfiSafis.LevelsAfiSafi.AfiSafiSegmentRouting.SegmentRoutingPrefixSids.SegmentRoutingPrefixSid, self).__init__()

                                                                self.yang_name = "segment-routing-prefix-sid"
                                                                self.yang_parent_name = "segment-routing-prefix-sids"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['prefix']
                                                                self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsAfiSafis.LevelsAfiSafi.AfiSafiSegmentRouting.SegmentRoutingPrefixSids.SegmentRoutingPrefixSid.State))])
                                                                self._leafs = OrderedDict([
                                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ])
                                                                self.prefix = None

                                                                self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsAfiSafis.LevelsAfiSafi.AfiSafiSegmentRouting.SegmentRoutingPrefixSids.SegmentRoutingPrefixSid.State()
                                                                self.state.parent = self
                                                                self._children_name_map["state"] = "state"
                                                                self._segment_path = lambda: "segment-routing-prefix-sid" + "[prefix='" + str(self.prefix) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsAfiSafis.LevelsAfiSafi.AfiSafiSegmentRouting.SegmentRoutingPrefixSids.SegmentRoutingPrefixSid, ['prefix'], name, value)


                                                            class State(Entity):
                                                                """
                                                                Operational state parameters for the IGP\-Prefix
                                                                SID
                                                                
                                                                .. attribute:: prefix
                                                                
                                                                	The IP prefix for which the IGP prefix SID should be advertised
                                                                	**type**\: str
                                                                
                                                                .. attribute:: sid_id
                                                                
                                                                	The Segment Identifier to be used when advertising the IGP Prefix SID
                                                                	**type**\: str
                                                                
                                                                .. attribute:: label_options
                                                                
                                                                	The options associated with the IGP prefix SID for MPLS
                                                                	**type**\:  :py:class:`OpenconfigSegmentRoutingLabelOptionsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigSegmentRoutingLabelOptionsEnum>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsAfiSafis.LevelsAfiSafi.AfiSafiSegmentRouting.SegmentRoutingPrefixSids.SegmentRoutingPrefixSid.State, self).__init__()

                                                                    self.yang_name = "state"
                                                                    self.yang_parent_name = "segment-routing-prefix-sid"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                        ('sid_id', (YLeaf(YType.str, 'sid-id'), ['str'])),
                                                                        ('label_options', (YLeaf(YType.enumeration, 'label-options'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigSegmentRoutingLabelOptionsEnum', '')])),
                                                                    ])
                                                                    self.prefix = None
                                                                    self.sid_id = None
                                                                    self.label_options = None
                                                                    self._segment_path = lambda: "state"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesLevels.InterfacesLevel.LevelsAfiSafis.LevelsAfiSafi.AfiSafiSegmentRouting.SegmentRoutingPrefixSids.SegmentRoutingPrefixSid.State, [u'prefix', u'sid_id', u'label_options'], name, value)


                                class CircuitCounters(Entity):
                                    """
                                    This container defines state information
                                    for ISIS circuit counters
                                    
                                    .. attribute:: state
                                    
                                    	The container defines a list of counters for IS circuit
                                    	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.CircuitCounters.State>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.CircuitCounters, self).__init__()

                                        self.yang_name = "circuit-counters"
                                        self.yang_parent_name = "isis-interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.CircuitCounters.State))])
                                        self._leafs = OrderedDict()

                                        self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.CircuitCounters.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._segment_path = lambda: "circuit-counters"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.CircuitCounters, [], name, value)


                                    class State(Entity):
                                        """
                                        The container defines a list of counters for IS
                                        circuit
                                        
                                        .. attribute:: adj_changes
                                        
                                        	Number of times an adjacency state change has occurred on this circuit
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rejected_adj
                                        
                                        	Number of times an adjacency has been rejected on this circuit
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: id_field_len_mismatches
                                        
                                        	Number of times an IS\-IS control PDU with an ID field length different from that for this system has been received
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: max_area_address_mismatches
                                        
                                        	Number of times an IS\-IS control PDU with a max area address field different from that for this system has been received
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: auth_fails
                                        
                                        	Number of times an IS\-IS control PDU with the correct auth type has failed to pass authentication validation
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lan_dis_changes
                                        
                                        	Number of times the Designated IS has changed on this circuit at this level
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.CircuitCounters.State, self).__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "circuit-counters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('adj_changes', (YLeaf(YType.uint32, 'adj-changes'), ['int'])),
                                                ('rejected_adj', (YLeaf(YType.uint32, 'rejected-adj'), ['int'])),
                                                ('id_field_len_mismatches', (YLeaf(YType.uint32, 'id-field-len-mismatches'), ['int'])),
                                                ('max_area_address_mismatches', (YLeaf(YType.uint32, 'max-area-address-mismatches'), ['int'])),
                                                ('auth_fails', (YLeaf(YType.uint32, 'auth-fails'), ['int'])),
                                                ('lan_dis_changes', (YLeaf(YType.uint32, 'lan-dis-changes'), ['int'])),
                                            ])
                                            self.adj_changes = None
                                            self.rejected_adj = None
                                            self.id_field_len_mismatches = None
                                            self.max_area_address_mismatches = None
                                            self.auth_fails = None
                                            self.lan_dis_changes = None
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.CircuitCounters.State, [u'adj_changes', u'rejected_adj', u'id_field_len_mismatches', u'max_area_address_mismatches', u'auth_fails', u'lan_dis_changes'], name, value)


                                class InterfacesAuthentication(Entity):
                                    """
                                    This container defines ISIS
                                    authentication
                                    
                                    .. attribute:: key
                                    
                                    	This container defines ISIS authentication key
                                    	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesAuthentication.Key>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesAuthentication, self).__init__()

                                        self.yang_name = "interfaces-authentication"
                                        self.yang_parent_name = "isis-interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key", ("key", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesAuthentication.Key))])
                                        self._leafs = OrderedDict()

                                        self.key = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesAuthentication.Key()
                                        self.key.parent = self
                                        self._children_name_map["key"] = "key"
                                        self._segment_path = lambda: "interfaces-authentication"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesAuthentication, [], name, value)


                                    class Key(Entity):
                                        """
                                        This container defines ISIS authentication key
                                        
                                        .. attribute:: state
                                        
                                        	This container defines ISIS authentication key state
                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesAuthentication.Key.State>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesAuthentication.Key, self).__init__()

                                            self.yang_name = "key"
                                            self.yang_parent_name = "interfaces-authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesAuthentication.Key.State))])
                                            self._leafs = OrderedDict()

                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesAuthentication.Key.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._segment_path = lambda: "key"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesAuthentication.Key, [], name, value)


                                        class State(Entity):
                                            """
                                            This container defines ISIS authentication key
                                            state
                                            
                                            .. attribute:: auth_password
                                            
                                            	Authentication key string
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesAuthentication.Key.State, self).__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('auth_password', (YLeaf(YType.str, 'auth-password'), ['str'])),
                                                ])
                                                self.auth_password = None
                                                self._segment_path = lambda: "state"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesAuthentication.Key.State, [u'auth_password'], name, value)


                                class InterfacesTimers(Entity):
                                    """
                                    This container describes ISIS interface
                                    timers configuration
                                    
                                    .. attribute:: state
                                    
                                    	This container defines state information for ISIS interface timers
                                    	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesTimers.State>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesTimers, self).__init__()

                                        self.yang_name = "interfaces-timers"
                                        self.yang_parent_name = "isis-interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesTimers.State))])
                                        self._leafs = OrderedDict()

                                        self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesTimers.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._segment_path = lambda: "interfaces-timers"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesTimers, [], name, value)


                                    class State(Entity):
                                        """
                                        This container defines state information for
                                        ISIS interface timers
                                        
                                        .. attribute:: csnp_interval
                                        
                                        	The interval, specified in seconds, at which periodic CSNP packets should be transmitted by the local IS
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: lsp_pacing_interval
                                        
                                        	The interval interval in milliseconds between the detection of topology change and when the SPF algorithm runs
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: millisecond
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesTimers.State, self).__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "interfaces-timers"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('csnp_interval', (YLeaf(YType.uint16, 'csnp-interval'), ['int'])),
                                                ('lsp_pacing_interval', (YLeaf(YType.uint64, 'lsp-pacing-interval'), ['int'])),
                                            ])
                                            self.csnp_interval = None
                                            self.lsp_pacing_interval = None
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.IsisInterfaces.IsisInterface.InterfacesTimers.State, [u'csnp_interval', u'lsp_pacing_interval'], name, value)


                        class Global(Entity):
                            """
                            This container defines global ISIS
                            configuration and state information
                            
                            .. attribute:: segment_routing
                            
                            	Configuration and operational state relating to segment routing
                            	**type**\:  :py:class:`SegmentRouting <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.SegmentRouting>`
                            
                            .. attribute:: lsp_bit
                            
                            	This container defines ISIS LSP Operational Bits
                            	**type**\:  :py:class:`LspBit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit>`
                            
                            .. attribute:: nsr
                            
                            	This container defines ISIS Non\-Stop Routing
                            	**type**\:  :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Nsr>`
                            
                            .. attribute:: graceful_restart
                            
                            	This container defines ISIS Graceful Restart
                            	**type**\:  :py:class:`GracefulRestart <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GracefulRestart>`
                            
                            .. attribute:: global_state
                            
                            	This container defines state for ISIS global router
                            	**type**\:  :py:class:`GlobalState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GlobalState>`
                            
                            .. attribute:: inter_level_propagation_policies
                            
                            	Policies to propagate prefixes between IS\-IS levels
                            	**type**\:  :py:class:`InterLevelPropagationPolicies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies>`
                            
                            .. attribute:: afi_safis
                            
                            	Address\-family/Subsequent Address\-family list
                            	**type**\:  :py:class:`AfiSafis <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafis>`
                            
                            .. attribute:: timers
                            
                            	This container defines ISIS timers
                            	**type**\:  :py:class:`Timers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers>`
                            
                            .. attribute:: transport
                            
                            	This container defines ISIS transport
                            	**type**\:  :py:class:`Transport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Transport>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global, self).__init__()

                                self.yang_name = "global"
                                self.yang_parent_name = "isis"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("segment-routing", ("segment_routing", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.SegmentRouting)), ("lsp-bit", ("lsp_bit", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit)), ("nsr", ("nsr", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Nsr)), ("graceful-restart", ("graceful_restart", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GracefulRestart)), ("global-state", ("global_state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GlobalState)), ("inter-level-propagation-policies", ("inter_level_propagation_policies", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies)), ("afi-safis", ("afi_safis", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafis)), ("timers", ("timers", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers)), ("transport", ("transport", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Transport))])
                                self._leafs = OrderedDict()

                                self.segment_routing = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.SegmentRouting()
                                self.segment_routing.parent = self
                                self._children_name_map["segment_routing"] = "segment-routing"

                                self.lsp_bit = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit()
                                self.lsp_bit.parent = self
                                self._children_name_map["lsp_bit"] = "lsp-bit"

                                self.nsr = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Nsr()
                                self.nsr.parent = self
                                self._children_name_map["nsr"] = "nsr"

                                self.graceful_restart = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GracefulRestart()
                                self.graceful_restart.parent = self
                                self._children_name_map["graceful_restart"] = "graceful-restart"

                                self.global_state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GlobalState()
                                self.global_state.parent = self
                                self._children_name_map["global_state"] = "global-state"

                                self.inter_level_propagation_policies = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies()
                                self.inter_level_propagation_policies.parent = self
                                self._children_name_map["inter_level_propagation_policies"] = "inter-level-propagation-policies"

                                self.afi_safis = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafis()
                                self.afi_safis.parent = self
                                self._children_name_map["afi_safis"] = "afi-safis"

                                self.timers = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers()
                                self.timers.parent = self
                                self._children_name_map["timers"] = "timers"

                                self.transport = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Transport()
                                self.transport.parent = self
                                self._children_name_map["transport"] = "transport"
                                self._segment_path = lambda: "global"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global, [], name, value)


                            class SegmentRouting(Entity):
                                """
                                Configuration and operational state
                                relating to segment routing
                                
                                .. attribute:: state
                                
                                	Operational state parameters relating to segment routing for the IGP instance
                                	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.SegmentRouting.State>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.SegmentRouting, self).__init__()

                                    self.yang_name = "segment-routing"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.SegmentRouting.State))])
                                    self._leafs = OrderedDict()

                                    self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.SegmentRouting.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "segment-routing"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.SegmentRouting, [], name, value)


                                class State(Entity):
                                    """
                                    Operational state parameters relating to segment
                                    routing for the IGP instance
                                    
                                    .. attribute:: enabled
                                    
                                    	When this leaf is set to true, the segment routing extensions are utilised within the IGP
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.SegmentRouting.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "segment-routing"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                        ])
                                        self.enabled = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.SegmentRouting.State, [u'enabled'], name, value)


                            class LspBit(Entity):
                                """
                                This container defines ISIS LSP
                                Operational Bits
                                
                                .. attribute:: overload_bit
                                
                                	This container defines Overload Bit configuration
                                	**type**\:  :py:class:`OverloadBit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit>`
                                
                                .. attribute:: attached_bit
                                
                                	This container defines Attached Bit
                                	**type**\:  :py:class:`AttachedBit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.AttachedBit>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit, self).__init__()

                                    self.yang_name = "lsp-bit"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("overload-bit", ("overload_bit", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit)), ("attached-bit", ("attached_bit", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.AttachedBit))])
                                    self._leafs = OrderedDict()

                                    self.overload_bit = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit()
                                    self.overload_bit.parent = self
                                    self._children_name_map["overload_bit"] = "overload-bit"

                                    self.attached_bit = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.AttachedBit()
                                    self.attached_bit.parent = self
                                    self._children_name_map["attached_bit"] = "attached-bit"
                                    self._segment_path = lambda: "lsp-bit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit, [], name, value)


                                class OverloadBit(Entity):
                                    """
                                    This container defines Overload Bit
                                    configuration
                                    
                                    .. attribute:: overload_bit_state
                                    
                                    	This container defines state for ISIS Overload Bit
                                    	**type**\:  :py:class:`OverloadBitState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.OverloadBitState>`
                                    
                                    .. attribute:: reset_triggers
                                    
                                    	This list describes ISIS Overload reset trigger reasons
                                    	**type**\:  :py:class:`ResetTriggers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit, self).__init__()

                                        self.yang_name = "overload-bit"
                                        self.yang_parent_name = "lsp-bit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("overload-bit-state", ("overload_bit_state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.OverloadBitState)), ("reset-triggers", ("reset_triggers", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers))])
                                        self._leafs = OrderedDict()

                                        self.overload_bit_state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.OverloadBitState()
                                        self.overload_bit_state.parent = self
                                        self._children_name_map["overload_bit_state"] = "overload-bit-state"

                                        self.reset_triggers = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers()
                                        self.reset_triggers.parent = self
                                        self._children_name_map["reset_triggers"] = "reset-triggers"
                                        self._segment_path = lambda: "overload-bit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit, [], name, value)


                                    class OverloadBitState(Entity):
                                        """
                                        This container defines state for ISIS
                                        Overload Bit
                                        
                                        .. attribute:: set_bit
                                        
                                        	When set to true, IS\-IS overload bit is set
                                        	**type**\: bool
                                        
                                        .. attribute:: set_bit_on_boot
                                        
                                        	When set to true, the IS\-IS overload bit is set on system boot
                                        	**type**\: bool
                                        
                                        .. attribute:: advertise_high_metric
                                        
                                        	When set to true, the local IS advertises links with the highest available metric regardless of their configured metric
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.OverloadBitState, self).__init__()

                                            self.yang_name = "overload-bit-state"
                                            self.yang_parent_name = "overload-bit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('set_bit', (YLeaf(YType.boolean, 'set-bit'), ['bool'])),
                                                ('set_bit_on_boot', (YLeaf(YType.boolean, 'set-bit-on-boot'), ['bool'])),
                                                ('advertise_high_metric', (YLeaf(YType.boolean, 'advertise-high-metric'), ['bool'])),
                                            ])
                                            self.set_bit = None
                                            self.set_bit_on_boot = None
                                            self.advertise_high_metric = None
                                            self._segment_path = lambda: "overload-bit-state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.OverloadBitState, [u'set_bit', u'set_bit_on_boot', u'advertise_high_metric'], name, value)


                                    class ResetTriggers(Entity):
                                        """
                                        This list describes ISIS Overload reset
                                        trigger reasons
                                        
                                        .. attribute:: reset_trigger
                                        
                                        	This list describes ISIS Overload reset trigger reasons
                                        	**type**\: list of  		 :py:class:`ResetTrigger <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers.ResetTrigger>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers, self).__init__()

                                            self.yang_name = "reset-triggers"
                                            self.yang_parent_name = "overload-bit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("reset-trigger", ("reset_trigger", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers.ResetTrigger))])
                                            self._leafs = OrderedDict()

                                            self.reset_trigger = YList(self)
                                            self._segment_path = lambda: "reset-triggers"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers, [], name, value)


                                        class ResetTrigger(Entity):
                                            """
                                            This list describes ISIS Overload reset
                                            trigger reasons
                                            
                                            .. attribute:: reset_trigger  (key)
                                            
                                            	Reference to the reset trigger reason
                                            	**type**\: str
                                            
                                            .. attribute:: state
                                            
                                            	This container defines state for ISIS Overload Bit reset triggers
                                            	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers.ResetTrigger.State>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers.ResetTrigger, self).__init__()

                                                self.yang_name = "reset-trigger"
                                                self.yang_parent_name = "reset-triggers"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['reset_trigger']
                                                self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers.ResetTrigger.State))])
                                                self._leafs = OrderedDict([
                                                    ('reset_trigger', (YLeaf(YType.str, 'reset-trigger'), ['str'])),
                                                ])
                                                self.reset_trigger = None

                                                self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers.ResetTrigger.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "reset-trigger" + "[reset-trigger='" + str(self.reset_trigger) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers.ResetTrigger, ['reset_trigger'], name, value)


                                            class State(Entity):
                                                """
                                                This container defines state for ISIS Overload
                                                Bit reset triggers
                                                
                                                .. attribute:: reset_trigger
                                                
                                                	In the case that the system sets the overload bit on start, the system should reset the bit (i
                                                	**type**\: str
                                                
                                                .. attribute:: delay
                                                
                                                	If a reset trigger is specified, the system should delay resetting the overload bit for the specified number of seconds after the trigger occurs
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: second
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers.ResetTrigger.State, self).__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "reset-trigger"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('reset_trigger', (YLeaf(YType.str, 'reset-trigger'), ['str'])),
                                                        ('delay', (YLeaf(YType.uint16, 'delay'), ['int'])),
                                                    ])
                                                    self.reset_trigger = None
                                                    self.delay = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers.ResetTrigger.State, [u'reset_trigger', u'delay'], name, value)


                                class AttachedBit(Entity):
                                    """
                                    This container defines Attached Bit
                                    
                                    .. attribute:: state
                                    
                                    	This container defines state for Link State PDU Bit
                                    	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.AttachedBit.State>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.AttachedBit, self).__init__()

                                        self.yang_name = "attached-bit"
                                        self.yang_parent_name = "lsp-bit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.AttachedBit.State))])
                                        self._leafs = OrderedDict()

                                        self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.AttachedBit.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._segment_path = lambda: "attached-bit"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.AttachedBit, [], name, value)


                                    class State(Entity):
                                        """
                                        This container defines state for Link State PDU
                                        Bit
                                        
                                        .. attribute:: ignore_bit
                                        
                                        	When set to true, if the attached bit is set on an incoming Level 1 IS\-IS, the local system ignores it
                                        	**type**\: bool
                                        
                                        .. attribute:: suppress_bit
                                        
                                        	When set to true, if the local IS acts as a L1L2 router, then the attached bit is not advertised in locally generated PDUs
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.AttachedBit.State, self).__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "attached-bit"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ignore_bit', (YLeaf(YType.boolean, 'ignore-bit'), ['bool'])),
                                                ('suppress_bit', (YLeaf(YType.boolean, 'suppress-bit'), ['bool'])),
                                            ])
                                            self.ignore_bit = None
                                            self.suppress_bit = None
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.AttachedBit.State, [u'ignore_bit', u'suppress_bit'], name, value)


                            class Nsr(Entity):
                                """
                                This container defines ISIS Non\-Stop
                                Routing
                                
                                .. attribute:: state
                                
                                	This container defines state for Non\-Stop\-Routing
                                	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Nsr.State>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Nsr, self).__init__()

                                    self.yang_name = "nsr"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Nsr.State))])
                                    self._leafs = OrderedDict()

                                    self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Nsr.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "nsr"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Nsr, [], name, value)


                                class State(Entity):
                                    """
                                    This container defines state for
                                    Non\-Stop\-Routing
                                    
                                    .. attribute:: enabled
                                    
                                    	When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Nsr.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "nsr"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                        ])
                                        self.enabled = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Nsr.State, [u'enabled'], name, value)


                            class GracefulRestart(Entity):
                                """
                                This container defines ISIS Graceful
                                Restart
                                
                                .. attribute:: state
                                
                                	This container defines state information for ISIS graceful\-restart
                                	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GracefulRestart.State>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GracefulRestart, self).__init__()

                                    self.yang_name = "graceful-restart"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GracefulRestart.State))])
                                    self._leafs = OrderedDict()

                                    self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GracefulRestart.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "graceful-restart"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GracefulRestart, [], name, value)


                                class State(Entity):
                                    """
                                    This container defines state information for
                                    ISIS graceful\-restart
                                    
                                    .. attribute:: enabled
                                    
                                    	When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GracefulRestart.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "graceful-restart"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                        ])
                                        self.enabled = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GracefulRestart.State, [u'enabled'], name, value)


                            class GlobalState(Entity):
                                """
                                This container defines state for ISIS
                                global router
                                
                                .. attribute:: authentication_check
                                
                                	When set to true, reject all ISIS protocol PDUs that either have a mismatch in authentication\-type or authentication\-key
                                	**type**\: bool
                                
                                .. attribute:: instance
                                
                                	ISIS Instance
                                	**type**\: str
                                
                                .. attribute:: level_capability
                                
                                	ISIS level capability(level\-1, level\-2 ,vlevel\-1\-2)
                                	**type**\:  :py:class:`OpenconfigIsisTypesLevelTypeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisTypesLevelTypeEnum>`
                                
                                .. attribute:: max_ecmp_paths
                                
                                	ISIS max\-paths count
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: iid_tlv
                                
                                	ISIS Instance Identifier TLV
                                	**type**\: bool
                                
                                .. attribute:: fast_flooding
                                
                                	When set to true, IS will always flood the LSP that triggered an SPF before the router actually runs the SPF computation
                                	**type**\: bool
                                
                                .. attribute:: net
                                
                                	ISIS network entity title (NET)
                                	**type**\: list of str
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GlobalState, self).__init__()

                                    self.yang_name = "global-state"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('authentication_check', (YLeaf(YType.boolean, 'authentication-check'), ['bool'])),
                                        ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                        ('level_capability', (YLeaf(YType.enumeration, 'level-capability'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisTypesLevelTypeEnum', '')])),
                                        ('max_ecmp_paths', (YLeaf(YType.uint8, 'max-ecmp-paths'), ['int'])),
                                        ('iid_tlv', (YLeaf(YType.boolean, 'iid-tlv'), ['bool'])),
                                        ('fast_flooding', (YLeaf(YType.boolean, 'fast-flooding'), ['bool'])),
                                        ('net', (YLeafList(YType.str, 'net'), ['str'])),
                                    ])
                                    self.authentication_check = None
                                    self.instance = None
                                    self.level_capability = None
                                    self.max_ecmp_paths = None
                                    self.iid_tlv = None
                                    self.fast_flooding = None
                                    self.net = []
                                    self._segment_path = lambda: "global-state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GlobalState, [u'authentication_check', u'instance', u'level_capability', u'max_ecmp_paths', u'iid_tlv', u'fast_flooding', u'net'], name, value)


                            class InterLevelPropagationPolicies(Entity):
                                """
                                Policies to propagate prefixes between
                                IS\-IS levels
                                
                                .. attribute:: level1_to_level2
                                
                                	Policies relating to prefixes to be propagated from Level 1 to Level 2
                                	**type**\:  :py:class:`Level1ToLevel2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level1ToLevel2>`
                                
                                .. attribute:: level2_to_level1
                                
                                	Policies relating to prefixes to be propagated from Level2 to Level 1
                                	**type**\:  :py:class:`Level2ToLevel1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level2ToLevel1>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies, self).__init__()

                                    self.yang_name = "inter-level-propagation-policies"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("level1-to-level2", ("level1_to_level2", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level1ToLevel2)), ("level2-to-level1", ("level2_to_level1", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level2ToLevel1))])
                                    self._leafs = OrderedDict()

                                    self.level1_to_level2 = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level1ToLevel2()
                                    self.level1_to_level2.parent = self
                                    self._children_name_map["level1_to_level2"] = "level1-to-level2"

                                    self.level2_to_level1 = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level2ToLevel1()
                                    self.level2_to_level1.parent = self
                                    self._children_name_map["level2_to_level1"] = "level2-to-level1"
                                    self._segment_path = lambda: "inter-level-propagation-policies"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies, [], name, value)


                                class Level1ToLevel2(Entity):
                                    """
                                    Policies relating to prefixes to be propagated
                                    from Level 1 to Level 2
                                    
                                    .. attribute:: state
                                    
                                    	Operational state parameters relating to the propagation of prefixes from IS\-IS Level 1 to Level 2
                                    	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level1ToLevel2.State>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level1ToLevel2, self).__init__()

                                        self.yang_name = "level1-to-level2"
                                        self.yang_parent_name = "inter-level-propagation-policies"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level1ToLevel2.State))])
                                        self._leafs = OrderedDict()

                                        self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level1ToLevel2.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._segment_path = lambda: "level1-to-level2"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level1ToLevel2, [], name, value)


                                    class State(Entity):
                                        """
                                        Operational state parameters relating to the
                                        propagation of prefixes from IS\-IS Level 1 to
                                        Level 2
                                        
                                        .. attribute:: import_policy
                                        
                                        	list of policy names in sequence to be applied on receiving a routing update in the current context, e
                                        	**type**\: list of str
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level1ToLevel2.State, self).__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "level1-to-level2"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('import_policy', (YLeafList(YType.str, 'import-policy'), ['str'])),
                                            ])
                                            self.import_policy = []
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level1ToLevel2.State, [u'import_policy'], name, value)


                                class Level2ToLevel1(Entity):
                                    """
                                    Policies relating to prefixes to be propagated
                                    from Level2 to Level 1
                                    
                                    .. attribute:: state
                                    
                                    	Operational state parameters relating to the propagation of prefixes from IS\-IS Level 2 to Level 1
                                    	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level2ToLevel1.State>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level2ToLevel1, self).__init__()

                                        self.yang_name = "level2-to-level1"
                                        self.yang_parent_name = "inter-level-propagation-policies"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level2ToLevel1.State))])
                                        self._leafs = OrderedDict()

                                        self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level2ToLevel1.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._segment_path = lambda: "level2-to-level1"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level2ToLevel1, [], name, value)


                                    class State(Entity):
                                        """
                                        Operational state parameters relating to the
                                        propagation of prefixes from IS\-IS Level 2 to
                                        Level 1
                                        
                                        .. attribute:: import_policy
                                        
                                        	list of policy names in sequence to be applied on receiving a routing update in the current context, e
                                        	**type**\: list of str
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level2ToLevel1.State, self).__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "level2-to-level1"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('import_policy', (YLeafList(YType.str, 'import-policy'), ['str'])),
                                            ])
                                            self.import_policy = []
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level2ToLevel1.State, [u'import_policy'], name, value)


                            class AfiSafis(Entity):
                                """
                                Address\-family/Subsequent Address\-family
                                list
                                
                                .. attribute:: afi_safi
                                
                                	Address\-family/Subsequent Address\-family list
                                	**type**\: list of  		 :py:class:`AfiSafi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafis.AfiSafi>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafis, self).__init__()

                                    self.yang_name = "afi-safis"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("afi-safi", ("afi_safi", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafis.AfiSafi))])
                                    self._leafs = OrderedDict()

                                    self.afi_safi = YList(self)
                                    self._segment_path = lambda: "afi-safis"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafis, [], name, value)


                                class AfiSafi(Entity):
                                    """
                                    Address\-family/Subsequent Address\-family
                                    list
                                    
                                    .. attribute:: afi_name
                                    
                                    	Reference to address\-family type
                                    	**type**\: str
                                    
                                    .. attribute:: safi_name
                                    
                                    	Reference to subsequent address\-family type
                                    	**type**\: str
                                    
                                    .. attribute:: state
                                    
                                    	This container defines AFI\-SAFI State information
                                    	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafis.AfiSafi.State>`
                                    
                                    .. attribute:: multi_topology
                                    
                                    	This container defines multi\-topology address\-family configuration and state information
                                    	**type**\:  :py:class:`MultiTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafis.AfiSafi.MultiTopology>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafis.AfiSafi, self).__init__()

                                        self.yang_name = "afi-safi"
                                        self.yang_parent_name = "afi-safis"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafis.AfiSafi.State)), ("multi-topology", ("multi_topology", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafis.AfiSafi.MultiTopology))])
                                        self._leafs = OrderedDict([
                                            ('afi_name', (YLeaf(YType.str, 'afi-name'), ['str'])),
                                            ('safi_name', (YLeaf(YType.str, 'safi-name'), ['str'])),
                                        ])
                                        self.afi_name = None
                                        self.safi_name = None

                                        self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafis.AfiSafi.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"

                                        self.multi_topology = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafis.AfiSafi.MultiTopology()
                                        self.multi_topology.parent = self
                                        self._children_name_map["multi_topology"] = "multi-topology"
                                        self._segment_path = lambda: "afi-safi"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafis.AfiSafi, ['afi_name', 'safi_name'], name, value)


                                    class State(Entity):
                                        """
                                        This container defines AFI\-SAFI State
                                        information
                                        
                                        .. attribute:: afi_name
                                        
                                        	Address\-family type
                                        	**type**\: str
                                        
                                        .. attribute:: safi_name
                                        
                                        	Subsequent address\-family type
                                        	**type**\: str
                                        
                                        .. attribute:: metric
                                        
                                        	ISIS metric value(default=10)
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: enabled
                                        
                                        	When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafis.AfiSafi.State, self).__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi_name', (YLeaf(YType.str, 'afi-name'), ['str'])),
                                                ('safi_name', (YLeaf(YType.str, 'safi-name'), ['str'])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                            ])
                                            self.afi_name = None
                                            self.safi_name = None
                                            self.metric = None
                                            self.enabled = None
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafis.AfiSafi.State, [u'afi_name', u'safi_name', u'metric', u'enabled'], name, value)


                                    class MultiTopology(Entity):
                                        """
                                        This container defines multi\-topology
                                        address\-family configuration and state
                                        information
                                        
                                        .. attribute:: state
                                        
                                        	This container defines AFI\-SAFI multi\-topology state information
                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafis.AfiSafi.MultiTopology.State>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafis.AfiSafi.MultiTopology, self).__init__()

                                            self.yang_name = "multi-topology"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafis.AfiSafi.MultiTopology.State))])
                                            self._leafs = OrderedDict()

                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafis.AfiSafi.MultiTopology.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._segment_path = lambda: "multi-topology"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafis.AfiSafi.MultiTopology, [], name, value)


                                        class State(Entity):
                                            """
                                            This container defines AFI\-SAFI multi\-topology
                                            state information
                                            
                                            .. attribute:: afi_name
                                            
                                            	Address\-family type
                                            	**type**\: str
                                            
                                            .. attribute:: safi_name
                                            
                                            	Subsequent address\-family type
                                            	**type**\: str
                                            
                                            .. attribute:: enabled
                                            
                                            	When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafis.AfiSafi.MultiTopology.State, self).__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "multi-topology"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('afi_name', (YLeaf(YType.str, 'afi-name'), ['str'])),
                                                    ('safi_name', (YLeaf(YType.str, 'safi-name'), ['str'])),
                                                    ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                                ])
                                                self.afi_name = None
                                                self.safi_name = None
                                                self.enabled = None
                                                self._segment_path = lambda: "state"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafis.AfiSafi.MultiTopology.State, [u'afi_name', u'safi_name', u'enabled'], name, value)


                            class Timers(Entity):
                                """
                                This container defines ISIS timers
                                
                                .. attribute:: state
                                
                                	This container defines state information for ISIS global timers
                                	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.State>`
                                
                                .. attribute:: spf
                                
                                	This container defines ISIS SPF timer settings
                                	**type**\:  :py:class:`Spf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Spf>`
                                
                                .. attribute:: lsp_generation
                                
                                	This container defines ISIS LSP Generation
                                	**type**\:  :py:class:`LspGeneration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.LspGeneration>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers, self).__init__()

                                    self.yang_name = "timers"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.State)), ("spf", ("spf", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Spf)), ("lsp-generation", ("lsp_generation", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.LspGeneration))])
                                    self._leafs = OrderedDict()

                                    self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"

                                    self.spf = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Spf()
                                    self.spf.parent = self
                                    self._children_name_map["spf"] = "spf"

                                    self.lsp_generation = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.LspGeneration()
                                    self.lsp_generation.parent = self
                                    self._children_name_map["lsp_generation"] = "lsp-generation"
                                    self._segment_path = lambda: "timers"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers, [], name, value)


                                class State(Entity):
                                    """
                                    This container defines state information for
                                    ISIS global timers
                                    
                                    .. attribute:: lsp_lifetime_interval
                                    
                                    	Time interval in seconds that specifies how long an LSP remains in LSDB without being refreshed
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: lsp_refresh_interval
                                    
                                    	Time interval in seconds that specifies how often route topology that a device originates is transmitted in LSPs
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: second
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "timers"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lsp_lifetime_interval', (YLeaf(YType.uint16, 'lsp-lifetime-interval'), ['int'])),
                                            ('lsp_refresh_interval', (YLeaf(YType.uint16, 'lsp-refresh-interval'), ['int'])),
                                        ])
                                        self.lsp_lifetime_interval = None
                                        self.lsp_refresh_interval = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.State, [u'lsp_lifetime_interval', u'lsp_refresh_interval'], name, value)


                                class Spf(Entity):
                                    """
                                    This container defines ISIS SPF timer settings
                                    
                                    .. attribute:: state
                                    
                                    	This container defines state information for ISIS SPF timers
                                    	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Spf.State>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Spf, self).__init__()

                                        self.yang_name = "spf"
                                        self.yang_parent_name = "timers"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Spf.State))])
                                        self._leafs = OrderedDict()

                                        self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Spf.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._segment_path = lambda: "spf"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Spf, [], name, value)


                                    class State(Entity):
                                        """
                                        This container defines state information for
                                        ISIS SPF timers
                                        
                                        .. attribute:: spf_hold_interval
                                        
                                        	SPF Hold Down time interval in milliseconds
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: spf_first_interval
                                        
                                        	Time interval in milliseconds between the detection of topology change and when the SPF algorithm runs
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: spf_second_interval
                                        
                                        	Time interval in milliseconds between the first and second SPF calculation
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: adaptive_timer
                                        
                                        	ISIS adaptive timer types (linear, exponential)
                                        	**type**\:  :py:class:`OpenconfigIsisTypesAdaptiveTimerTypeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisTypesAdaptiveTimerTypeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Spf.State, self).__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "spf"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('spf_hold_interval', (YLeaf(YType.uint64, 'spf-hold-interval'), ['int'])),
                                                ('spf_first_interval', (YLeaf(YType.uint64, 'spf-first-interval'), ['int'])),
                                                ('spf_second_interval', (YLeaf(YType.uint64, 'spf-second-interval'), ['int'])),
                                                ('adaptive_timer', (YLeaf(YType.enumeration, 'adaptive-timer'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisTypesAdaptiveTimerTypeEnum', '')])),
                                            ])
                                            self.spf_hold_interval = None
                                            self.spf_first_interval = None
                                            self.spf_second_interval = None
                                            self.adaptive_timer = None
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Spf.State, [u'spf_hold_interval', u'spf_first_interval', u'spf_second_interval', u'adaptive_timer'], name, value)


                                class LspGeneration(Entity):
                                    """
                                    This container defines ISIS LSP Generation
                                    
                                    .. attribute:: state
                                    
                                    	This container defines state information for ISIS LSP Generation timers
                                    	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.LspGeneration.State>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.LspGeneration, self).__init__()

                                        self.yang_name = "lsp-generation"
                                        self.yang_parent_name = "timers"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.LspGeneration.State))])
                                        self._leafs = OrderedDict()

                                        self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.LspGeneration.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._segment_path = lambda: "lsp-generation"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.LspGeneration, [], name, value)


                                    class State(Entity):
                                        """
                                        This container defines state information for
                                        ISIS LSP Generation timers
                                        
                                        .. attribute:: lsp_max_wait_interval
                                        
                                        	Time interval in milliseconds that specifies max interval between two consecutive occurrences of an LSP being generated
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: lsp_first_wait_interval
                                        
                                        	Time interval in milliseconds that specifies the first LSP generation delay
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: lsp_second_wait_interval
                                        
                                        	Time interval in milliseconds that specifies the millisecond LSP generation delay
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: millisecond
                                        
                                        .. attribute:: adaptive_timer
                                        
                                        	ISIS adaptive timer types (linear, exponential)
                                        	**type**\:  :py:class:`OpenconfigIsisTypesAdaptiveTimerTypeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisTypesAdaptiveTimerTypeEnum>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.LspGeneration.State, self).__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "lsp-generation"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsp_max_wait_interval', (YLeaf(YType.uint64, 'lsp-max-wait-interval'), ['int'])),
                                                ('lsp_first_wait_interval', (YLeaf(YType.uint64, 'lsp-first-wait-interval'), ['int'])),
                                                ('lsp_second_wait_interval', (YLeaf(YType.uint64, 'lsp-second-wait-interval'), ['int'])),
                                                ('adaptive_timer', (YLeaf(YType.enumeration, 'adaptive-timer'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisTypesAdaptiveTimerTypeEnum', '')])),
                                            ])
                                            self.lsp_max_wait_interval = None
                                            self.lsp_first_wait_interval = None
                                            self.lsp_second_wait_interval = None
                                            self.adaptive_timer = None
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.LspGeneration.State, [u'lsp_max_wait_interval', u'lsp_first_wait_interval', u'lsp_second_wait_interval', u'adaptive_timer'], name, value)


                            class Transport(Entity):
                                """
                                This container defines ISIS transport
                                
                                .. attribute:: state
                                
                                	This container defines state information for ISIS transport parameters
                                	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Transport.State>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Transport, self).__init__()

                                    self.yang_name = "transport"
                                    self.yang_parent_name = "global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Transport.State))])
                                    self._leafs = OrderedDict()

                                    self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Transport.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "transport"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Transport, [], name, value)


                                class State(Entity):
                                    """
                                    This container defines state information for
                                    ISIS transport parameters
                                    
                                    .. attribute:: lsp_mtu_size
                                    
                                    	The maximum size in bytes of an IS\-IS Link state PDU
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Transport.State, self).__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "transport"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lsp_mtu_size', (YLeaf(YType.uint16, 'lsp-mtu-size'), ['int'])),
                                        ])
                                        self.lsp_mtu_size = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Transport.State, [u'lsp_mtu_size'], name, value)


                        class Levels(Entity):
                            """
                            Configuration and operational state
                            parameters related to a particular level
                            within the IS\-IS protocol instance
                            
                            .. attribute:: level
                            
                            	Configuration and operational state parameters related to a particular level within the IS\-IS protocol instance
                            	**type**\: list of  		 :py:class:`Level <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels, self).__init__()

                                self.yang_name = "levels"
                                self.yang_parent_name = "isis"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("level", ("level", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level))])
                                self._leafs = OrderedDict()

                                self.level = YList(self)
                                self._segment_path = lambda: "levels"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels, [], name, value)


                            class Level(Entity):
                                """
                                Configuration and operational state
                                parameters related to a particular level
                                within the IS\-IS protocol instance
                                
                                .. attribute:: level_number  (key)
                                
                                	Reference to ISIS level\-number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: route_preference
                                
                                	This container defines Administrative Distance (or preference) assigned to ISIS routes (level1 internal, level2 internal, level1 external, level2 external)
                                	**type**\:  :py:class:`RoutePreference <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.RoutePreference>`
                                
                                .. attribute:: levels_state
                                
                                	This container defines ISIS level state information
                                	**type**\:  :py:class:`LevelsState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LevelsState>`
                                
                                .. attribute:: traffic_engineering
                                
                                	This container defines ISIS TE
                                	**type**\:  :py:class:`TrafficEngineering <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.TrafficEngineering>`
                                
                                .. attribute:: levels_authentication
                                
                                	This container defines ISIS authentication
                                	**type**\:  :py:class:`LevelsAuthentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LevelsAuthentication>`
                                
                                .. attribute:: system_level_counters
                                
                                	This container defines ISIS system level counters
                                	**type**\:  :py:class:`SystemLevelCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.SystemLevelCounters>`
                                
                                .. attribute:: link_state_databases
                                
                                	This list describes LSPs in the LSDB
                                	**type**\:  :py:class:`LinkStateDatabases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level, self).__init__()

                                    self.yang_name = "level"
                                    self.yang_parent_name = "levels"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['level_number']
                                    self._child_classes = OrderedDict([("route-preference", ("route_preference", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.RoutePreference)), ("levels-state", ("levels_state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LevelsState)), ("traffic-engineering", ("traffic_engineering", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.TrafficEngineering)), ("levels-authentication", ("levels_authentication", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LevelsAuthentication)), ("system-level-counters", ("system_level_counters", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.SystemLevelCounters)), ("link-state-databases", ("link_state_databases", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases))])
                                    self._leafs = OrderedDict([
                                        ('level_number', (YLeaf(YType.uint32, 'level-number'), ['int'])),
                                    ])
                                    self.level_number = None

                                    self.route_preference = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.RoutePreference()
                                    self.route_preference.parent = self
                                    self._children_name_map["route_preference"] = "route-preference"

                                    self.levels_state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LevelsState()
                                    self.levels_state.parent = self
                                    self._children_name_map["levels_state"] = "levels-state"

                                    self.traffic_engineering = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.TrafficEngineering()
                                    self.traffic_engineering.parent = self
                                    self._children_name_map["traffic_engineering"] = "traffic-engineering"

                                    self.levels_authentication = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LevelsAuthentication()
                                    self.levels_authentication.parent = self
                                    self._children_name_map["levels_authentication"] = "levels-authentication"

                                    self.system_level_counters = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.SystemLevelCounters()
                                    self.system_level_counters.parent = self
                                    self._children_name_map["system_level_counters"] = "system-level-counters"

                                    self.link_state_databases = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases()
                                    self.link_state_databases.parent = self
                                    self._children_name_map["link_state_databases"] = "link-state-databases"
                                    self._segment_path = lambda: "level" + "[level-number='" + str(self.level_number) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level, ['level_number'], name, value)


                                class RoutePreference(Entity):
                                    """
                                    This container defines Administrative
                                    Distance (or preference) assigned to ISIS
                                    routes (level1 internal, level2 internal,
                                    level1 external, level2 external)
                                    
                                    .. attribute:: state
                                    
                                    	This container defines ISIS route preference state information
                                    	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.RoutePreference.State>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.RoutePreference, self).__init__()

                                        self.yang_name = "route-preference"
                                        self.yang_parent_name = "level"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.RoutePreference.State))])
                                        self._leafs = OrderedDict()

                                        self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.RoutePreference.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._segment_path = lambda: "route-preference"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.RoutePreference, [], name, value)


                                    class State(Entity):
                                        """
                                        This container defines ISIS route preference
                                        state information
                                        
                                        .. attribute:: external_route_preference
                                        
                                        	Administrative Distance(preference) for external ISIS routes
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: internal_route_preference
                                        
                                        	Administrative Distance(preference) for internal ISIS routes
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.RoutePreference.State, self).__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "route-preference"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('external_route_preference', (YLeaf(YType.uint8, 'external-route-preference'), ['int'])),
                                                ('internal_route_preference', (YLeaf(YType.uint8, 'internal-route-preference'), ['int'])),
                                            ])
                                            self.external_route_preference = None
                                            self.internal_route_preference = None
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.RoutePreference.State, [u'external_route_preference', u'internal_route_preference'], name, value)


                                class LevelsState(Entity):
                                    """
                                    This container defines ISIS level state
                                    information
                                    
                                    .. attribute:: level_number
                                    
                                    	ISIS level number (level\-1, level\-2)
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: metric_style
                                    
                                    	ISIS metric style types(narrow, wide)
                                    	**type**\:  :py:class:`OpenconfigIsisTypesMetricStyleEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisTypesMetricStyleEnum>`
                                    
                                    .. attribute:: authentication_check
                                    
                                    	When set to true, reject all ISIS protocol PDUs that either have a mismatch in authentication\-type or authentication\-key
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LevelsState, self).__init__()

                                        self.yang_name = "levels-state"
                                        self.yang_parent_name = "level"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('level_number', (YLeaf(YType.uint8, 'level-number'), ['int'])),
                                            ('metric_style', (YLeaf(YType.enumeration, 'metric-style'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisTypesMetricStyleEnum', '')])),
                                            ('authentication_check', (YLeaf(YType.boolean, 'authentication-check'), ['bool'])),
                                        ])
                                        self.level_number = None
                                        self.metric_style = None
                                        self.authentication_check = None
                                        self._segment_path = lambda: "levels-state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LevelsState, [u'level_number', u'metric_style', u'authentication_check'], name, value)


                                class TrafficEngineering(Entity):
                                    """
                                    This container defines ISIS TE
                                    
                                    .. attribute:: state
                                    
                                    	This container defines ISIS TE state information
                                    	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.TrafficEngineering.State>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.TrafficEngineering, self).__init__()

                                        self.yang_name = "traffic-engineering"
                                        self.yang_parent_name = "level"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.TrafficEngineering.State))])
                                        self._leafs = OrderedDict()

                                        self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.TrafficEngineering.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._segment_path = lambda: "traffic-engineering"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.TrafficEngineering, [], name, value)


                                    class State(Entity):
                                        """
                                        This container defines ISIS TE state information
                                        
                                        .. attribute:: enabled
                                        
                                        	When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: ipv4_router_id
                                        
                                        	IPv4 MPLS Traffic Engineering Router\-ID
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_router_id
                                        
                                        	IPv6 MPLS Traffic Engineering Router\-ID
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.TrafficEngineering.State, self).__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "traffic-engineering"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                                ('ipv4_router_id', (YLeaf(YType.str, 'ipv4-router-id'), ['str'])),
                                                ('ipv6_router_id', (YLeaf(YType.str, 'ipv6-router-id'), ['str'])),
                                            ])
                                            self.enabled = None
                                            self.ipv4_router_id = None
                                            self.ipv6_router_id = None
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.TrafficEngineering.State, [u'enabled', u'ipv4_router_id', u'ipv6_router_id'], name, value)


                                class LevelsAuthentication(Entity):
                                    """
                                    This container defines ISIS
                                    authentication
                                    
                                    .. attribute:: key
                                    
                                    	This container defines ISIS authentication key
                                    	**type**\:  :py:class:`Key <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LevelsAuthentication.Key>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LevelsAuthentication, self).__init__()

                                        self.yang_name = "levels-authentication"
                                        self.yang_parent_name = "level"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("key", ("key", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LevelsAuthentication.Key))])
                                        self._leafs = OrderedDict()

                                        self.key = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LevelsAuthentication.Key()
                                        self.key.parent = self
                                        self._children_name_map["key"] = "key"
                                        self._segment_path = lambda: "levels-authentication"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LevelsAuthentication, [], name, value)


                                    class Key(Entity):
                                        """
                                        This container defines ISIS authentication key
                                        
                                        .. attribute:: state
                                        
                                        	This container defines ISIS authentication key state
                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LevelsAuthentication.Key.State>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LevelsAuthentication.Key, self).__init__()

                                            self.yang_name = "key"
                                            self.yang_parent_name = "levels-authentication"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LevelsAuthentication.Key.State))])
                                            self._leafs = OrderedDict()

                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LevelsAuthentication.Key.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._segment_path = lambda: "key"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LevelsAuthentication.Key, [], name, value)


                                        class State(Entity):
                                            """
                                            This container defines ISIS authentication key
                                            state
                                            
                                            .. attribute:: auth_password
                                            
                                            	Authentication key string
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LevelsAuthentication.Key.State, self).__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "key"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('auth_password', (YLeaf(YType.str, 'auth-password'), ['str'])),
                                                ])
                                                self.auth_password = None
                                                self._segment_path = lambda: "state"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LevelsAuthentication.Key.State, [u'auth_password'], name, value)


                                class SystemLevelCounters(Entity):
                                    """
                                    This container defines ISIS system level
                                    counters
                                    
                                    .. attribute:: state
                                    
                                    	The container defines a list of system counters for the IS
                                    	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.SystemLevelCounters.State>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.SystemLevelCounters, self).__init__()

                                        self.yang_name = "system-level-counters"
                                        self.yang_parent_name = "level"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.SystemLevelCounters.State))])
                                        self._leafs = OrderedDict()

                                        self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.SystemLevelCounters.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._segment_path = lambda: "system-level-counters"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.SystemLevelCounters, [], name, value)


                                    class State(Entity):
                                        """
                                        The container defines a list of system counters
                                        for the IS
                                        
                                        .. attribute:: corrupted_lsps
                                        
                                        	Number of corrupted in\-memory LSPs detected
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: database_overloads
                                        
                                        	Number of times the database has become overloaded
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: exceed_max_seq_nums
                                        
                                        	The number of times the system has attempted to exceed the maximum sequence number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: seq_num_skips
                                        
                                        	Number of times a sequence number skip has occurred
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: own_lsp_purges
                                        
                                        	Number of times a zero\-aged copy of the system's own LSP is received from some other node
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: id_len_mismatch
                                        
                                        	Number of times a PDU is received with a different value for ID field length from that of the receiving system
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: max_area_address_mismatches
                                        
                                        	Number of times a PDU is received with a different value for MaximumAreaAddresses from that of the receiving system
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: spf_runs
                                        
                                        	The number of times SPF was ran at this level
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: lsp_errors
                                        
                                        	The number of received LSPs with errors
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.SystemLevelCounters.State, self).__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "system-level-counters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('corrupted_lsps', (YLeaf(YType.uint32, 'corrupted-lsps'), ['int'])),
                                                ('database_overloads', (YLeaf(YType.uint32, 'database-overloads'), ['int'])),
                                                ('exceed_max_seq_nums', (YLeaf(YType.uint32, 'exceed-max-seq-nums'), ['int'])),
                                                ('seq_num_skips', (YLeaf(YType.uint32, 'seq-num-skips'), ['int'])),
                                                ('own_lsp_purges', (YLeaf(YType.uint32, 'own-lsp-purges'), ['int'])),
                                                ('id_len_mismatch', (YLeaf(YType.uint32, 'id-len-mismatch'), ['int'])),
                                                ('max_area_address_mismatches', (YLeaf(YType.uint32, 'max-area-address-mismatches'), ['int'])),
                                                ('spf_runs', (YLeaf(YType.uint32, 'spf-runs'), ['int'])),
                                                ('lsp_errors', (YLeaf(YType.uint32, 'lsp-errors'), ['int'])),
                                            ])
                                            self.corrupted_lsps = None
                                            self.database_overloads = None
                                            self.exceed_max_seq_nums = None
                                            self.seq_num_skips = None
                                            self.own_lsp_purges = None
                                            self.id_len_mismatch = None
                                            self.max_area_address_mismatches = None
                                            self.spf_runs = None
                                            self.lsp_errors = None
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.SystemLevelCounters.State, [u'corrupted_lsps', u'database_overloads', u'exceed_max_seq_nums', u'seq_num_skips', u'own_lsp_purges', u'id_len_mismatch', u'max_area_address_mismatches', u'spf_runs', u'lsp_errors'], name, value)


                                class LinkStateDatabases(Entity):
                                    """
                                    This list describes LSPs in the LSDB
                                    
                                    .. attribute:: link_state_database
                                    
                                    	This list describes LSPs in the LSDB
                                    	**type**\: list of  		 :py:class:`LinkStateDatabase <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases, self).__init__()

                                        self.yang_name = "link-state-databases"
                                        self.yang_parent_name = "level"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("link-state-database", ("link_state_database", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase))])
                                        self._leafs = OrderedDict()

                                        self.link_state_database = YList(self)
                                        self._segment_path = lambda: "link-state-databases"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases, [], name, value)


                                    class LinkStateDatabase(Entity):
                                        """
                                        This list describes LSPs in the LSDB
                                        
                                        .. attribute:: lsp_id  (key)
                                        
                                        	A reference to the Link State PDU ID
                                        	**type**\: str
                                        
                                        .. attribute:: undefined_tlvs
                                        
                                        	List of TLVs that are not defined within the model, or are not recognised by the system
                                        	**type**\:  :py:class:`UndefinedTlvs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.UndefinedTlvs>`
                                        
                                        .. attribute:: link_state_database_state
                                        
                                        	State parameters of Link State PDU
                                        	**type**\:  :py:class:`LinkStateDatabaseState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.LinkStateDatabaseState>`
                                        
                                        .. attribute:: tlvses
                                        
                                        	List of TLV types in the LSDB for the specified LSP
                                        	**type**\:  :py:class:`Tlvses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase, self).__init__()

                                            self.yang_name = "link-state-database"
                                            self.yang_parent_name = "link-state-databases"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['lsp_id']
                                            self._child_classes = OrderedDict([("undefined-tlvs", ("undefined_tlvs", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.UndefinedTlvs)), ("link-state-database-state", ("link_state_database_state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.LinkStateDatabaseState)), ("tlvses", ("tlvses", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses))])
                                            self._leafs = OrderedDict([
                                                ('lsp_id', (YLeaf(YType.str, 'lsp-id'), ['str'])),
                                            ])
                                            self.lsp_id = None

                                            self.undefined_tlvs = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.UndefinedTlvs()
                                            self.undefined_tlvs.parent = self
                                            self._children_name_map["undefined_tlvs"] = "undefined-tlvs"

                                            self.link_state_database_state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.LinkStateDatabaseState()
                                            self.link_state_database_state.parent = self
                                            self._children_name_map["link_state_database_state"] = "link-state-database-state"

                                            self.tlvses = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses()
                                            self.tlvses.parent = self
                                            self._children_name_map["tlvses"] = "tlvses"
                                            self._segment_path = lambda: "link-state-database" + "[lsp-id='" + str(self.lsp_id) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase, ['lsp_id'], name, value)


                                        class UndefinedTlvs(Entity):
                                            """
                                            List of TLVs that are not defined
                                            within the model, or are not recognised
                                            by the system
                                            
                                            .. attribute:: undefined_tlv
                                            
                                            	List of TLVs that are not defined within the model, or are not recognised by the system
                                            	**type**\: list of  		 :py:class:`UndefinedTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.UndefinedTlvs.UndefinedTlv>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.UndefinedTlvs, self).__init__()

                                                self.yang_name = "undefined-tlvs"
                                                self.yang_parent_name = "link-state-database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("undefined-tlv", ("undefined_tlv", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.UndefinedTlvs.UndefinedTlv))])
                                                self._leafs = OrderedDict()

                                                self.undefined_tlv = YList(self)
                                                self._segment_path = lambda: "undefined-tlvs"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.UndefinedTlvs, [], name, value)


                                            class UndefinedTlv(Entity):
                                                """
                                                List of TLVs that are not defined
                                                within the model, or are not
                                                recognised by the system
                                                
                                                .. attribute:: type  (key)
                                                
                                                	Reference to the undefined TLV's type
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: state
                                                
                                                	State parameters of the undefined TLV
                                                	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.UndefinedTlvs.UndefinedTlv.State>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.UndefinedTlvs.UndefinedTlv, self).__init__()

                                                    self.yang_name = "undefined-tlv"
                                                    self.yang_parent_name = "undefined-tlvs"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['type']
                                                    self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.UndefinedTlvs.UndefinedTlv.State))])
                                                    self._leafs = OrderedDict([
                                                        ('type', (YLeaf(YType.uint32, 'type'), ['int'])),
                                                    ])
                                                    self.type = None

                                                    self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.UndefinedTlvs.UndefinedTlv.State()
                                                    self.state.parent = self
                                                    self._children_name_map["state"] = "state"
                                                    self._segment_path = lambda: "undefined-tlv" + "[type='" + str(self.type) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.UndefinedTlvs.UndefinedTlv, ['type'], name, value)


                                                class State(Entity):
                                                    """
                                                    State parameters of the undefined TLV
                                                    
                                                    .. attribute:: type
                                                    
                                                    	TLV Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: length
                                                    
                                                    	TLV length
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: value
                                                    
                                                    	TLV value
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.UndefinedTlvs.UndefinedTlv.State, self).__init__()

                                                        self.yang_name = "state"
                                                        self.yang_parent_name = "undefined-tlv"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                            ('length', (YLeaf(YType.uint8, 'length'), ['int'])),
                                                            ('value', (YLeaf(YType.str, 'value'), ['str'])),
                                                        ])
                                                        self.type = None
                                                        self.length = None
                                                        self.value = None
                                                        self._segment_path = lambda: "state"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.UndefinedTlvs.UndefinedTlv.State, [u'type', u'length', u'value'], name, value)


                                        class LinkStateDatabaseState(Entity):
                                            """
                                            State parameters of Link State PDU
                                            
                                            .. attribute:: lsp_id
                                            
                                            	LSP ID of the LSP
                                            	**type**\: str
                                            
                                            .. attribute:: maximum_area_addresses
                                            
                                            	Number of area addresses permitted for this ISs area
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: version
                                            
                                            	PDU version
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: version2
                                            
                                            	PDU version2
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: id_length
                                            
                                            	Length of the ID field of NSAP addresses and NETs used in this routing domain
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: pdu_type
                                            
                                            	Link State PDU type
                                            	**type**\:  :py:class:`OpenconfigIsisLspPduTypeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisLspPduTypeEnum>`
                                            
                                            .. attribute:: remaining_lifetime
                                            
                                            	Remaining lifetime in seconds before the LSP expiration
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: sequence_number
                                            
                                            	Sequence number of the LSP
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: checksum
                                            
                                            	Checksum of the LSP
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: pdu_length
                                            
                                            	Total length of the LSP
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: is_type
                                            
                                            	Type of neighboring system
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: flags
                                            
                                            	LSP Type\-Block flags
                                            	**type**\: list of   :py:class:`OpenconfigIsisLspFlagsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisLspFlagsEnum>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.LinkStateDatabaseState, self).__init__()

                                                self.yang_name = "link-state-database-state"
                                                self.yang_parent_name = "link-state-database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lsp_id', (YLeaf(YType.str, 'lsp-id'), ['str'])),
                                                    ('maximum_area_addresses', (YLeaf(YType.uint8, 'maximum-area-addresses'), ['int'])),
                                                    ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                                                    ('version2', (YLeaf(YType.uint8, 'version2'), ['int'])),
                                                    ('id_length', (YLeaf(YType.uint8, 'id-length'), ['int'])),
                                                    ('pdu_type', (YLeaf(YType.enumeration, 'pdu-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisLspPduTypeEnum', '')])),
                                                    ('remaining_lifetime', (YLeaf(YType.uint16, 'remaining-lifetime'), ['int'])),
                                                    ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                    ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                    ('pdu_length', (YLeaf(YType.uint16, 'pdu-length'), ['int'])),
                                                    ('is_type', (YLeaf(YType.uint8, 'is-type'), ['int'])),
                                                    ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisLspFlagsEnum', '')])),
                                                ])
                                                self.lsp_id = None
                                                self.maximum_area_addresses = None
                                                self.version = None
                                                self.version2 = None
                                                self.id_length = None
                                                self.pdu_type = None
                                                self.remaining_lifetime = None
                                                self.sequence_number = None
                                                self.checksum = None
                                                self.pdu_length = None
                                                self.is_type = None
                                                self.flags = []
                                                self._segment_path = lambda: "link-state-database-state"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.LinkStateDatabaseState, [u'lsp_id', u'maximum_area_addresses', u'version', u'version2', u'id_length', u'pdu_type', u'remaining_lifetime', u'sequence_number', u'checksum', u'pdu_length', u'is_type', u'flags'], name, value)


                                        class Tlvses(Entity):
                                            """
                                            List of TLV types in the LSDB for the
                                            specified LSP
                                            
                                            .. attribute:: tlvs
                                            
                                            	List of TLV types in the LSDB for the specified LSP
                                            	**type**\: list of  		 :py:class:`Tlvs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses, self).__init__()

                                                self.yang_name = "tlvses"
                                                self.yang_parent_name = "link-state-database"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tlvs", ("tlvs", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs))])
                                                self._leafs = OrderedDict()

                                                self.tlvs = YList(self)
                                                self._segment_path = lambda: "tlvses"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses, [], name, value)


                                            class Tlvs(Entity):
                                                """
                                                List of TLV types in the LSDB for the
                                                specified LSP
                                                
                                                .. attribute:: type  (key)
                                                
                                                	Reference to the TLV's type
                                                	**type**\: str
                                                
                                                .. attribute:: area_address
                                                
                                                	This container defines TLV 1
                                                	**type**\:  :py:class:`AreaAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.AreaAddress>`
                                                
                                                .. attribute:: authentication
                                                
                                                	This container defines authentication information of the node
                                                	**type**\:  :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Authentication>`
                                                
                                                .. attribute:: ipv4_interface_addresses
                                                
                                                	This container defines TLV 132
                                                	**type**\:  :py:class:`Ipv4InterfaceAddresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InterfaceAddresses>`
                                                
                                                .. attribute:: router_capabilities
                                                
                                                	This list describes IS Router capabilities
                                                	**type**\:  :py:class:`RouterCapabilities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities>`
                                                
                                                .. attribute:: mt_ipv4_reachability
                                                
                                                	This container defines list of IPv4 reachability Information in multi\-topology environment
                                                	**type**\:  :py:class:`MtIpv4Reachability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability>`
                                                
                                                .. attribute:: mt_isn
                                                
                                                	This container defines list of ISIS multi\-topology neighbors
                                                	**type**\:  :py:class:`MtIsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn>`
                                                
                                                .. attribute:: ipv6_srlgs
                                                
                                                	Instance of the IPv6 SRLG TLV
                                                	**type**\:  :py:class:`Ipv6Srlgs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Srlgs>`
                                                
                                                .. attribute:: tlvs_state
                                                
                                                	Operational state parameters relating to the specified LSP
                                                	**type**\:  :py:class:`TlvsState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.TlvsState>`
                                                
                                                .. attribute:: purge_oi
                                                
                                                	This container defines ISIS purge TLV
                                                	**type**\:  :py:class:`PurgeOi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.PurgeOi>`
                                                
                                                .. attribute:: host_name
                                                
                                                	This container defines TLV 137
                                                	**type**\:  :py:class:`HostName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.HostName>`
                                                
                                                .. attribute:: ipv6_reachability
                                                
                                                	This container defines list of IPv6 reachability information
                                                	**type**\:  :py:class:`Ipv6Reachability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability>`
                                                
                                                .. attribute:: ipv6_te_router_id
                                                
                                                	This container defines TLV 140
                                                	**type**\:  :py:class:`Ipv6TeRouterId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6TeRouterId>`
                                                
                                                .. attribute:: ipv4_internal_reachability
                                                
                                                	This container defines list of IPv4 internal reachability information
                                                	**type**\:  :py:class:`Ipv4InternalReachability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability>`
                                                
                                                .. attribute:: ipv6_interface_addresses
                                                
                                                	This container defines TLV 232
                                                	**type**\:  :py:class:`Ipv6InterfaceAddresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6InterfaceAddresses>`
                                                
                                                .. attribute:: extended_is_reachability
                                                
                                                	This container defines list of ISIS extended reachability neighbors
                                                	**type**\:  :py:class:`ExtendedIsReachability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability>`
                                                
                                                .. attribute:: instance_ids
                                                
                                                	A list of instance IDs received within TLV 7 within an IS\-IS LSP
                                                	**type**\:  :py:class:`InstanceIds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.InstanceIds>`
                                                
                                                .. attribute:: ipv4_srlgs
                                                
                                                	Instance of the IPv4 SRLG TLV
                                                	**type**\:  :py:class:`Ipv4Srlgs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4Srlgs>`
                                                
                                                .. attribute:: is_reachability
                                                
                                                	This container describes list of ISIS neighbors and attributes
                                                	**type**\:  :py:class:`IsReachability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability>`
                                                
                                                .. attribute:: ipv4_te_router_id
                                                
                                                	This container defines TLV 134
                                                	**type**\:  :py:class:`Ipv4TeRouterId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4TeRouterId>`
                                                
                                                .. attribute:: nlpid
                                                
                                                	This container defines TLV 129
                                                	**type**\:  :py:class:`Nlpid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Nlpid>`
                                                
                                                .. attribute:: extended_ipv4_reachability
                                                
                                                	This container defines list of IPv4 extended reachability information
                                                	**type**\:  :py:class:`ExtendedIpv4Reachability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability>`
                                                
                                                .. attribute:: multi_topology
                                                
                                                	This container defines the topology supported
                                                	**type**\:  :py:class:`MultiTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MultiTopology>`
                                                
                                                .. attribute:: ipv4_external_reachability
                                                
                                                	This container defines list of IPv4 external reachability information
                                                	**type**\:  :py:class:`Ipv4ExternalReachability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability>`
                                                
                                                .. attribute:: mt_ipv6_reachability
                                                
                                                	This container defines list of IPv6 reachability information in multi \- topology environment
                                                	**type**\:  :py:class:`MtIpv6Reachability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs, self).__init__()

                                                    self.yang_name = "tlvs"
                                                    self.yang_parent_name = "tlvses"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['type']
                                                    self._child_classes = OrderedDict([("area-address", ("area_address", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.AreaAddress)), ("authentication", ("authentication", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Authentication)), ("ipv4-interface-addresses", ("ipv4_interface_addresses", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InterfaceAddresses)), ("router-capabilities", ("router_capabilities", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities)), ("mt-ipv4-reachability", ("mt_ipv4_reachability", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability)), ("mt-isn", ("mt_isn", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn)), ("ipv6-srlgs", ("ipv6_srlgs", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Srlgs)), ("tlvs-state", ("tlvs_state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.TlvsState)), ("purge-oi", ("purge_oi", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.PurgeOi)), ("host-name", ("host_name", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.HostName)), ("ipv6-reachability", ("ipv6_reachability", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability)), ("ipv6-te-router-id", ("ipv6_te_router_id", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6TeRouterId)), ("ipv4-internal-reachability", ("ipv4_internal_reachability", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability)), ("ipv6-interface-addresses", ("ipv6_interface_addresses", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6InterfaceAddresses)), ("extended-is-reachability", ("extended_is_reachability", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability)), ("instance-ids", ("instance_ids", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.InstanceIds)), ("ipv4-srlgs", ("ipv4_srlgs", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4Srlgs)), ("is-reachability", ("is_reachability", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability)), ("ipv4-te-router-id", ("ipv4_te_router_id", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4TeRouterId)), ("nlpid", ("nlpid", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Nlpid)), ("extended-ipv4-reachability", ("extended_ipv4_reachability", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability)), ("multi-topology", ("multi_topology", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MultiTopology)), ("ipv4-external-reachability", ("ipv4_external_reachability", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability)), ("mt-ipv6-reachability", ("mt_ipv6_reachability", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability))])
                                                    self._leafs = OrderedDict([
                                                        ('type', (YLeaf(YType.str, 'type'), ['str'])),
                                                    ])
                                                    self.type = None

                                                    self.area_address = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.AreaAddress()
                                                    self.area_address.parent = self
                                                    self._children_name_map["area_address"] = "area-address"

                                                    self.authentication = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Authentication()
                                                    self.authentication.parent = self
                                                    self._children_name_map["authentication"] = "authentication"

                                                    self.ipv4_interface_addresses = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InterfaceAddresses()
                                                    self.ipv4_interface_addresses.parent = self
                                                    self._children_name_map["ipv4_interface_addresses"] = "ipv4-interface-addresses"

                                                    self.router_capabilities = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities()
                                                    self.router_capabilities.parent = self
                                                    self._children_name_map["router_capabilities"] = "router-capabilities"

                                                    self.mt_ipv4_reachability = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability()
                                                    self.mt_ipv4_reachability.parent = self
                                                    self._children_name_map["mt_ipv4_reachability"] = "mt-ipv4-reachability"

                                                    self.mt_isn = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn()
                                                    self.mt_isn.parent = self
                                                    self._children_name_map["mt_isn"] = "mt-isn"

                                                    self.ipv6_srlgs = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Srlgs()
                                                    self.ipv6_srlgs.parent = self
                                                    self._children_name_map["ipv6_srlgs"] = "ipv6-srlgs"

                                                    self.tlvs_state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.TlvsState()
                                                    self.tlvs_state.parent = self
                                                    self._children_name_map["tlvs_state"] = "tlvs-state"

                                                    self.purge_oi = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.PurgeOi()
                                                    self.purge_oi.parent = self
                                                    self._children_name_map["purge_oi"] = "purge-oi"

                                                    self.host_name = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.HostName()
                                                    self.host_name.parent = self
                                                    self._children_name_map["host_name"] = "host-name"

                                                    self.ipv6_reachability = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability()
                                                    self.ipv6_reachability.parent = self
                                                    self._children_name_map["ipv6_reachability"] = "ipv6-reachability"

                                                    self.ipv6_te_router_id = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6TeRouterId()
                                                    self.ipv6_te_router_id.parent = self
                                                    self._children_name_map["ipv6_te_router_id"] = "ipv6-te-router-id"

                                                    self.ipv4_internal_reachability = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability()
                                                    self.ipv4_internal_reachability.parent = self
                                                    self._children_name_map["ipv4_internal_reachability"] = "ipv4-internal-reachability"

                                                    self.ipv6_interface_addresses = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6InterfaceAddresses()
                                                    self.ipv6_interface_addresses.parent = self
                                                    self._children_name_map["ipv6_interface_addresses"] = "ipv6-interface-addresses"

                                                    self.extended_is_reachability = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability()
                                                    self.extended_is_reachability.parent = self
                                                    self._children_name_map["extended_is_reachability"] = "extended-is-reachability"

                                                    self.instance_ids = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.InstanceIds()
                                                    self.instance_ids.parent = self
                                                    self._children_name_map["instance_ids"] = "instance-ids"

                                                    self.ipv4_srlgs = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4Srlgs()
                                                    self.ipv4_srlgs.parent = self
                                                    self._children_name_map["ipv4_srlgs"] = "ipv4-srlgs"

                                                    self.is_reachability = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability()
                                                    self.is_reachability.parent = self
                                                    self._children_name_map["is_reachability"] = "is-reachability"

                                                    self.ipv4_te_router_id = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4TeRouterId()
                                                    self.ipv4_te_router_id.parent = self
                                                    self._children_name_map["ipv4_te_router_id"] = "ipv4-te-router-id"

                                                    self.nlpid = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Nlpid()
                                                    self.nlpid.parent = self
                                                    self._children_name_map["nlpid"] = "nlpid"

                                                    self.extended_ipv4_reachability = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability()
                                                    self.extended_ipv4_reachability.parent = self
                                                    self._children_name_map["extended_ipv4_reachability"] = "extended-ipv4-reachability"

                                                    self.multi_topology = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MultiTopology()
                                                    self.multi_topology.parent = self
                                                    self._children_name_map["multi_topology"] = "multi-topology"

                                                    self.ipv4_external_reachability = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability()
                                                    self.ipv4_external_reachability.parent = self
                                                    self._children_name_map["ipv4_external_reachability"] = "ipv4-external-reachability"

                                                    self.mt_ipv6_reachability = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability()
                                                    self.mt_ipv6_reachability.parent = self
                                                    self._children_name_map["mt_ipv6_reachability"] = "mt-ipv6-reachability"
                                                    self._segment_path = lambda: "tlvs" + "[type='" + str(self.type) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs, ['type'], name, value)


                                                class AreaAddress(Entity):
                                                    """
                                                    This container defines TLV 1
                                                    
                                                    .. attribute:: state
                                                    
                                                    	State parameters of ISIS TLV 1
                                                    	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.AreaAddress.State>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.AreaAddress, self).__init__()

                                                        self.yang_name = "area-address"
                                                        self.yang_parent_name = "tlvs"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.AreaAddress.State))])
                                                        self._leafs = OrderedDict()

                                                        self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.AreaAddress.State()
                                                        self.state.parent = self
                                                        self._children_name_map["state"] = "state"
                                                        self._segment_path = lambda: "area-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.AreaAddress, [], name, value)


                                                    class State(Entity):
                                                        """
                                                        State parameters of ISIS TLV 1
                                                        
                                                        .. attribute:: area_address
                                                        
                                                        	Area adress(es) of the IS
                                                        	**type**\: list of str
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.AreaAddress.State, self).__init__()

                                                            self.yang_name = "state"
                                                            self.yang_parent_name = "area-address"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('area_address', (YLeafList(YType.str, 'area-address'), ['str'])),
                                                            ])
                                                            self.area_address = []
                                                            self._segment_path = lambda: "state"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.AreaAddress.State, [u'area_address'], name, value)


                                                class Authentication(Entity):
                                                    """
                                                    This container defines authentication
                                                    information of the node
                                                    
                                                    .. attribute:: state
                                                    
                                                    	State parameters of TLV 10
                                                    	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Authentication.State>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Authentication, self).__init__()

                                                        self.yang_name = "authentication"
                                                        self.yang_parent_name = "tlvs"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Authentication.State))])
                                                        self._leafs = OrderedDict()

                                                        self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Authentication.State()
                                                        self.state.parent = self
                                                        self._children_name_map["state"] = "state"
                                                        self._segment_path = lambda: "authentication"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Authentication, [], name, value)


                                                    class State(Entity):
                                                        """
                                                        State parameters of TLV 10
                                                        
                                                        .. attribute:: crypto_type
                                                        
                                                        	Authentication type to be used
                                                        	**type**\:  :py:class:`OpenconfigIsisLspCryptoTypeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisLspCryptoTypeEnum>`
                                                        
                                                        .. attribute:: authentication_key
                                                        
                                                        	Authentication key to be used
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Authentication.State, self).__init__()

                                                            self.yang_name = "state"
                                                            self.yang_parent_name = "authentication"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('crypto_type', (YLeaf(YType.enumeration, 'crypto-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisLspCryptoTypeEnum', '')])),
                                                                ('authentication_key', (YLeaf(YType.str, 'authentication-key'), ['str'])),
                                                            ])
                                                            self.crypto_type = None
                                                            self.authentication_key = None
                                                            self._segment_path = lambda: "state"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Authentication.State, [u'crypto_type', u'authentication_key'], name, value)


                                                class Ipv4InterfaceAddresses(Entity):
                                                    """
                                                    This container defines TLV 132
                                                    
                                                    .. attribute:: state
                                                    
                                                    	State parameters of ISIS TLV 132
                                                    	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InterfaceAddresses.State>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InterfaceAddresses, self).__init__()

                                                        self.yang_name = "ipv4-interface-addresses"
                                                        self.yang_parent_name = "tlvs"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InterfaceAddresses.State))])
                                                        self._leafs = OrderedDict()

                                                        self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InterfaceAddresses.State()
                                                        self.state.parent = self
                                                        self._children_name_map["state"] = "state"
                                                        self._segment_path = lambda: "ipv4-interface-addresses"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InterfaceAddresses, [], name, value)


                                                    class State(Entity):
                                                        """
                                                        State parameters of ISIS TLV 132
                                                        
                                                        .. attribute:: ipv4_interface_address
                                                        
                                                        	IPv4 address(es) of the interface corresponding to the SNPA over which this PDU is to be transmitted
                                                        	**type**\: list of str
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InterfaceAddresses.State, self).__init__()

                                                            self.yang_name = "state"
                                                            self.yang_parent_name = "ipv4-interface-addresses"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv4_interface_address', (YLeafList(YType.str, 'ipv4-interface-address'), ['str'])),
                                                            ])
                                                            self.ipv4_interface_address = []
                                                            self._segment_path = lambda: "state"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InterfaceAddresses.State, [u'ipv4_interface_address'], name, value)


                                                class RouterCapabilities(Entity):
                                                    """
                                                    This list describes IS Router
                                                    capabilities
                                                    
                                                    .. attribute:: router_capability
                                                    
                                                    	This list describes IS Router capabilities
                                                    	**type**\: list of  		 :py:class:`RouterCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities, self).__init__()

                                                        self.yang_name = "router-capabilities"
                                                        self.yang_parent_name = "tlvs"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("router-capability", ("router_capability", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability))])
                                                        self._leafs = OrderedDict()

                                                        self.router_capability = YList(self)
                                                        self._segment_path = lambda: "router-capabilities"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities, [], name, value)


                                                    class RouterCapability(Entity):
                                                        """
                                                        This list describes IS Router
                                                        capabilities
                                                        
                                                        .. attribute:: instance_number  (key)
                                                        
                                                        	Reference to the instance number of the router capability TLV
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: router_capabilities_state
                                                        
                                                        	State parameters of TLV 242
                                                        	**type**\:  :py:class:`RouterCapabilitiesState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.RouterCapabilitiesState>`
                                                        
                                                        .. attribute:: undefined_subtlvs
                                                        
                                                        	Sub\-TLVs that are not defined in the model or not recognised by system
                                                        	**type**\:  :py:class:`UndefinedSubtlvs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.UndefinedSubtlvs>`
                                                        
                                                        .. attribute:: subtlvs
                                                        
                                                        	List of subTLV types in the LSDB for the specified TLV
                                                        	**type**\:  :py:class:`Subtlvs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability, self).__init__()

                                                            self.yang_name = "router-capability"
                                                            self.yang_parent_name = "router-capabilities"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['instance_number']
                                                            self._child_classes = OrderedDict([("router-capabilities-state", ("router_capabilities_state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.RouterCapabilitiesState)), ("undefined-subtlvs", ("undefined_subtlvs", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.UndefinedSubtlvs)), ("subtlvs", ("subtlvs", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs))])
                                                            self._leafs = OrderedDict([
                                                                ('instance_number', (YLeaf(YType.uint32, 'instance-number'), ['int'])),
                                                            ])
                                                            self.instance_number = None

                                                            self.router_capabilities_state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.RouterCapabilitiesState()
                                                            self.router_capabilities_state.parent = self
                                                            self._children_name_map["router_capabilities_state"] = "router-capabilities-state"

                                                            self.undefined_subtlvs = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.UndefinedSubtlvs()
                                                            self.undefined_subtlvs.parent = self
                                                            self._children_name_map["undefined_subtlvs"] = "undefined-subtlvs"

                                                            self.subtlvs = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs()
                                                            self.subtlvs.parent = self
                                                            self._children_name_map["subtlvs"] = "subtlvs"
                                                            self._segment_path = lambda: "router-capability" + "[instance-number='" + str(self.instance_number) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability, ['instance_number'], name, value)


                                                        class RouterCapabilitiesState(Entity):
                                                            """
                                                            State parameters of TLV 242
                                                            
                                                            .. attribute:: instance_number
                                                            
                                                            	A unique instance number for the instance of the router capabilities TLV
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: router_id
                                                            
                                                            	IPv4 router\-id
                                                            	**type**\: str
                                                            
                                                            .. attribute:: flags
                                                            
                                                            	Router capability flags
                                                            	**type**\: list of   :py:class:`OpenconfigIsisLspRouterCapabilityStateFlagsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisLspRouterCapabilityStateFlagsEnum>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'clns-isis-oper'
                                                            _revision = '2018-04-07'

                                                            def __init__(self):
                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.RouterCapabilitiesState, self).__init__()

                                                                self.yang_name = "router-capabilities-state"
                                                                self.yang_parent_name = "router-capability"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('instance_number', (YLeaf(YType.uint32, 'instance-number'), ['int'])),
                                                                    ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                                                    ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisLspRouterCapabilityStateFlagsEnum', '')])),
                                                                ])
                                                                self.instance_number = None
                                                                self.router_id = None
                                                                self.flags = []
                                                                self._segment_path = lambda: "router-capabilities-state"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.RouterCapabilitiesState, [u'instance_number', u'router_id', u'flags'], name, value)


                                                        class UndefinedSubtlvs(Entity):
                                                            """
                                                            Sub\-TLVs that are not defined in
                                                            the model or not recognised by
                                                            system
                                                            
                                                            .. attribute:: undefined_subtlv
                                                            
                                                            	Sub\-TLVs that are not defined in the model or not recognised by system
                                                            	**type**\: list of  		 :py:class:`UndefinedSubtlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.UndefinedSubtlvs.UndefinedSubtlv>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'clns-isis-oper'
                                                            _revision = '2018-04-07'

                                                            def __init__(self):
                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.UndefinedSubtlvs, self).__init__()

                                                                self.yang_name = "undefined-subtlvs"
                                                                self.yang_parent_name = "router-capability"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("undefined-subtlv", ("undefined_subtlv", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.UndefinedSubtlvs.UndefinedSubtlv))])
                                                                self._leafs = OrderedDict()

                                                                self.undefined_subtlv = YList(self)
                                                                self._segment_path = lambda: "undefined-subtlvs"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.UndefinedSubtlvs, [], name, value)


                                                            class UndefinedSubtlv(Entity):
                                                                """
                                                                Sub\-TLVs that are not defined in
                                                                the model or not recognised by
                                                                system
                                                                
                                                                .. attribute:: type  (key)
                                                                
                                                                	Reference to the type of the undefined sub\-TLV
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: state
                                                                
                                                                	State parameters of the undefined sub\-TLV
                                                                	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.UndefinedSubtlvs.UndefinedSubtlv, self).__init__()

                                                                    self.yang_name = "undefined-subtlv"
                                                                    self.yang_parent_name = "undefined-subtlvs"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['type']
                                                                    self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.UndefinedSubtlvs.UndefinedSubtlv.State))])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.uint32, 'type'), ['int'])),
                                                                    ])
                                                                    self.type = None

                                                                    self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.UndefinedSubtlvs.UndefinedSubtlv.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"
                                                                    self._segment_path = lambda: "undefined-subtlv" + "[type='" + str(self.type) + "']"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.UndefinedSubtlvs.UndefinedSubtlv, ['type'], name, value)


                                                                class State(Entity):
                                                                    """
                                                                    State parameters of the undefined sub\-TLV
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	TLV Type
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: length
                                                                    
                                                                    	TLV length
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: value
                                                                    
                                                                    	TLV value
                                                                    	**type**\: str
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'clns-isis-oper'
                                                                    _revision = '2018-04-07'

                                                                    def __init__(self):
                                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.UndefinedSubtlvs.UndefinedSubtlv.State, self).__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "undefined-subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                                            ('length', (YLeaf(YType.uint8, 'length'), ['int'])),
                                                                            ('value', (YLeaf(YType.str, 'value'), ['str'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.length = None
                                                                        self.value = None
                                                                        self._segment_path = lambda: "state"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.UndefinedSubtlvs.UndefinedSubtlv.State, [u'type', u'length', u'value'], name, value)


                                                        class Subtlvs(Entity):
                                                            """
                                                            List of subTLV types in the LSDB
                                                            for the specified TLV
                                                            
                                                            .. attribute:: subtlv
                                                            
                                                            	List of subTLV types in the LSDB for the specified TLV
                                                            	**type**\: list of  		 :py:class:`Subtlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'clns-isis-oper'
                                                            _revision = '2018-04-07'

                                                            def __init__(self):
                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs, self).__init__()

                                                                self.yang_name = "subtlvs"
                                                                self.yang_parent_name = "router-capability"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("subtlv", ("subtlv", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv))])
                                                                self._leafs = OrderedDict()

                                                                self.subtlv = YList(self)
                                                                self._segment_path = lambda: "subtlvs"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs, [], name, value)


                                                            class Subtlv(Entity):
                                                                """
                                                                List of subTLV types in the LSDB
                                                                for the specified TLV
                                                                
                                                                .. attribute:: type  (key)
                                                                
                                                                	Reference to the sub\-TLV type
                                                                	**type**\: str
                                                                
                                                                .. attribute:: subtlvs_state
                                                                
                                                                	State parameters of IS Router Capabilities
                                                                	**type**\:  :py:class:`SubtlvsState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SubtlvsState>`
                                                                
                                                                .. attribute:: segment_routing_algorithms
                                                                
                                                                	List of the segment routing algorithsm advertised within the TLV
                                                                	**type**\:  :py:class:`SegmentRoutingAlgorithms <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingAlgorithms>`
                                                                
                                                                .. attribute:: segment_routing_capability
                                                                
                                                                	This container defines SR Capability sub\-TLV 2
                                                                	**type**\:  :py:class:`SegmentRoutingCapability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv, self).__init__()

                                                                    self.yang_name = "subtlv"
                                                                    self.yang_parent_name = "subtlvs"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['type']
                                                                    self._child_classes = OrderedDict([("subtlvs-state", ("subtlvs_state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SubtlvsState)), ("segment-routing-algorithms", ("segment_routing_algorithms", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingAlgorithms)), ("segment-routing-capability", ("segment_routing_capability", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability))])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.str, 'type'), ['str'])),
                                                                    ])
                                                                    self.type = None

                                                                    self.subtlvs_state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SubtlvsState()
                                                                    self.subtlvs_state.parent = self
                                                                    self._children_name_map["subtlvs_state"] = "subtlvs-state"

                                                                    self.segment_routing_algorithms = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingAlgorithms()
                                                                    self.segment_routing_algorithms.parent = self
                                                                    self._children_name_map["segment_routing_algorithms"] = "segment-routing-algorithms"

                                                                    self.segment_routing_capability = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability()
                                                                    self.segment_routing_capability.parent = self
                                                                    self._children_name_map["segment_routing_capability"] = "segment-routing-capability"
                                                                    self._segment_path = lambda: "subtlv" + "[type='" + str(self.type) + "']"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv, ['type'], name, value)


                                                                class SubtlvsState(Entity):
                                                                    """
                                                                    State parameters of IS Router
                                                                    Capabilities
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                    	The type of subTLV being described
                                                                    	**type**\: str
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'clns-isis-oper'
                                                                    _revision = '2018-04-07'

                                                                    def __init__(self):
                                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SubtlvsState, self).__init__()

                                                                        self.yang_name = "subtlvs-state"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.str, 'type'), ['str'])),
                                                                        ])
                                                                        self.type = None
                                                                        self._segment_path = lambda: "subtlvs-state"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SubtlvsState, [u'type'], name, value)


                                                                class SegmentRoutingAlgorithms(Entity):
                                                                    """
                                                                    List of the segment routing
                                                                    algorithsm advertised within the
                                                                    TLV
                                                                    
                                                                    .. attribute:: segment_routing_algorithm
                                                                    
                                                                    	List of the segment routing algorithsm advertised within the TLV
                                                                    	**type**\: list of  		 :py:class:`SegmentRoutingAlgorithm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingAlgorithms.SegmentRoutingAlgorithm>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'clns-isis-oper'
                                                                    _revision = '2018-04-07'

                                                                    def __init__(self):
                                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingAlgorithms, self).__init__()

                                                                        self.yang_name = "segment-routing-algorithms"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([("segment-routing-algorithm", ("segment_routing_algorithm", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingAlgorithms.SegmentRoutingAlgorithm))])
                                                                        self._leafs = OrderedDict()

                                                                        self.segment_routing_algorithm = YList(self)
                                                                        self._segment_path = lambda: "segment-routing-algorithms"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingAlgorithms, [], name, value)


                                                                    class SegmentRoutingAlgorithm(Entity):
                                                                        """
                                                                        List of the segment routing
                                                                        algorithsm advertised within the
                                                                        TLV
                                                                        
                                                                        .. attribute:: algorithm  (key)
                                                                        
                                                                        	Reference to the SR algorithm that the subTLV describes
                                                                        	**type**\:  :py:class:`Algorithm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingAlgorithms.SegmentRoutingAlgorithm.Algorithm>`
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 19 \- Segment Routing Algorithm
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingAlgorithms.SegmentRoutingAlgorithm.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingAlgorithms.SegmentRoutingAlgorithm, self).__init__()

                                                                            self.yang_name = "segment-routing-algorithm"
                                                                            self.yang_parent_name = "segment-routing-algorithms"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = ['algorithm']
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingAlgorithms.SegmentRoutingAlgorithm.State))])
                                                                            self._leafs = OrderedDict([
                                                                                ('algorithm', (YLeaf(YType.enumeration, 'algorithm'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OcniIsis', 'NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingAlgorithms.SegmentRoutingAlgorithm.Algorithm')])),
                                                                            ])
                                                                            self.algorithm = None

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingAlgorithms.SegmentRoutingAlgorithm.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "segment-routing-algorithm" + "[algorithm='" + str(self.algorithm) + "']"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingAlgorithms.SegmentRoutingAlgorithm, ['algorithm'], name, value)

                                                                        class Algorithm(Enum):
                                                                            """
                                                                            Algorithm (Enum Class)

                                                                            Reference to the SR algorithm

                                                                            that the subTLV describes

                                                                            .. data:: spf = 0

                                                                            	Shortest Path First (SPF)

                                                                            	algorithm based on link

                                                                            	metric.  This is the

                                                                            	well-known shortest path

                                                                            	algorithm as computed by the

                                                                            	IS-IS Decision process. 

                                                                            	Consistent with the deployed

                                                                            	practice for link- state

                                                                            	protocols, algorithm 0

                                                                            	permits any node to overwrite

                                                                            	the SPF path with a different

                                                                            	path based on local policy.

                                                                            .. data:: strict_spf = 1

                                                                            	Strict Shortest Path First

                                                                            	(SPF) algorithm based on link

                                                                            	metric. The algorithm is

                                                                            	identical to algorithm 0 but

                                                                            	algorithm 1 requires that all

                                                                            	nodes along the path will

                                                                            	honor the SPF routing

                                                                            	decision. Local policy MUST

                                                                            	NOT alter the forwarding

                                                                            	decision computed by

                                                                            	algorithm 1 at the node

                                                                            	claiming to support algorithm

                                                                            	1.

                                                                            """

                                                                            spf = Enum.YLeaf(0, "spf")

                                                                            strict_spf = Enum.YLeaf(1, "strict-spf")



                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 19 \- Segment Routing
                                                                            Algorithm
                                                                            
                                                                            .. attribute:: algorithm
                                                                            
                                                                            	The Segment Routing algorithm that is described by the TLV
                                                                            	**type**\:  :py:class:`OpenconfigIsisLspAlgorithmEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisLspAlgorithmEnum>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingAlgorithms.SegmentRoutingAlgorithm.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "segment-routing-algorithm"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('algorithm', (YLeaf(YType.enumeration, 'algorithm'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisLspAlgorithmEnum', '')])),
                                                                                ])
                                                                                self.algorithm = None
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingAlgorithms.SegmentRoutingAlgorithm.State, [u'algorithm'], name, value)


                                                                class SegmentRoutingCapability(Entity):
                                                                    """
                                                                    This container defines SR
                                                                    Capability sub\-TLV 2
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of IS SR Router Capability
                                                                    	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.State>`
                                                                    
                                                                    .. attribute:: srgb_descriptors
                                                                    
                                                                    	SRGB Descriptors included within the SR capability sub\-TLV
                                                                    	**type**\:  :py:class:`SrgbDescriptors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'clns-isis-oper'
                                                                    _revision = '2018-04-07'

                                                                    def __init__(self):
                                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability, self).__init__()

                                                                        self.yang_name = "segment-routing-capability"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.State)), ("srgb-descriptors", ("srgb_descriptors", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors))])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"

                                                                        self.srgb_descriptors = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors()
                                                                        self.srgb_descriptors.parent = self
                                                                        self._children_name_map["srgb_descriptors"] = "srgb-descriptors"
                                                                        self._segment_path = lambda: "segment-routing-capability"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability, [], name, value)


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of IS SR Router Capability
                                                                        
                                                                        .. attribute:: flags
                                                                        
                                                                        	Segment Routing Capability Flags
                                                                        	**type**\: list of   :py:class:`OpenconfigIsisLspSegmentRoutingCapabilityStateFlagsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisLspSegmentRoutingCapabilityStateFlagsEnum>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "segment-routing-capability"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisLspSegmentRoutingCapabilityStateFlagsEnum', '')])),
                                                                            ])
                                                                            self.flags = []
                                                                            self._segment_path = lambda: "state"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.State, [u'flags'], name, value)


                                                                    class SrgbDescriptors(Entity):
                                                                        """
                                                                        SRGB Descriptors included within the SR
                                                                        capability sub\-TLV
                                                                        
                                                                        .. attribute:: srgb_descriptor
                                                                        
                                                                        	Descriptor entry within the SR capabilty sub\-TLV
                                                                        	**type**\: list of  		 :py:class:`SrgbDescriptor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors.SrgbDescriptor>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors, self).__init__()

                                                                            self.yang_name = "srgb-descriptors"
                                                                            self.yang_parent_name = "segment-routing-capability"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("srgb-descriptor", ("srgb_descriptor", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors.SrgbDescriptor))])
                                                                            self._leafs = OrderedDict()

                                                                            self.srgb_descriptor = YList(self)
                                                                            self._segment_path = lambda: "srgb-descriptors"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors, [], name, value)


                                                                        class SrgbDescriptor(Entity):
                                                                            """
                                                                            Descriptor entry within the SR capabilty sub\-TLV
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                            	State parameters of the SR range
                                                                            	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors.SrgbDescriptor.State>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors.SrgbDescriptor, self).__init__()

                                                                                self.yang_name = "srgb-descriptor"
                                                                                self.yang_parent_name = "srgb-descriptors"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors.SrgbDescriptor.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors.SrgbDescriptor.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "srgb-descriptor"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors.SrgbDescriptor, [], name, value)


                                                                            class State(Entity):
                                                                                """
                                                                                State parameters of the SR range
                                                                                
                                                                                .. attribute:: range
                                                                                
                                                                                	Number of SRGB elements
                                                                                	**type**\: int
                                                                                
                                                                                	**range:** 0..4294967295
                                                                                
                                                                                .. attribute:: label
                                                                                
                                                                                	The first value of the SRGB when expressed as an MPLS label
                                                                                	**type**\: str
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'clns-isis-oper'
                                                                                _revision = '2018-04-07'

                                                                                def __init__(self):
                                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors.SrgbDescriptor.State, self).__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "srgb-descriptor"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('range', (YLeaf(YType.uint32, 'range'), ['int'])),
                                                                                        ('label', (YLeaf(YType.str, 'label'), ['str'])),
                                                                                    ])
                                                                                    self.range = None
                                                                                    self.label = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.RouterCapabilities.RouterCapability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors.SrgbDescriptor.State, [u'range', u'label'], name, value)


                                                class MtIpv4Reachability(Entity):
                                                    """
                                                    This container defines list of IPv4
                                                    reachability Information in
                                                    multi\-topology environment
                                                    
                                                    .. attribute:: mt_ipv4_reachability_prefixes
                                                    
                                                    	IPv4 prefixes that are contained within MT reachability TLV
                                                    	**type**\:  :py:class:`MtIpv4ReachabilityPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability, self).__init__()

                                                        self.yang_name = "mt-ipv4-reachability"
                                                        self.yang_parent_name = "tlvs"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("mt-ipv4-reachability-prefixes", ("mt_ipv4_reachability_prefixes", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes))])
                                                        self._leafs = OrderedDict()

                                                        self.mt_ipv4_reachability_prefixes = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes()
                                                        self.mt_ipv4_reachability_prefixes.parent = self
                                                        self._children_name_map["mt_ipv4_reachability_prefixes"] = "mt-ipv4-reachability-prefixes"
                                                        self._segment_path = lambda: "mt-ipv4-reachability"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability, [], name, value)


                                                    class MtIpv4ReachabilityPrefixes(Entity):
                                                        """
                                                        IPv4 prefixes that are contained
                                                        within MT reachability TLV
                                                        
                                                        .. attribute:: mt_ipv4_reachability_prefixe
                                                        
                                                        	IPv4 prefixes that are contained within MT reachability TLV
                                                        	**type**\: list of  		 :py:class:`MtIpv4ReachabilityPrefixe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes, self).__init__()

                                                            self.yang_name = "mt-ipv4-reachability-prefixes"
                                                            self.yang_parent_name = "mt-ipv4-reachability"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("mt-ipv4-reachability-prefixe", ("mt_ipv4_reachability_prefixe", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe))])
                                                            self._leafs = OrderedDict()

                                                            self.mt_ipv4_reachability_prefixe = YList(self)
                                                            self._segment_path = lambda: "mt-ipv4-reachability-prefixes"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes, [], name, value)


                                                        class MtIpv4ReachabilityPrefixe(Entity):
                                                            """
                                                            IPv4 prefixes that are contained
                                                            within MT reachability TLV
                                                            
                                                            .. attribute:: mt_ipv4_reachability_prefixes_state
                                                            
                                                            	State parameters of an IPv4 extended prefix
                                                            	**type**\:  :py:class:`MtIpv4ReachabilityPrefixesState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesState>`
                                                            
                                                            .. attribute:: mt_ipv4_reachability_prefixes_undefined_subtlvs
                                                            
                                                            	Sub\-TLVs that are not defined in the model or not recognised by system
                                                            	**type**\:  :py:class:`MtIpv4ReachabilityPrefixesUndefinedSubtlvs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesUndefinedSubtlvs>`
                                                            
                                                            .. attribute:: mt_ipv4_reachability_prefixes_subtlvs
                                                            
                                                            	List of subTLV types in the LSDB for the specified TLV
                                                            	**type**\:  :py:class:`MtIpv4ReachabilityPrefixesSubtlvs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs>`
                                                            
                                                            .. attribute:: mt_id
                                                            
                                                            	Reference to the topology ID of the topology that the prefix is within
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: prefix
                                                            
                                                            	Reference to the prefix to which reachability is being advertised
                                                            	**type**\: str
                                                            
                                                            

                                                            """

                                                            _prefix = 'clns-isis-oper'
                                                            _revision = '2018-04-07'

                                                            def __init__(self):
                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe, self).__init__()

                                                                self.yang_name = "mt-ipv4-reachability-prefixe"
                                                                self.yang_parent_name = "mt-ipv4-reachability-prefixes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("mt-ipv4-reachability-prefixes-state", ("mt_ipv4_reachability_prefixes_state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesState)), ("mt-ipv4-reachability-prefixes-undefined-subtlvs", ("mt_ipv4_reachability_prefixes_undefined_subtlvs", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesUndefinedSubtlvs)), ("mt-ipv4-reachability-prefixes-subtlvs", ("mt_ipv4_reachability_prefixes_subtlvs", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs))])
                                                                self._leafs = OrderedDict([
                                                                    ('mt_id', (YLeaf(YType.uint32, 'mt-id'), ['int'])),
                                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ])
                                                                self.mt_id = None
                                                                self.prefix = None

                                                                self.mt_ipv4_reachability_prefixes_state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesState()
                                                                self.mt_ipv4_reachability_prefixes_state.parent = self
                                                                self._children_name_map["mt_ipv4_reachability_prefixes_state"] = "mt-ipv4-reachability-prefixes-state"

                                                                self.mt_ipv4_reachability_prefixes_undefined_subtlvs = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesUndefinedSubtlvs()
                                                                self.mt_ipv4_reachability_prefixes_undefined_subtlvs.parent = self
                                                                self._children_name_map["mt_ipv4_reachability_prefixes_undefined_subtlvs"] = "mt-ipv4-reachability-prefixes-undefined-subtlvs"

                                                                self.mt_ipv4_reachability_prefixes_subtlvs = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs()
                                                                self.mt_ipv4_reachability_prefixes_subtlvs.parent = self
                                                                self._children_name_map["mt_ipv4_reachability_prefixes_subtlvs"] = "mt-ipv4-reachability-prefixes-subtlvs"
                                                                self._segment_path = lambda: "mt-ipv4-reachability-prefixe"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe, ['mt_id', 'prefix'], name, value)


                                                            class MtIpv4ReachabilityPrefixesState(Entity):
                                                                """
                                                                State parameters of an IPv4
                                                                extended prefix
                                                                
                                                                .. attribute:: up_down
                                                                
                                                                	The up/down bit
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: sbit
                                                                
                                                                	The Sub\-TLV present bit
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: prefix
                                                                
                                                                	IPv4 prefix contained within extended reachability TLVs
                                                                	**type**\: str
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	ISIS metric value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mt_id
                                                                
                                                                	Multi\-topology ID
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesState, self).__init__()

                                                                    self.yang_name = "mt-ipv4-reachability-prefixes-state"
                                                                    self.yang_parent_name = "mt-ipv4-reachability-prefixe"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('up_down', (YLeaf(YType.boolean, 'up-down'), ['bool'])),
                                                                        ('sbit', (YLeaf(YType.boolean, 'sbit'), ['bool'])),
                                                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                        ('mt_id', (YLeaf(YType.uint16, 'mt-id'), ['int'])),
                                                                    ])
                                                                    self.up_down = None
                                                                    self.sbit = None
                                                                    self.prefix = None
                                                                    self.metric = None
                                                                    self.mt_id = None
                                                                    self._segment_path = lambda: "mt-ipv4-reachability-prefixes-state"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesState, [u'up_down', u'sbit', u'prefix', u'metric', u'mt_id'], name, value)


                                                            class MtIpv4ReachabilityPrefixesUndefinedSubtlvs(Entity):
                                                                """
                                                                Sub\-TLVs that are not defined in
                                                                the model or not recognised by
                                                                system
                                                                
                                                                .. attribute:: mt_ipv4_reachability_prefixes_undefined_subtlv
                                                                
                                                                	Sub\-TLVs that are not defined in the model or not recognised by system
                                                                	**type**\: list of  		 :py:class:`MtIpv4ReachabilityPrefixesUndefinedSubtlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesUndefinedSubtlvs.MtIpv4ReachabilityPrefixesUndefinedSubtlv>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesUndefinedSubtlvs, self).__init__()

                                                                    self.yang_name = "mt-ipv4-reachability-prefixes-undefined-subtlvs"
                                                                    self.yang_parent_name = "mt-ipv4-reachability-prefixe"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("mt-ipv4-reachability-prefixes-undefined-subtlv", ("mt_ipv4_reachability_prefixes_undefined_subtlv", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesUndefinedSubtlvs.MtIpv4ReachabilityPrefixesUndefinedSubtlv))])
                                                                    self._leafs = OrderedDict()

                                                                    self.mt_ipv4_reachability_prefixes_undefined_subtlv = YList(self)
                                                                    self._segment_path = lambda: "mt-ipv4-reachability-prefixes-undefined-subtlvs"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesUndefinedSubtlvs, [], name, value)


                                                                class MtIpv4ReachabilityPrefixesUndefinedSubtlv(Entity):
                                                                    """
                                                                    Sub\-TLVs that are not defined in
                                                                    the model or not recognised by
                                                                    system
                                                                    
                                                                    .. attribute:: type  (key)
                                                                    
                                                                    	Reference to the type of the undefined sub\-TLV
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of the undefined sub\-TLV
                                                                    	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesUndefinedSubtlvs.MtIpv4ReachabilityPrefixesUndefinedSubtlv.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'clns-isis-oper'
                                                                    _revision = '2018-04-07'

                                                                    def __init__(self):
                                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesUndefinedSubtlvs.MtIpv4ReachabilityPrefixesUndefinedSubtlv, self).__init__()

                                                                        self.yang_name = "mt-ipv4-reachability-prefixes-undefined-subtlv"
                                                                        self.yang_parent_name = "mt-ipv4-reachability-prefixes-undefined-subtlvs"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = ['type']
                                                                        self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesUndefinedSubtlvs.MtIpv4ReachabilityPrefixesUndefinedSubtlv.State))])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.uint32, 'type'), ['int'])),
                                                                        ])
                                                                        self.type = None

                                                                        self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesUndefinedSubtlvs.MtIpv4ReachabilityPrefixesUndefinedSubtlv.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._segment_path = lambda: "mt-ipv4-reachability-prefixes-undefined-subtlv" + "[type='" + str(self.type) + "']"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesUndefinedSubtlvs.MtIpv4ReachabilityPrefixesUndefinedSubtlv, ['type'], name, value)


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of the undefined sub\-TLV
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	TLV Type
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: length
                                                                        
                                                                        	TLV length
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: value
                                                                        
                                                                        	TLV value
                                                                        	**type**\: str
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesUndefinedSubtlvs.MtIpv4ReachabilityPrefixesUndefinedSubtlv.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "mt-ipv4-reachability-prefixes-undefined-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                                                ('length', (YLeaf(YType.uint8, 'length'), ['int'])),
                                                                                ('value', (YLeaf(YType.str, 'value'), ['str'])),
                                                                            ])
                                                                            self.type = None
                                                                            self.length = None
                                                                            self.value = None
                                                                            self._segment_path = lambda: "state"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesUndefinedSubtlvs.MtIpv4ReachabilityPrefixesUndefinedSubtlv.State, [u'type', u'length', u'value'], name, value)


                                                            class MtIpv4ReachabilityPrefixesSubtlvs(Entity):
                                                                """
                                                                List of subTLV types in the LSDB
                                                                for the specified TLV
                                                                
                                                                .. attribute:: mt_ipv4_reachability_prefixes_subtlv
                                                                
                                                                	List of subTLV types in the LSDB for the specified TLV
                                                                	**type**\: list of  		 :py:class:`MtIpv4ReachabilityPrefixesSubtlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs, self).__init__()

                                                                    self.yang_name = "mt-ipv4-reachability-prefixes-subtlvs"
                                                                    self.yang_parent_name = "mt-ipv4-reachability-prefixe"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("mt-ipv4-reachability-prefixes-subtlv", ("mt_ipv4_reachability_prefixes_subtlv", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv))])
                                                                    self._leafs = OrderedDict()

                                                                    self.mt_ipv4_reachability_prefixes_subtlv = YList(self)
                                                                    self._segment_path = lambda: "mt-ipv4-reachability-prefixes-subtlvs"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs, [], name, value)


                                                                class MtIpv4ReachabilityPrefixesSubtlv(Entity):
                                                                    """
                                                                    List of subTLV types in the LSDB
                                                                    for the specified TLV
                                                                    
                                                                    .. attribute:: type  (key)
                                                                    
                                                                    	Reference to the sub\-TLV type
                                                                    	**type**\: str
                                                                    
                                                                    .. attribute:: prefixes_subtlvs_tag64
                                                                    
                                                                    	This container defines sub\-TLV 2
                                                                    	**type**\:  :py:class:`PrefixesSubtlvsTag64 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsTag64>`
                                                                    
                                                                    .. attribute:: prefixes_subtlvs_tag
                                                                    
                                                                    	This container defines sub\-TLV 1
                                                                    	**type**\:  :py:class:`PrefixesSubtlvsTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsTag>`
                                                                    
                                                                    .. attribute:: mt_ipv4_reachability_prefixes_subtlvs_state
                                                                    
                                                                    	State parameters for a prefix
                                                                    	**type**\:  :py:class:`MtIpv4ReachabilityPrefixesSubtlvsState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.MtIpv4ReachabilityPrefixesSubtlvsState>`
                                                                    
                                                                    .. attribute:: prefixes_subtlvs_ipv4_source_router_id
                                                                    
                                                                    	This container defines sub\-TLV 11
                                                                    	**type**\:  :py:class:`PrefixesSubtlvsIpv4SourceRouterId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsIpv4SourceRouterId>`
                                                                    
                                                                    .. attribute:: prefixes_subtlvs_ipv6_source_router_id
                                                                    
                                                                    	This container defines sub\-TLV 12
                                                                    	**type**\:  :py:class:`PrefixesSubtlvsIpv6SourceRouterId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsIpv6SourceRouterId>`
                                                                    
                                                                    .. attribute:: prefixes_subtlvs_prefix_sids
                                                                    
                                                                    	Prefix Segment\-ID list
                                                                    	**type**\:  :py:class:`PrefixesSubtlvsPrefixSids <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsPrefixSids>`
                                                                    
                                                                    .. attribute:: prefixes_subtlvs_flags
                                                                    
                                                                    	This container defines sub\-TLV 4
                                                                    	**type**\:  :py:class:`PrefixesSubtlvsFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsFlags>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'clns-isis-oper'
                                                                    _revision = '2018-04-07'

                                                                    def __init__(self):
                                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv, self).__init__()

                                                                        self.yang_name = "mt-ipv4-reachability-prefixes-subtlv"
                                                                        self.yang_parent_name = "mt-ipv4-reachability-prefixes-subtlvs"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = ['type']
                                                                        self._child_classes = OrderedDict([("prefixes-subtlvs-tag64", ("prefixes_subtlvs_tag64", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsTag64)), ("prefixes-subtlvs-tag", ("prefixes_subtlvs_tag", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsTag)), ("mt-ipv4-reachability-prefixes-subtlvs-state", ("mt_ipv4_reachability_prefixes_subtlvs_state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.MtIpv4ReachabilityPrefixesSubtlvsState)), ("prefixes-subtlvs-ipv4-source-router-id", ("prefixes_subtlvs_ipv4_source_router_id", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsIpv4SourceRouterId)), ("prefixes-subtlvs-ipv6-source-router-id", ("prefixes_subtlvs_ipv6_source_router_id", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsIpv6SourceRouterId)), ("prefixes-subtlvs-prefix-sids", ("prefixes_subtlvs_prefix_sids", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsPrefixSids)), ("prefixes-subtlvs-flags", ("prefixes_subtlvs_flags", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsFlags))])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.str, 'type'), ['str'])),
                                                                        ])
                                                                        self.type = None

                                                                        self.prefixes_subtlvs_tag64 = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsTag64()
                                                                        self.prefixes_subtlvs_tag64.parent = self
                                                                        self._children_name_map["prefixes_subtlvs_tag64"] = "prefixes-subtlvs-tag64"

                                                                        self.prefixes_subtlvs_tag = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsTag()
                                                                        self.prefixes_subtlvs_tag.parent = self
                                                                        self._children_name_map["prefixes_subtlvs_tag"] = "prefixes-subtlvs-tag"

                                                                        self.mt_ipv4_reachability_prefixes_subtlvs_state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.MtIpv4ReachabilityPrefixesSubtlvsState()
                                                                        self.mt_ipv4_reachability_prefixes_subtlvs_state.parent = self
                                                                        self._children_name_map["mt_ipv4_reachability_prefixes_subtlvs_state"] = "mt-ipv4-reachability-prefixes-subtlvs-state"

                                                                        self.prefixes_subtlvs_ipv4_source_router_id = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsIpv4SourceRouterId()
                                                                        self.prefixes_subtlvs_ipv4_source_router_id.parent = self
                                                                        self._children_name_map["prefixes_subtlvs_ipv4_source_router_id"] = "prefixes-subtlvs-ipv4-source-router-id"

                                                                        self.prefixes_subtlvs_ipv6_source_router_id = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsIpv6SourceRouterId()
                                                                        self.prefixes_subtlvs_ipv6_source_router_id.parent = self
                                                                        self._children_name_map["prefixes_subtlvs_ipv6_source_router_id"] = "prefixes-subtlvs-ipv6-source-router-id"

                                                                        self.prefixes_subtlvs_prefix_sids = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsPrefixSids()
                                                                        self.prefixes_subtlvs_prefix_sids.parent = self
                                                                        self._children_name_map["prefixes_subtlvs_prefix_sids"] = "prefixes-subtlvs-prefix-sids"

                                                                        self.prefixes_subtlvs_flags = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsFlags()
                                                                        self.prefixes_subtlvs_flags.parent = self
                                                                        self._children_name_map["prefixes_subtlvs_flags"] = "prefixes-subtlvs-flags"
                                                                        self._segment_path = lambda: "mt-ipv4-reachability-prefixes-subtlv" + "[type='" + str(self.type) + "']"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv, ['type'], name, value)


                                                                    class PrefixesSubtlvsTag64(Entity):
                                                                        """
                                                                        This container defines sub\-TLV 2
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 2
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsTag64.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsTag64, self).__init__()

                                                                            self.yang_name = "prefixes-subtlvs-tag64"
                                                                            self.yang_parent_name = "mt-ipv4-reachability-prefixes-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsTag64.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsTag64.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "prefixes-subtlvs-tag64"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsTag64, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 2
                                                                            
                                                                            .. attribute:: tag64
                                                                            
                                                                            	List of 64\-bit tags associated with the prefix
                                                                            	**type**\: list of int
                                                                            
                                                                            	**range:** 0..18446744073709551615
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsTag64.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "prefixes-subtlvs-tag64"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('tag64', (YLeafList(YType.uint64, 'tag64'), ['int'])),
                                                                                ])
                                                                                self.tag64 = []
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsTag64.State, [u'tag64'], name, value)


                                                                    class PrefixesSubtlvsTag(Entity):
                                                                        """
                                                                        This container defines sub\-TLV 1
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 1
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsTag.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsTag, self).__init__()

                                                                            self.yang_name = "prefixes-subtlvs-tag"
                                                                            self.yang_parent_name = "mt-ipv4-reachability-prefixes-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsTag.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsTag.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "prefixes-subtlvs-tag"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsTag, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 1
                                                                            
                                                                            .. attribute:: tag32
                                                                            
                                                                            	List of 32\-bit tags associated with the prefix
                                                                            	**type**\: list of int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsTag.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "prefixes-subtlvs-tag"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('tag32', (YLeafList(YType.uint32, 'tag32'), ['int'])),
                                                                                ])
                                                                                self.tag32 = []
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsTag.State, [u'tag32'], name, value)


                                                                    class MtIpv4ReachabilityPrefixesSubtlvsState(Entity):
                                                                        """
                                                                        State parameters for a prefix
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	The type of subTLV being described
                                                                        	**type**\: str
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.MtIpv4ReachabilityPrefixesSubtlvsState, self).__init__()

                                                                            self.yang_name = "mt-ipv4-reachability-prefixes-subtlvs-state"
                                                                            self.yang_parent_name = "mt-ipv4-reachability-prefixes-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', (YLeaf(YType.str, 'type'), ['str'])),
                                                                            ])
                                                                            self.type = None
                                                                            self._segment_path = lambda: "mt-ipv4-reachability-prefixes-subtlvs-state"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.MtIpv4ReachabilityPrefixesSubtlvsState, [u'type'], name, value)


                                                                    class PrefixesSubtlvsIpv4SourceRouterId(Entity):
                                                                        """
                                                                        This container defines sub\-TLV
                                                                        11
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 11
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsIpv4SourceRouterId.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsIpv4SourceRouterId, self).__init__()

                                                                            self.yang_name = "prefixes-subtlvs-ipv4-source-router-id"
                                                                            self.yang_parent_name = "mt-ipv4-reachability-prefixes-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsIpv4SourceRouterId.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsIpv4SourceRouterId.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "prefixes-subtlvs-ipv4-source-router-id"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsIpv4SourceRouterId, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 11
                                                                            
                                                                            .. attribute:: type
                                                                            
                                                                            	The type of subTLV being described
                                                                            	**type**\: str
                                                                            
                                                                            .. attribute:: ipv4_source_router_id
                                                                            
                                                                            	IPv4 Source router ID address
                                                                            	**type**\: str
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsIpv4SourceRouterId.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "prefixes-subtlvs-ipv4-source-router-id"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('type', (YLeaf(YType.str, 'type'), ['str'])),
                                                                                    ('ipv4_source_router_id', (YLeaf(YType.str, 'ipv4-source-router-id'), ['str'])),
                                                                                ])
                                                                                self.type = None
                                                                                self.ipv4_source_router_id = None
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsIpv4SourceRouterId.State, [u'type', u'ipv4_source_router_id'], name, value)


                                                                    class PrefixesSubtlvsIpv6SourceRouterId(Entity):
                                                                        """
                                                                        This container defines sub\-TLV
                                                                        12
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 12
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsIpv6SourceRouterId.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsIpv6SourceRouterId, self).__init__()

                                                                            self.yang_name = "prefixes-subtlvs-ipv6-source-router-id"
                                                                            self.yang_parent_name = "mt-ipv4-reachability-prefixes-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsIpv6SourceRouterId.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsIpv6SourceRouterId.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "prefixes-subtlvs-ipv6-source-router-id"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsIpv6SourceRouterId, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 12
                                                                            
                                                                            .. attribute:: type
                                                                            
                                                                            	The type of subTLV being described
                                                                            	**type**\: str
                                                                            
                                                                            .. attribute:: ipv6_source_router_id
                                                                            
                                                                            	IPv6 Source router ID address
                                                                            	**type**\: str
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsIpv6SourceRouterId.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "prefixes-subtlvs-ipv6-source-router-id"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('type', (YLeaf(YType.str, 'type'), ['str'])),
                                                                                    ('ipv6_source_router_id', (YLeaf(YType.str, 'ipv6-source-router-id'), ['str'])),
                                                                                ])
                                                                                self.type = None
                                                                                self.ipv6_source_router_id = None
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsIpv6SourceRouterId.State, [u'type', u'ipv6_source_router_id'], name, value)


                                                                    class PrefixesSubtlvsPrefixSids(Entity):
                                                                        """
                                                                        Prefix Segment\-ID list
                                                                        
                                                                        .. attribute:: prefixes_subtlvs_prefix_sid
                                                                        
                                                                        	Prefix Segment\-ID list
                                                                        	**type**\: list of  		 :py:class:`PrefixesSubtlvsPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsPrefixSids.PrefixesSubtlvsPrefixSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsPrefixSids, self).__init__()

                                                                            self.yang_name = "prefixes-subtlvs-prefix-sids"
                                                                            self.yang_parent_name = "mt-ipv4-reachability-prefixes-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("prefixes-subtlvs-prefix-sid", ("prefixes_subtlvs_prefix_sid", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsPrefixSids.PrefixesSubtlvsPrefixSid))])
                                                                            self._leafs = OrderedDict()

                                                                            self.prefixes_subtlvs_prefix_sid = YList(self)
                                                                            self._segment_path = lambda: "prefixes-subtlvs-prefix-sids"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsPrefixSids, [], name, value)


                                                                        class PrefixesSubtlvsPrefixSid(Entity):
                                                                            """
                                                                            Prefix Segment\-ID list
                                                                            
                                                                            .. attribute:: value  (key)
                                                                            
                                                                            	Reference to the value of the prefix SID
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                            	State parameters for Prefix\-SID
                                                                            	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsPrefixSids.PrefixesSubtlvsPrefixSid.State>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsPrefixSids.PrefixesSubtlvsPrefixSid, self).__init__()

                                                                                self.yang_name = "prefixes-subtlvs-prefix-sid"
                                                                                self.yang_parent_name = "prefixes-subtlvs-prefix-sids"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = ['value']
                                                                                self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsPrefixSids.PrefixesSubtlvsPrefixSid.State))])
                                                                                self._leafs = OrderedDict([
                                                                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                                                                ])
                                                                                self.value = None

                                                                                self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsPrefixSids.PrefixesSubtlvsPrefixSid.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "prefixes-subtlvs-prefix-sid" + "[value='" + str(self.value) + "']"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsPrefixSids.PrefixesSubtlvsPrefixSid, ['value'], name, value)


                                                                            class State(Entity):
                                                                                """
                                                                                State parameters for Prefix\-SID
                                                                                
                                                                                .. attribute:: value
                                                                                
                                                                                	IGP Prefix\-SID value
                                                                                	**type**\: int
                                                                                
                                                                                	**range:** 0..4294967295
                                                                                
                                                                                .. attribute:: algorithm
                                                                                
                                                                                	Prefix\-SID algorithm to be used for path computation
                                                                                	**type**\: int
                                                                                
                                                                                	**range:** 0..255
                                                                                
                                                                                .. attribute:: flags
                                                                                
                                                                                	Flags associated with Prefix Segment\-ID
                                                                                	**type**\: list of   :py:class:`OpenconfigIsisLspPrefixSidStateFlagsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisLspPrefixSidStateFlagsEnum>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'clns-isis-oper'
                                                                                _revision = '2018-04-07'

                                                                                def __init__(self):
                                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsPrefixSids.PrefixesSubtlvsPrefixSid.State, self).__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "prefixes-subtlvs-prefix-sid"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                                                                        ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                                                                        ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisLspPrefixSidStateFlagsEnum', '')])),
                                                                                    ])
                                                                                    self.value = None
                                                                                    self.algorithm = None
                                                                                    self.flags = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsPrefixSids.PrefixesSubtlvsPrefixSid.State, [u'value', u'algorithm', u'flags'], name, value)


                                                                    class PrefixesSubtlvsFlags(Entity):
                                                                        """
                                                                        This container defines sub\-TLV 4
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 4
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsFlags.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsFlags, self).__init__()

                                                                            self.yang_name = "prefixes-subtlvs-flags"
                                                                            self.yang_parent_name = "mt-ipv4-reachability-prefixes-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsFlags.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsFlags.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "prefixes-subtlvs-flags"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsFlags, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 4
                                                                            
                                                                            .. attribute:: type
                                                                            
                                                                            	The type of subTLV being described
                                                                            	**type**\: str
                                                                            
                                                                            .. attribute:: flags
                                                                            
                                                                            	Additional prefix reachability flags
                                                                            	**type**\: list of   :py:class:`OpenconfigIsisLspFlagsStateFlagsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisLspFlagsStateFlagsEnum>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsFlags.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "prefixes-subtlvs-flags"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('type', (YLeaf(YType.str, 'type'), ['str'])),
                                                                                    ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisLspFlagsStateFlagsEnum', '')])),
                                                                                ])
                                                                                self.type = None
                                                                                self.flags = []
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv4Reachability.MtIpv4ReachabilityPrefixes.MtIpv4ReachabilityPrefixe.MtIpv4ReachabilityPrefixesSubtlvs.MtIpv4ReachabilityPrefixesSubtlv.PrefixesSubtlvsFlags.State, [u'type', u'flags'], name, value)


                                                class MtIsn(Entity):
                                                    """
                                                    This container defines list of ISIS
                                                    multi\-topology neighbors
                                                    
                                                    .. attribute:: mt_isn_neighbors
                                                    
                                                    	This container describes IS neighbors
                                                    	**type**\:  :py:class:`MtIsnNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn, self).__init__()

                                                        self.yang_name = "mt-isn"
                                                        self.yang_parent_name = "tlvs"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("mt-isn-neighbors", ("mt_isn_neighbors", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors))])
                                                        self._leafs = OrderedDict()

                                                        self.mt_isn_neighbors = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors()
                                                        self.mt_isn_neighbors.parent = self
                                                        self._children_name_map["mt_isn_neighbors"] = "mt-isn-neighbors"
                                                        self._segment_path = lambda: "mt-isn"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn, [], name, value)


                                                    class MtIsnNeighbors(Entity):
                                                        """
                                                        This container describes IS
                                                        neighbors
                                                        
                                                        .. attribute:: mt_isn_neighbor
                                                        
                                                        	This container describes IS neighbors
                                                        	**type**\: list of  		 :py:class:`MtIsnNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors, self).__init__()

                                                            self.yang_name = "mt-isn-neighbors"
                                                            self.yang_parent_name = "mt-isn"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("mt-isn-neighbor", ("mt_isn_neighbor", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor))])
                                                            self._leafs = OrderedDict()

                                                            self.mt_isn_neighbor = YList(self)
                                                            self._segment_path = lambda: "mt-isn-neighbors"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors, [], name, value)


                                                        class MtIsnNeighbor(Entity):
                                                            """
                                                            This container describes IS
                                                            neighbors
                                                            
                                                            .. attribute:: mt_isn_neighbors_subtlvs
                                                            
                                                            	List of subTLV types in the LSDB for the specified TLV
                                                            	**type**\:  :py:class:`MtIsnNeighborsSubtlvs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs>`
                                                            
                                                            .. attribute:: mt_isn_neighbors_state
                                                            
                                                            	State parameters of MT neighbor
                                                            	**type**\:  :py:class:`MtIsnNeighborsState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsState>`
                                                            
                                                            .. attribute:: mt_isn_neighbors_undefined_subtlvs
                                                            
                                                            	Sub\-TLVs that are not defined in the model or not recognised by system
                                                            	**type**\:  :py:class:`MtIsnNeighborsUndefinedSubtlvs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsUndefinedSubtlvs>`
                                                            
                                                            .. attribute:: mt_id
                                                            
                                                            	       Reference to the topology that the neighbor is within
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: system_id
                                                            
                                                            	Reference to the System ID of the neighbor
                                                            	**type**\: str
                                                            
                                                            

                                                            """

                                                            _prefix = 'clns-isis-oper'
                                                            _revision = '2018-04-07'

                                                            def __init__(self):
                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor, self).__init__()

                                                                self.yang_name = "mt-isn-neighbor"
                                                                self.yang_parent_name = "mt-isn-neighbors"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("mt-isn-neighbors-subtlvs", ("mt_isn_neighbors_subtlvs", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs)), ("mt-isn-neighbors-state", ("mt_isn_neighbors_state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsState)), ("mt-isn-neighbors-undefined-subtlvs", ("mt_isn_neighbors_undefined_subtlvs", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsUndefinedSubtlvs))])
                                                                self._leafs = OrderedDict([
                                                                    ('mt_id', (YLeaf(YType.uint32, 'mt-id'), ['int'])),
                                                                    ('system_id', (YLeaf(YType.str, 'system-id'), ['str'])),
                                                                ])
                                                                self.mt_id = None
                                                                self.system_id = None

                                                                self.mt_isn_neighbors_subtlvs = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs()
                                                                self.mt_isn_neighbors_subtlvs.parent = self
                                                                self._children_name_map["mt_isn_neighbors_subtlvs"] = "mt-isn-neighbors-subtlvs"

                                                                self.mt_isn_neighbors_state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsState()
                                                                self.mt_isn_neighbors_state.parent = self
                                                                self._children_name_map["mt_isn_neighbors_state"] = "mt-isn-neighbors-state"

                                                                self.mt_isn_neighbors_undefined_subtlvs = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsUndefinedSubtlvs()
                                                                self.mt_isn_neighbors_undefined_subtlvs.parent = self
                                                                self._children_name_map["mt_isn_neighbors_undefined_subtlvs"] = "mt-isn-neighbors-undefined-subtlvs"
                                                                self._segment_path = lambda: "mt-isn-neighbor"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor, ['mt_id', 'system_id'], name, value)


                                                            class MtIsnNeighborsSubtlvs(Entity):
                                                                """
                                                                List of subTLV types in the LSDB
                                                                for the specified TLV
                                                                
                                                                .. attribute:: mt_isn_neighbors_subtlv
                                                                
                                                                	List of subTLV types in the LSDB for the specified TLV
                                                                	**type**\: list of  		 :py:class:`MtIsnNeighborsSubtlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs, self).__init__()

                                                                    self.yang_name = "mt-isn-neighbors-subtlvs"
                                                                    self.yang_parent_name = "mt-isn-neighbor"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("mt-isn-neighbors-subtlv", ("mt_isn_neighbors_subtlv", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv))])
                                                                    self._leafs = OrderedDict()

                                                                    self.mt_isn_neighbors_subtlv = YList(self)
                                                                    self._segment_path = lambda: "mt-isn-neighbors-subtlvs"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs, [], name, value)


                                                                class MtIsnNeighborsSubtlv(Entity):
                                                                    """
                                                                    List of subTLV types in the LSDB
                                                                    for the specified TLV
                                                                    
                                                                    .. attribute:: type  (key)
                                                                    
                                                                    	Reference to the sub\-TLV type
                                                                    	**type**\: str
                                                                    
                                                                    .. attribute:: subtlvs_ipv6_neighbor_address
                                                                    
                                                                    	This container defines sub\-TLV 13
                                                                    	**type**\:  :py:class:`SubtlvsIpv6NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv6NeighborAddress>`
                                                                    
                                                                    .. attribute:: subtlvs_ipv4_interface_address
                                                                    
                                                                    	This container defines sub\-TLV 6
                                                                    	**type**\:  :py:class:`SubtlvsIpv4InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv4InterfaceAddress>`
                                                                    
                                                                    .. attribute:: subtlvs_max_reservable_link_bandwidth
                                                                    
                                                                    	This container defines sub\-TLV 10
                                                                    	**type**\:  :py:class:`SubtlvsMaxReservableLinkBandwidth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsMaxReservableLinkBandwidth>`
                                                                    
                                                                    .. attribute:: subtlvs_max_link_bandwidth
                                                                    
                                                                    	This container defines sub\-TLV 9
                                                                    	**type**\:  :py:class:`SubtlvsMaxLinkBandwidth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsMaxLinkBandwidth>`
                                                                    
                                                                    .. attribute:: subtlvs_adjacency_sids
                                                                    
                                                                    	Adjacency Segment\-IDs List
                                                                    	**type**\:  :py:class:`SubtlvsAdjacencySids <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsAdjacencySids>`
                                                                    
                                                                    .. attribute:: subtlvs_bandwidth_constraints
                                                                    
                                                                    	List of the Bandwidth Constraints sub\-TLV instances present in the TLV
                                                                    	**type**\:  :py:class:`SubtlvsBandwidthConstraints <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsBandwidthConstraints>`
                                                                    
                                                                    .. attribute:: subtlvs_unreserved_bandwidths
                                                                    
                                                                    	Setup priority (0 through 7) for unreserved bandwidth
                                                                    	**type**\:  :py:class:`SubtlvsUnreservedBandwidths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsUnreservedBandwidths>`
                                                                    
                                                                    .. attribute:: subtlvs_ipv4_neighbor_address
                                                                    
                                                                    	This container defines sub\-TLV 8
                                                                    	**type**\:  :py:class:`SubtlvsIpv4NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv4NeighborAddress>`
                                                                    
                                                                    .. attribute:: subtlvs_te_default_metric
                                                                    
                                                                    	This container defines sub\-TLV 18
                                                                    	**type**\:  :py:class:`SubtlvsTeDefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsTeDefaultMetric>`
                                                                    
                                                                    .. attribute:: subtlvs_ipv6_interface_address
                                                                    
                                                                    	This container defines sub\-TLV 12
                                                                    	**type**\:  :py:class:`SubtlvsIpv6InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv6InterfaceAddress>`
                                                                    
                                                                    .. attribute:: subtlvs_admin_group
                                                                    
                                                                    	This container defines sub\-TLV 3
                                                                    	**type**\:  :py:class:`SubtlvsAdminGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsAdminGroup>`
                                                                    
                                                                    .. attribute:: subtlvs_lan_adjacency_sids
                                                                    
                                                                    	Adjacency Segment\-IDs List
                                                                    	**type**\:  :py:class:`SubtlvsLanAdjacencySids <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsLanAdjacencySids>`
                                                                    
                                                                    .. attribute:: subtlvs_extended_admin_group
                                                                    
                                                                    	This container defines sub\-TLV 14
                                                                    	**type**\:  :py:class:`SubtlvsExtendedAdminGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsExtendedAdminGroup>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'clns-isis-oper'
                                                                    _revision = '2018-04-07'

                                                                    def __init__(self):
                                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv, self).__init__()

                                                                        self.yang_name = "mt-isn-neighbors-subtlv"
                                                                        self.yang_parent_name = "mt-isn-neighbors-subtlvs"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = ['type']
                                                                        self._child_classes = OrderedDict([("subtlvs-ipv6-neighbor-address", ("subtlvs_ipv6_neighbor_address", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv6NeighborAddress)), ("subtlvs-ipv4-interface-address", ("subtlvs_ipv4_interface_address", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv4InterfaceAddress)), ("subtlvs-max-reservable-link-bandwidth", ("subtlvs_max_reservable_link_bandwidth", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsMaxReservableLinkBandwidth)), ("subtlvs-max-link-bandwidth", ("subtlvs_max_link_bandwidth", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsMaxLinkBandwidth)), ("subtlvs-adjacency-sids", ("subtlvs_adjacency_sids", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsAdjacencySids)), ("subtlvs-bandwidth-constraints", ("subtlvs_bandwidth_constraints", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsBandwidthConstraints)), ("subtlvs-unreserved-bandwidths", ("subtlvs_unreserved_bandwidths", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsUnreservedBandwidths)), ("subtlvs-ipv4-neighbor-address", ("subtlvs_ipv4_neighbor_address", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv4NeighborAddress)), ("subtlvs-te-default-metric", ("subtlvs_te_default_metric", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsTeDefaultMetric)), ("subtlvs-ipv6-interface-address", ("subtlvs_ipv6_interface_address", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv6InterfaceAddress)), ("subtlvs-admin-group", ("subtlvs_admin_group", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsAdminGroup)), ("subtlvs-lan-adjacency-sids", ("subtlvs_lan_adjacency_sids", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsLanAdjacencySids)), ("subtlvs-extended-admin-group", ("subtlvs_extended_admin_group", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsExtendedAdminGroup))])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.str, 'type'), ['str'])),
                                                                        ])
                                                                        self.type = None

                                                                        self.subtlvs_ipv6_neighbor_address = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv6NeighborAddress()
                                                                        self.subtlvs_ipv6_neighbor_address.parent = self
                                                                        self._children_name_map["subtlvs_ipv6_neighbor_address"] = "subtlvs-ipv6-neighbor-address"

                                                                        self.subtlvs_ipv4_interface_address = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv4InterfaceAddress()
                                                                        self.subtlvs_ipv4_interface_address.parent = self
                                                                        self._children_name_map["subtlvs_ipv4_interface_address"] = "subtlvs-ipv4-interface-address"

                                                                        self.subtlvs_max_reservable_link_bandwidth = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsMaxReservableLinkBandwidth()
                                                                        self.subtlvs_max_reservable_link_bandwidth.parent = self
                                                                        self._children_name_map["subtlvs_max_reservable_link_bandwidth"] = "subtlvs-max-reservable-link-bandwidth"

                                                                        self.subtlvs_max_link_bandwidth = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsMaxLinkBandwidth()
                                                                        self.subtlvs_max_link_bandwidth.parent = self
                                                                        self._children_name_map["subtlvs_max_link_bandwidth"] = "subtlvs-max-link-bandwidth"

                                                                        self.subtlvs_adjacency_sids = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsAdjacencySids()
                                                                        self.subtlvs_adjacency_sids.parent = self
                                                                        self._children_name_map["subtlvs_adjacency_sids"] = "subtlvs-adjacency-sids"

                                                                        self.subtlvs_bandwidth_constraints = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsBandwidthConstraints()
                                                                        self.subtlvs_bandwidth_constraints.parent = self
                                                                        self._children_name_map["subtlvs_bandwidth_constraints"] = "subtlvs-bandwidth-constraints"

                                                                        self.subtlvs_unreserved_bandwidths = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsUnreservedBandwidths()
                                                                        self.subtlvs_unreserved_bandwidths.parent = self
                                                                        self._children_name_map["subtlvs_unreserved_bandwidths"] = "subtlvs-unreserved-bandwidths"

                                                                        self.subtlvs_ipv4_neighbor_address = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv4NeighborAddress()
                                                                        self.subtlvs_ipv4_neighbor_address.parent = self
                                                                        self._children_name_map["subtlvs_ipv4_neighbor_address"] = "subtlvs-ipv4-neighbor-address"

                                                                        self.subtlvs_te_default_metric = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsTeDefaultMetric()
                                                                        self.subtlvs_te_default_metric.parent = self
                                                                        self._children_name_map["subtlvs_te_default_metric"] = "subtlvs-te-default-metric"

                                                                        self.subtlvs_ipv6_interface_address = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv6InterfaceAddress()
                                                                        self.subtlvs_ipv6_interface_address.parent = self
                                                                        self._children_name_map["subtlvs_ipv6_interface_address"] = "subtlvs-ipv6-interface-address"

                                                                        self.subtlvs_admin_group = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsAdminGroup()
                                                                        self.subtlvs_admin_group.parent = self
                                                                        self._children_name_map["subtlvs_admin_group"] = "subtlvs-admin-group"

                                                                        self.subtlvs_lan_adjacency_sids = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsLanAdjacencySids()
                                                                        self.subtlvs_lan_adjacency_sids.parent = self
                                                                        self._children_name_map["subtlvs_lan_adjacency_sids"] = "subtlvs-lan-adjacency-sids"

                                                                        self.subtlvs_extended_admin_group = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsExtendedAdminGroup()
                                                                        self.subtlvs_extended_admin_group.parent = self
                                                                        self._children_name_map["subtlvs_extended_admin_group"] = "subtlvs-extended-admin-group"
                                                                        self._segment_path = lambda: "mt-isn-neighbors-subtlv" + "[type='" + str(self.type) + "']"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv, ['type'], name, value)


                                                                    class SubtlvsIpv6NeighborAddress(Entity):
                                                                        """
                                                                        This container defines sub\-TLV
                                                                        13
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 13
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv6NeighborAddress.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv6NeighborAddress, self).__init__()

                                                                            self.yang_name = "subtlvs-ipv6-neighbor-address"
                                                                            self.yang_parent_name = "mt-isn-neighbors-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv6NeighborAddress.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv6NeighborAddress.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "subtlvs-ipv6-neighbor-address"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv6NeighborAddress, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 13
                                                                            
                                                                            .. attribute:: ipv6_neighbor_address
                                                                            
                                                                            	Contains a 16\-octet IPv6 address for a neighboring router on the link described by the (main) TLV
                                                                            	**type**\: list of str
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv6NeighborAddress.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "subtlvs-ipv6-neighbor-address"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('ipv6_neighbor_address', (YLeafList(YType.str, 'ipv6-neighbor-address'), ['str'])),
                                                                                ])
                                                                                self.ipv6_neighbor_address = []
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv6NeighborAddress.State, [u'ipv6_neighbor_address'], name, value)


                                                                    class SubtlvsIpv4InterfaceAddress(Entity):
                                                                        """
                                                                        This container defines sub\-TLV 6
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 6
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv4InterfaceAddress.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv4InterfaceAddress, self).__init__()

                                                                            self.yang_name = "subtlvs-ipv4-interface-address"
                                                                            self.yang_parent_name = "mt-isn-neighbors-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv4InterfaceAddress.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv4InterfaceAddress.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "subtlvs-ipv4-interface-address"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv4InterfaceAddress, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 6
                                                                            
                                                                            .. attribute:: ipv4_interface_address
                                                                            
                                                                            	A 4\-octet IPv4 address for the interface described by the (main) TLV
                                                                            	**type**\: list of str
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv4InterfaceAddress.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "subtlvs-ipv4-interface-address"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('ipv4_interface_address', (YLeafList(YType.str, 'ipv4-interface-address'), ['str'])),
                                                                                ])
                                                                                self.ipv4_interface_address = []
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv4InterfaceAddress.State, [u'ipv4_interface_address'], name, value)


                                                                    class SubtlvsMaxReservableLinkBandwidth(Entity):
                                                                        """
                                                                        This container defines sub\-TLV
                                                                        10
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 10
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsMaxReservableLinkBandwidth.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsMaxReservableLinkBandwidth, self).__init__()

                                                                            self.yang_name = "subtlvs-max-reservable-link-bandwidth"
                                                                            self.yang_parent_name = "mt-isn-neighbors-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsMaxReservableLinkBandwidth.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsMaxReservableLinkBandwidth.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "subtlvs-max-reservable-link-bandwidth"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsMaxReservableLinkBandwidth, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 10
                                                                            
                                                                            .. attribute:: max_reservable_link_bandwidth
                                                                            
                                                                            	The maximum amount of bandwidth that can be reserved in this direction on this link
                                                                            	**type**\: str
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsMaxReservableLinkBandwidth.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "subtlvs-max-reservable-link-bandwidth"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('max_reservable_link_bandwidth', (YLeaf(YType.str, 'max-reservable-link-bandwidth'), ['str'])),
                                                                                ])
                                                                                self.max_reservable_link_bandwidth = None
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsMaxReservableLinkBandwidth.State, [u'max_reservable_link_bandwidth'], name, value)


                                                                    class SubtlvsMaxLinkBandwidth(Entity):
                                                                        """
                                                                        This container defines sub\-TLV 9
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 9
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsMaxLinkBandwidth.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsMaxLinkBandwidth, self).__init__()

                                                                            self.yang_name = "subtlvs-max-link-bandwidth"
                                                                            self.yang_parent_name = "mt-isn-neighbors-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsMaxLinkBandwidth.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsMaxLinkBandwidth.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "subtlvs-max-link-bandwidth"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsMaxLinkBandwidth, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 9
                                                                            
                                                                            .. attribute:: max_link_bandwidth
                                                                            
                                                                            	The maximum bandwidth that can be used on this link in this direction (from the system originating the LSP to its neighbors)
                                                                            	**type**\: str
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsMaxLinkBandwidth.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "subtlvs-max-link-bandwidth"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('max_link_bandwidth', (YLeaf(YType.str, 'max-link-bandwidth'), ['str'])),
                                                                                ])
                                                                                self.max_link_bandwidth = None
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsMaxLinkBandwidth.State, [u'max_link_bandwidth'], name, value)


                                                                    class SubtlvsAdjacencySids(Entity):
                                                                        """
                                                                        Adjacency Segment\-IDs List
                                                                        
                                                                        .. attribute:: subtlvs_adjacency_sid
                                                                        
                                                                        	Adjacency Segment\-IDs List
                                                                        	**type**\: list of  		 :py:class:`SubtlvsAdjacencySid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsAdjacencySids.SubtlvsAdjacencySid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsAdjacencySids, self).__init__()

                                                                            self.yang_name = "subtlvs-adjacency-sids"
                                                                            self.yang_parent_name = "mt-isn-neighbors-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("subtlvs-adjacency-sid", ("subtlvs_adjacency_sid", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsAdjacencySids.SubtlvsAdjacencySid))])
                                                                            self._leafs = OrderedDict()

                                                                            self.subtlvs_adjacency_sid = YList(self)
                                                                            self._segment_path = lambda: "subtlvs-adjacency-sids"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsAdjacencySids, [], name, value)


                                                                        class SubtlvsAdjacencySid(Entity):
                                                                            """
                                                                            Adjacency Segment\-IDs List
                                                                            
                                                                            .. attribute:: value  (key)
                                                                            
                                                                            	Reference to the value of the Adjacency\-SID
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                            	State parameters of Adjacency\-SID
                                                                            	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsAdjacencySids.SubtlvsAdjacencySid.State>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsAdjacencySids.SubtlvsAdjacencySid, self).__init__()

                                                                                self.yang_name = "subtlvs-adjacency-sid"
                                                                                self.yang_parent_name = "subtlvs-adjacency-sids"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = ['value']
                                                                                self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsAdjacencySids.SubtlvsAdjacencySid.State))])
                                                                                self._leafs = OrderedDict([
                                                                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                                                                ])
                                                                                self.value = None

                                                                                self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsAdjacencySids.SubtlvsAdjacencySid.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "subtlvs-adjacency-sid" + "[value='" + str(self.value) + "']"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsAdjacencySids.SubtlvsAdjacencySid, ['value'], name, value)


                                                                            class State(Entity):
                                                                                """
                                                                                State parameters of Adjacency\-SID
                                                                                
                                                                                .. attribute:: value
                                                                                
                                                                                	Adjacency\-SID value
                                                                                	**type**\: int
                                                                                
                                                                                	**range:** 0..4294967295
                                                                                
                                                                                .. attribute:: weight
                                                                                
                                                                                	Value that represents the weight of the Adj\-SID for the purpose of load balancing
                                                                                	**type**\: int
                                                                                
                                                                                	**range:** 0..255
                                                                                
                                                                                .. attribute:: flags
                                                                                
                                                                                	Flags associated with Adj\-Segment\-ID
                                                                                	**type**\: list of   :py:class:`OpenconfigIsisLspAdjacencySidStateFlagsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisLspAdjacencySidStateFlagsEnum>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'clns-isis-oper'
                                                                                _revision = '2018-04-07'

                                                                                def __init__(self):
                                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsAdjacencySids.SubtlvsAdjacencySid.State, self).__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "subtlvs-adjacency-sid"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                                        ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisLspAdjacencySidStateFlagsEnum', '')])),
                                                                                    ])
                                                                                    self.value = None
                                                                                    self.weight = None
                                                                                    self.flags = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsAdjacencySids.SubtlvsAdjacencySid.State, [u'value', u'weight', u'flags'], name, value)


                                                                    class SubtlvsBandwidthConstraints(Entity):
                                                                        """
                                                                        List of the Bandwidth
                                                                        Constraints sub\-TLV instances
                                                                        present in the TLV
                                                                        
                                                                        .. attribute:: subtlvs_bandwidth_constraint
                                                                        
                                                                        	List of the Bandwidth Constraints sub\-TLV instances present in the TLV
                                                                        	**type**\: list of  		 :py:class:`SubtlvsBandwidthConstraint <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsBandwidthConstraints.SubtlvsBandwidthConstraint>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsBandwidthConstraints, self).__init__()

                                                                            self.yang_name = "subtlvs-bandwidth-constraints"
                                                                            self.yang_parent_name = "mt-isn-neighbors-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("subtlvs-bandwidth-constraint", ("subtlvs_bandwidth_constraint", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsBandwidthConstraints.SubtlvsBandwidthConstraint))])
                                                                            self._leafs = OrderedDict()

                                                                            self.subtlvs_bandwidth_constraint = YList(self)
                                                                            self._segment_path = lambda: "subtlvs-bandwidth-constraints"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsBandwidthConstraints, [], name, value)


                                                                        class SubtlvsBandwidthConstraint(Entity):
                                                                            """
                                                                            List of the Bandwidth
                                                                            Constraints sub\-TLV instances
                                                                            present in the TLV
                                                                            
                                                                            .. attribute:: model_id  (key)
                                                                            
                                                                            	Reference to the model ID associated with the instance of the Bandwidth Constraints sub\-TLV
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: bandwidth_constraints_constraints
                                                                            
                                                                            	List of the constraints within the Bandwidth Constraints sub\-TLV
                                                                            	**type**\:  :py:class:`BandwidthConstraintsConstraints <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsBandwidthConstraints.SubtlvsBandwidthConstraint.BandwidthConstraintsConstraints>`
                                                                            
                                                                            .. attribute:: subtlvs_bandwidth_constraints_state
                                                                            
                                                                            	State parameters of IS Extended Reachability sub\-TLV 22
                                                                            	**type**\:  :py:class:`SubtlvsBandwidthConstraintsState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsBandwidthConstraints.SubtlvsBandwidthConstraint.SubtlvsBandwidthConstraintsState>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsBandwidthConstraints.SubtlvsBandwidthConstraint, self).__init__()

                                                                                self.yang_name = "subtlvs-bandwidth-constraint"
                                                                                self.yang_parent_name = "subtlvs-bandwidth-constraints"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = ['model_id']
                                                                                self._child_classes = OrderedDict([("bandwidth-constraints-constraints", ("bandwidth_constraints_constraints", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsBandwidthConstraints.SubtlvsBandwidthConstraint.BandwidthConstraintsConstraints)), ("subtlvs-bandwidth-constraints-state", ("subtlvs_bandwidth_constraints_state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsBandwidthConstraints.SubtlvsBandwidthConstraint.SubtlvsBandwidthConstraintsState))])
                                                                                self._leafs = OrderedDict([
                                                                                    ('model_id', (YLeaf(YType.uint32, 'model-id'), ['int'])),
                                                                                ])
                                                                                self.model_id = None

                                                                                self.bandwidth_constraints_constraints = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsBandwidthConstraints.SubtlvsBandwidthConstraint.BandwidthConstraintsConstraints()
                                                                                self.bandwidth_constraints_constraints.parent = self
                                                                                self._children_name_map["bandwidth_constraints_constraints"] = "bandwidth-constraints-constraints"

                                                                                self.subtlvs_bandwidth_constraints_state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsBandwidthConstraints.SubtlvsBandwidthConstraint.SubtlvsBandwidthConstraintsState()
                                                                                self.subtlvs_bandwidth_constraints_state.parent = self
                                                                                self._children_name_map["subtlvs_bandwidth_constraints_state"] = "subtlvs-bandwidth-constraints-state"
                                                                                self._segment_path = lambda: "subtlvs-bandwidth-constraint" + "[model-id='" + str(self.model_id) + "']"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsBandwidthConstraints.SubtlvsBandwidthConstraint, ['model_id'], name, value)


                                                                            class BandwidthConstraintsConstraints(Entity):
                                                                                """
                                                                                List of the constraints within
                                                                                the Bandwidth Constraints
                                                                                sub\-TLV
                                                                                
                                                                                .. attribute:: bandwidth_constraints_constraint
                                                                                
                                                                                	List of the constraints within the Bandwidth Constraints sub\-TLV
                                                                                	**type**\: list of  		 :py:class:`BandwidthConstraintsConstraint <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsBandwidthConstraints.SubtlvsBandwidthConstraint.BandwidthConstraintsConstraints.BandwidthConstraintsConstraint>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'clns-isis-oper'
                                                                                _revision = '2018-04-07'

                                                                                def __init__(self):
                                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsBandwidthConstraints.SubtlvsBandwidthConstraint.BandwidthConstraintsConstraints, self).__init__()

                                                                                    self.yang_name = "bandwidth-constraints-constraints"
                                                                                    self.yang_parent_name = "subtlvs-bandwidth-constraint"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([("bandwidth-constraints-constraint", ("bandwidth_constraints_constraint", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsBandwidthConstraints.SubtlvsBandwidthConstraint.BandwidthConstraintsConstraints.BandwidthConstraintsConstraint))])
                                                                                    self._leafs = OrderedDict()

                                                                                    self.bandwidth_constraints_constraint = YList(self)
                                                                                    self._segment_path = lambda: "bandwidth-constraints-constraints"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsBandwidthConstraints.SubtlvsBandwidthConstraint.BandwidthConstraintsConstraints, [], name, value)


                                                                                class BandwidthConstraintsConstraint(Entity):
                                                                                    """
                                                                                    List of the constraints
                                                                                    within the Bandwidth
                                                                                    Constraints sub\-TLV
                                                                                    
                                                                                    .. attribute:: constraint_id  (key)
                                                                                    
                                                                                    	Reference to the unique ID for the BCN level
                                                                                    	**type**\: int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: state
                                                                                    
                                                                                    	Operational state parameters of the BCN level
                                                                                    	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsBandwidthConstraints.SubtlvsBandwidthConstraint.BandwidthConstraintsConstraints.BandwidthConstraintsConstraint.State>`
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'clns-isis-oper'
                                                                                    _revision = '2018-04-07'

                                                                                    def __init__(self):
                                                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsBandwidthConstraints.SubtlvsBandwidthConstraint.BandwidthConstraintsConstraints.BandwidthConstraintsConstraint, self).__init__()

                                                                                        self.yang_name = "bandwidth-constraints-constraint"
                                                                                        self.yang_parent_name = "bandwidth-constraints-constraints"
                                                                                        self.is_top_level_class = False
                                                                                        self.has_list_ancestor = True
                                                                                        self.ylist_key_names = ['constraint_id']
                                                                                        self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsBandwidthConstraints.SubtlvsBandwidthConstraint.BandwidthConstraintsConstraints.BandwidthConstraintsConstraint.State))])
                                                                                        self._leafs = OrderedDict([
                                                                                            ('constraint_id', (YLeaf(YType.uint32, 'constraint-id'), ['int'])),
                                                                                        ])
                                                                                        self.constraint_id = None

                                                                                        self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsBandwidthConstraints.SubtlvsBandwidthConstraint.BandwidthConstraintsConstraints.BandwidthConstraintsConstraint.State()
                                                                                        self.state.parent = self
                                                                                        self._children_name_map["state"] = "state"
                                                                                        self._segment_path = lambda: "bandwidth-constraints-constraint" + "[constraint-id='" + str(self.constraint_id) + "']"
                                                                                        self._is_frozen = True

                                                                                    def __setattr__(self, name, value):
                                                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsBandwidthConstraints.SubtlvsBandwidthConstraint.BandwidthConstraintsConstraints.BandwidthConstraintsConstraint, ['constraint_id'], name, value)


                                                                                    class State(Entity):
                                                                                        """
                                                                                        Operational state parameters of the BCN level
                                                                                        
                                                                                        .. attribute:: constraint_id
                                                                                        
                                                                                        	Unique reference for the bandwidth constraint level
                                                                                        	**type**\: int
                                                                                        
                                                                                        	**range:** 0..4294967295
                                                                                        
                                                                                        .. attribute:: bandwidth
                                                                                        
                                                                                        	The bandwidth constraint, expressed as a 32\-bit IEEE floating point number expressed in bytes per second
                                                                                        	**type**\: str
                                                                                        
                                                                                        	**units**\: byte/s
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'clns-isis-oper'
                                                                                        _revision = '2018-04-07'

                                                                                        def __init__(self):
                                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsBandwidthConstraints.SubtlvsBandwidthConstraint.BandwidthConstraintsConstraints.BandwidthConstraintsConstraint.State, self).__init__()

                                                                                            self.yang_name = "state"
                                                                                            self.yang_parent_name = "bandwidth-constraints-constraint"
                                                                                            self.is_top_level_class = False
                                                                                            self.has_list_ancestor = True
                                                                                            self.ylist_key_names = []
                                                                                            self._child_classes = OrderedDict([])
                                                                                            self._leafs = OrderedDict([
                                                                                                ('constraint_id', (YLeaf(YType.uint32, 'constraint-id'), ['int'])),
                                                                                                ('bandwidth', (YLeaf(YType.str, 'bandwidth'), ['str'])),
                                                                                            ])
                                                                                            self.constraint_id = None
                                                                                            self.bandwidth = None
                                                                                            self._segment_path = lambda: "state"
                                                                                            self._is_frozen = True

                                                                                        def __setattr__(self, name, value):
                                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsBandwidthConstraints.SubtlvsBandwidthConstraint.BandwidthConstraintsConstraints.BandwidthConstraintsConstraint.State, [u'constraint_id', u'bandwidth'], name, value)


                                                                            class SubtlvsBandwidthConstraintsState(Entity):
                                                                                """
                                                                                State parameters of IS
                                                                                Extended Reachability sub\-TLV
                                                                                22
                                                                                
                                                                                .. attribute:: model_id
                                                                                
                                                                                	Identifier for the Bandwidth Constraints  Model currently in use by the LSR initiating the IGP advertisement
                                                                                	**type**\: int
                                                                                
                                                                                	**range:** 0..255
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'clns-isis-oper'
                                                                                _revision = '2018-04-07'

                                                                                def __init__(self):
                                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsBandwidthConstraints.SubtlvsBandwidthConstraint.SubtlvsBandwidthConstraintsState, self).__init__()

                                                                                    self.yang_name = "subtlvs-bandwidth-constraints-state"
                                                                                    self.yang_parent_name = "subtlvs-bandwidth-constraint"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('model_id', (YLeaf(YType.uint8, 'model-id'), ['int'])),
                                                                                    ])
                                                                                    self.model_id = None
                                                                                    self._segment_path = lambda: "subtlvs-bandwidth-constraints-state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsBandwidthConstraints.SubtlvsBandwidthConstraint.SubtlvsBandwidthConstraintsState, [u'model_id'], name, value)


                                                                    class SubtlvsUnreservedBandwidths(Entity):
                                                                        """
                                                                        Setup priority (0 through 7) for
                                                                        unreserved bandwidth
                                                                        
                                                                        .. attribute:: subtlvs_unreserved_bandwidth
                                                                        
                                                                        	Setup priority (0 through 7) for unreserved bandwidth
                                                                        	**type**\: list of  		 :py:class:`SubtlvsUnreservedBandwidth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsUnreservedBandwidths.SubtlvsUnreservedBandwidth>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsUnreservedBandwidths, self).__init__()

                                                                            self.yang_name = "subtlvs-unreserved-bandwidths"
                                                                            self.yang_parent_name = "mt-isn-neighbors-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("subtlvs-unreserved-bandwidth", ("subtlvs_unreserved_bandwidth", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsUnreservedBandwidths.SubtlvsUnreservedBandwidth))])
                                                                            self._leafs = OrderedDict()

                                                                            self.subtlvs_unreserved_bandwidth = YList(self)
                                                                            self._segment_path = lambda: "subtlvs-unreserved-bandwidths"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsUnreservedBandwidths, [], name, value)


                                                                        class SubtlvsUnreservedBandwidth(Entity):
                                                                            """
                                                                            Setup priority (0 through 7)
                                                                            for unreserved bandwidth
                                                                            
                                                                            .. attribute:: priority  (key)
                                                                            
                                                                            	Reference to the setup priority to which the unreserved bandwidth corresponds
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                            	State parameters of IS Extended Reachability sub\-TLV 11
                                                                            	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsUnreservedBandwidths.SubtlvsUnreservedBandwidth.State>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsUnreservedBandwidths.SubtlvsUnreservedBandwidth, self).__init__()

                                                                                self.yang_name = "subtlvs-unreserved-bandwidth"
                                                                                self.yang_parent_name = "subtlvs-unreserved-bandwidths"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = ['priority']
                                                                                self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsUnreservedBandwidths.SubtlvsUnreservedBandwidth.State))])
                                                                                self._leafs = OrderedDict([
                                                                                    ('priority', (YLeaf(YType.uint32, 'priority'), ['int'])),
                                                                                ])
                                                                                self.priority = None

                                                                                self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsUnreservedBandwidths.SubtlvsUnreservedBandwidth.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "subtlvs-unreserved-bandwidth" + "[priority='" + str(self.priority) + "']"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsUnreservedBandwidths.SubtlvsUnreservedBandwidth, ['priority'], name, value)


                                                                            class State(Entity):
                                                                                """
                                                                                State parameters of IS Extended Reachability
                                                                                sub\-TLV 11
                                                                                
                                                                                .. attribute:: priority
                                                                                
                                                                                	Setup priority level of 0 through 7 to be used by Unreserved Bandwidth sub\-TLV 11
                                                                                	**type**\: int
                                                                                
                                                                                	**range:** 0..255
                                                                                
                                                                                .. attribute:: unreserved_bandwidth
                                                                                
                                                                                	The amount of bandwidth reservable in this direction on this link
                                                                                	**type**\: str
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'clns-isis-oper'
                                                                                _revision = '2018-04-07'

                                                                                def __init__(self):
                                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsUnreservedBandwidths.SubtlvsUnreservedBandwidth.State, self).__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "subtlvs-unreserved-bandwidth"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                                        ('unreserved_bandwidth', (YLeaf(YType.str, 'unreserved-bandwidth'), ['str'])),
                                                                                    ])
                                                                                    self.priority = None
                                                                                    self.unreserved_bandwidth = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsUnreservedBandwidths.SubtlvsUnreservedBandwidth.State, [u'priority', u'unreserved_bandwidth'], name, value)


                                                                    class SubtlvsIpv4NeighborAddress(Entity):
                                                                        """
                                                                        This container defines sub\-TLV 8
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 8
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv4NeighborAddress.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv4NeighborAddress, self).__init__()

                                                                            self.yang_name = "subtlvs-ipv4-neighbor-address"
                                                                            self.yang_parent_name = "mt-isn-neighbors-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv4NeighborAddress.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv4NeighborAddress.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "subtlvs-ipv4-neighbor-address"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv4NeighborAddress, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 8
                                                                            
                                                                            .. attribute:: ipv4_neighbor_address
                                                                            
                                                                            	A single IPv4 address for a neighboring router on this link
                                                                            	**type**\: list of str
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv4NeighborAddress.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "subtlvs-ipv4-neighbor-address"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('ipv4_neighbor_address', (YLeafList(YType.str, 'ipv4-neighbor-address'), ['str'])),
                                                                                ])
                                                                                self.ipv4_neighbor_address = []
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv4NeighborAddress.State, [u'ipv4_neighbor_address'], name, value)


                                                                    class SubtlvsTeDefaultMetric(Entity):
                                                                        """
                                                                        This container defines sub\-TLV
                                                                        18
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 18
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsTeDefaultMetric.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsTeDefaultMetric, self).__init__()

                                                                            self.yang_name = "subtlvs-te-default-metric"
                                                                            self.yang_parent_name = "mt-isn-neighbors-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsTeDefaultMetric.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsTeDefaultMetric.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "subtlvs-te-default-metric"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsTeDefaultMetric, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 18
                                                                            
                                                                            .. attribute:: te_default_metric
                                                                            
                                                                            	This metric is administratively assigned and can be used to present a differently weighted topology to traffic engineering SPF calculations
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsTeDefaultMetric.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "subtlvs-te-default-metric"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('te_default_metric', (YLeaf(YType.uint32, 'te-default-metric'), ['int'])),
                                                                                ])
                                                                                self.te_default_metric = None
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsTeDefaultMetric.State, [u'te_default_metric'], name, value)


                                                                    class SubtlvsIpv6InterfaceAddress(Entity):
                                                                        """
                                                                        This container defines sub\-TLV
                                                                        12
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 12
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv6InterfaceAddress.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv6InterfaceAddress, self).__init__()

                                                                            self.yang_name = "subtlvs-ipv6-interface-address"
                                                                            self.yang_parent_name = "mt-isn-neighbors-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv6InterfaceAddress.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv6InterfaceAddress.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "subtlvs-ipv6-interface-address"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv6InterfaceAddress, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 12
                                                                            
                                                                            .. attribute:: ipv6_interface_address
                                                                            
                                                                            	Contains a 16\-octet IPv6 address for the interface described by the containing  Extended IS Reachability TLV
                                                                            	**type**\: list of str
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv6InterfaceAddress.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "subtlvs-ipv6-interface-address"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('ipv6_interface_address', (YLeafList(YType.str, 'ipv6-interface-address'), ['str'])),
                                                                                ])
                                                                                self.ipv6_interface_address = []
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsIpv6InterfaceAddress.State, [u'ipv6_interface_address'], name, value)


                                                                    class SubtlvsAdminGroup(Entity):
                                                                        """
                                                                        This container defines sub\-TLV 3
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 3
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsAdminGroup.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsAdminGroup, self).__init__()

                                                                            self.yang_name = "subtlvs-admin-group"
                                                                            self.yang_parent_name = "mt-isn-neighbors-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsAdminGroup.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsAdminGroup.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "subtlvs-admin-group"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsAdminGroup, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 3
                                                                            
                                                                            .. attribute:: admin_group
                                                                            
                                                                            	The administrative group sub\-TLV contains a 4\-octet bit mask assigned by the network administrator
                                                                            	**type**\: list of int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsAdminGroup.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "subtlvs-admin-group"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('admin_group', (YLeafList(YType.uint32, 'admin-group'), ['int'])),
                                                                                ])
                                                                                self.admin_group = []
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsAdminGroup.State, [u'admin_group'], name, value)


                                                                    class SubtlvsLanAdjacencySids(Entity):
                                                                        """
                                                                        Adjacency Segment\-IDs List
                                                                        
                                                                        .. attribute:: subtlvs_lan_adjacency_sid
                                                                        
                                                                        	Adjacency Segment\-IDs List
                                                                        	**type**\: list of  		 :py:class:`SubtlvsLanAdjacencySid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsLanAdjacencySids.SubtlvsLanAdjacencySid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsLanAdjacencySids, self).__init__()

                                                                            self.yang_name = "subtlvs-lan-adjacency-sids"
                                                                            self.yang_parent_name = "mt-isn-neighbors-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("subtlvs-lan-adjacency-sid", ("subtlvs_lan_adjacency_sid", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsLanAdjacencySids.SubtlvsLanAdjacencySid))])
                                                                            self._leafs = OrderedDict()

                                                                            self.subtlvs_lan_adjacency_sid = YList(self)
                                                                            self._segment_path = lambda: "subtlvs-lan-adjacency-sids"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsLanAdjacencySids, [], name, value)


                                                                        class SubtlvsLanAdjacencySid(Entity):
                                                                            """
                                                                            Adjacency Segment\-IDs List
                                                                            
                                                                            .. attribute:: value  (key)
                                                                            
                                                                            	Reference to the value of the LAN Adjacency\-SID
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                            	State parameters of LAN Adjacency\-SID
                                                                            	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsLanAdjacencySids.SubtlvsLanAdjacencySid.State>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsLanAdjacencySids.SubtlvsLanAdjacencySid, self).__init__()

                                                                                self.yang_name = "subtlvs-lan-adjacency-sid"
                                                                                self.yang_parent_name = "subtlvs-lan-adjacency-sids"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = ['value']
                                                                                self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsLanAdjacencySids.SubtlvsLanAdjacencySid.State))])
                                                                                self._leafs = OrderedDict([
                                                                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                                                                ])
                                                                                self.value = None

                                                                                self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsLanAdjacencySids.SubtlvsLanAdjacencySid.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "subtlvs-lan-adjacency-sid" + "[value='" + str(self.value) + "']"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsLanAdjacencySids.SubtlvsLanAdjacencySid, ['value'], name, value)


                                                                            class State(Entity):
                                                                                """
                                                                                State parameters of LAN Adjacency\-SID
                                                                                
                                                                                .. attribute:: value
                                                                                
                                                                                	LAN Adjacency\-SID value
                                                                                	**type**\: int
                                                                                
                                                                                	**range:** 0..4294967295
                                                                                
                                                                                .. attribute:: weight
                                                                                
                                                                                	Value that represents the weight of the Adj\-SID for the purpose of load balancing
                                                                                	**type**\: int
                                                                                
                                                                                	**range:** 0..255
                                                                                
                                                                                .. attribute:: neighbor_id
                                                                                
                                                                                	System ID of the neighbor associated with the LAN\- Adj\-Segment\-ID value
                                                                                	**type**\: str
                                                                                
                                                                                .. attribute:: flags
                                                                                
                                                                                	Flags associated with LAN\-Adj\-Segment\-ID
                                                                                	**type**\: list of   :py:class:`OpenconfigIsisLspLanAdjacencySidStateFlagsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisLspLanAdjacencySidStateFlagsEnum>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'clns-isis-oper'
                                                                                _revision = '2018-04-07'

                                                                                def __init__(self):
                                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsLanAdjacencySids.SubtlvsLanAdjacencySid.State, self).__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "subtlvs-lan-adjacency-sid"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                                                        ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisLspLanAdjacencySidStateFlagsEnum', '')])),
                                                                                    ])
                                                                                    self.value = None
                                                                                    self.weight = None
                                                                                    self.neighbor_id = None
                                                                                    self.flags = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsLanAdjacencySids.SubtlvsLanAdjacencySid.State, [u'value', u'weight', u'neighbor_id', u'flags'], name, value)


                                                                    class SubtlvsExtendedAdminGroup(Entity):
                                                                        """
                                                                        This container defines sub\-TLV
                                                                        14
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 14
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsExtendedAdminGroup.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsExtendedAdminGroup, self).__init__()

                                                                            self.yang_name = "subtlvs-extended-admin-group"
                                                                            self.yang_parent_name = "mt-isn-neighbors-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsExtendedAdminGroup.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsExtendedAdminGroup.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "subtlvs-extended-admin-group"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsExtendedAdminGroup, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 14
                                                                            
                                                                            .. attribute:: extended_admin_group
                                                                            
                                                                            	The extended\-admin\-group sub\-TLV is used in addition to the Administrative Groups when it is desirable to make more than 32 colors available for advertisement in a network
                                                                            	**type**\: list of int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsExtendedAdminGroup.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "subtlvs-extended-admin-group"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('extended_admin_group', (YLeafList(YType.uint32, 'extended-admin-group'), ['int'])),
                                                                                ])
                                                                                self.extended_admin_group = []
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsSubtlvs.MtIsnNeighborsSubtlv.SubtlvsExtendedAdminGroup.State, [u'extended_admin_group'], name, value)


                                                            class MtIsnNeighborsState(Entity):
                                                                """
                                                                State parameters of MT neighbor
                                                                
                                                                .. attribute:: mt_id
                                                                
                                                                	Identifier of a topology being announced
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: system_id
                                                                
                                                                	System\-id of the IS neighbor
                                                                	**type**\: str
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	ISIS metric value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsState, self).__init__()

                                                                    self.yang_name = "mt-isn-neighbors-state"
                                                                    self.yang_parent_name = "mt-isn-neighbor"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('mt_id', (YLeaf(YType.uint16, 'mt-id'), ['int'])),
                                                                        ('system_id', (YLeaf(YType.str, 'system-id'), ['str'])),
                                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                    ])
                                                                    self.mt_id = None
                                                                    self.system_id = None
                                                                    self.metric = None
                                                                    self._segment_path = lambda: "mt-isn-neighbors-state"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsState, [u'mt_id', u'system_id', u'metric'], name, value)


                                                            class MtIsnNeighborsUndefinedSubtlvs(Entity):
                                                                """
                                                                Sub\-TLVs that are not defined in
                                                                the model or not recognised by
                                                                system
                                                                
                                                                .. attribute:: mt_isn_neighbors_undefined_subtlv
                                                                
                                                                	Sub\-TLVs that are not defined in the model or not recognised by system
                                                                	**type**\: list of  		 :py:class:`MtIsnNeighborsUndefinedSubtlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsUndefinedSubtlvs.MtIsnNeighborsUndefinedSubtlv>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsUndefinedSubtlvs, self).__init__()

                                                                    self.yang_name = "mt-isn-neighbors-undefined-subtlvs"
                                                                    self.yang_parent_name = "mt-isn-neighbor"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("mt-isn-neighbors-undefined-subtlv", ("mt_isn_neighbors_undefined_subtlv", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsUndefinedSubtlvs.MtIsnNeighborsUndefinedSubtlv))])
                                                                    self._leafs = OrderedDict()

                                                                    self.mt_isn_neighbors_undefined_subtlv = YList(self)
                                                                    self._segment_path = lambda: "mt-isn-neighbors-undefined-subtlvs"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsUndefinedSubtlvs, [], name, value)


                                                                class MtIsnNeighborsUndefinedSubtlv(Entity):
                                                                    """
                                                                    Sub\-TLVs that are not defined in
                                                                    the model or not recognised by
                                                                    system
                                                                    
                                                                    .. attribute:: type  (key)
                                                                    
                                                                    	Reference to the type of the undefined sub\-TLV
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of the undefined sub\-TLV
                                                                    	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsUndefinedSubtlvs.MtIsnNeighborsUndefinedSubtlv.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'clns-isis-oper'
                                                                    _revision = '2018-04-07'

                                                                    def __init__(self):
                                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsUndefinedSubtlvs.MtIsnNeighborsUndefinedSubtlv, self).__init__()

                                                                        self.yang_name = "mt-isn-neighbors-undefined-subtlv"
                                                                        self.yang_parent_name = "mt-isn-neighbors-undefined-subtlvs"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = ['type']
                                                                        self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsUndefinedSubtlvs.MtIsnNeighborsUndefinedSubtlv.State))])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.uint32, 'type'), ['int'])),
                                                                        ])
                                                                        self.type = None

                                                                        self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsUndefinedSubtlvs.MtIsnNeighborsUndefinedSubtlv.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._segment_path = lambda: "mt-isn-neighbors-undefined-subtlv" + "[type='" + str(self.type) + "']"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsUndefinedSubtlvs.MtIsnNeighborsUndefinedSubtlv, ['type'], name, value)


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of the undefined sub\-TLV
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	TLV Type
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: length
                                                                        
                                                                        	TLV length
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: value
                                                                        
                                                                        	TLV value
                                                                        	**type**\: str
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsUndefinedSubtlvs.MtIsnNeighborsUndefinedSubtlv.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "mt-isn-neighbors-undefined-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                                                ('length', (YLeaf(YType.uint8, 'length'), ['int'])),
                                                                                ('value', (YLeaf(YType.str, 'value'), ['str'])),
                                                                            ])
                                                                            self.type = None
                                                                            self.length = None
                                                                            self.value = None
                                                                            self._segment_path = lambda: "state"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIsn.MtIsnNeighbors.MtIsnNeighbor.MtIsnNeighborsUndefinedSubtlvs.MtIsnNeighborsUndefinedSubtlv.State, [u'type', u'length', u'value'], name, value)


                                                class Ipv6Srlgs(Entity):
                                                    """
                                                    Instance of the IPv6 SRLG TLV
                                                    
                                                    .. attribute:: ipv6_srlg
                                                    
                                                    	Instance of the IPv6 SRLG TLV
                                                    	**type**\: list of  		 :py:class:`Ipv6Srlg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Srlgs.Ipv6Srlg>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Srlgs, self).__init__()

                                                        self.yang_name = "ipv6-srlgs"
                                                        self.yang_parent_name = "tlvs"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("ipv6-srlg", ("ipv6_srlg", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Srlgs.Ipv6Srlg))])
                                                        self._leafs = OrderedDict()

                                                        self.ipv6_srlg = YList(self)
                                                        self._segment_path = lambda: "ipv6-srlgs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Srlgs, [], name, value)


                                                    class Ipv6Srlg(Entity):
                                                        """
                                                        Instance of the IPv6 SRLG TLV
                                                        
                                                        .. attribute:: instance_number  (key)
                                                        
                                                        	Reference to the instance number of the IPv6 Shared Risk Link Group (SRLG) TLV
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	State parameters of TLV 139
                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Srlgs.Ipv6Srlg.State>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Srlgs.Ipv6Srlg, self).__init__()

                                                            self.yang_name = "ipv6-srlg"
                                                            self.yang_parent_name = "ipv6-srlgs"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['instance_number']
                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Srlgs.Ipv6Srlg.State))])
                                                            self._leafs = OrderedDict([
                                                                ('instance_number', (YLeaf(YType.uint32, 'instance-number'), ['int'])),
                                                            ])
                                                            self.instance_number = None

                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Srlgs.Ipv6Srlg.State()
                                                            self.state.parent = self
                                                            self._children_name_map["state"] = "state"
                                                            self._segment_path = lambda: "ipv6-srlg" + "[instance-number='" + str(self.instance_number) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Srlgs.Ipv6Srlg, ['instance_number'], name, value)


                                                        class State(Entity):
                                                            """
                                                            State parameters of TLV 139
                                                            
                                                            .. attribute:: instance_number
                                                            
                                                            	An arbitrary unsigned 32\-bit integer used to disambiguate the instance of TLV 138
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: system_id
                                                            
                                                            	Neighbor system ID
                                                            	**type**\: str
                                                            
                                                            .. attribute:: psn_number
                                                            
                                                            	Pseudonode number if the neighbor is on a LAN interface
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ipv6_interface_address
                                                            
                                                            	IPv6 interface address or Link Local Identifier
                                                            	**type**\: str
                                                            
                                                            .. attribute:: ipv6_neighbor_address
                                                            
                                                            	IPv6 neighbor address or Link Remote Identifier
                                                            	**type**\: str
                                                            
                                                            .. attribute:: flags
                                                            
                                                            	IPv6 SRLG flags
                                                            	**type**\: list of   :py:class:`OpenconfigIsisLspIpv6SrlgStateFlagsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisLspIpv6SrlgStateFlagsEnum>`
                                                            
                                                            .. attribute:: srlg_value
                                                            
                                                            	SRLG values
                                                            	**type**\: list of int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'clns-isis-oper'
                                                            _revision = '2018-04-07'

                                                            def __init__(self):
                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Srlgs.Ipv6Srlg.State, self).__init__()

                                                                self.yang_name = "state"
                                                                self.yang_parent_name = "ipv6-srlg"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('instance_number', (YLeaf(YType.uint32, 'instance-number'), ['int'])),
                                                                    ('system_id', (YLeaf(YType.str, 'system-id'), ['str'])),
                                                                    ('psn_number', (YLeaf(YType.uint8, 'psn-number'), ['int'])),
                                                                    ('ipv6_interface_address', (YLeaf(YType.str, 'ipv6-interface-address'), ['str'])),
                                                                    ('ipv6_neighbor_address', (YLeaf(YType.str, 'ipv6-neighbor-address'), ['str'])),
                                                                    ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisLspIpv6SrlgStateFlagsEnum', '')])),
                                                                    ('srlg_value', (YLeafList(YType.uint32, 'srlg-value'), ['int'])),
                                                                ])
                                                                self.instance_number = None
                                                                self.system_id = None
                                                                self.psn_number = None
                                                                self.ipv6_interface_address = None
                                                                self.ipv6_neighbor_address = None
                                                                self.flags = []
                                                                self.srlg_value = []
                                                                self._segment_path = lambda: "state"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Srlgs.Ipv6Srlg.State, [u'instance_number', u'system_id', u'psn_number', u'ipv6_interface_address', u'ipv6_neighbor_address', u'flags', u'srlg_value'], name, value)


                                                class TlvsState(Entity):
                                                    """
                                                    Operational state parameters relating
                                                    to the specified LSP
                                                    
                                                    .. attribute:: type
                                                    
                                                    	The type of TLV being described
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.TlvsState, self).__init__()

                                                        self.yang_name = "tlvs-state"
                                                        self.yang_parent_name = "tlvs"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('type', (YLeaf(YType.str, 'type'), ['str'])),
                                                        ])
                                                        self.type = None
                                                        self._segment_path = lambda: "tlvs-state"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.TlvsState, [u'type'], name, value)


                                                class PurgeOi(Entity):
                                                    """
                                                    This container defines ISIS purge TLV
                                                    
                                                    .. attribute:: state
                                                    
                                                    	State parameters of TLV 13
                                                    	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.PurgeOi.State>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.PurgeOi, self).__init__()

                                                        self.yang_name = "purge-oi"
                                                        self.yang_parent_name = "tlvs"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.PurgeOi.State))])
                                                        self._leafs = OrderedDict()

                                                        self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.PurgeOi.State()
                                                        self.state.parent = self
                                                        self._children_name_map["state"] = "state"
                                                        self._segment_path = lambda: "purge-oi"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.PurgeOi, [], name, value)


                                                    class State(Entity):
                                                        """
                                                        State parameters of TLV 13
                                                        
                                                        .. attribute:: system_id_count
                                                        
                                                        	Number of system IDs carried in this TLV
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: source_system_id
                                                        
                                                        	System ID of the Intermediate System that inserted this TLV
                                                        	**type**\: str
                                                        
                                                        .. attribute:: received_system_id
                                                        
                                                        	System ID of the Intermediate System from which the purge was received
                                                        	**type**\: str
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.PurgeOi.State, self).__init__()

                                                            self.yang_name = "state"
                                                            self.yang_parent_name = "purge-oi"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('system_id_count', (YLeaf(YType.uint8, 'system-id-count'), ['int'])),
                                                                ('source_system_id', (YLeaf(YType.str, 'source-system-id'), ['str'])),
                                                                ('received_system_id', (YLeaf(YType.str, 'received-system-id'), ['str'])),
                                                            ])
                                                            self.system_id_count = None
                                                            self.source_system_id = None
                                                            self.received_system_id = None
                                                            self._segment_path = lambda: "state"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.PurgeOi.State, [u'system_id_count', u'source_system_id', u'received_system_id'], name, value)


                                                class HostName(Entity):
                                                    """
                                                    This container defines TLV 137
                                                    
                                                    .. attribute:: state
                                                    
                                                    	State parameters of ISIS TLV 137
                                                    	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.HostName.State>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.HostName, self).__init__()

                                                        self.yang_name = "host-name"
                                                        self.yang_parent_name = "tlvs"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.HostName.State))])
                                                        self._leafs = OrderedDict()

                                                        self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.HostName.State()
                                                        self.state.parent = self
                                                        self._children_name_map["state"] = "state"
                                                        self._segment_path = lambda: "host-name"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.HostName, [], name, value)


                                                    class State(Entity):
                                                        """
                                                        State parameters of ISIS TLV 137
                                                        
                                                        .. attribute:: host_name
                                                        
                                                        	Name of the node
                                                        	**type**\: list of str
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.HostName.State, self).__init__()

                                                            self.yang_name = "state"
                                                            self.yang_parent_name = "host-name"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('host_name', (YLeafList(YType.str, 'host-name'), ['str'])),
                                                            ])
                                                            self.host_name = []
                                                            self._segment_path = lambda: "state"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.HostName.State, [u'host_name'], name, value)


                                                class Ipv6Reachability(Entity):
                                                    """
                                                    This container defines list of IPv6
                                                    reachability information
                                                    
                                                    .. attribute:: ipv6_reachability_prefixes
                                                    
                                                    	This list defines IPv6 extended prefix attributes
                                                    	**type**\:  :py:class:`Ipv6ReachabilityPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability, self).__init__()

                                                        self.yang_name = "ipv6-reachability"
                                                        self.yang_parent_name = "tlvs"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("ipv6-reachability-prefixes", ("ipv6_reachability_prefixes", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes))])
                                                        self._leafs = OrderedDict()

                                                        self.ipv6_reachability_prefixes = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes()
                                                        self.ipv6_reachability_prefixes.parent = self
                                                        self._children_name_map["ipv6_reachability_prefixes"] = "ipv6-reachability-prefixes"
                                                        self._segment_path = lambda: "ipv6-reachability"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability, [], name, value)


                                                    class Ipv6ReachabilityPrefixes(Entity):
                                                        """
                                                        This list defines IPv6 extended
                                                        prefix attributes
                                                        
                                                        .. attribute:: ipv6_reachability_prefixe
                                                        
                                                        	This list defines IPv6 extended prefix attributes
                                                        	**type**\: list of  		 :py:class:`Ipv6ReachabilityPrefixe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes, self).__init__()

                                                            self.yang_name = "ipv6-reachability-prefixes"
                                                            self.yang_parent_name = "ipv6-reachability"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("ipv6-reachability-prefixe", ("ipv6_reachability_prefixe", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe))])
                                                            self._leafs = OrderedDict()

                                                            self.ipv6_reachability_prefixe = YList(self)
                                                            self._segment_path = lambda: "ipv6-reachability-prefixes"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes, [], name, value)


                                                        class Ipv6ReachabilityPrefixe(Entity):
                                                            """
                                                            This list defines IPv6 extended
                                                            prefix attributes
                                                            
                                                            .. attribute:: prefix  (key)
                                                            
                                                            	Reference to the IPv6 prefix that the TLV corresponds to
                                                            	**type**\: str
                                                            
                                                            .. attribute:: ipv6_reachability_prefixes_state
                                                            
                                                            	State parameters of IPv6 prefix attributes
                                                            	**type**\:  :py:class:`Ipv6ReachabilityPrefixesState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesState>`
                                                            
                                                            .. attribute:: ipv6_reachability_prefixes_subtlvs
                                                            
                                                            	List of subTLV types in the LSDB for the specified TLV
                                                            	**type**\:  :py:class:`Ipv6ReachabilityPrefixesSubtlvs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs>`
                                                            
                                                            .. attribute:: ipv6_reachability_prefixes_undefined_subtlvs
                                                            
                                                            	Sub\-TLVs that are not defined in the model or not recognised by system
                                                            	**type**\:  :py:class:`Ipv6ReachabilityPrefixesUndefinedSubtlvs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesUndefinedSubtlvs>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'clns-isis-oper'
                                                            _revision = '2018-04-07'

                                                            def __init__(self):
                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe, self).__init__()

                                                                self.yang_name = "ipv6-reachability-prefixe"
                                                                self.yang_parent_name = "ipv6-reachability-prefixes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['prefix']
                                                                self._child_classes = OrderedDict([("ipv6-reachability-prefixes-state", ("ipv6_reachability_prefixes_state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesState)), ("ipv6-reachability-prefixes-subtlvs", ("ipv6_reachability_prefixes_subtlvs", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs)), ("ipv6-reachability-prefixes-undefined-subtlvs", ("ipv6_reachability_prefixes_undefined_subtlvs", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesUndefinedSubtlvs))])
                                                                self._leafs = OrderedDict([
                                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ])
                                                                self.prefix = None

                                                                self.ipv6_reachability_prefixes_state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesState()
                                                                self.ipv6_reachability_prefixes_state.parent = self
                                                                self._children_name_map["ipv6_reachability_prefixes_state"] = "ipv6-reachability-prefixes-state"

                                                                self.ipv6_reachability_prefixes_subtlvs = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs()
                                                                self.ipv6_reachability_prefixes_subtlvs.parent = self
                                                                self._children_name_map["ipv6_reachability_prefixes_subtlvs"] = "ipv6-reachability-prefixes-subtlvs"

                                                                self.ipv6_reachability_prefixes_undefined_subtlvs = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesUndefinedSubtlvs()
                                                                self.ipv6_reachability_prefixes_undefined_subtlvs.parent = self
                                                                self._children_name_map["ipv6_reachability_prefixes_undefined_subtlvs"] = "ipv6-reachability-prefixes-undefined-subtlvs"
                                                                self._segment_path = lambda: "ipv6-reachability-prefixe" + "[prefix='" + str(self.prefix) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe, ['prefix'], name, value)


                                                            class Ipv6ReachabilityPrefixesState(Entity):
                                                                """
                                                                State parameters of IPv6 prefix
                                                                attributes
                                                                
                                                                .. attribute:: up_down
                                                                
                                                                	The up/down bit
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: sbit
                                                                
                                                                	The Sub\-TLV present bit
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: prefix
                                                                
                                                                	IPv4 prefix contained within extended reachability TLVs
                                                                	**type**\: str
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	ISIS metric value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesState, self).__init__()

                                                                    self.yang_name = "ipv6-reachability-prefixes-state"
                                                                    self.yang_parent_name = "ipv6-reachability-prefixe"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('up_down', (YLeaf(YType.boolean, 'up-down'), ['bool'])),
                                                                        ('sbit', (YLeaf(YType.boolean, 'sbit'), ['bool'])),
                                                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                    ])
                                                                    self.up_down = None
                                                                    self.sbit = None
                                                                    self.prefix = None
                                                                    self.metric = None
                                                                    self._segment_path = lambda: "ipv6-reachability-prefixes-state"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesState, [u'up_down', u'sbit', u'prefix', u'metric'], name, value)


                                                            class Ipv6ReachabilityPrefixesSubtlvs(Entity):
                                                                """
                                                                List of subTLV types in the LSDB
                                                                for the specified TLV
                                                                
                                                                .. attribute:: ipv6_reachability_prefixes_subtlv
                                                                
                                                                	List of subTLV types in the LSDB for the specified TLV
                                                                	**type**\: list of  		 :py:class:`Ipv6ReachabilityPrefixesSubtlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs, self).__init__()

                                                                    self.yang_name = "ipv6-reachability-prefixes-subtlvs"
                                                                    self.yang_parent_name = "ipv6-reachability-prefixe"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("ipv6-reachability-prefixes-subtlv", ("ipv6_reachability_prefixes_subtlv", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv))])
                                                                    self._leafs = OrderedDict()

                                                                    self.ipv6_reachability_prefixes_subtlv = YList(self)
                                                                    self._segment_path = lambda: "ipv6-reachability-prefixes-subtlvs"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs, [], name, value)


                                                                class Ipv6ReachabilityPrefixesSubtlv(Entity):
                                                                    """
                                                                    List of subTLV types in the LSDB
                                                                    for the specified TLV
                                                                    
                                                                    .. attribute:: type  (key)
                                                                    
                                                                    	Reference to the sub\-TLV type
                                                                    	**type**\: str
                                                                    
                                                                    .. attribute:: subtlvs_tag
                                                                    
                                                                    	This container defines sub\-TLV 1
                                                                    	**type**\:  :py:class:`SubtlvsTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsTag>`
                                                                    
                                                                    .. attribute:: subtlvs_tag64
                                                                    
                                                                    	This container defines sub\-TLV 2
                                                                    	**type**\:  :py:class:`SubtlvsTag64 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsTag64>`
                                                                    
                                                                    .. attribute:: subtlvs_prefix_sids
                                                                    
                                                                    	Prefix Segment\-ID list
                                                                    	**type**\:  :py:class:`SubtlvsPrefixSids <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsPrefixSids>`
                                                                    
                                                                    .. attribute:: subtlvs_ipv4_source_router_id
                                                                    
                                                                    	This container defines sub\-TLV 11
                                                                    	**type**\:  :py:class:`SubtlvsIpv4SourceRouterId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsIpv4SourceRouterId>`
                                                                    
                                                                    .. attribute:: ipv6_reachability_prefixes_subtlvs_state
                                                                    
                                                                    	State parameters for a prefix
                                                                    	**type**\:  :py:class:`Ipv6ReachabilityPrefixesSubtlvsState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.Ipv6ReachabilityPrefixesSubtlvsState>`
                                                                    
                                                                    .. attribute:: subtlvs_ipv6_source_router_id
                                                                    
                                                                    	This container defines sub\-TLV 12
                                                                    	**type**\:  :py:class:`SubtlvsIpv6SourceRouterId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsIpv6SourceRouterId>`
                                                                    
                                                                    .. attribute:: subtlvs_flags
                                                                    
                                                                    	This container defines sub\-TLV 4
                                                                    	**type**\:  :py:class:`SubtlvsFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsFlags>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'clns-isis-oper'
                                                                    _revision = '2018-04-07'

                                                                    def __init__(self):
                                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv, self).__init__()

                                                                        self.yang_name = "ipv6-reachability-prefixes-subtlv"
                                                                        self.yang_parent_name = "ipv6-reachability-prefixes-subtlvs"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = ['type']
                                                                        self._child_classes = OrderedDict([("subtlvs-tag", ("subtlvs_tag", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsTag)), ("subtlvs-tag64", ("subtlvs_tag64", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsTag64)), ("subtlvs-prefix-sids", ("subtlvs_prefix_sids", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsPrefixSids)), ("subtlvs-ipv4-source-router-id", ("subtlvs_ipv4_source_router_id", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsIpv4SourceRouterId)), ("ipv6-reachability-prefixes-subtlvs-state", ("ipv6_reachability_prefixes_subtlvs_state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.Ipv6ReachabilityPrefixesSubtlvsState)), ("subtlvs-ipv6-source-router-id", ("subtlvs_ipv6_source_router_id", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsIpv6SourceRouterId)), ("subtlvs-flags", ("subtlvs_flags", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsFlags))])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.str, 'type'), ['str'])),
                                                                        ])
                                                                        self.type = None

                                                                        self.subtlvs_tag = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsTag()
                                                                        self.subtlvs_tag.parent = self
                                                                        self._children_name_map["subtlvs_tag"] = "subtlvs-tag"

                                                                        self.subtlvs_tag64 = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsTag64()
                                                                        self.subtlvs_tag64.parent = self
                                                                        self._children_name_map["subtlvs_tag64"] = "subtlvs-tag64"

                                                                        self.subtlvs_prefix_sids = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsPrefixSids()
                                                                        self.subtlvs_prefix_sids.parent = self
                                                                        self._children_name_map["subtlvs_prefix_sids"] = "subtlvs-prefix-sids"

                                                                        self.subtlvs_ipv4_source_router_id = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsIpv4SourceRouterId()
                                                                        self.subtlvs_ipv4_source_router_id.parent = self
                                                                        self._children_name_map["subtlvs_ipv4_source_router_id"] = "subtlvs-ipv4-source-router-id"

                                                                        self.ipv6_reachability_prefixes_subtlvs_state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.Ipv6ReachabilityPrefixesSubtlvsState()
                                                                        self.ipv6_reachability_prefixes_subtlvs_state.parent = self
                                                                        self._children_name_map["ipv6_reachability_prefixes_subtlvs_state"] = "ipv6-reachability-prefixes-subtlvs-state"

                                                                        self.subtlvs_ipv6_source_router_id = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsIpv6SourceRouterId()
                                                                        self.subtlvs_ipv6_source_router_id.parent = self
                                                                        self._children_name_map["subtlvs_ipv6_source_router_id"] = "subtlvs-ipv6-source-router-id"

                                                                        self.subtlvs_flags = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsFlags()
                                                                        self.subtlvs_flags.parent = self
                                                                        self._children_name_map["subtlvs_flags"] = "subtlvs-flags"
                                                                        self._segment_path = lambda: "ipv6-reachability-prefixes-subtlv" + "[type='" + str(self.type) + "']"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv, ['type'], name, value)


                                                                    class SubtlvsTag(Entity):
                                                                        """
                                                                        This container defines sub\-TLV 1
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 1
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsTag.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsTag, self).__init__()

                                                                            self.yang_name = "subtlvs-tag"
                                                                            self.yang_parent_name = "ipv6-reachability-prefixes-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsTag.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsTag.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "subtlvs-tag"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsTag, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 1
                                                                            
                                                                            .. attribute:: tag32
                                                                            
                                                                            	List of 32\-bit tags associated with the prefix
                                                                            	**type**\: list of int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsTag.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "subtlvs-tag"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('tag32', (YLeafList(YType.uint32, 'tag32'), ['int'])),
                                                                                ])
                                                                                self.tag32 = []
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsTag.State, [u'tag32'], name, value)


                                                                    class SubtlvsTag64(Entity):
                                                                        """
                                                                        This container defines sub\-TLV 2
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 2
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsTag64.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsTag64, self).__init__()

                                                                            self.yang_name = "subtlvs-tag64"
                                                                            self.yang_parent_name = "ipv6-reachability-prefixes-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsTag64.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsTag64.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "subtlvs-tag64"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsTag64, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 2
                                                                            
                                                                            .. attribute:: tag64
                                                                            
                                                                            	List of 64\-bit tags associated with the prefix
                                                                            	**type**\: list of int
                                                                            
                                                                            	**range:** 0..18446744073709551615
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsTag64.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "subtlvs-tag64"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('tag64', (YLeafList(YType.uint64, 'tag64'), ['int'])),
                                                                                ])
                                                                                self.tag64 = []
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsTag64.State, [u'tag64'], name, value)


                                                                    class SubtlvsPrefixSids(Entity):
                                                                        """
                                                                        Prefix Segment\-ID list
                                                                        
                                                                        .. attribute:: subtlvs_prefix_sid
                                                                        
                                                                        	Prefix Segment\-ID list
                                                                        	**type**\: list of  		 :py:class:`SubtlvsPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsPrefixSids.SubtlvsPrefixSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsPrefixSids, self).__init__()

                                                                            self.yang_name = "subtlvs-prefix-sids"
                                                                            self.yang_parent_name = "ipv6-reachability-prefixes-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("subtlvs-prefix-sid", ("subtlvs_prefix_sid", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsPrefixSids.SubtlvsPrefixSid))])
                                                                            self._leafs = OrderedDict()

                                                                            self.subtlvs_prefix_sid = YList(self)
                                                                            self._segment_path = lambda: "subtlvs-prefix-sids"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsPrefixSids, [], name, value)


                                                                        class SubtlvsPrefixSid(Entity):
                                                                            """
                                                                            Prefix Segment\-ID list
                                                                            
                                                                            .. attribute:: value  (key)
                                                                            
                                                                            	Reference to the value of the prefix SID
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                            	State parameters for Prefix\-SID
                                                                            	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsPrefixSids.SubtlvsPrefixSid.State>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsPrefixSids.SubtlvsPrefixSid, self).__init__()

                                                                                self.yang_name = "subtlvs-prefix-sid"
                                                                                self.yang_parent_name = "subtlvs-prefix-sids"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = ['value']
                                                                                self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsPrefixSids.SubtlvsPrefixSid.State))])
                                                                                self._leafs = OrderedDict([
                                                                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                                                                ])
                                                                                self.value = None

                                                                                self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsPrefixSids.SubtlvsPrefixSid.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "subtlvs-prefix-sid" + "[value='" + str(self.value) + "']"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsPrefixSids.SubtlvsPrefixSid, ['value'], name, value)


                                                                            class State(Entity):
                                                                                """
                                                                                State parameters for Prefix\-SID
                                                                                
                                                                                .. attribute:: value
                                                                                
                                                                                	IGP Prefix\-SID value
                                                                                	**type**\: int
                                                                                
                                                                                	**range:** 0..4294967295
                                                                                
                                                                                .. attribute:: algorithm
                                                                                
                                                                                	Prefix\-SID algorithm to be used for path computation
                                                                                	**type**\: int
                                                                                
                                                                                	**range:** 0..255
                                                                                
                                                                                .. attribute:: flags
                                                                                
                                                                                	Flags associated with Prefix Segment\-ID
                                                                                	**type**\: list of   :py:class:`OpenconfigIsisLspPrefixSidStateFlagsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisLspPrefixSidStateFlagsEnum>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'clns-isis-oper'
                                                                                _revision = '2018-04-07'

                                                                                def __init__(self):
                                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsPrefixSids.SubtlvsPrefixSid.State, self).__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "subtlvs-prefix-sid"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                                                                        ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                                                                        ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisLspPrefixSidStateFlagsEnum', '')])),
                                                                                    ])
                                                                                    self.value = None
                                                                                    self.algorithm = None
                                                                                    self.flags = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsPrefixSids.SubtlvsPrefixSid.State, [u'value', u'algorithm', u'flags'], name, value)


                                                                    class SubtlvsIpv4SourceRouterId(Entity):
                                                                        """
                                                                        This container defines sub\-TLV
                                                                        11
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 11
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsIpv4SourceRouterId.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsIpv4SourceRouterId, self).__init__()

                                                                            self.yang_name = "subtlvs-ipv4-source-router-id"
                                                                            self.yang_parent_name = "ipv6-reachability-prefixes-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsIpv4SourceRouterId.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsIpv4SourceRouterId.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "subtlvs-ipv4-source-router-id"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsIpv4SourceRouterId, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 11
                                                                            
                                                                            .. attribute:: type
                                                                            
                                                                            	The type of subTLV being described
                                                                            	**type**\: str
                                                                            
                                                                            .. attribute:: ipv4_source_router_id
                                                                            
                                                                            	IPv4 Source router ID address
                                                                            	**type**\: str
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsIpv4SourceRouterId.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "subtlvs-ipv4-source-router-id"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('type', (YLeaf(YType.str, 'type'), ['str'])),
                                                                                    ('ipv4_source_router_id', (YLeaf(YType.str, 'ipv4-source-router-id'), ['str'])),
                                                                                ])
                                                                                self.type = None
                                                                                self.ipv4_source_router_id = None
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsIpv4SourceRouterId.State, [u'type', u'ipv4_source_router_id'], name, value)


                                                                    class Ipv6ReachabilityPrefixesSubtlvsState(Entity):
                                                                        """
                                                                        State parameters for a prefix
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	The type of subTLV being described
                                                                        	**type**\: str
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.Ipv6ReachabilityPrefixesSubtlvsState, self).__init__()

                                                                            self.yang_name = "ipv6-reachability-prefixes-subtlvs-state"
                                                                            self.yang_parent_name = "ipv6-reachability-prefixes-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', (YLeaf(YType.str, 'type'), ['str'])),
                                                                            ])
                                                                            self.type = None
                                                                            self._segment_path = lambda: "ipv6-reachability-prefixes-subtlvs-state"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.Ipv6ReachabilityPrefixesSubtlvsState, [u'type'], name, value)


                                                                    class SubtlvsIpv6SourceRouterId(Entity):
                                                                        """
                                                                        This container defines sub\-TLV
                                                                        12
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 12
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsIpv6SourceRouterId.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsIpv6SourceRouterId, self).__init__()

                                                                            self.yang_name = "subtlvs-ipv6-source-router-id"
                                                                            self.yang_parent_name = "ipv6-reachability-prefixes-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsIpv6SourceRouterId.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsIpv6SourceRouterId.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "subtlvs-ipv6-source-router-id"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsIpv6SourceRouterId, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 12
                                                                            
                                                                            .. attribute:: type
                                                                            
                                                                            	The type of subTLV being described
                                                                            	**type**\: str
                                                                            
                                                                            .. attribute:: ipv6_source_router_id
                                                                            
                                                                            	IPv6 Source router ID address
                                                                            	**type**\: str
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsIpv6SourceRouterId.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "subtlvs-ipv6-source-router-id"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('type', (YLeaf(YType.str, 'type'), ['str'])),
                                                                                    ('ipv6_source_router_id', (YLeaf(YType.str, 'ipv6-source-router-id'), ['str'])),
                                                                                ])
                                                                                self.type = None
                                                                                self.ipv6_source_router_id = None
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsIpv6SourceRouterId.State, [u'type', u'ipv6_source_router_id'], name, value)


                                                                    class SubtlvsFlags(Entity):
                                                                        """
                                                                        This container defines sub\-TLV 4
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 4
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsFlags.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsFlags, self).__init__()

                                                                            self.yang_name = "subtlvs-flags"
                                                                            self.yang_parent_name = "ipv6-reachability-prefixes-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsFlags.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsFlags.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "subtlvs-flags"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsFlags, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 4
                                                                            
                                                                            .. attribute:: type
                                                                            
                                                                            	The type of subTLV being described
                                                                            	**type**\: str
                                                                            
                                                                            .. attribute:: flags
                                                                            
                                                                            	Additional prefix reachability flags
                                                                            	**type**\: list of   :py:class:`OpenconfigIsisLspFlagsStateFlagsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisLspFlagsStateFlagsEnum>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsFlags.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "subtlvs-flags"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('type', (YLeaf(YType.str, 'type'), ['str'])),
                                                                                    ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisLspFlagsStateFlagsEnum', '')])),
                                                                                ])
                                                                                self.type = None
                                                                                self.flags = []
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesSubtlvs.Ipv6ReachabilityPrefixesSubtlv.SubtlvsFlags.State, [u'type', u'flags'], name, value)


                                                            class Ipv6ReachabilityPrefixesUndefinedSubtlvs(Entity):
                                                                """
                                                                Sub\-TLVs that are not defined in
                                                                the model or not recognised by
                                                                system
                                                                
                                                                .. attribute:: ipv6_reachability_prefixes_undefined_subtlv
                                                                
                                                                	Sub\-TLVs that are not defined in the model or not recognised by system
                                                                	**type**\: list of  		 :py:class:`Ipv6ReachabilityPrefixesUndefinedSubtlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesUndefinedSubtlvs.Ipv6ReachabilityPrefixesUndefinedSubtlv>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesUndefinedSubtlvs, self).__init__()

                                                                    self.yang_name = "ipv6-reachability-prefixes-undefined-subtlvs"
                                                                    self.yang_parent_name = "ipv6-reachability-prefixe"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("ipv6-reachability-prefixes-undefined-subtlv", ("ipv6_reachability_prefixes_undefined_subtlv", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesUndefinedSubtlvs.Ipv6ReachabilityPrefixesUndefinedSubtlv))])
                                                                    self._leafs = OrderedDict()

                                                                    self.ipv6_reachability_prefixes_undefined_subtlv = YList(self)
                                                                    self._segment_path = lambda: "ipv6-reachability-prefixes-undefined-subtlvs"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesUndefinedSubtlvs, [], name, value)


                                                                class Ipv6ReachabilityPrefixesUndefinedSubtlv(Entity):
                                                                    """
                                                                    Sub\-TLVs that are not defined in
                                                                    the model or not recognised by
                                                                    system
                                                                    
                                                                    .. attribute:: type  (key)
                                                                    
                                                                    	Reference to the type of the undefined sub\-TLV
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of the undefined sub\-TLV
                                                                    	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesUndefinedSubtlvs.Ipv6ReachabilityPrefixesUndefinedSubtlv.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'clns-isis-oper'
                                                                    _revision = '2018-04-07'

                                                                    def __init__(self):
                                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesUndefinedSubtlvs.Ipv6ReachabilityPrefixesUndefinedSubtlv, self).__init__()

                                                                        self.yang_name = "ipv6-reachability-prefixes-undefined-subtlv"
                                                                        self.yang_parent_name = "ipv6-reachability-prefixes-undefined-subtlvs"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = ['type']
                                                                        self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesUndefinedSubtlvs.Ipv6ReachabilityPrefixesUndefinedSubtlv.State))])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.uint32, 'type'), ['int'])),
                                                                        ])
                                                                        self.type = None

                                                                        self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesUndefinedSubtlvs.Ipv6ReachabilityPrefixesUndefinedSubtlv.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._segment_path = lambda: "ipv6-reachability-prefixes-undefined-subtlv" + "[type='" + str(self.type) + "']"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesUndefinedSubtlvs.Ipv6ReachabilityPrefixesUndefinedSubtlv, ['type'], name, value)


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of the undefined sub\-TLV
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	TLV Type
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: length
                                                                        
                                                                        	TLV length
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: value
                                                                        
                                                                        	TLV value
                                                                        	**type**\: str
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesUndefinedSubtlvs.Ipv6ReachabilityPrefixesUndefinedSubtlv.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "ipv6-reachability-prefixes-undefined-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                                                ('length', (YLeaf(YType.uint8, 'length'), ['int'])),
                                                                                ('value', (YLeaf(YType.str, 'value'), ['str'])),
                                                                            ])
                                                                            self.type = None
                                                                            self.length = None
                                                                            self.value = None
                                                                            self._segment_path = lambda: "state"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6Reachability.Ipv6ReachabilityPrefixes.Ipv6ReachabilityPrefixe.Ipv6ReachabilityPrefixesUndefinedSubtlvs.Ipv6ReachabilityPrefixesUndefinedSubtlv.State, [u'type', u'length', u'value'], name, value)


                                                class Ipv6TeRouterId(Entity):
                                                    """
                                                    This container defines TLV 140
                                                    
                                                    .. attribute:: state
                                                    
                                                    	State parameters of ISIS TLV 140
                                                    	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6TeRouterId.State>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6TeRouterId, self).__init__()

                                                        self.yang_name = "ipv6-te-router-id"
                                                        self.yang_parent_name = "tlvs"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6TeRouterId.State))])
                                                        self._leafs = OrderedDict()

                                                        self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6TeRouterId.State()
                                                        self.state.parent = self
                                                        self._children_name_map["state"] = "state"
                                                        self._segment_path = lambda: "ipv6-te-router-id"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6TeRouterId, [], name, value)


                                                    class State(Entity):
                                                        """
                                                        State parameters of ISIS TLV 140
                                                        
                                                        .. attribute:: router_id
                                                        
                                                        	IPv6 Traffic Engineering router ID of the node
                                                        	**type**\: list of str
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6TeRouterId.State, self).__init__()

                                                            self.yang_name = "state"
                                                            self.yang_parent_name = "ipv6-te-router-id"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('router_id', (YLeafList(YType.str, 'router-id'), ['str'])),
                                                            ])
                                                            self.router_id = []
                                                            self._segment_path = lambda: "state"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6TeRouterId.State, [u'router_id'], name, value)


                                                class Ipv4InternalReachability(Entity):
                                                    """
                                                    This container defines list of IPv4
                                                    internal reachability information
                                                    
                                                    .. attribute:: prefixes
                                                    
                                                    	IPv4 prefixes and internal reachability attributes
                                                    	**type**\:  :py:class:`Prefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability, self).__init__()

                                                        self.yang_name = "ipv4-internal-reachability"
                                                        self.yang_parent_name = "tlvs"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefixes", ("prefixes", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes))])
                                                        self._leafs = OrderedDict()

                                                        self.prefixes = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes()
                                                        self.prefixes.parent = self
                                                        self._children_name_map["prefixes"] = "prefixes"
                                                        self._segment_path = lambda: "ipv4-internal-reachability"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability, [], name, value)


                                                    class Prefixes(Entity):
                                                        """
                                                        IPv4 prefixes and internal
                                                        reachability attributes
                                                        
                                                        .. attribute:: prefixe
                                                        
                                                        	IPv4 prefixes and internal reachability attributes
                                                        	**type**\: list of  		 :py:class:`Prefixe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes, self).__init__()

                                                            self.yang_name = "prefixes"
                                                            self.yang_parent_name = "ipv4-internal-reachability"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("prefixe", ("prefixe", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe))])
                                                            self._leafs = OrderedDict()

                                                            self.prefixe = YList(self)
                                                            self._segment_path = lambda: "prefixes"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes, [], name, value)


                                                        class Prefixe(Entity):
                                                            """
                                                            IPv4 prefixes and internal
                                                            reachability attributes
                                                            
                                                            .. attribute:: prefix  (key)
                                                            
                                                            	Reference to the IPv4 prefix
                                                            	**type**\: str
                                                            
                                                            .. attribute:: state
                                                            
                                                            	State parameters of IPv4 standard prefix
                                                            	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.State>`
                                                            
                                                            .. attribute:: default_metric
                                                            
                                                            	This container defines ISIS Default Metric
                                                            	**type**\:  :py:class:`DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.DefaultMetric>`
                                                            
                                                            .. attribute:: delay_metric
                                                            
                                                            	This container defines the ISIS delay metric
                                                            	**type**\:  :py:class:`DelayMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.DelayMetric>`
                                                            
                                                            .. attribute:: expense_metric
                                                            
                                                            	This container defines the ISIS expense metric
                                                            	**type**\:  :py:class:`ExpenseMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.ExpenseMetric>`
                                                            
                                                            .. attribute:: error_metric
                                                            
                                                            	This container defines the ISIS error metric
                                                            	**type**\:  :py:class:`ErrorMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.ErrorMetric>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'clns-isis-oper'
                                                            _revision = '2018-04-07'

                                                            def __init__(self):
                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe, self).__init__()

                                                                self.yang_name = "prefixe"
                                                                self.yang_parent_name = "prefixes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['prefix']
                                                                self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.State)), ("default-metric", ("default_metric", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.DefaultMetric)), ("delay-metric", ("delay_metric", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.DelayMetric)), ("expense-metric", ("expense_metric", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.ExpenseMetric)), ("error-metric", ("error_metric", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.ErrorMetric))])
                                                                self._leafs = OrderedDict([
                                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ])
                                                                self.prefix = None

                                                                self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.State()
                                                                self.state.parent = self
                                                                self._children_name_map["state"] = "state"

                                                                self.default_metric = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.DefaultMetric()
                                                                self.default_metric.parent = self
                                                                self._children_name_map["default_metric"] = "default-metric"

                                                                self.delay_metric = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.DelayMetric()
                                                                self.delay_metric.parent = self
                                                                self._children_name_map["delay_metric"] = "delay-metric"

                                                                self.expense_metric = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.ExpenseMetric()
                                                                self.expense_metric.parent = self
                                                                self._children_name_map["expense_metric"] = "expense-metric"

                                                                self.error_metric = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.ErrorMetric()
                                                                self.error_metric.parent = self
                                                                self._children_name_map["error_metric"] = "error-metric"
                                                                self._segment_path = lambda: "prefixe" + "[prefix='" + str(self.prefix) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe, ['prefix'], name, value)


                                                            class State(Entity):
                                                                """
                                                                State parameters of IPv4 standard prefix
                                                                
                                                                .. attribute:: up_down
                                                                
                                                                	The up/down bit
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: prefix
                                                                
                                                                	IPv4 prefix contained within reachability TLVs
                                                                	**type**\: str
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.State, self).__init__()

                                                                    self.yang_name = "state"
                                                                    self.yang_parent_name = "prefixe"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('up_down', (YLeaf(YType.boolean, 'up-down'), ['bool'])),
                                                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                    ])
                                                                    self.up_down = None
                                                                    self.prefix = None
                                                                    self._segment_path = lambda: "state"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.State, [u'up_down', u'prefix'], name, value)


                                                            class DefaultMetric(Entity):
                                                                """
                                                                This container defines ISIS Default Metric
                                                                
                                                                .. attribute:: state
                                                                
                                                                	State parameters for default\-metric
                                                                	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.DefaultMetric.State>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.DefaultMetric, self).__init__()

                                                                    self.yang_name = "default-metric"
                                                                    self.yang_parent_name = "prefixe"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.DefaultMetric.State))])
                                                                    self._leafs = OrderedDict()

                                                                    self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.DefaultMetric.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"
                                                                    self._segment_path = lambda: "default-metric"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.DefaultMetric, [], name, value)


                                                                class State(Entity):
                                                                    """
                                                                    State parameters for default\-metric
                                                                    
                                                                    .. attribute:: flags
                                                                    
                                                                    	ISIS Default\-Metric Flags
                                                                    	**type**\:  :py:class:`OpenconfigIsisLspDefaultMetricStateFlagsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisLspDefaultMetricStateFlagsEnum>`
                                                                    
                                                                    .. attribute:: default_metric
                                                                    
                                                                    	ISIS default metric value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'clns-isis-oper'
                                                                    _revision = '2018-04-07'

                                                                    def __init__(self):
                                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.DefaultMetric.State, self).__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "default-metric"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('flags', (YLeaf(YType.enumeration, 'flags'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisLspDefaultMetricStateFlagsEnum', '')])),
                                                                            ('default_metric', (YLeaf(YType.uint8, 'default-metric'), ['int'])),
                                                                        ])
                                                                        self.flags = None
                                                                        self.default_metric = None
                                                                        self._segment_path = lambda: "state"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.DefaultMetric.State, [u'flags', u'default_metric'], name, value)


                                                            class DelayMetric(Entity):
                                                                """
                                                                This container defines the ISIS delay metric
                                                                
                                                                .. attribute:: state
                                                                
                                                                	State parameters of delay\-metric
                                                                	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.DelayMetric.State>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.DelayMetric, self).__init__()

                                                                    self.yang_name = "delay-metric"
                                                                    self.yang_parent_name = "prefixe"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.DelayMetric.State))])
                                                                    self._leafs = OrderedDict()

                                                                    self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.DelayMetric.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"
                                                                    self._segment_path = lambda: "delay-metric"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.DelayMetric, [], name, value)


                                                                class State(Entity):
                                                                    """
                                                                    State parameters of delay\-metric
                                                                    
                                                                    .. attribute:: metric
                                                                    
                                                                    	ISIS delay metric value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: flags
                                                                    
                                                                    	ISIS Delay Metric Flags
                                                                    	**type**\: list of   :py:class:`OpenconfigIsisLspIsisMetricFlagsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisLspIsisMetricFlagsEnum>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'clns-isis-oper'
                                                                    _revision = '2018-04-07'

                                                                    def __init__(self):
                                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.DelayMetric.State, self).__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "delay-metric"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                                                                            ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisLspIsisMetricFlagsEnum', '')])),
                                                                        ])
                                                                        self.metric = None
                                                                        self.flags = []
                                                                        self._segment_path = lambda: "state"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.DelayMetric.State, [u'metric', u'flags'], name, value)


                                                            class ExpenseMetric(Entity):
                                                                """
                                                                This container defines the ISIS expense metric
                                                                
                                                                .. attribute:: state
                                                                
                                                                	State parameters of expense\-metric
                                                                	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.ExpenseMetric.State>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.ExpenseMetric, self).__init__()

                                                                    self.yang_name = "expense-metric"
                                                                    self.yang_parent_name = "prefixe"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.ExpenseMetric.State))])
                                                                    self._leafs = OrderedDict()

                                                                    self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.ExpenseMetric.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"
                                                                    self._segment_path = lambda: "expense-metric"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.ExpenseMetric, [], name, value)


                                                                class State(Entity):
                                                                    """
                                                                    State parameters of expense\-metric
                                                                    
                                                                    .. attribute:: metric
                                                                    
                                                                    	ISIS expense metric value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: flags
                                                                    
                                                                    	ISIS Expense Metric Flags
                                                                    	**type**\: list of   :py:class:`OpenconfigIsisLspIsisMetricFlagsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisLspIsisMetricFlagsEnum>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'clns-isis-oper'
                                                                    _revision = '2018-04-07'

                                                                    def __init__(self):
                                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.ExpenseMetric.State, self).__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "expense-metric"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                                                                            ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisLspIsisMetricFlagsEnum', '')])),
                                                                        ])
                                                                        self.metric = None
                                                                        self.flags = []
                                                                        self._segment_path = lambda: "state"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.ExpenseMetric.State, [u'metric', u'flags'], name, value)


                                                            class ErrorMetric(Entity):
                                                                """
                                                                This container defines the ISIS error metric
                                                                
                                                                .. attribute:: state
                                                                
                                                                	State parameters of error\-metric
                                                                	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.ErrorMetric.State>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.ErrorMetric, self).__init__()

                                                                    self.yang_name = "error-metric"
                                                                    self.yang_parent_name = "prefixe"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.ErrorMetric.State))])
                                                                    self._leafs = OrderedDict()

                                                                    self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.ErrorMetric.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"
                                                                    self._segment_path = lambda: "error-metric"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.ErrorMetric, [], name, value)


                                                                class State(Entity):
                                                                    """
                                                                    State parameters of error\-metric
                                                                    
                                                                    .. attribute:: metric
                                                                    
                                                                    	ISIS error metric value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: flags
                                                                    
                                                                    	IS\-IS error metric flags
                                                                    	**type**\: list of   :py:class:`OpenconfigIsisLspIsisMetricFlagsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisLspIsisMetricFlagsEnum>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'clns-isis-oper'
                                                                    _revision = '2018-04-07'

                                                                    def __init__(self):
                                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.ErrorMetric.State, self).__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "error-metric"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                                                                            ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisLspIsisMetricFlagsEnum', '')])),
                                                                        ])
                                                                        self.metric = None
                                                                        self.flags = []
                                                                        self._segment_path = lambda: "state"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4InternalReachability.Prefixes.Prefixe.ErrorMetric.State, [u'metric', u'flags'], name, value)


                                                class Ipv6InterfaceAddresses(Entity):
                                                    """
                                                    This container defines TLV 232
                                                    
                                                    .. attribute:: state
                                                    
                                                    	State parameters of ISIS TLV 232
                                                    	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6InterfaceAddresses.State>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6InterfaceAddresses, self).__init__()

                                                        self.yang_name = "ipv6-interface-addresses"
                                                        self.yang_parent_name = "tlvs"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6InterfaceAddresses.State))])
                                                        self._leafs = OrderedDict()

                                                        self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6InterfaceAddresses.State()
                                                        self.state.parent = self
                                                        self._children_name_map["state"] = "state"
                                                        self._segment_path = lambda: "ipv6-interface-addresses"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6InterfaceAddresses, [], name, value)


                                                    class State(Entity):
                                                        """
                                                        State parameters of ISIS TLV 232
                                                        
                                                        .. attribute:: ipv6_interface_address
                                                        
                                                        	IPv6 interface addresses of the node
                                                        	**type**\: list of str
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6InterfaceAddresses.State, self).__init__()

                                                            self.yang_name = "state"
                                                            self.yang_parent_name = "ipv6-interface-addresses"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('ipv6_interface_address', (YLeafList(YType.str, 'ipv6-interface-address'), ['str'])),
                                                            ])
                                                            self.ipv6_interface_address = []
                                                            self._segment_path = lambda: "state"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv6InterfaceAddresses.State, [u'ipv6_interface_address'], name, value)


                                                class ExtendedIsReachability(Entity):
                                                    """
                                                    This container defines list of ISIS
                                                    extended reachability neighbors
                                                    
                                                    .. attribute:: extended_is_reachability_neighbors
                                                    
                                                    	This list describes ISIS extended neigbors and reachability attributes
                                                    	**type**\:  :py:class:`ExtendedIsReachabilityNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability, self).__init__()

                                                        self.yang_name = "extended-is-reachability"
                                                        self.yang_parent_name = "tlvs"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("extended-is-reachability-neighbors", ("extended_is_reachability_neighbors", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors))])
                                                        self._leafs = OrderedDict()

                                                        self.extended_is_reachability_neighbors = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors()
                                                        self.extended_is_reachability_neighbors.parent = self
                                                        self._children_name_map["extended_is_reachability_neighbors"] = "extended-is-reachability-neighbors"
                                                        self._segment_path = lambda: "extended-is-reachability"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability, [], name, value)


                                                    class ExtendedIsReachabilityNeighbors(Entity):
                                                        """
                                                        This list describes ISIS extended
                                                        neigbors and reachability attributes
                                                        
                                                        .. attribute:: extended_is_reachability_neighbor
                                                        
                                                        	This list describes ISIS extended neigbors and reachability attributes
                                                        	**type**\: list of  		 :py:class:`ExtendedIsReachabilityNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors, self).__init__()

                                                            self.yang_name = "extended-is-reachability-neighbors"
                                                            self.yang_parent_name = "extended-is-reachability"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("extended-is-reachability-neighbor", ("extended_is_reachability_neighbor", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor))])
                                                            self._leafs = OrderedDict()

                                                            self.extended_is_reachability_neighbor = YList(self)
                                                            self._segment_path = lambda: "extended-is-reachability-neighbors"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors, [], name, value)


                                                        class ExtendedIsReachabilityNeighbor(Entity):
                                                            """
                                                            This list describes ISIS extended
                                                            neigbors and reachability
                                                            attributes
                                                            
                                                            .. attribute:: system_id  (key)
                                                            
                                                            	Reference to the neighboring system's system ID
                                                            	**type**\: str
                                                            
                                                            .. attribute:: neighbors_subtlvs
                                                            
                                                            	List of subTLV types in the LSDB for the specified TLV
                                                            	**type**\:  :py:class:`NeighborsSubtlvs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs>`
                                                            
                                                            .. attribute:: neighbors_undefined_subtlvs
                                                            
                                                            	Sub\-TLVs that are not defined in the model or not recognised by system
                                                            	**type**\:  :py:class:`NeighborsUndefinedSubtlvs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsUndefinedSubtlvs>`
                                                            
                                                            .. attribute:: neighbors_state
                                                            
                                                            	State parameters of extended neighbor
                                                            	**type**\:  :py:class:`NeighborsState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsState>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'clns-isis-oper'
                                                            _revision = '2018-04-07'

                                                            def __init__(self):
                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor, self).__init__()

                                                                self.yang_name = "extended-is-reachability-neighbor"
                                                                self.yang_parent_name = "extended-is-reachability-neighbors"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['system_id']
                                                                self._child_classes = OrderedDict([("neighbors-subtlvs", ("neighbors_subtlvs", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs)), ("neighbors-undefined-subtlvs", ("neighbors_undefined_subtlvs", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsUndefinedSubtlvs)), ("neighbors-state", ("neighbors_state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsState))])
                                                                self._leafs = OrderedDict([
                                                                    ('system_id', (YLeaf(YType.str, 'system-id'), ['str'])),
                                                                ])
                                                                self.system_id = None

                                                                self.neighbors_subtlvs = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs()
                                                                self.neighbors_subtlvs.parent = self
                                                                self._children_name_map["neighbors_subtlvs"] = "neighbors-subtlvs"

                                                                self.neighbors_undefined_subtlvs = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsUndefinedSubtlvs()
                                                                self.neighbors_undefined_subtlvs.parent = self
                                                                self._children_name_map["neighbors_undefined_subtlvs"] = "neighbors-undefined-subtlvs"

                                                                self.neighbors_state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsState()
                                                                self.neighbors_state.parent = self
                                                                self._children_name_map["neighbors_state"] = "neighbors-state"
                                                                self._segment_path = lambda: "extended-is-reachability-neighbor" + "[system-id='" + str(self.system_id) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor, ['system_id'], name, value)


                                                            class NeighborsSubtlvs(Entity):
                                                                """
                                                                List of subTLV types in the LSDB
                                                                for the specified TLV
                                                                
                                                                .. attribute:: neighbors_subtlv
                                                                
                                                                	List of subTLV types in the LSDB for the specified TLV
                                                                	**type**\: list of  		 :py:class:`NeighborsSubtlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs, self).__init__()

                                                                    self.yang_name = "neighbors-subtlvs"
                                                                    self.yang_parent_name = "extended-is-reachability-neighbor"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("neighbors-subtlv", ("neighbors_subtlv", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv))])
                                                                    self._leafs = OrderedDict()

                                                                    self.neighbors_subtlv = YList(self)
                                                                    self._segment_path = lambda: "neighbors-subtlvs"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs, [], name, value)


                                                                class NeighborsSubtlv(Entity):
                                                                    """
                                                                    List of subTLV types in the LSDB
                                                                    for the specified TLV
                                                                    
                                                                    .. attribute:: type  (key)
                                                                    
                                                                    	Reference to the sub\-TLV type
                                                                    	**type**\: str
                                                                    
                                                                    .. attribute:: max_link_bandwidth
                                                                    
                                                                    	This container defines sub\-TLV 9
                                                                    	**type**\:  :py:class:`MaxLinkBandwidth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.MaxLinkBandwidth>`
                                                                    
                                                                    .. attribute:: ipv6_neighbor_address
                                                                    
                                                                    	This container defines sub\-TLV 13
                                                                    	**type**\:  :py:class:`Ipv6NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv6NeighborAddress>`
                                                                    
                                                                    .. attribute:: ipv6_interface_address
                                                                    
                                                                    	This container defines sub\-TLV 12
                                                                    	**type**\:  :py:class:`Ipv6InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv6InterfaceAddress>`
                                                                    
                                                                    .. attribute:: lan_adjacency_sids
                                                                    
                                                                    	Adjacency Segment\-IDs List
                                                                    	**type**\:  :py:class:`LanAdjacencySids <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.LanAdjacencySids>`
                                                                    
                                                                    .. attribute:: adjacency_sids
                                                                    
                                                                    	Adjacency Segment\-IDs List
                                                                    	**type**\:  :py:class:`AdjacencySids <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.AdjacencySids>`
                                                                    
                                                                    .. attribute:: te_default_metric
                                                                    
                                                                    	This container defines sub\-TLV 18
                                                                    	**type**\:  :py:class:`TeDefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.TeDefaultMetric>`
                                                                    
                                                                    .. attribute:: admin_group
                                                                    
                                                                    	This container defines sub\-TLV 3
                                                                    	**type**\:  :py:class:`AdminGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.AdminGroup>`
                                                                    
                                                                    .. attribute:: max_reservable_link_bandwidth
                                                                    
                                                                    	This container defines sub\-TLV 10
                                                                    	**type**\:  :py:class:`MaxReservableLinkBandwidth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.MaxReservableLinkBandwidth>`
                                                                    
                                                                    .. attribute:: extended_admin_group
                                                                    
                                                                    	This container defines sub\-TLV 14
                                                                    	**type**\:  :py:class:`ExtendedAdminGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.ExtendedAdminGroup>`
                                                                    
                                                                    .. attribute:: unreserved_bandwidths
                                                                    
                                                                    	Setup priority (0 through 7) for unreserved bandwidth
                                                                    	**type**\:  :py:class:`UnreservedBandwidths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.UnreservedBandwidths>`
                                                                    
                                                                    .. attribute:: ipv4_interface_address
                                                                    
                                                                    	This container defines sub\-TLV 6
                                                                    	**type**\:  :py:class:`Ipv4InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv4InterfaceAddress>`
                                                                    
                                                                    .. attribute:: ipv4_neighbor_address
                                                                    
                                                                    	This container defines sub\-TLV 8
                                                                    	**type**\:  :py:class:`Ipv4NeighborAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv4NeighborAddress>`
                                                                    
                                                                    .. attribute:: bandwidth_constraints
                                                                    
                                                                    	List of the Bandwidth Constraints sub\-TLV instances present in the TLV
                                                                    	**type**\:  :py:class:`BandwidthConstraints <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.BandwidthConstraints>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'clns-isis-oper'
                                                                    _revision = '2018-04-07'

                                                                    def __init__(self):
                                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv, self).__init__()

                                                                        self.yang_name = "neighbors-subtlv"
                                                                        self.yang_parent_name = "neighbors-subtlvs"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = ['type']
                                                                        self._child_classes = OrderedDict([("max-link-bandwidth", ("max_link_bandwidth", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.MaxLinkBandwidth)), ("ipv6-neighbor-address", ("ipv6_neighbor_address", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv6NeighborAddress)), ("ipv6-interface-address", ("ipv6_interface_address", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv6InterfaceAddress)), ("lan-adjacency-sids", ("lan_adjacency_sids", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.LanAdjacencySids)), ("adjacency-sids", ("adjacency_sids", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.AdjacencySids)), ("te-default-metric", ("te_default_metric", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.TeDefaultMetric)), ("admin-group", ("admin_group", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.AdminGroup)), ("max-reservable-link-bandwidth", ("max_reservable_link_bandwidth", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.MaxReservableLinkBandwidth)), ("extended-admin-group", ("extended_admin_group", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.ExtendedAdminGroup)), ("unreserved-bandwidths", ("unreserved_bandwidths", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.UnreservedBandwidths)), ("ipv4-interface-address", ("ipv4_interface_address", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv4InterfaceAddress)), ("ipv4-neighbor-address", ("ipv4_neighbor_address", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv4NeighborAddress)), ("bandwidth-constraints", ("bandwidth_constraints", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.BandwidthConstraints))])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.str, 'type'), ['str'])),
                                                                        ])
                                                                        self.type = None

                                                                        self.max_link_bandwidth = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.MaxLinkBandwidth()
                                                                        self.max_link_bandwidth.parent = self
                                                                        self._children_name_map["max_link_bandwidth"] = "max-link-bandwidth"

                                                                        self.ipv6_neighbor_address = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv6NeighborAddress()
                                                                        self.ipv6_neighbor_address.parent = self
                                                                        self._children_name_map["ipv6_neighbor_address"] = "ipv6-neighbor-address"

                                                                        self.ipv6_interface_address = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv6InterfaceAddress()
                                                                        self.ipv6_interface_address.parent = self
                                                                        self._children_name_map["ipv6_interface_address"] = "ipv6-interface-address"

                                                                        self.lan_adjacency_sids = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.LanAdjacencySids()
                                                                        self.lan_adjacency_sids.parent = self
                                                                        self._children_name_map["lan_adjacency_sids"] = "lan-adjacency-sids"

                                                                        self.adjacency_sids = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.AdjacencySids()
                                                                        self.adjacency_sids.parent = self
                                                                        self._children_name_map["adjacency_sids"] = "adjacency-sids"

                                                                        self.te_default_metric = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.TeDefaultMetric()
                                                                        self.te_default_metric.parent = self
                                                                        self._children_name_map["te_default_metric"] = "te-default-metric"

                                                                        self.admin_group = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.AdminGroup()
                                                                        self.admin_group.parent = self
                                                                        self._children_name_map["admin_group"] = "admin-group"

                                                                        self.max_reservable_link_bandwidth = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.MaxReservableLinkBandwidth()
                                                                        self.max_reservable_link_bandwidth.parent = self
                                                                        self._children_name_map["max_reservable_link_bandwidth"] = "max-reservable-link-bandwidth"

                                                                        self.extended_admin_group = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.ExtendedAdminGroup()
                                                                        self.extended_admin_group.parent = self
                                                                        self._children_name_map["extended_admin_group"] = "extended-admin-group"

                                                                        self.unreserved_bandwidths = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.UnreservedBandwidths()
                                                                        self.unreserved_bandwidths.parent = self
                                                                        self._children_name_map["unreserved_bandwidths"] = "unreserved-bandwidths"

                                                                        self.ipv4_interface_address = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv4InterfaceAddress()
                                                                        self.ipv4_interface_address.parent = self
                                                                        self._children_name_map["ipv4_interface_address"] = "ipv4-interface-address"

                                                                        self.ipv4_neighbor_address = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv4NeighborAddress()
                                                                        self.ipv4_neighbor_address.parent = self
                                                                        self._children_name_map["ipv4_neighbor_address"] = "ipv4-neighbor-address"

                                                                        self.bandwidth_constraints = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.BandwidthConstraints()
                                                                        self.bandwidth_constraints.parent = self
                                                                        self._children_name_map["bandwidth_constraints"] = "bandwidth-constraints"
                                                                        self._segment_path = lambda: "neighbors-subtlv" + "[type='" + str(self.type) + "']"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv, ['type'], name, value)


                                                                    class MaxLinkBandwidth(Entity):
                                                                        """
                                                                        This container defines sub\-TLV 9
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 9
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.MaxLinkBandwidth.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.MaxLinkBandwidth, self).__init__()

                                                                            self.yang_name = "max-link-bandwidth"
                                                                            self.yang_parent_name = "neighbors-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.MaxLinkBandwidth.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.MaxLinkBandwidth.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "max-link-bandwidth"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.MaxLinkBandwidth, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 9
                                                                            
                                                                            .. attribute:: max_link_bandwidth
                                                                            
                                                                            	The maximum bandwidth that can be used on this link in this direction (from the system originating the LSP to its neighbors)
                                                                            	**type**\: str
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.MaxLinkBandwidth.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "max-link-bandwidth"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('max_link_bandwidth', (YLeaf(YType.str, 'max-link-bandwidth'), ['str'])),
                                                                                ])
                                                                                self.max_link_bandwidth = None
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.MaxLinkBandwidth.State, [u'max_link_bandwidth'], name, value)


                                                                    class Ipv6NeighborAddress(Entity):
                                                                        """
                                                                        This container defines sub\-TLV
                                                                        13
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 13
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv6NeighborAddress.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv6NeighborAddress, self).__init__()

                                                                            self.yang_name = "ipv6-neighbor-address"
                                                                            self.yang_parent_name = "neighbors-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv6NeighborAddress.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv6NeighborAddress.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "ipv6-neighbor-address"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv6NeighborAddress, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 13
                                                                            
                                                                            .. attribute:: ipv6_neighbor_address
                                                                            
                                                                            	Contains a 16\-octet IPv6 address for a neighboring router on the link described by the (main) TLV
                                                                            	**type**\: list of str
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv6NeighborAddress.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "ipv6-neighbor-address"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('ipv6_neighbor_address', (YLeafList(YType.str, 'ipv6-neighbor-address'), ['str'])),
                                                                                ])
                                                                                self.ipv6_neighbor_address = []
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv6NeighborAddress.State, [u'ipv6_neighbor_address'], name, value)


                                                                    class Ipv6InterfaceAddress(Entity):
                                                                        """
                                                                        This container defines sub\-TLV
                                                                        12
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 12
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv6InterfaceAddress.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv6InterfaceAddress, self).__init__()

                                                                            self.yang_name = "ipv6-interface-address"
                                                                            self.yang_parent_name = "neighbors-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv6InterfaceAddress.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv6InterfaceAddress.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "ipv6-interface-address"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv6InterfaceAddress, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 12
                                                                            
                                                                            .. attribute:: ipv6_interface_address
                                                                            
                                                                            	Contains a 16\-octet IPv6 address for the interface described by the containing  Extended IS Reachability TLV
                                                                            	**type**\: list of str
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv6InterfaceAddress.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "ipv6-interface-address"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('ipv6_interface_address', (YLeafList(YType.str, 'ipv6-interface-address'), ['str'])),
                                                                                ])
                                                                                self.ipv6_interface_address = []
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv6InterfaceAddress.State, [u'ipv6_interface_address'], name, value)


                                                                    class LanAdjacencySids(Entity):
                                                                        """
                                                                        Adjacency Segment\-IDs List
                                                                        
                                                                        .. attribute:: lan_adjacency_sid
                                                                        
                                                                        	Adjacency Segment\-IDs List
                                                                        	**type**\: list of  		 :py:class:`LanAdjacencySid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.LanAdjacencySids.LanAdjacencySid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.LanAdjacencySids, self).__init__()

                                                                            self.yang_name = "lan-adjacency-sids"
                                                                            self.yang_parent_name = "neighbors-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("lan-adjacency-sid", ("lan_adjacency_sid", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.LanAdjacencySids.LanAdjacencySid))])
                                                                            self._leafs = OrderedDict()

                                                                            self.lan_adjacency_sid = YList(self)
                                                                            self._segment_path = lambda: "lan-adjacency-sids"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.LanAdjacencySids, [], name, value)


                                                                        class LanAdjacencySid(Entity):
                                                                            """
                                                                            Adjacency Segment\-IDs List
                                                                            
                                                                            .. attribute:: value  (key)
                                                                            
                                                                            	Reference to the value of the LAN Adjacency\-SID
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                            	State parameters of LAN Adjacency\-SID
                                                                            	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.LanAdjacencySids.LanAdjacencySid.State>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.LanAdjacencySids.LanAdjacencySid, self).__init__()

                                                                                self.yang_name = "lan-adjacency-sid"
                                                                                self.yang_parent_name = "lan-adjacency-sids"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = ['value']
                                                                                self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.LanAdjacencySids.LanAdjacencySid.State))])
                                                                                self._leafs = OrderedDict([
                                                                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                                                                ])
                                                                                self.value = None

                                                                                self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.LanAdjacencySids.LanAdjacencySid.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "lan-adjacency-sid" + "[value='" + str(self.value) + "']"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.LanAdjacencySids.LanAdjacencySid, ['value'], name, value)


                                                                            class State(Entity):
                                                                                """
                                                                                State parameters of LAN Adjacency\-SID
                                                                                
                                                                                .. attribute:: value
                                                                                
                                                                                	LAN Adjacency\-SID value
                                                                                	**type**\: int
                                                                                
                                                                                	**range:** 0..4294967295
                                                                                
                                                                                .. attribute:: weight
                                                                                
                                                                                	Value that represents the weight of the Adj\-SID for the purpose of load balancing
                                                                                	**type**\: int
                                                                                
                                                                                	**range:** 0..255
                                                                                
                                                                                .. attribute:: neighbor_id
                                                                                
                                                                                	System ID of the neighbor associated with the LAN\- Adj\-Segment\-ID value
                                                                                	**type**\: str
                                                                                
                                                                                .. attribute:: flags
                                                                                
                                                                                	Flags associated with LAN\-Adj\-Segment\-ID
                                                                                	**type**\: list of   :py:class:`OpenconfigIsisLspLanAdjacencySidStateFlagsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisLspLanAdjacencySidStateFlagsEnum>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'clns-isis-oper'
                                                                                _revision = '2018-04-07'

                                                                                def __init__(self):
                                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.LanAdjacencySids.LanAdjacencySid.State, self).__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "lan-adjacency-sid"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                                                        ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisLspLanAdjacencySidStateFlagsEnum', '')])),
                                                                                    ])
                                                                                    self.value = None
                                                                                    self.weight = None
                                                                                    self.neighbor_id = None
                                                                                    self.flags = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.LanAdjacencySids.LanAdjacencySid.State, [u'value', u'weight', u'neighbor_id', u'flags'], name, value)


                                                                    class AdjacencySids(Entity):
                                                                        """
                                                                        Adjacency Segment\-IDs List
                                                                        
                                                                        .. attribute:: adjacency_sid
                                                                        
                                                                        	Adjacency Segment\-IDs List
                                                                        	**type**\: list of  		 :py:class:`AdjacencySid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.AdjacencySids.AdjacencySid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.AdjacencySids, self).__init__()

                                                                            self.yang_name = "adjacency-sids"
                                                                            self.yang_parent_name = "neighbors-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("adjacency-sid", ("adjacency_sid", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.AdjacencySids.AdjacencySid))])
                                                                            self._leafs = OrderedDict()

                                                                            self.adjacency_sid = YList(self)
                                                                            self._segment_path = lambda: "adjacency-sids"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.AdjacencySids, [], name, value)


                                                                        class AdjacencySid(Entity):
                                                                            """
                                                                            Adjacency Segment\-IDs List
                                                                            
                                                                            .. attribute:: value  (key)
                                                                            
                                                                            	Reference to the value of the Adjacency\-SID
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                            	State parameters of Adjacency\-SID
                                                                            	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.AdjacencySids.AdjacencySid.State>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.AdjacencySids.AdjacencySid, self).__init__()

                                                                                self.yang_name = "adjacency-sid"
                                                                                self.yang_parent_name = "adjacency-sids"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = ['value']
                                                                                self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.AdjacencySids.AdjacencySid.State))])
                                                                                self._leafs = OrderedDict([
                                                                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                                                                ])
                                                                                self.value = None

                                                                                self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.AdjacencySids.AdjacencySid.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "adjacency-sid" + "[value='" + str(self.value) + "']"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.AdjacencySids.AdjacencySid, ['value'], name, value)


                                                                            class State(Entity):
                                                                                """
                                                                                State parameters of Adjacency\-SID
                                                                                
                                                                                .. attribute:: value
                                                                                
                                                                                	Adjacency\-SID value
                                                                                	**type**\: int
                                                                                
                                                                                	**range:** 0..4294967295
                                                                                
                                                                                .. attribute:: weight
                                                                                
                                                                                	Value that represents the weight of the Adj\-SID for the purpose of load balancing
                                                                                	**type**\: int
                                                                                
                                                                                	**range:** 0..255
                                                                                
                                                                                .. attribute:: flags
                                                                                
                                                                                	Flags associated with Adj\-Segment\-ID
                                                                                	**type**\: list of   :py:class:`OpenconfigIsisLspAdjacencySidStateFlagsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisLspAdjacencySidStateFlagsEnum>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'clns-isis-oper'
                                                                                _revision = '2018-04-07'

                                                                                def __init__(self):
                                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.AdjacencySids.AdjacencySid.State, self).__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "adjacency-sid"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                                                                        ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                                        ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisLspAdjacencySidStateFlagsEnum', '')])),
                                                                                    ])
                                                                                    self.value = None
                                                                                    self.weight = None
                                                                                    self.flags = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.AdjacencySids.AdjacencySid.State, [u'value', u'weight', u'flags'], name, value)


                                                                    class TeDefaultMetric(Entity):
                                                                        """
                                                                        This container defines sub\-TLV
                                                                        18
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 18
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.TeDefaultMetric.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.TeDefaultMetric, self).__init__()

                                                                            self.yang_name = "te-default-metric"
                                                                            self.yang_parent_name = "neighbors-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.TeDefaultMetric.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.TeDefaultMetric.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "te-default-metric"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.TeDefaultMetric, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 18
                                                                            
                                                                            .. attribute:: te_default_metric
                                                                            
                                                                            	This metric is administratively assigned and can be used to present a differently weighted topology to traffic engineering SPF calculations
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.TeDefaultMetric.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "te-default-metric"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('te_default_metric', (YLeaf(YType.uint32, 'te-default-metric'), ['int'])),
                                                                                ])
                                                                                self.te_default_metric = None
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.TeDefaultMetric.State, [u'te_default_metric'], name, value)


                                                                    class AdminGroup(Entity):
                                                                        """
                                                                        This container defines sub\-TLV 3
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 3
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.AdminGroup.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.AdminGroup, self).__init__()

                                                                            self.yang_name = "admin-group"
                                                                            self.yang_parent_name = "neighbors-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.AdminGroup.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.AdminGroup.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "admin-group"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.AdminGroup, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 3
                                                                            
                                                                            .. attribute:: admin_group
                                                                            
                                                                            	The administrative group sub\-TLV contains a 4\-octet bit mask assigned by the network administrator
                                                                            	**type**\: list of int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.AdminGroup.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "admin-group"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('admin_group', (YLeafList(YType.uint32, 'admin-group'), ['int'])),
                                                                                ])
                                                                                self.admin_group = []
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.AdminGroup.State, [u'admin_group'], name, value)


                                                                    class MaxReservableLinkBandwidth(Entity):
                                                                        """
                                                                        This container defines sub\-TLV
                                                                        10
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 10
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.MaxReservableLinkBandwidth.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.MaxReservableLinkBandwidth, self).__init__()

                                                                            self.yang_name = "max-reservable-link-bandwidth"
                                                                            self.yang_parent_name = "neighbors-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.MaxReservableLinkBandwidth.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.MaxReservableLinkBandwidth.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "max-reservable-link-bandwidth"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.MaxReservableLinkBandwidth, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 10
                                                                            
                                                                            .. attribute:: max_reservable_link_bandwidth
                                                                            
                                                                            	The maximum amount of bandwidth that can be reserved in this direction on this link
                                                                            	**type**\: str
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.MaxReservableLinkBandwidth.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "max-reservable-link-bandwidth"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('max_reservable_link_bandwidth', (YLeaf(YType.str, 'max-reservable-link-bandwidth'), ['str'])),
                                                                                ])
                                                                                self.max_reservable_link_bandwidth = None
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.MaxReservableLinkBandwidth.State, [u'max_reservable_link_bandwidth'], name, value)


                                                                    class ExtendedAdminGroup(Entity):
                                                                        """
                                                                        This container defines sub\-TLV
                                                                        14
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 14
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.ExtendedAdminGroup.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.ExtendedAdminGroup, self).__init__()

                                                                            self.yang_name = "extended-admin-group"
                                                                            self.yang_parent_name = "neighbors-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.ExtendedAdminGroup.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.ExtendedAdminGroup.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "extended-admin-group"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.ExtendedAdminGroup, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 14
                                                                            
                                                                            .. attribute:: extended_admin_group
                                                                            
                                                                            	The extended\-admin\-group sub\-TLV is used in addition to the Administrative Groups when it is desirable to make more than 32 colors available for advertisement in a network
                                                                            	**type**\: list of int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.ExtendedAdminGroup.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "extended-admin-group"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('extended_admin_group', (YLeafList(YType.uint32, 'extended-admin-group'), ['int'])),
                                                                                ])
                                                                                self.extended_admin_group = []
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.ExtendedAdminGroup.State, [u'extended_admin_group'], name, value)


                                                                    class UnreservedBandwidths(Entity):
                                                                        """
                                                                        Setup priority (0 through 7) for
                                                                        unreserved bandwidth
                                                                        
                                                                        .. attribute:: unreserved_bandwidth
                                                                        
                                                                        	Setup priority (0 through 7) for unreserved bandwidth
                                                                        	**type**\: list of  		 :py:class:`UnreservedBandwidth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.UnreservedBandwidths.UnreservedBandwidth>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.UnreservedBandwidths, self).__init__()

                                                                            self.yang_name = "unreserved-bandwidths"
                                                                            self.yang_parent_name = "neighbors-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("unreserved-bandwidth", ("unreserved_bandwidth", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.UnreservedBandwidths.UnreservedBandwidth))])
                                                                            self._leafs = OrderedDict()

                                                                            self.unreserved_bandwidth = YList(self)
                                                                            self._segment_path = lambda: "unreserved-bandwidths"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.UnreservedBandwidths, [], name, value)


                                                                        class UnreservedBandwidth(Entity):
                                                                            """
                                                                            Setup priority (0 through 7)
                                                                            for unreserved bandwidth
                                                                            
                                                                            .. attribute:: priority  (key)
                                                                            
                                                                            	Reference to the setup priority to which the unreserved bandwidth corresponds
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                            	State parameters of IS Extended Reachability sub\-TLV 11
                                                                            	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.UnreservedBandwidths.UnreservedBandwidth.State>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.UnreservedBandwidths.UnreservedBandwidth, self).__init__()

                                                                                self.yang_name = "unreserved-bandwidth"
                                                                                self.yang_parent_name = "unreserved-bandwidths"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = ['priority']
                                                                                self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.UnreservedBandwidths.UnreservedBandwidth.State))])
                                                                                self._leafs = OrderedDict([
                                                                                    ('priority', (YLeaf(YType.uint32, 'priority'), ['int'])),
                                                                                ])
                                                                                self.priority = None

                                                                                self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.UnreservedBandwidths.UnreservedBandwidth.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "unreserved-bandwidth" + "[priority='" + str(self.priority) + "']"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.UnreservedBandwidths.UnreservedBandwidth, ['priority'], name, value)


                                                                            class State(Entity):
                                                                                """
                                                                                State parameters of IS Extended Reachability
                                                                                sub\-TLV 11
                                                                                
                                                                                .. attribute:: priority
                                                                                
                                                                                	Setup priority level of 0 through 7 to be used by Unreserved Bandwidth sub\-TLV 11
                                                                                	**type**\: int
                                                                                
                                                                                	**range:** 0..255
                                                                                
                                                                                .. attribute:: unreserved_bandwidth
                                                                                
                                                                                	The amount of bandwidth reservable in this direction on this link
                                                                                	**type**\: str
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'clns-isis-oper'
                                                                                _revision = '2018-04-07'

                                                                                def __init__(self):
                                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.UnreservedBandwidths.UnreservedBandwidth.State, self).__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "unreserved-bandwidth"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                                        ('unreserved_bandwidth', (YLeaf(YType.str, 'unreserved-bandwidth'), ['str'])),
                                                                                    ])
                                                                                    self.priority = None
                                                                                    self.unreserved_bandwidth = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.UnreservedBandwidths.UnreservedBandwidth.State, [u'priority', u'unreserved_bandwidth'], name, value)


                                                                    class Ipv4InterfaceAddress(Entity):
                                                                        """
                                                                        This container defines sub\-TLV 6
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 6
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv4InterfaceAddress.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv4InterfaceAddress, self).__init__()

                                                                            self.yang_name = "ipv4-interface-address"
                                                                            self.yang_parent_name = "neighbors-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv4InterfaceAddress.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv4InterfaceAddress.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "ipv4-interface-address"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv4InterfaceAddress, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 6
                                                                            
                                                                            .. attribute:: ipv4_interface_address
                                                                            
                                                                            	A 4\-octet IPv4 address for the interface described by the (main) TLV
                                                                            	**type**\: list of str
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv4InterfaceAddress.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "ipv4-interface-address"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('ipv4_interface_address', (YLeafList(YType.str, 'ipv4-interface-address'), ['str'])),
                                                                                ])
                                                                                self.ipv4_interface_address = []
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv4InterfaceAddress.State, [u'ipv4_interface_address'], name, value)


                                                                    class Ipv4NeighborAddress(Entity):
                                                                        """
                                                                        This container defines sub\-TLV 8
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 8
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv4NeighborAddress.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv4NeighborAddress, self).__init__()

                                                                            self.yang_name = "ipv4-neighbor-address"
                                                                            self.yang_parent_name = "neighbors-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv4NeighborAddress.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv4NeighborAddress.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "ipv4-neighbor-address"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv4NeighborAddress, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 8
                                                                            
                                                                            .. attribute:: ipv4_neighbor_address
                                                                            
                                                                            	A single IPv4 address for a neighboring router on this link
                                                                            	**type**\: list of str
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv4NeighborAddress.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "ipv4-neighbor-address"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('ipv4_neighbor_address', (YLeafList(YType.str, 'ipv4-neighbor-address'), ['str'])),
                                                                                ])
                                                                                self.ipv4_neighbor_address = []
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.Ipv4NeighborAddress.State, [u'ipv4_neighbor_address'], name, value)


                                                                    class BandwidthConstraints(Entity):
                                                                        """
                                                                        List of the Bandwidth
                                                                        Constraints sub\-TLV instances
                                                                        present in the TLV
                                                                        
                                                                        .. attribute:: bandwidth_constraint
                                                                        
                                                                        	List of the Bandwidth Constraints sub\-TLV instances present in the TLV
                                                                        	**type**\: list of  		 :py:class:`BandwidthConstraint <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.BandwidthConstraints.BandwidthConstraint>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.BandwidthConstraints, self).__init__()

                                                                            self.yang_name = "bandwidth-constraints"
                                                                            self.yang_parent_name = "neighbors-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("bandwidth-constraint", ("bandwidth_constraint", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.BandwidthConstraints.BandwidthConstraint))])
                                                                            self._leafs = OrderedDict()

                                                                            self.bandwidth_constraint = YList(self)
                                                                            self._segment_path = lambda: "bandwidth-constraints"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.BandwidthConstraints, [], name, value)


                                                                        class BandwidthConstraint(Entity):
                                                                            """
                                                                            List of the Bandwidth
                                                                            Constraints sub\-TLV instances
                                                                            present in the TLV
                                                                            
                                                                            .. attribute:: model_id  (key)
                                                                            
                                                                            	Reference to the model ID associated with the instance of the Bandwidth Constraints sub\-TLV
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: constraints
                                                                            
                                                                            	List of the constraints within the Bandwidth Constraints sub\-TLV
                                                                            	**type**\:  :py:class:`Constraints <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.BandwidthConstraints.BandwidthConstraint.Constraints>`
                                                                            
                                                                            .. attribute:: bandwidth_constraints_state
                                                                            
                                                                            	State parameters of IS Extended Reachability sub\-TLV 22
                                                                            	**type**\:  :py:class:`BandwidthConstraintsState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.BandwidthConstraints.BandwidthConstraint.BandwidthConstraintsState>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.BandwidthConstraints.BandwidthConstraint, self).__init__()

                                                                                self.yang_name = "bandwidth-constraint"
                                                                                self.yang_parent_name = "bandwidth-constraints"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = ['model_id']
                                                                                self._child_classes = OrderedDict([("constraints", ("constraints", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.BandwidthConstraints.BandwidthConstraint.Constraints)), ("bandwidth-constraints-state", ("bandwidth_constraints_state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.BandwidthConstraints.BandwidthConstraint.BandwidthConstraintsState))])
                                                                                self._leafs = OrderedDict([
                                                                                    ('model_id', (YLeaf(YType.uint32, 'model-id'), ['int'])),
                                                                                ])
                                                                                self.model_id = None

                                                                                self.constraints = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.BandwidthConstraints.BandwidthConstraint.Constraints()
                                                                                self.constraints.parent = self
                                                                                self._children_name_map["constraints"] = "constraints"

                                                                                self.bandwidth_constraints_state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.BandwidthConstraints.BandwidthConstraint.BandwidthConstraintsState()
                                                                                self.bandwidth_constraints_state.parent = self
                                                                                self._children_name_map["bandwidth_constraints_state"] = "bandwidth-constraints-state"
                                                                                self._segment_path = lambda: "bandwidth-constraint" + "[model-id='" + str(self.model_id) + "']"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.BandwidthConstraints.BandwidthConstraint, ['model_id'], name, value)


                                                                            class Constraints(Entity):
                                                                                """
                                                                                List of the constraints within
                                                                                the Bandwidth Constraints
                                                                                sub\-TLV
                                                                                
                                                                                .. attribute:: constraint
                                                                                
                                                                                	List of the constraints within the Bandwidth Constraints sub\-TLV
                                                                                	**type**\: list of  		 :py:class:`Constraint <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'clns-isis-oper'
                                                                                _revision = '2018-04-07'

                                                                                def __init__(self):
                                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.BandwidthConstraints.BandwidthConstraint.Constraints, self).__init__()

                                                                                    self.yang_name = "constraints"
                                                                                    self.yang_parent_name = "bandwidth-constraint"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([("constraint", ("constraint", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint))])
                                                                                    self._leafs = OrderedDict()

                                                                                    self.constraint = YList(self)
                                                                                    self._segment_path = lambda: "constraints"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.BandwidthConstraints.BandwidthConstraint.Constraints, [], name, value)


                                                                                class Constraint(Entity):
                                                                                    """
                                                                                    List of the constraints
                                                                                    within the Bandwidth
                                                                                    Constraints sub\-TLV
                                                                                    
                                                                                    .. attribute:: constraint_id  (key)
                                                                                    
                                                                                    	Reference to the unique ID for the BCN level
                                                                                    	**type**\: int
                                                                                    
                                                                                    	**range:** 0..4294967295
                                                                                    
                                                                                    .. attribute:: state
                                                                                    
                                                                                    	Operational state parameters of the BCN level
                                                                                    	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State>`
                                                                                    
                                                                                    

                                                                                    """

                                                                                    _prefix = 'clns-isis-oper'
                                                                                    _revision = '2018-04-07'

                                                                                    def __init__(self):
                                                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint, self).__init__()

                                                                                        self.yang_name = "constraint"
                                                                                        self.yang_parent_name = "constraints"
                                                                                        self.is_top_level_class = False
                                                                                        self.has_list_ancestor = True
                                                                                        self.ylist_key_names = ['constraint_id']
                                                                                        self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State))])
                                                                                        self._leafs = OrderedDict([
                                                                                            ('constraint_id', (YLeaf(YType.uint32, 'constraint-id'), ['int'])),
                                                                                        ])
                                                                                        self.constraint_id = None

                                                                                        self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State()
                                                                                        self.state.parent = self
                                                                                        self._children_name_map["state"] = "state"
                                                                                        self._segment_path = lambda: "constraint" + "[constraint-id='" + str(self.constraint_id) + "']"
                                                                                        self._is_frozen = True

                                                                                    def __setattr__(self, name, value):
                                                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint, ['constraint_id'], name, value)


                                                                                    class State(Entity):
                                                                                        """
                                                                                        Operational state parameters of the BCN level
                                                                                        
                                                                                        .. attribute:: constraint_id
                                                                                        
                                                                                        	Unique reference for the bandwidth constraint level
                                                                                        	**type**\: int
                                                                                        
                                                                                        	**range:** 0..4294967295
                                                                                        
                                                                                        .. attribute:: bandwidth
                                                                                        
                                                                                        	The bandwidth constraint, expressed as a 32\-bit IEEE floating point number expressed in bytes per second
                                                                                        	**type**\: str
                                                                                        
                                                                                        	**units**\: byte/s
                                                                                        
                                                                                        

                                                                                        """

                                                                                        _prefix = 'clns-isis-oper'
                                                                                        _revision = '2018-04-07'

                                                                                        def __init__(self):
                                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State, self).__init__()

                                                                                            self.yang_name = "state"
                                                                                            self.yang_parent_name = "constraint"
                                                                                            self.is_top_level_class = False
                                                                                            self.has_list_ancestor = True
                                                                                            self.ylist_key_names = []
                                                                                            self._child_classes = OrderedDict([])
                                                                                            self._leafs = OrderedDict([
                                                                                                ('constraint_id', (YLeaf(YType.uint32, 'constraint-id'), ['int'])),
                                                                                                ('bandwidth', (YLeaf(YType.str, 'bandwidth'), ['str'])),
                                                                                            ])
                                                                                            self.constraint_id = None
                                                                                            self.bandwidth = None
                                                                                            self._segment_path = lambda: "state"
                                                                                            self._is_frozen = True

                                                                                        def __setattr__(self, name, value):
                                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State, [u'constraint_id', u'bandwidth'], name, value)


                                                                            class BandwidthConstraintsState(Entity):
                                                                                """
                                                                                State parameters of IS
                                                                                Extended Reachability sub\-TLV
                                                                                22
                                                                                
                                                                                .. attribute:: model_id
                                                                                
                                                                                	Identifier for the Bandwidth Constraints  Model currently in use by the LSR initiating the IGP advertisement
                                                                                	**type**\: int
                                                                                
                                                                                	**range:** 0..255
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'clns-isis-oper'
                                                                                _revision = '2018-04-07'

                                                                                def __init__(self):
                                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.BandwidthConstraints.BandwidthConstraint.BandwidthConstraintsState, self).__init__()

                                                                                    self.yang_name = "bandwidth-constraints-state"
                                                                                    self.yang_parent_name = "bandwidth-constraint"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('model_id', (YLeaf(YType.uint8, 'model-id'), ['int'])),
                                                                                    ])
                                                                                    self.model_id = None
                                                                                    self._segment_path = lambda: "bandwidth-constraints-state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsSubtlvs.NeighborsSubtlv.BandwidthConstraints.BandwidthConstraint.BandwidthConstraintsState, [u'model_id'], name, value)


                                                            class NeighborsUndefinedSubtlvs(Entity):
                                                                """
                                                                Sub\-TLVs that are not defined in
                                                                the model or not recognised by
                                                                system
                                                                
                                                                .. attribute:: neighbors_undefined_subtlv
                                                                
                                                                	Sub\-TLVs that are not defined in the model or not recognised by system
                                                                	**type**\: list of  		 :py:class:`NeighborsUndefinedSubtlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsUndefinedSubtlvs.NeighborsUndefinedSubtlv>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsUndefinedSubtlvs, self).__init__()

                                                                    self.yang_name = "neighbors-undefined-subtlvs"
                                                                    self.yang_parent_name = "extended-is-reachability-neighbor"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("neighbors-undefined-subtlv", ("neighbors_undefined_subtlv", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsUndefinedSubtlvs.NeighborsUndefinedSubtlv))])
                                                                    self._leafs = OrderedDict()

                                                                    self.neighbors_undefined_subtlv = YList(self)
                                                                    self._segment_path = lambda: "neighbors-undefined-subtlvs"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsUndefinedSubtlvs, [], name, value)


                                                                class NeighborsUndefinedSubtlv(Entity):
                                                                    """
                                                                    Sub\-TLVs that are not defined in
                                                                    the model or not recognised by
                                                                    system
                                                                    
                                                                    .. attribute:: type  (key)
                                                                    
                                                                    	Reference to the type of the undefined sub\-TLV
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of the undefined sub\-TLV
                                                                    	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsUndefinedSubtlvs.NeighborsUndefinedSubtlv.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'clns-isis-oper'
                                                                    _revision = '2018-04-07'

                                                                    def __init__(self):
                                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsUndefinedSubtlvs.NeighborsUndefinedSubtlv, self).__init__()

                                                                        self.yang_name = "neighbors-undefined-subtlv"
                                                                        self.yang_parent_name = "neighbors-undefined-subtlvs"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = ['type']
                                                                        self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsUndefinedSubtlvs.NeighborsUndefinedSubtlv.State))])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.uint32, 'type'), ['int'])),
                                                                        ])
                                                                        self.type = None

                                                                        self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsUndefinedSubtlvs.NeighborsUndefinedSubtlv.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._segment_path = lambda: "neighbors-undefined-subtlv" + "[type='" + str(self.type) + "']"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsUndefinedSubtlvs.NeighborsUndefinedSubtlv, ['type'], name, value)


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of the undefined sub\-TLV
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	TLV Type
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: length
                                                                        
                                                                        	TLV length
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: value
                                                                        
                                                                        	TLV value
                                                                        	**type**\: str
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsUndefinedSubtlvs.NeighborsUndefinedSubtlv.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "neighbors-undefined-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                                                ('length', (YLeaf(YType.uint8, 'length'), ['int'])),
                                                                                ('value', (YLeaf(YType.str, 'value'), ['str'])),
                                                                            ])
                                                                            self.type = None
                                                                            self.length = None
                                                                            self.value = None
                                                                            self._segment_path = lambda: "state"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsUndefinedSubtlvs.NeighborsUndefinedSubtlv.State, [u'type', u'length', u'value'], name, value)


                                                            class NeighborsState(Entity):
                                                                """
                                                                State parameters of extended
                                                                neighbor
                                                                
                                                                .. attribute:: system_id
                                                                
                                                                	System\-id of the neighbor
                                                                	**type**\: str
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metric value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsState, self).__init__()

                                                                    self.yang_name = "neighbors-state"
                                                                    self.yang_parent_name = "extended-is-reachability-neighbor"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('system_id', (YLeaf(YType.str, 'system-id'), ['str'])),
                                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                    ])
                                                                    self.system_id = None
                                                                    self.metric = None
                                                                    self._segment_path = lambda: "neighbors-state"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIsReachability.ExtendedIsReachabilityNeighbors.ExtendedIsReachabilityNeighbor.NeighborsState, [u'system_id', u'metric'], name, value)


                                                class InstanceIds(Entity):
                                                    """
                                                    A list of instance IDs received
                                                    within TLV 7 within an IS\-IS LSP
                                                    
                                                    .. attribute:: instance_id
                                                    
                                                    	A list of instance IDs received within TLV 7 within an IS\-IS LSP
                                                    	**type**\: list of  		 :py:class:`InstanceId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.InstanceIds.InstanceId>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.InstanceIds, self).__init__()

                                                        self.yang_name = "instance-ids"
                                                        self.yang_parent_name = "tlvs"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("instance-id", ("instance_id", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.InstanceIds.InstanceId))])
                                                        self._leafs = OrderedDict()

                                                        self.instance_id = YList(self)
                                                        self._segment_path = lambda: "instance-ids"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.InstanceIds, [], name, value)


                                                    class InstanceId(Entity):
                                                        """
                                                        A list of instance IDs received
                                                        within TLV 7 within an IS\-IS LSP
                                                        
                                                        .. attribute:: instance_id  (key)
                                                        
                                                        	Reference to the unique instance ID
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	State parameters of ISIS TLV 7
                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.InstanceIds.InstanceId.State>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.InstanceIds.InstanceId, self).__init__()

                                                            self.yang_name = "instance-id"
                                                            self.yang_parent_name = "instance-ids"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['instance_id']
                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.InstanceIds.InstanceId.State))])
                                                            self._leafs = OrderedDict([
                                                                ('instance_id', (YLeaf(YType.uint32, 'instance-id'), ['int'])),
                                                            ])
                                                            self.instance_id = None

                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.InstanceIds.InstanceId.State()
                                                            self.state.parent = self
                                                            self._children_name_map["state"] = "state"
                                                            self._segment_path = lambda: "instance-id" + "[instance-id='" + str(self.instance_id) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.InstanceIds.InstanceId, ['instance_id'], name, value)


                                                        class State(Entity):
                                                            """
                                                            State parameters of ISIS TLV 7
                                                            
                                                            .. attribute:: instance_id
                                                            
                                                            	An Instance Identifier (IID) to uniquely identify an IS\-IS instance
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            .. attribute:: topology_id
                                                            
                                                            	Instance\-Specific Topology Identifiers (ITIDs)
                                                            	**type**\: list of int
                                                            
                                                            	**range:** 0..65535
                                                            
                                                            

                                                            """

                                                            _prefix = 'clns-isis-oper'
                                                            _revision = '2018-04-07'

                                                            def __init__(self):
                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.InstanceIds.InstanceId.State, self).__init__()

                                                                self.yang_name = "state"
                                                                self.yang_parent_name = "instance-id"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('instance_id', (YLeaf(YType.uint16, 'instance-id'), ['int'])),
                                                                    ('topology_id', (YLeafList(YType.uint16, 'topology-id'), ['int'])),
                                                                ])
                                                                self.instance_id = None
                                                                self.topology_id = []
                                                                self._segment_path = lambda: "state"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.InstanceIds.InstanceId.State, [u'instance_id', u'topology_id'], name, value)


                                                class Ipv4Srlgs(Entity):
                                                    """
                                                    Instance of the IPv4 SRLG TLV
                                                    
                                                    .. attribute:: ipv4_srlg
                                                    
                                                    	Instance of the IPv4 SRLG TLV
                                                    	**type**\: list of  		 :py:class:`Ipv4Srlg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4Srlgs.Ipv4Srlg>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4Srlgs, self).__init__()

                                                        self.yang_name = "ipv4-srlgs"
                                                        self.yang_parent_name = "tlvs"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("ipv4-srlg", ("ipv4_srlg", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4Srlgs.Ipv4Srlg))])
                                                        self._leafs = OrderedDict()

                                                        self.ipv4_srlg = YList(self)
                                                        self._segment_path = lambda: "ipv4-srlgs"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4Srlgs, [], name, value)


                                                    class Ipv4Srlg(Entity):
                                                        """
                                                        Instance of the IPv4 SRLG TLV
                                                        
                                                        .. attribute:: instance_number  (key)
                                                        
                                                        	Reference to the instance number of TLV 138
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: state
                                                        
                                                        	State parameters of TLV 138
                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4Srlgs.Ipv4Srlg.State>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4Srlgs.Ipv4Srlg, self).__init__()

                                                            self.yang_name = "ipv4-srlg"
                                                            self.yang_parent_name = "ipv4-srlgs"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['instance_number']
                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4Srlgs.Ipv4Srlg.State))])
                                                            self._leafs = OrderedDict([
                                                                ('instance_number', (YLeaf(YType.uint32, 'instance-number'), ['int'])),
                                                            ])
                                                            self.instance_number = None

                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4Srlgs.Ipv4Srlg.State()
                                                            self.state.parent = self
                                                            self._children_name_map["state"] = "state"
                                                            self._segment_path = lambda: "ipv4-srlg" + "[instance-number='" + str(self.instance_number) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4Srlgs.Ipv4Srlg, ['instance_number'], name, value)


                                                        class State(Entity):
                                                            """
                                                            State parameters of TLV 138
                                                            
                                                            .. attribute:: instance_number
                                                            
                                                            	An arbitrary unsigned 32\-bit integer used to disambiguate the instance of TLV 138
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: system_id
                                                            
                                                            	Neighbor system ID
                                                            	**type**\: str
                                                            
                                                            .. attribute:: psn_number
                                                            
                                                            	Pseudonode number if the neighbor is on a LAN interface
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..255
                                                            
                                                            .. attribute:: ipv4_interface_address
                                                            
                                                            	IPv4 interface address
                                                            	**type**\: str
                                                            
                                                            .. attribute:: ipv4_neighbor_address
                                                            
                                                            	IPv4 neighbor address
                                                            	**type**\: str
                                                            
                                                            .. attribute:: flags
                                                            
                                                            	SRLG flags
                                                            	**type**\: list of   :py:class:`OpenconfigIsisLspStateFlagsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisLspStateFlagsEnum>`
                                                            
                                                            .. attribute:: srlg_value
                                                            
                                                            	List of SRLG values
                                                            	**type**\: list of int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'clns-isis-oper'
                                                            _revision = '2018-04-07'

                                                            def __init__(self):
                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4Srlgs.Ipv4Srlg.State, self).__init__()

                                                                self.yang_name = "state"
                                                                self.yang_parent_name = "ipv4-srlg"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('instance_number', (YLeaf(YType.uint32, 'instance-number'), ['int'])),
                                                                    ('system_id', (YLeaf(YType.str, 'system-id'), ['str'])),
                                                                    ('psn_number', (YLeaf(YType.uint8, 'psn-number'), ['int'])),
                                                                    ('ipv4_interface_address', (YLeaf(YType.str, 'ipv4-interface-address'), ['str'])),
                                                                    ('ipv4_neighbor_address', (YLeaf(YType.str, 'ipv4-neighbor-address'), ['str'])),
                                                                    ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisLspStateFlagsEnum', '')])),
                                                                    ('srlg_value', (YLeafList(YType.uint32, 'srlg-value'), ['int'])),
                                                                ])
                                                                self.instance_number = None
                                                                self.system_id = None
                                                                self.psn_number = None
                                                                self.ipv4_interface_address = None
                                                                self.ipv4_neighbor_address = None
                                                                self.flags = []
                                                                self.srlg_value = []
                                                                self._segment_path = lambda: "state"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4Srlgs.Ipv4Srlg.State, [u'instance_number', u'system_id', u'psn_number', u'ipv4_interface_address', u'ipv4_neighbor_address', u'flags', u'srlg_value'], name, value)


                                                class IsReachability(Entity):
                                                    """
                                                    This container describes list of ISIS
                                                    neighbors and attributes
                                                    
                                                    .. attribute:: neighbors
                                                    
                                                    	IS reachability neighbor attributes
                                                    	**type**\:  :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability, self).__init__()

                                                        self.yang_name = "is-reachability"
                                                        self.yang_parent_name = "tlvs"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbors", ("neighbors", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors))])
                                                        self._leafs = OrderedDict()

                                                        self.neighbors = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors()
                                                        self.neighbors.parent = self
                                                        self._children_name_map["neighbors"] = "neighbors"
                                                        self._segment_path = lambda: "is-reachability"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability, [], name, value)


                                                    class Neighbors(Entity):
                                                        """
                                                        IS reachability neighbor attributes
                                                        
                                                        .. attribute:: neighbor
                                                        
                                                        	IS reachability neighbor attributes
                                                        	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors, self).__init__()

                                                            self.yang_name = "neighbors"
                                                            self.yang_parent_name = "is-reachability"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("neighbor", ("neighbor", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor))])
                                                            self._leafs = OrderedDict()

                                                            self.neighbor = YList(self)
                                                            self._segment_path = lambda: "neighbors"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors, [], name, value)


                                                        class Neighbor(Entity):
                                                            """
                                                            IS reachability neighbor attributes
                                                            
                                                            .. attribute:: system_id  (key)
                                                            
                                                            	Reference to the system ID of the neighbor
                                                            	**type**\: str
                                                            
                                                            .. attribute:: state
                                                            
                                                            	State parameters of IS standard neighbor
                                                            	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.State>`
                                                            
                                                            .. attribute:: default_metric
                                                            
                                                            	This container defines ISIS Default Metric
                                                            	**type**\:  :py:class:`DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.DefaultMetric>`
                                                            
                                                            .. attribute:: delay_metric
                                                            
                                                            	This container defines the ISIS delay metric
                                                            	**type**\:  :py:class:`DelayMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.DelayMetric>`
                                                            
                                                            .. attribute:: expense_metric
                                                            
                                                            	This container defines the ISIS expense metric
                                                            	**type**\:  :py:class:`ExpenseMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.ExpenseMetric>`
                                                            
                                                            .. attribute:: error_metric
                                                            
                                                            	This container defines the ISIS error metric
                                                            	**type**\:  :py:class:`ErrorMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.ErrorMetric>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'clns-isis-oper'
                                                            _revision = '2018-04-07'

                                                            def __init__(self):
                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor, self).__init__()

                                                                self.yang_name = "neighbor"
                                                                self.yang_parent_name = "neighbors"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['system_id']
                                                                self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.State)), ("default-metric", ("default_metric", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.DefaultMetric)), ("delay-metric", ("delay_metric", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.DelayMetric)), ("expense-metric", ("expense_metric", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.ExpenseMetric)), ("error-metric", ("error_metric", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.ErrorMetric))])
                                                                self._leafs = OrderedDict([
                                                                    ('system_id', (YLeaf(YType.str, 'system-id'), ['str'])),
                                                                ])
                                                                self.system_id = None

                                                                self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.State()
                                                                self.state.parent = self
                                                                self._children_name_map["state"] = "state"

                                                                self.default_metric = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.DefaultMetric()
                                                                self.default_metric.parent = self
                                                                self._children_name_map["default_metric"] = "default-metric"

                                                                self.delay_metric = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.DelayMetric()
                                                                self.delay_metric.parent = self
                                                                self._children_name_map["delay_metric"] = "delay-metric"

                                                                self.expense_metric = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.ExpenseMetric()
                                                                self.expense_metric.parent = self
                                                                self._children_name_map["expense_metric"] = "expense-metric"

                                                                self.error_metric = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.ErrorMetric()
                                                                self.error_metric.parent = self
                                                                self._children_name_map["error_metric"] = "error-metric"
                                                                self._segment_path = lambda: "neighbor" + "[system-id='" + str(self.system_id) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor, ['system_id'], name, value)


                                                            class State(Entity):
                                                                """
                                                                State parameters of IS standard neighbor
                                                                
                                                                .. attribute:: system_id
                                                                
                                                                	System\-ID of IS neighbor
                                                                	**type**\: str
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.State, self).__init__()

                                                                    self.yang_name = "state"
                                                                    self.yang_parent_name = "neighbor"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('system_id', (YLeaf(YType.str, 'system-id'), ['str'])),
                                                                    ])
                                                                    self.system_id = None
                                                                    self._segment_path = lambda: "state"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.State, [u'system_id'], name, value)


                                                            class DefaultMetric(Entity):
                                                                """
                                                                This container defines ISIS Default Metric
                                                                
                                                                .. attribute:: state
                                                                
                                                                	State parameters for default\-metric
                                                                	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.DefaultMetric.State>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.DefaultMetric, self).__init__()

                                                                    self.yang_name = "default-metric"
                                                                    self.yang_parent_name = "neighbor"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.DefaultMetric.State))])
                                                                    self._leafs = OrderedDict()

                                                                    self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.DefaultMetric.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"
                                                                    self._segment_path = lambda: "default-metric"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.DefaultMetric, [], name, value)


                                                                class State(Entity):
                                                                    """
                                                                    State parameters for default\-metric
                                                                    
                                                                    .. attribute:: flags
                                                                    
                                                                    	ISIS Default\-Metric Flags
                                                                    	**type**\:  :py:class:`OpenconfigIsisLspDefaultMetricStateFlagsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisLspDefaultMetricStateFlagsEnum>`
                                                                    
                                                                    .. attribute:: default_metric
                                                                    
                                                                    	ISIS default metric value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'clns-isis-oper'
                                                                    _revision = '2018-04-07'

                                                                    def __init__(self):
                                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.DefaultMetric.State, self).__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "default-metric"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('flags', (YLeaf(YType.enumeration, 'flags'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisLspDefaultMetricStateFlagsEnum', '')])),
                                                                            ('default_metric', (YLeaf(YType.uint8, 'default-metric'), ['int'])),
                                                                        ])
                                                                        self.flags = None
                                                                        self.default_metric = None
                                                                        self._segment_path = lambda: "state"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.DefaultMetric.State, [u'flags', u'default_metric'], name, value)


                                                            class DelayMetric(Entity):
                                                                """
                                                                This container defines the ISIS delay metric
                                                                
                                                                .. attribute:: state
                                                                
                                                                	State parameters of delay\-metric
                                                                	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.DelayMetric.State>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.DelayMetric, self).__init__()

                                                                    self.yang_name = "delay-metric"
                                                                    self.yang_parent_name = "neighbor"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.DelayMetric.State))])
                                                                    self._leafs = OrderedDict()

                                                                    self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.DelayMetric.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"
                                                                    self._segment_path = lambda: "delay-metric"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.DelayMetric, [], name, value)


                                                                class State(Entity):
                                                                    """
                                                                    State parameters of delay\-metric
                                                                    
                                                                    .. attribute:: metric
                                                                    
                                                                    	ISIS delay metric value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: flags
                                                                    
                                                                    	ISIS Delay Metric Flags
                                                                    	**type**\: list of   :py:class:`OpenconfigIsisLspIsisMetricFlagsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisLspIsisMetricFlagsEnum>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'clns-isis-oper'
                                                                    _revision = '2018-04-07'

                                                                    def __init__(self):
                                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.DelayMetric.State, self).__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "delay-metric"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                                                                            ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisLspIsisMetricFlagsEnum', '')])),
                                                                        ])
                                                                        self.metric = None
                                                                        self.flags = []
                                                                        self._segment_path = lambda: "state"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.DelayMetric.State, [u'metric', u'flags'], name, value)


                                                            class ExpenseMetric(Entity):
                                                                """
                                                                This container defines the ISIS expense metric
                                                                
                                                                .. attribute:: state
                                                                
                                                                	State parameters of expense\-metric
                                                                	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.ExpenseMetric.State>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.ExpenseMetric, self).__init__()

                                                                    self.yang_name = "expense-metric"
                                                                    self.yang_parent_name = "neighbor"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.ExpenseMetric.State))])
                                                                    self._leafs = OrderedDict()

                                                                    self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.ExpenseMetric.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"
                                                                    self._segment_path = lambda: "expense-metric"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.ExpenseMetric, [], name, value)


                                                                class State(Entity):
                                                                    """
                                                                    State parameters of expense\-metric
                                                                    
                                                                    .. attribute:: metric
                                                                    
                                                                    	ISIS expense metric value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: flags
                                                                    
                                                                    	ISIS Expense Metric Flags
                                                                    	**type**\: list of   :py:class:`OpenconfigIsisLspIsisMetricFlagsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisLspIsisMetricFlagsEnum>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'clns-isis-oper'
                                                                    _revision = '2018-04-07'

                                                                    def __init__(self):
                                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.ExpenseMetric.State, self).__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "expense-metric"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                                                                            ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisLspIsisMetricFlagsEnum', '')])),
                                                                        ])
                                                                        self.metric = None
                                                                        self.flags = []
                                                                        self._segment_path = lambda: "state"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.ExpenseMetric.State, [u'metric', u'flags'], name, value)


                                                            class ErrorMetric(Entity):
                                                                """
                                                                This container defines the ISIS error metric
                                                                
                                                                .. attribute:: state
                                                                
                                                                	State parameters of error\-metric
                                                                	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.ErrorMetric.State>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.ErrorMetric, self).__init__()

                                                                    self.yang_name = "error-metric"
                                                                    self.yang_parent_name = "neighbor"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.ErrorMetric.State))])
                                                                    self._leafs = OrderedDict()

                                                                    self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.ErrorMetric.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"
                                                                    self._segment_path = lambda: "error-metric"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.ErrorMetric, [], name, value)


                                                                class State(Entity):
                                                                    """
                                                                    State parameters of error\-metric
                                                                    
                                                                    .. attribute:: metric
                                                                    
                                                                    	ISIS error metric value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: flags
                                                                    
                                                                    	IS\-IS error metric flags
                                                                    	**type**\: list of   :py:class:`OpenconfigIsisLspIsisMetricFlagsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisLspIsisMetricFlagsEnum>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'clns-isis-oper'
                                                                    _revision = '2018-04-07'

                                                                    def __init__(self):
                                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.ErrorMetric.State, self).__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "error-metric"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                                                                            ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisLspIsisMetricFlagsEnum', '')])),
                                                                        ])
                                                                        self.metric = None
                                                                        self.flags = []
                                                                        self._segment_path = lambda: "state"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.IsReachability.Neighbors.Neighbor.ErrorMetric.State, [u'metric', u'flags'], name, value)


                                                class Ipv4TeRouterId(Entity):
                                                    """
                                                    This container defines TLV 134
                                                    
                                                    .. attribute:: state
                                                    
                                                    	State parameters of ISIS TLV 134
                                                    	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4TeRouterId.State>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4TeRouterId, self).__init__()

                                                        self.yang_name = "ipv4-te-router-id"
                                                        self.yang_parent_name = "tlvs"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4TeRouterId.State))])
                                                        self._leafs = OrderedDict()

                                                        self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4TeRouterId.State()
                                                        self.state.parent = self
                                                        self._children_name_map["state"] = "state"
                                                        self._segment_path = lambda: "ipv4-te-router-id"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4TeRouterId, [], name, value)


                                                    class State(Entity):
                                                        """
                                                        State parameters of ISIS TLV 134
                                                        
                                                        .. attribute:: router_id
                                                        
                                                        	IPv4 Traffic Engineering router ID of the node
                                                        	**type**\: list of str
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4TeRouterId.State, self).__init__()

                                                            self.yang_name = "state"
                                                            self.yang_parent_name = "ipv4-te-router-id"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('router_id', (YLeafList(YType.str, 'router-id'), ['str'])),
                                                            ])
                                                            self.router_id = []
                                                            self._segment_path = lambda: "state"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4TeRouterId.State, [u'router_id'], name, value)


                                                class Nlpid(Entity):
                                                    """
                                                    This container defines TLV 129
                                                    
                                                    .. attribute:: state
                                                    
                                                    	State parameters of ISIS TLV 129
                                                    	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Nlpid.State>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Nlpid, self).__init__()

                                                        self.yang_name = "nlpid"
                                                        self.yang_parent_name = "tlvs"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Nlpid.State))])
                                                        self._leafs = OrderedDict()

                                                        self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Nlpid.State()
                                                        self.state.parent = self
                                                        self._children_name_map["state"] = "state"
                                                        self._segment_path = lambda: "nlpid"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Nlpid, [], name, value)


                                                    class State(Entity):
                                                        """
                                                        State parameters of ISIS TLV 129
                                                        
                                                        .. attribute:: nlpid
                                                        
                                                        	Protocol supported
                                                        	**type**\: list of   :py:class:`OpenconfigIsisLspNlpidEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisLspNlpidEnum>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Nlpid.State, self).__init__()

                                                            self.yang_name = "state"
                                                            self.yang_parent_name = "nlpid"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('nlpid', (YLeafList(YType.enumeration, 'nlpid'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisLspNlpidEnum', '')])),
                                                            ])
                                                            self.nlpid = []
                                                            self._segment_path = lambda: "state"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Nlpid.State, [u'nlpid'], name, value)


                                                class ExtendedIpv4Reachability(Entity):
                                                    """
                                                    This container defines list of IPv4
                                                    extended reachability information
                                                    
                                                    .. attribute:: extended_ipv4_reachability_prefixes
                                                    
                                                    	This list describes IPv4 extended prefixes and attributes
                                                    	**type**\:  :py:class:`ExtendedIpv4ReachabilityPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability, self).__init__()

                                                        self.yang_name = "extended-ipv4-reachability"
                                                        self.yang_parent_name = "tlvs"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("extended-ipv4-reachability-prefixes", ("extended_ipv4_reachability_prefixes", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes))])
                                                        self._leafs = OrderedDict()

                                                        self.extended_ipv4_reachability_prefixes = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes()
                                                        self.extended_ipv4_reachability_prefixes.parent = self
                                                        self._children_name_map["extended_ipv4_reachability_prefixes"] = "extended-ipv4-reachability-prefixes"
                                                        self._segment_path = lambda: "extended-ipv4-reachability"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability, [], name, value)


                                                    class ExtendedIpv4ReachabilityPrefixes(Entity):
                                                        """
                                                        This list describes IPv4 extended
                                                        prefixes and attributes
                                                        
                                                        .. attribute:: extended_ipv4_reachability_prefixe
                                                        
                                                        	This list describes IPv4 extended prefixes and attributes
                                                        	**type**\: list of  		 :py:class:`ExtendedIpv4ReachabilityPrefixe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes, self).__init__()

                                                            self.yang_name = "extended-ipv4-reachability-prefixes"
                                                            self.yang_parent_name = "extended-ipv4-reachability"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("extended-ipv4-reachability-prefixe", ("extended_ipv4_reachability_prefixe", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe))])
                                                            self._leafs = OrderedDict()

                                                            self.extended_ipv4_reachability_prefixe = YList(self)
                                                            self._segment_path = lambda: "extended-ipv4-reachability-prefixes"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes, [], name, value)


                                                        class ExtendedIpv4ReachabilityPrefixe(Entity):
                                                            """
                                                            This list describes IPv4 extended
                                                            prefixes and attributes
                                                            
                                                            .. attribute:: prefix  (key)
                                                            
                                                            	Reference to the IPv4 prefix that the TLV describes the attributes of
                                                            	**type**\: str
                                                            
                                                            .. attribute:: prefixes_state
                                                            
                                                            	State parameters of an IPv4 extended prefix
                                                            	**type**\:  :py:class:`PrefixesState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesState>`
                                                            
                                                            .. attribute:: prefixes_subtlvs
                                                            
                                                            	List of subTLV types in the LSDB for the specified TLV
                                                            	**type**\:  :py:class:`PrefixesSubtlvs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs>`
                                                            
                                                            .. attribute:: prefixes_undefined_subtlvs
                                                            
                                                            	Sub\-TLVs that are not defined in the model or not recognised by system
                                                            	**type**\:  :py:class:`PrefixesUndefinedSubtlvs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesUndefinedSubtlvs>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'clns-isis-oper'
                                                            _revision = '2018-04-07'

                                                            def __init__(self):
                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe, self).__init__()

                                                                self.yang_name = "extended-ipv4-reachability-prefixe"
                                                                self.yang_parent_name = "extended-ipv4-reachability-prefixes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['prefix']
                                                                self._child_classes = OrderedDict([("prefixes-state", ("prefixes_state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesState)), ("prefixes-subtlvs", ("prefixes_subtlvs", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs)), ("prefixes-undefined-subtlvs", ("prefixes_undefined_subtlvs", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesUndefinedSubtlvs))])
                                                                self._leafs = OrderedDict([
                                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ])
                                                                self.prefix = None

                                                                self.prefixes_state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesState()
                                                                self.prefixes_state.parent = self
                                                                self._children_name_map["prefixes_state"] = "prefixes-state"

                                                                self.prefixes_subtlvs = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs()
                                                                self.prefixes_subtlvs.parent = self
                                                                self._children_name_map["prefixes_subtlvs"] = "prefixes-subtlvs"

                                                                self.prefixes_undefined_subtlvs = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesUndefinedSubtlvs()
                                                                self.prefixes_undefined_subtlvs.parent = self
                                                                self._children_name_map["prefixes_undefined_subtlvs"] = "prefixes-undefined-subtlvs"
                                                                self._segment_path = lambda: "extended-ipv4-reachability-prefixe" + "[prefix='" + str(self.prefix) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe, ['prefix'], name, value)


                                                            class PrefixesState(Entity):
                                                                """
                                                                State parameters of an IPv4
                                                                extended prefix
                                                                
                                                                .. attribute:: up_down
                                                                
                                                                	The up/down bit
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: sbit
                                                                
                                                                	The Sub\-TLV present bit
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: prefix
                                                                
                                                                	IPv4 prefix contained within extended reachability TLVs
                                                                	**type**\: str
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	ISIS metric value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesState, self).__init__()

                                                                    self.yang_name = "prefixes-state"
                                                                    self.yang_parent_name = "extended-ipv4-reachability-prefixe"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('up_down', (YLeaf(YType.boolean, 'up-down'), ['bool'])),
                                                                        ('sbit', (YLeaf(YType.boolean, 'sbit'), ['bool'])),
                                                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                    ])
                                                                    self.up_down = None
                                                                    self.sbit = None
                                                                    self.prefix = None
                                                                    self.metric = None
                                                                    self._segment_path = lambda: "prefixes-state"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesState, [u'up_down', u'sbit', u'prefix', u'metric'], name, value)


                                                            class PrefixesSubtlvs(Entity):
                                                                """
                                                                List of subTLV types in the LSDB
                                                                for the specified TLV
                                                                
                                                                .. attribute:: prefixes_subtlv
                                                                
                                                                	List of subTLV types in the LSDB for the specified TLV
                                                                	**type**\: list of  		 :py:class:`PrefixesSubtlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs, self).__init__()

                                                                    self.yang_name = "prefixes-subtlvs"
                                                                    self.yang_parent_name = "extended-ipv4-reachability-prefixe"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("prefixes-subtlv", ("prefixes_subtlv", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv))])
                                                                    self._leafs = OrderedDict()

                                                                    self.prefixes_subtlv = YList(self)
                                                                    self._segment_path = lambda: "prefixes-subtlvs"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs, [], name, value)


                                                                class PrefixesSubtlv(Entity):
                                                                    """
                                                                    List of subTLV types in the LSDB
                                                                    for the specified TLV
                                                                    
                                                                    .. attribute:: type  (key)
                                                                    
                                                                    	Reference to the sub\-TLV type
                                                                    	**type**\: str
                                                                    
                                                                    .. attribute:: tag
                                                                    
                                                                    	This container defines sub\-TLV 1
                                                                    	**type**\:  :py:class:`Tag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Tag>`
                                                                    
                                                                    .. attribute:: ipv4_source_router_id
                                                                    
                                                                    	This container defines sub\-TLV 11
                                                                    	**type**\:  :py:class:`Ipv4SourceRouterId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Ipv4SourceRouterId>`
                                                                    
                                                                    .. attribute:: ipv6_source_router_id
                                                                    
                                                                    	This container defines sub\-TLV 12
                                                                    	**type**\:  :py:class:`Ipv6SourceRouterId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Ipv6SourceRouterId>`
                                                                    
                                                                    .. attribute:: prefixes_subtlvs_state
                                                                    
                                                                    	State parameters for a prefix
                                                                    	**type**\:  :py:class:`PrefixesSubtlvsState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.PrefixesSubtlvsState>`
                                                                    
                                                                    .. attribute:: flags
                                                                    
                                                                    	This container defines sub\-TLV 4
                                                                    	**type**\:  :py:class:`Flags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Flags>`
                                                                    
                                                                    .. attribute:: tag64
                                                                    
                                                                    	This container defines sub\-TLV 2
                                                                    	**type**\:  :py:class:`Tag64 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Tag64>`
                                                                    
                                                                    .. attribute:: prefix_sids
                                                                    
                                                                    	Prefix Segment\-ID list
                                                                    	**type**\:  :py:class:`PrefixSids <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.PrefixSids>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'clns-isis-oper'
                                                                    _revision = '2018-04-07'

                                                                    def __init__(self):
                                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv, self).__init__()

                                                                        self.yang_name = "prefixes-subtlv"
                                                                        self.yang_parent_name = "prefixes-subtlvs"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = ['type']
                                                                        self._child_classes = OrderedDict([("tag", ("tag", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Tag)), ("ipv4-source-router-id", ("ipv4_source_router_id", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Ipv4SourceRouterId)), ("ipv6-source-router-id", ("ipv6_source_router_id", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Ipv6SourceRouterId)), ("prefixes-subtlvs-state", ("prefixes_subtlvs_state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.PrefixesSubtlvsState)), ("flags", ("flags", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Flags)), ("tag64", ("tag64", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Tag64)), ("prefix-sids", ("prefix_sids", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.PrefixSids))])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.str, 'type'), ['str'])),
                                                                        ])
                                                                        self.type = None

                                                                        self.tag = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Tag()
                                                                        self.tag.parent = self
                                                                        self._children_name_map["tag"] = "tag"

                                                                        self.ipv4_source_router_id = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Ipv4SourceRouterId()
                                                                        self.ipv4_source_router_id.parent = self
                                                                        self._children_name_map["ipv4_source_router_id"] = "ipv4-source-router-id"

                                                                        self.ipv6_source_router_id = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Ipv6SourceRouterId()
                                                                        self.ipv6_source_router_id.parent = self
                                                                        self._children_name_map["ipv6_source_router_id"] = "ipv6-source-router-id"

                                                                        self.prefixes_subtlvs_state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.PrefixesSubtlvsState()
                                                                        self.prefixes_subtlvs_state.parent = self
                                                                        self._children_name_map["prefixes_subtlvs_state"] = "prefixes-subtlvs-state"

                                                                        self.flags = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Flags()
                                                                        self.flags.parent = self
                                                                        self._children_name_map["flags"] = "flags"

                                                                        self.tag64 = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Tag64()
                                                                        self.tag64.parent = self
                                                                        self._children_name_map["tag64"] = "tag64"

                                                                        self.prefix_sids = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.PrefixSids()
                                                                        self.prefix_sids.parent = self
                                                                        self._children_name_map["prefix_sids"] = "prefix-sids"
                                                                        self._segment_path = lambda: "prefixes-subtlv" + "[type='" + str(self.type) + "']"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv, ['type'], name, value)


                                                                    class Tag(Entity):
                                                                        """
                                                                        This container defines sub\-TLV 1
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 1
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Tag.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Tag, self).__init__()

                                                                            self.yang_name = "tag"
                                                                            self.yang_parent_name = "prefixes-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Tag.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Tag.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "tag"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Tag, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 1
                                                                            
                                                                            .. attribute:: tag32
                                                                            
                                                                            	List of 32\-bit tags associated with the prefix
                                                                            	**type**\: list of int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Tag.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "tag"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('tag32', (YLeafList(YType.uint32, 'tag32'), ['int'])),
                                                                                ])
                                                                                self.tag32 = []
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Tag.State, [u'tag32'], name, value)


                                                                    class Ipv4SourceRouterId(Entity):
                                                                        """
                                                                        This container defines sub\-TLV
                                                                        11
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 11
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Ipv4SourceRouterId.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Ipv4SourceRouterId, self).__init__()

                                                                            self.yang_name = "ipv4-source-router-id"
                                                                            self.yang_parent_name = "prefixes-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Ipv4SourceRouterId.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Ipv4SourceRouterId.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "ipv4-source-router-id"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Ipv4SourceRouterId, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 11
                                                                            
                                                                            .. attribute:: type
                                                                            
                                                                            	The type of subTLV being described
                                                                            	**type**\: str
                                                                            
                                                                            .. attribute:: ipv4_source_router_id
                                                                            
                                                                            	IPv4 Source router ID address
                                                                            	**type**\: str
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Ipv4SourceRouterId.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "ipv4-source-router-id"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('type', (YLeaf(YType.str, 'type'), ['str'])),
                                                                                    ('ipv4_source_router_id', (YLeaf(YType.str, 'ipv4-source-router-id'), ['str'])),
                                                                                ])
                                                                                self.type = None
                                                                                self.ipv4_source_router_id = None
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Ipv4SourceRouterId.State, [u'type', u'ipv4_source_router_id'], name, value)


                                                                    class Ipv6SourceRouterId(Entity):
                                                                        """
                                                                        This container defines sub\-TLV
                                                                        12
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 12
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Ipv6SourceRouterId.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Ipv6SourceRouterId, self).__init__()

                                                                            self.yang_name = "ipv6-source-router-id"
                                                                            self.yang_parent_name = "prefixes-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Ipv6SourceRouterId.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Ipv6SourceRouterId.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "ipv6-source-router-id"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Ipv6SourceRouterId, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 12
                                                                            
                                                                            .. attribute:: type
                                                                            
                                                                            	The type of subTLV being described
                                                                            	**type**\: str
                                                                            
                                                                            .. attribute:: ipv6_source_router_id
                                                                            
                                                                            	IPv6 Source router ID address
                                                                            	**type**\: str
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Ipv6SourceRouterId.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "ipv6-source-router-id"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('type', (YLeaf(YType.str, 'type'), ['str'])),
                                                                                    ('ipv6_source_router_id', (YLeaf(YType.str, 'ipv6-source-router-id'), ['str'])),
                                                                                ])
                                                                                self.type = None
                                                                                self.ipv6_source_router_id = None
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Ipv6SourceRouterId.State, [u'type', u'ipv6_source_router_id'], name, value)


                                                                    class PrefixesSubtlvsState(Entity):
                                                                        """
                                                                        State parameters for a prefix
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	The type of subTLV being described
                                                                        	**type**\: str
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.PrefixesSubtlvsState, self).__init__()

                                                                            self.yang_name = "prefixes-subtlvs-state"
                                                                            self.yang_parent_name = "prefixes-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', (YLeaf(YType.str, 'type'), ['str'])),
                                                                            ])
                                                                            self.type = None
                                                                            self._segment_path = lambda: "prefixes-subtlvs-state"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.PrefixesSubtlvsState, [u'type'], name, value)


                                                                    class Flags(Entity):
                                                                        """
                                                                        This container defines sub\-TLV 4
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 4
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Flags.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Flags, self).__init__()

                                                                            self.yang_name = "flags"
                                                                            self.yang_parent_name = "prefixes-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Flags.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Flags.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "flags"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Flags, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 4
                                                                            
                                                                            .. attribute:: type
                                                                            
                                                                            	The type of subTLV being described
                                                                            	**type**\: str
                                                                            
                                                                            .. attribute:: flags
                                                                            
                                                                            	Additional prefix reachability flags
                                                                            	**type**\: list of   :py:class:`OpenconfigIsisLspFlagsStateFlagsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisLspFlagsStateFlagsEnum>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Flags.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "flags"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('type', (YLeaf(YType.str, 'type'), ['str'])),
                                                                                    ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisLspFlagsStateFlagsEnum', '')])),
                                                                                ])
                                                                                self.type = None
                                                                                self.flags = []
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Flags.State, [u'type', u'flags'], name, value)


                                                                    class Tag64(Entity):
                                                                        """
                                                                        This container defines sub\-TLV 2
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 2
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Tag64.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Tag64, self).__init__()

                                                                            self.yang_name = "tag64"
                                                                            self.yang_parent_name = "prefixes-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Tag64.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Tag64.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "tag64"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Tag64, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 2
                                                                            
                                                                            .. attribute:: tag64
                                                                            
                                                                            	List of 64\-bit tags associated with the prefix
                                                                            	**type**\: list of int
                                                                            
                                                                            	**range:** 0..18446744073709551615
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Tag64.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "tag64"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('tag64', (YLeafList(YType.uint64, 'tag64'), ['int'])),
                                                                                ])
                                                                                self.tag64 = []
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.Tag64.State, [u'tag64'], name, value)


                                                                    class PrefixSids(Entity):
                                                                        """
                                                                        Prefix Segment\-ID list
                                                                        
                                                                        .. attribute:: prefix_sid
                                                                        
                                                                        	Prefix Segment\-ID list
                                                                        	**type**\: list of  		 :py:class:`PrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.PrefixSids.PrefixSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.PrefixSids, self).__init__()

                                                                            self.yang_name = "prefix-sids"
                                                                            self.yang_parent_name = "prefixes-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("prefix-sid", ("prefix_sid", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.PrefixSids.PrefixSid))])
                                                                            self._leafs = OrderedDict()

                                                                            self.prefix_sid = YList(self)
                                                                            self._segment_path = lambda: "prefix-sids"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.PrefixSids, [], name, value)


                                                                        class PrefixSid(Entity):
                                                                            """
                                                                            Prefix Segment\-ID list
                                                                            
                                                                            .. attribute:: value  (key)
                                                                            
                                                                            	Reference to the value of the prefix SID
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                            	State parameters for Prefix\-SID
                                                                            	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.PrefixSids.PrefixSid.State>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.PrefixSids.PrefixSid, self).__init__()

                                                                                self.yang_name = "prefix-sid"
                                                                                self.yang_parent_name = "prefix-sids"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = ['value']
                                                                                self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.PrefixSids.PrefixSid.State))])
                                                                                self._leafs = OrderedDict([
                                                                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                                                                ])
                                                                                self.value = None

                                                                                self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.PrefixSids.PrefixSid.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "prefix-sid" + "[value='" + str(self.value) + "']"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.PrefixSids.PrefixSid, ['value'], name, value)


                                                                            class State(Entity):
                                                                                """
                                                                                State parameters for Prefix\-SID
                                                                                
                                                                                .. attribute:: value
                                                                                
                                                                                	IGP Prefix\-SID value
                                                                                	**type**\: int
                                                                                
                                                                                	**range:** 0..4294967295
                                                                                
                                                                                .. attribute:: algorithm
                                                                                
                                                                                	Prefix\-SID algorithm to be used for path computation
                                                                                	**type**\: int
                                                                                
                                                                                	**range:** 0..255
                                                                                
                                                                                .. attribute:: flags
                                                                                
                                                                                	Flags associated with Prefix Segment\-ID
                                                                                	**type**\: list of   :py:class:`OpenconfigIsisLspPrefixSidStateFlagsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisLspPrefixSidStateFlagsEnum>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'clns-isis-oper'
                                                                                _revision = '2018-04-07'

                                                                                def __init__(self):
                                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.PrefixSids.PrefixSid.State, self).__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "prefix-sid"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                                                                        ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                                                                        ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisLspPrefixSidStateFlagsEnum', '')])),
                                                                                    ])
                                                                                    self.value = None
                                                                                    self.algorithm = None
                                                                                    self.flags = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesSubtlvs.PrefixesSubtlv.PrefixSids.PrefixSid.State, [u'value', u'algorithm', u'flags'], name, value)


                                                            class PrefixesUndefinedSubtlvs(Entity):
                                                                """
                                                                Sub\-TLVs that are not defined in
                                                                the model or not recognised by
                                                                system
                                                                
                                                                .. attribute:: prefixes_undefined_subtlv
                                                                
                                                                	Sub\-TLVs that are not defined in the model or not recognised by system
                                                                	**type**\: list of  		 :py:class:`PrefixesUndefinedSubtlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesUndefinedSubtlvs.PrefixesUndefinedSubtlv>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesUndefinedSubtlvs, self).__init__()

                                                                    self.yang_name = "prefixes-undefined-subtlvs"
                                                                    self.yang_parent_name = "extended-ipv4-reachability-prefixe"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("prefixes-undefined-subtlv", ("prefixes_undefined_subtlv", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesUndefinedSubtlvs.PrefixesUndefinedSubtlv))])
                                                                    self._leafs = OrderedDict()

                                                                    self.prefixes_undefined_subtlv = YList(self)
                                                                    self._segment_path = lambda: "prefixes-undefined-subtlvs"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesUndefinedSubtlvs, [], name, value)


                                                                class PrefixesUndefinedSubtlv(Entity):
                                                                    """
                                                                    Sub\-TLVs that are not defined in
                                                                    the model or not recognised by
                                                                    system
                                                                    
                                                                    .. attribute:: type  (key)
                                                                    
                                                                    	Reference to the type of the undefined sub\-TLV
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of the undefined sub\-TLV
                                                                    	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesUndefinedSubtlvs.PrefixesUndefinedSubtlv.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'clns-isis-oper'
                                                                    _revision = '2018-04-07'

                                                                    def __init__(self):
                                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesUndefinedSubtlvs.PrefixesUndefinedSubtlv, self).__init__()

                                                                        self.yang_name = "prefixes-undefined-subtlv"
                                                                        self.yang_parent_name = "prefixes-undefined-subtlvs"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = ['type']
                                                                        self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesUndefinedSubtlvs.PrefixesUndefinedSubtlv.State))])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.uint32, 'type'), ['int'])),
                                                                        ])
                                                                        self.type = None

                                                                        self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesUndefinedSubtlvs.PrefixesUndefinedSubtlv.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._segment_path = lambda: "prefixes-undefined-subtlv" + "[type='" + str(self.type) + "']"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesUndefinedSubtlvs.PrefixesUndefinedSubtlv, ['type'], name, value)


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of the undefined sub\-TLV
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	TLV Type
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: length
                                                                        
                                                                        	TLV length
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: value
                                                                        
                                                                        	TLV value
                                                                        	**type**\: str
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesUndefinedSubtlvs.PrefixesUndefinedSubtlv.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "prefixes-undefined-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                                                ('length', (YLeaf(YType.uint8, 'length'), ['int'])),
                                                                                ('value', (YLeaf(YType.str, 'value'), ['str'])),
                                                                            ])
                                                                            self.type = None
                                                                            self.length = None
                                                                            self.value = None
                                                                            self._segment_path = lambda: "state"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.ExtendedIpv4Reachability.ExtendedIpv4ReachabilityPrefixes.ExtendedIpv4ReachabilityPrefixe.PrefixesUndefinedSubtlvs.PrefixesUndefinedSubtlv.State, [u'type', u'length', u'value'], name, value)


                                                class MultiTopology(Entity):
                                                    """
                                                    This container defines the topology
                                                    supported
                                                    
                                                    .. attribute:: topologies
                                                    
                                                    	This list describes a topology
                                                    	**type**\:  :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MultiTopology.Topologies>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MultiTopology, self).__init__()

                                                        self.yang_name = "multi-topology"
                                                        self.yang_parent_name = "tlvs"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("topologies", ("topologies", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MultiTopology.Topologies))])
                                                        self._leafs = OrderedDict()

                                                        self.topologies = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MultiTopology.Topologies()
                                                        self.topologies.parent = self
                                                        self._children_name_map["topologies"] = "topologies"
                                                        self._segment_path = lambda: "multi-topology"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MultiTopology, [], name, value)


                                                    class Topologies(Entity):
                                                        """
                                                        This list describes a topology
                                                        
                                                        .. attribute:: topology
                                                        
                                                        	This list describes a topology
                                                        	**type**\: list of  		 :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MultiTopology.Topologies.Topology>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MultiTopology.Topologies, self).__init__()

                                                            self.yang_name = "topologies"
                                                            self.yang_parent_name = "multi-topology"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("topology", ("topology", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MultiTopology.Topologies.Topology))])
                                                            self._leafs = OrderedDict()

                                                            self.topology = YList(self)
                                                            self._segment_path = lambda: "topologies"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MultiTopology.Topologies, [], name, value)


                                                        class Topology(Entity):
                                                            """
                                                            This list describes a topology
                                                            
                                                            .. attribute:: mt_id  (key)
                                                            
                                                            	Reference to the multi\-topology ID being described by the list entry
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            .. attribute:: state
                                                            
                                                            	State parameters of IS multi\-topology TLV 229
                                                            	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MultiTopology.Topologies.Topology.State>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'clns-isis-oper'
                                                            _revision = '2018-04-07'

                                                            def __init__(self):
                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MultiTopology.Topologies.Topology, self).__init__()

                                                                self.yang_name = "topology"
                                                                self.yang_parent_name = "topologies"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['mt_id']
                                                                self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MultiTopology.Topologies.Topology.State))])
                                                                self._leafs = OrderedDict([
                                                                    ('mt_id', (YLeaf(YType.uint32, 'mt-id'), ['int'])),
                                                                ])
                                                                self.mt_id = None

                                                                self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MultiTopology.Topologies.Topology.State()
                                                                self.state.parent = self
                                                                self._children_name_map["state"] = "state"
                                                                self._segment_path = lambda: "topology" + "[mt-id='" + str(self.mt_id) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MultiTopology.Topologies.Topology, ['mt_id'], name, value)


                                                            class State(Entity):
                                                                """
                                                                State parameters of IS multi\-topology TLV 229
                                                                
                                                                .. attribute:: mt_id
                                                                
                                                                	Multi\-topology ID
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: attributes
                                                                
                                                                	Attributes of the LSP for the associated topology
                                                                	**type**\:  :py:class:`OpenconfigIsisLspAttributesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisLspAttributesEnum>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MultiTopology.Topologies.Topology.State, self).__init__()

                                                                    self.yang_name = "state"
                                                                    self.yang_parent_name = "topology"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('mt_id', (YLeaf(YType.uint16, 'mt-id'), ['int'])),
                                                                        ('attributes', (YLeaf(YType.enumeration, 'attributes'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisLspAttributesEnum', '')])),
                                                                    ])
                                                                    self.mt_id = None
                                                                    self.attributes = None
                                                                    self._segment_path = lambda: "state"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MultiTopology.Topologies.Topology.State, [u'mt_id', u'attributes'], name, value)


                                                class Ipv4ExternalReachability(Entity):
                                                    """
                                                    This container defines list of IPv4
                                                    external reachability information
                                                    
                                                    .. attribute:: ipv4_external_reachability_prefixes
                                                    
                                                    	IPv4 external prefixes and reachability attributes
                                                    	**type**\:  :py:class:`Ipv4ExternalReachabilityPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability, self).__init__()

                                                        self.yang_name = "ipv4-external-reachability"
                                                        self.yang_parent_name = "tlvs"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("ipv4-external-reachability-prefixes", ("ipv4_external_reachability_prefixes", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes))])
                                                        self._leafs = OrderedDict()

                                                        self.ipv4_external_reachability_prefixes = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes()
                                                        self.ipv4_external_reachability_prefixes.parent = self
                                                        self._children_name_map["ipv4_external_reachability_prefixes"] = "ipv4-external-reachability-prefixes"
                                                        self._segment_path = lambda: "ipv4-external-reachability"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability, [], name, value)


                                                    class Ipv4ExternalReachabilityPrefixes(Entity):
                                                        """
                                                        IPv4 external prefixes and
                                                        reachability attributes
                                                        
                                                        .. attribute:: ipv4_external_reachability_prefixe
                                                        
                                                        	IPv4 external prefixes and reachability attributes
                                                        	**type**\: list of  		 :py:class:`Ipv4ExternalReachabilityPrefixe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes, self).__init__()

                                                            self.yang_name = "ipv4-external-reachability-prefixes"
                                                            self.yang_parent_name = "ipv4-external-reachability"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("ipv4-external-reachability-prefixe", ("ipv4_external_reachability_prefixe", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe))])
                                                            self._leafs = OrderedDict()

                                                            self.ipv4_external_reachability_prefixe = YList(self)
                                                            self._segment_path = lambda: "ipv4-external-reachability-prefixes"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes, [], name, value)


                                                        class Ipv4ExternalReachabilityPrefixe(Entity):
                                                            """
                                                            IPv4 external prefixes and
                                                            reachability attributes
                                                            
                                                            .. attribute:: prefix  (key)
                                                            
                                                            	Reference to the IPv4 prefix
                                                            	**type**\: str
                                                            
                                                            .. attribute:: state
                                                            
                                                            	State parameters of IPv4 standard prefix
                                                            	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.State>`
                                                            
                                                            .. attribute:: default_metric
                                                            
                                                            	This container defines ISIS Default Metric
                                                            	**type**\:  :py:class:`DefaultMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.DefaultMetric>`
                                                            
                                                            .. attribute:: delay_metric
                                                            
                                                            	This container defines the ISIS delay metric
                                                            	**type**\:  :py:class:`DelayMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.DelayMetric>`
                                                            
                                                            .. attribute:: expense_metric
                                                            
                                                            	This container defines the ISIS expense metric
                                                            	**type**\:  :py:class:`ExpenseMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.ExpenseMetric>`
                                                            
                                                            .. attribute:: error_metric
                                                            
                                                            	This container defines the ISIS error metric
                                                            	**type**\:  :py:class:`ErrorMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.ErrorMetric>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'clns-isis-oper'
                                                            _revision = '2018-04-07'

                                                            def __init__(self):
                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe, self).__init__()

                                                                self.yang_name = "ipv4-external-reachability-prefixe"
                                                                self.yang_parent_name = "ipv4-external-reachability-prefixes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['prefix']
                                                                self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.State)), ("default-metric", ("default_metric", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.DefaultMetric)), ("delay-metric", ("delay_metric", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.DelayMetric)), ("expense-metric", ("expense_metric", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.ExpenseMetric)), ("error-metric", ("error_metric", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.ErrorMetric))])
                                                                self._leafs = OrderedDict([
                                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ])
                                                                self.prefix = None

                                                                self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.State()
                                                                self.state.parent = self
                                                                self._children_name_map["state"] = "state"

                                                                self.default_metric = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.DefaultMetric()
                                                                self.default_metric.parent = self
                                                                self._children_name_map["default_metric"] = "default-metric"

                                                                self.delay_metric = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.DelayMetric()
                                                                self.delay_metric.parent = self
                                                                self._children_name_map["delay_metric"] = "delay-metric"

                                                                self.expense_metric = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.ExpenseMetric()
                                                                self.expense_metric.parent = self
                                                                self._children_name_map["expense_metric"] = "expense-metric"

                                                                self.error_metric = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.ErrorMetric()
                                                                self.error_metric.parent = self
                                                                self._children_name_map["error_metric"] = "error-metric"
                                                                self._segment_path = lambda: "ipv4-external-reachability-prefixe" + "[prefix='" + str(self.prefix) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe, ['prefix'], name, value)


                                                            class State(Entity):
                                                                """
                                                                State parameters of IPv4 standard prefix
                                                                
                                                                .. attribute:: up_down
                                                                
                                                                	The up/down bit
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: prefix
                                                                
                                                                	IPv4 prefix contained within reachability TLVs
                                                                	**type**\: str
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.State, self).__init__()

                                                                    self.yang_name = "state"
                                                                    self.yang_parent_name = "ipv4-external-reachability-prefixe"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('up_down', (YLeaf(YType.boolean, 'up-down'), ['bool'])),
                                                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                    ])
                                                                    self.up_down = None
                                                                    self.prefix = None
                                                                    self._segment_path = lambda: "state"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.State, [u'up_down', u'prefix'], name, value)


                                                            class DefaultMetric(Entity):
                                                                """
                                                                This container defines ISIS Default Metric
                                                                
                                                                .. attribute:: state
                                                                
                                                                	State parameters for default\-metric
                                                                	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.DefaultMetric.State>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.DefaultMetric, self).__init__()

                                                                    self.yang_name = "default-metric"
                                                                    self.yang_parent_name = "ipv4-external-reachability-prefixe"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.DefaultMetric.State))])
                                                                    self._leafs = OrderedDict()

                                                                    self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.DefaultMetric.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"
                                                                    self._segment_path = lambda: "default-metric"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.DefaultMetric, [], name, value)


                                                                class State(Entity):
                                                                    """
                                                                    State parameters for default\-metric
                                                                    
                                                                    .. attribute:: flags
                                                                    
                                                                    	ISIS Default\-Metric Flags
                                                                    	**type**\:  :py:class:`OpenconfigIsisLspDefaultMetricStateFlagsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisLspDefaultMetricStateFlagsEnum>`
                                                                    
                                                                    .. attribute:: default_metric
                                                                    
                                                                    	ISIS default metric value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'clns-isis-oper'
                                                                    _revision = '2018-04-07'

                                                                    def __init__(self):
                                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.DefaultMetric.State, self).__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "default-metric"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('flags', (YLeaf(YType.enumeration, 'flags'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisLspDefaultMetricStateFlagsEnum', '')])),
                                                                            ('default_metric', (YLeaf(YType.uint8, 'default-metric'), ['int'])),
                                                                        ])
                                                                        self.flags = None
                                                                        self.default_metric = None
                                                                        self._segment_path = lambda: "state"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.DefaultMetric.State, [u'flags', u'default_metric'], name, value)


                                                            class DelayMetric(Entity):
                                                                """
                                                                This container defines the ISIS delay metric
                                                                
                                                                .. attribute:: state
                                                                
                                                                	State parameters of delay\-metric
                                                                	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.DelayMetric.State>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.DelayMetric, self).__init__()

                                                                    self.yang_name = "delay-metric"
                                                                    self.yang_parent_name = "ipv4-external-reachability-prefixe"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.DelayMetric.State))])
                                                                    self._leafs = OrderedDict()

                                                                    self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.DelayMetric.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"
                                                                    self._segment_path = lambda: "delay-metric"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.DelayMetric, [], name, value)


                                                                class State(Entity):
                                                                    """
                                                                    State parameters of delay\-metric
                                                                    
                                                                    .. attribute:: metric
                                                                    
                                                                    	ISIS delay metric value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: flags
                                                                    
                                                                    	ISIS Delay Metric Flags
                                                                    	**type**\: list of   :py:class:`OpenconfigIsisLspIsisMetricFlagsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisLspIsisMetricFlagsEnum>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'clns-isis-oper'
                                                                    _revision = '2018-04-07'

                                                                    def __init__(self):
                                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.DelayMetric.State, self).__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "delay-metric"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                                                                            ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisLspIsisMetricFlagsEnum', '')])),
                                                                        ])
                                                                        self.metric = None
                                                                        self.flags = []
                                                                        self._segment_path = lambda: "state"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.DelayMetric.State, [u'metric', u'flags'], name, value)


                                                            class ExpenseMetric(Entity):
                                                                """
                                                                This container defines the ISIS expense metric
                                                                
                                                                .. attribute:: state
                                                                
                                                                	State parameters of expense\-metric
                                                                	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.ExpenseMetric.State>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.ExpenseMetric, self).__init__()

                                                                    self.yang_name = "expense-metric"
                                                                    self.yang_parent_name = "ipv4-external-reachability-prefixe"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.ExpenseMetric.State))])
                                                                    self._leafs = OrderedDict()

                                                                    self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.ExpenseMetric.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"
                                                                    self._segment_path = lambda: "expense-metric"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.ExpenseMetric, [], name, value)


                                                                class State(Entity):
                                                                    """
                                                                    State parameters of expense\-metric
                                                                    
                                                                    .. attribute:: metric
                                                                    
                                                                    	ISIS expense metric value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: flags
                                                                    
                                                                    	ISIS Expense Metric Flags
                                                                    	**type**\: list of   :py:class:`OpenconfigIsisLspIsisMetricFlagsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisLspIsisMetricFlagsEnum>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'clns-isis-oper'
                                                                    _revision = '2018-04-07'

                                                                    def __init__(self):
                                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.ExpenseMetric.State, self).__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "expense-metric"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                                                                            ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisLspIsisMetricFlagsEnum', '')])),
                                                                        ])
                                                                        self.metric = None
                                                                        self.flags = []
                                                                        self._segment_path = lambda: "state"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.ExpenseMetric.State, [u'metric', u'flags'], name, value)


                                                            class ErrorMetric(Entity):
                                                                """
                                                                This container defines the ISIS error metric
                                                                
                                                                .. attribute:: state
                                                                
                                                                	State parameters of error\-metric
                                                                	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.ErrorMetric.State>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.ErrorMetric, self).__init__()

                                                                    self.yang_name = "error-metric"
                                                                    self.yang_parent_name = "ipv4-external-reachability-prefixe"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.ErrorMetric.State))])
                                                                    self._leafs = OrderedDict()

                                                                    self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.ErrorMetric.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"
                                                                    self._segment_path = lambda: "error-metric"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.ErrorMetric, [], name, value)


                                                                class State(Entity):
                                                                    """
                                                                    State parameters of error\-metric
                                                                    
                                                                    .. attribute:: metric
                                                                    
                                                                    	ISIS error metric value
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..255
                                                                    
                                                                    .. attribute:: flags
                                                                    
                                                                    	IS\-IS error metric flags
                                                                    	**type**\: list of   :py:class:`OpenconfigIsisLspIsisMetricFlagsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisLspIsisMetricFlagsEnum>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'clns-isis-oper'
                                                                    _revision = '2018-04-07'

                                                                    def __init__(self):
                                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.ErrorMetric.State, self).__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "error-metric"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                                                                            ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisLspIsisMetricFlagsEnum', '')])),
                                                                        ])
                                                                        self.metric = None
                                                                        self.flags = []
                                                                        self._segment_path = lambda: "state"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.Ipv4ExternalReachability.Ipv4ExternalReachabilityPrefixes.Ipv4ExternalReachabilityPrefixe.ErrorMetric.State, [u'metric', u'flags'], name, value)


                                                class MtIpv6Reachability(Entity):
                                                    """
                                                    This container defines list of IPv6
                                                    reachability information in multi \-
                                                    topology environment
                                                    
                                                    .. attribute:: mt_ipv6_reachability_prefixes
                                                    
                                                    	List of IPv6 prefixes contained within MT reachability TLV
                                                    	**type**\:  :py:class:`MtIpv6ReachabilityPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability, self).__init__()

                                                        self.yang_name = "mt-ipv6-reachability"
                                                        self.yang_parent_name = "tlvs"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("mt-ipv6-reachability-prefixes", ("mt_ipv6_reachability_prefixes", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes))])
                                                        self._leafs = OrderedDict()

                                                        self.mt_ipv6_reachability_prefixes = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes()
                                                        self.mt_ipv6_reachability_prefixes.parent = self
                                                        self._children_name_map["mt_ipv6_reachability_prefixes"] = "mt-ipv6-reachability-prefixes"
                                                        self._segment_path = lambda: "mt-ipv6-reachability"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability, [], name, value)


                                                    class MtIpv6ReachabilityPrefixes(Entity):
                                                        """
                                                        List of IPv6 prefixes contained
                                                        within MT reachability TLV
                                                        
                                                        .. attribute:: mt_ipv6_reachability_prefixe
                                                        
                                                        	List of IPv6 prefixes contained within MT reachability TLV
                                                        	**type**\: list of  		 :py:class:`MtIpv6ReachabilityPrefixe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes, self).__init__()

                                                            self.yang_name = "mt-ipv6-reachability-prefixes"
                                                            self.yang_parent_name = "mt-ipv6-reachability"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("mt-ipv6-reachability-prefixe", ("mt_ipv6_reachability_prefixe", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe))])
                                                            self._leafs = OrderedDict()

                                                            self.mt_ipv6_reachability_prefixe = YList(self)
                                                            self._segment_path = lambda: "mt-ipv6-reachability-prefixes"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes, [], name, value)


                                                        class MtIpv6ReachabilityPrefixe(Entity):
                                                            """
                                                            List of IPv6 prefixes contained
                                                            within MT reachability TLV
                                                            
                                                            .. attribute:: mt_ipv6_reachability_prefixes_state
                                                            
                                                            	State parameters relating an IPv6 prefix attribute
                                                            	**type**\:  :py:class:`MtIpv6ReachabilityPrefixesState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesState>`
                                                            
                                                            .. attribute:: mt_ipv6_reachability_prefixes_subtlvs
                                                            
                                                            	List of subTLV types in the LSDB for the specified TLV
                                                            	**type**\:  :py:class:`MtIpv6ReachabilityPrefixesSubtlvs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs>`
                                                            
                                                            .. attribute:: mt_ipv6_reachability_prefixes_undefined_subtlvs
                                                            
                                                            	Sub\-TLVs that are not defined in the model or not recognised by system
                                                            	**type**\:  :py:class:`MtIpv6ReachabilityPrefixesUndefinedSubtlvs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesUndefinedSubtlvs>`
                                                            
                                                            .. attribute:: prefix
                                                            
                                                            	Reference to the IPv6 prefix described by the TLV
                                                            	**type**\: str
                                                            
                                                            .. attribute:: mt_id
                                                            
                                                            	Reference to the multi\-topology ID
                                                            	**type**\: int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'clns-isis-oper'
                                                            _revision = '2018-04-07'

                                                            def __init__(self):
                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe, self).__init__()

                                                                self.yang_name = "mt-ipv6-reachability-prefixe"
                                                                self.yang_parent_name = "mt-ipv6-reachability-prefixes"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("mt-ipv6-reachability-prefixes-state", ("mt_ipv6_reachability_prefixes_state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesState)), ("mt-ipv6-reachability-prefixes-subtlvs", ("mt_ipv6_reachability_prefixes_subtlvs", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs)), ("mt-ipv6-reachability-prefixes-undefined-subtlvs", ("mt_ipv6_reachability_prefixes_undefined_subtlvs", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesUndefinedSubtlvs))])
                                                                self._leafs = OrderedDict([
                                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                    ('mt_id', (YLeaf(YType.uint32, 'mt-id'), ['int'])),
                                                                ])
                                                                self.prefix = None
                                                                self.mt_id = None

                                                                self.mt_ipv6_reachability_prefixes_state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesState()
                                                                self.mt_ipv6_reachability_prefixes_state.parent = self
                                                                self._children_name_map["mt_ipv6_reachability_prefixes_state"] = "mt-ipv6-reachability-prefixes-state"

                                                                self.mt_ipv6_reachability_prefixes_subtlvs = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs()
                                                                self.mt_ipv6_reachability_prefixes_subtlvs.parent = self
                                                                self._children_name_map["mt_ipv6_reachability_prefixes_subtlvs"] = "mt-ipv6-reachability-prefixes-subtlvs"

                                                                self.mt_ipv6_reachability_prefixes_undefined_subtlvs = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesUndefinedSubtlvs()
                                                                self.mt_ipv6_reachability_prefixes_undefined_subtlvs.parent = self
                                                                self._children_name_map["mt_ipv6_reachability_prefixes_undefined_subtlvs"] = "mt-ipv6-reachability-prefixes-undefined-subtlvs"
                                                                self._segment_path = lambda: "mt-ipv6-reachability-prefixe"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe, ['prefix', 'mt_id'], name, value)


                                                            class MtIpv6ReachabilityPrefixesState(Entity):
                                                                """
                                                                State parameters relating an IPv6
                                                                prefix attribute
                                                                
                                                                .. attribute:: up_down
                                                                
                                                                	The up/down bit
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: xbit
                                                                
                                                                	The external bit
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: sbit
                                                                
                                                                	The sub\-tlv present bit
                                                                	**type**\: bool
                                                                
                                                                .. attribute:: prefix
                                                                
                                                                	IPv6 prefix contained within extended reachability TLVs
                                                                	**type**\: str
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	ISIS metric value
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mt_id
                                                                
                                                                	Multi\-topology ID
                                                                	**type**\: int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesState, self).__init__()

                                                                    self.yang_name = "mt-ipv6-reachability-prefixes-state"
                                                                    self.yang_parent_name = "mt-ipv6-reachability-prefixe"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('up_down', (YLeaf(YType.boolean, 'up-down'), ['bool'])),
                                                                        ('xbit', (YLeaf(YType.boolean, 'xbit'), ['bool'])),
                                                                        ('sbit', (YLeaf(YType.boolean, 'sbit'), ['bool'])),
                                                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                        ('mt_id', (YLeaf(YType.uint16, 'mt-id'), ['int'])),
                                                                    ])
                                                                    self.up_down = None
                                                                    self.xbit = None
                                                                    self.sbit = None
                                                                    self.prefix = None
                                                                    self.metric = None
                                                                    self.mt_id = None
                                                                    self._segment_path = lambda: "mt-ipv6-reachability-prefixes-state"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesState, [u'up_down', u'xbit', u'sbit', u'prefix', u'metric', u'mt_id'], name, value)


                                                            class MtIpv6ReachabilityPrefixesSubtlvs(Entity):
                                                                """
                                                                List of subTLV types in the LSDB
                                                                for the specified TLV
                                                                
                                                                .. attribute:: mt_ipv6_reachability_prefixes_subtlv
                                                                
                                                                	List of subTLV types in the LSDB for the specified TLV
                                                                	**type**\: list of  		 :py:class:`MtIpv6ReachabilityPrefixesSubtlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs, self).__init__()

                                                                    self.yang_name = "mt-ipv6-reachability-prefixes-subtlvs"
                                                                    self.yang_parent_name = "mt-ipv6-reachability-prefixe"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("mt-ipv6-reachability-prefixes-subtlv", ("mt_ipv6_reachability_prefixes_subtlv", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv))])
                                                                    self._leafs = OrderedDict()

                                                                    self.mt_ipv6_reachability_prefixes_subtlv = YList(self)
                                                                    self._segment_path = lambda: "mt-ipv6-reachability-prefixes-subtlvs"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs, [], name, value)


                                                                class MtIpv6ReachabilityPrefixesSubtlv(Entity):
                                                                    """
                                                                    List of subTLV types in the LSDB
                                                                    for the specified TLV
                                                                    
                                                                    .. attribute:: type  (key)
                                                                    
                                                                    	Reference to the sub\-TLV type
                                                                    	**type**\: str
                                                                    
                                                                    .. attribute:: mt_ipv6_reachability_prefixes_subtlvs_prefix_sids
                                                                    
                                                                    	Prefix Segment\-ID list
                                                                    	**type**\:  :py:class:`MtIpv6ReachabilityPrefixesSubtlvsPrefixSids <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsPrefixSids>`
                                                                    
                                                                    .. attribute:: mt_ipv6_reachability_prefixes_subtlvs_flags
                                                                    
                                                                    	This container defines sub\-TLV 4
                                                                    	**type**\:  :py:class:`MtIpv6ReachabilityPrefixesSubtlvsFlags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsFlags>`
                                                                    
                                                                    .. attribute:: mt_ipv6_reachability_prefixes_subtlvs_ipv4_source_router_id
                                                                    
                                                                    	This container defines sub\-TLV 11
                                                                    	**type**\:  :py:class:`MtIpv6ReachabilityPrefixesSubtlvsIpv4SourceRouterId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsIpv4SourceRouterId>`
                                                                    
                                                                    .. attribute:: mt_ipv6_reachability_prefixes_subtlvs_tag64
                                                                    
                                                                    	This container defines sub\-TLV 2
                                                                    	**type**\:  :py:class:`MtIpv6ReachabilityPrefixesSubtlvsTag64 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsTag64>`
                                                                    
                                                                    .. attribute:: mt_ipv6_reachability_prefixes_subtlvs_ipv6_source_router_id
                                                                    
                                                                    	This container defines sub\-TLV 12
                                                                    	**type**\:  :py:class:`MtIpv6ReachabilityPrefixesSubtlvsIpv6SourceRouterId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsIpv6SourceRouterId>`
                                                                    
                                                                    .. attribute:: mt_ipv6_reachability_prefixes_subtlvs_tag
                                                                    
                                                                    	This container defines sub\-TLV 1
                                                                    	**type**\:  :py:class:`MtIpv6ReachabilityPrefixesSubtlvsTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsTag>`
                                                                    
                                                                    .. attribute:: mt_ipv6_reachability_prefixes_subtlvs_state
                                                                    
                                                                    	State parameters for a prefix
                                                                    	**type**\:  :py:class:`MtIpv6ReachabilityPrefixesSubtlvsState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsState>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'clns-isis-oper'
                                                                    _revision = '2018-04-07'

                                                                    def __init__(self):
                                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv, self).__init__()

                                                                        self.yang_name = "mt-ipv6-reachability-prefixes-subtlv"
                                                                        self.yang_parent_name = "mt-ipv6-reachability-prefixes-subtlvs"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = ['type']
                                                                        self._child_classes = OrderedDict([("mt-ipv6-reachability-prefixes-subtlvs-prefix-sids", ("mt_ipv6_reachability_prefixes_subtlvs_prefix_sids", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsPrefixSids)), ("mt-ipv6-reachability-prefixes-subtlvs-flags", ("mt_ipv6_reachability_prefixes_subtlvs_flags", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsFlags)), ("mt-ipv6-reachability-prefixes-subtlvs-ipv4-source-router-id", ("mt_ipv6_reachability_prefixes_subtlvs_ipv4_source_router_id", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsIpv4SourceRouterId)), ("mt-ipv6-reachability-prefixes-subtlvs-tag64", ("mt_ipv6_reachability_prefixes_subtlvs_tag64", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsTag64)), ("mt-ipv6-reachability-prefixes-subtlvs-ipv6-source-router-id", ("mt_ipv6_reachability_prefixes_subtlvs_ipv6_source_router_id", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsIpv6SourceRouterId)), ("mt-ipv6-reachability-prefixes-subtlvs-tag", ("mt_ipv6_reachability_prefixes_subtlvs_tag", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsTag)), ("mt-ipv6-reachability-prefixes-subtlvs-state", ("mt_ipv6_reachability_prefixes_subtlvs_state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsState))])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.str, 'type'), ['str'])),
                                                                        ])
                                                                        self.type = None

                                                                        self.mt_ipv6_reachability_prefixes_subtlvs_prefix_sids = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsPrefixSids()
                                                                        self.mt_ipv6_reachability_prefixes_subtlvs_prefix_sids.parent = self
                                                                        self._children_name_map["mt_ipv6_reachability_prefixes_subtlvs_prefix_sids"] = "mt-ipv6-reachability-prefixes-subtlvs-prefix-sids"

                                                                        self.mt_ipv6_reachability_prefixes_subtlvs_flags = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsFlags()
                                                                        self.mt_ipv6_reachability_prefixes_subtlvs_flags.parent = self
                                                                        self._children_name_map["mt_ipv6_reachability_prefixes_subtlvs_flags"] = "mt-ipv6-reachability-prefixes-subtlvs-flags"

                                                                        self.mt_ipv6_reachability_prefixes_subtlvs_ipv4_source_router_id = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsIpv4SourceRouterId()
                                                                        self.mt_ipv6_reachability_prefixes_subtlvs_ipv4_source_router_id.parent = self
                                                                        self._children_name_map["mt_ipv6_reachability_prefixes_subtlvs_ipv4_source_router_id"] = "mt-ipv6-reachability-prefixes-subtlvs-ipv4-source-router-id"

                                                                        self.mt_ipv6_reachability_prefixes_subtlvs_tag64 = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsTag64()
                                                                        self.mt_ipv6_reachability_prefixes_subtlvs_tag64.parent = self
                                                                        self._children_name_map["mt_ipv6_reachability_prefixes_subtlvs_tag64"] = "mt-ipv6-reachability-prefixes-subtlvs-tag64"

                                                                        self.mt_ipv6_reachability_prefixes_subtlvs_ipv6_source_router_id = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsIpv6SourceRouterId()
                                                                        self.mt_ipv6_reachability_prefixes_subtlvs_ipv6_source_router_id.parent = self
                                                                        self._children_name_map["mt_ipv6_reachability_prefixes_subtlvs_ipv6_source_router_id"] = "mt-ipv6-reachability-prefixes-subtlvs-ipv6-source-router-id"

                                                                        self.mt_ipv6_reachability_prefixes_subtlvs_tag = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsTag()
                                                                        self.mt_ipv6_reachability_prefixes_subtlvs_tag.parent = self
                                                                        self._children_name_map["mt_ipv6_reachability_prefixes_subtlvs_tag"] = "mt-ipv6-reachability-prefixes-subtlvs-tag"

                                                                        self.mt_ipv6_reachability_prefixes_subtlvs_state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsState()
                                                                        self.mt_ipv6_reachability_prefixes_subtlvs_state.parent = self
                                                                        self._children_name_map["mt_ipv6_reachability_prefixes_subtlvs_state"] = "mt-ipv6-reachability-prefixes-subtlvs-state"
                                                                        self._segment_path = lambda: "mt-ipv6-reachability-prefixes-subtlv" + "[type='" + str(self.type) + "']"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv, ['type'], name, value)


                                                                    class MtIpv6ReachabilityPrefixesSubtlvsPrefixSids(Entity):
                                                                        """
                                                                        Prefix Segment\-ID list
                                                                        
                                                                        .. attribute:: mt_ipv6_reachability_prefixes_subtlvs_prefix_sid
                                                                        
                                                                        	Prefix Segment\-ID list
                                                                        	**type**\: list of  		 :py:class:`MtIpv6ReachabilityPrefixesSubtlvsPrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsPrefixSids.MtIpv6ReachabilityPrefixesSubtlvsPrefixSid>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsPrefixSids, self).__init__()

                                                                            self.yang_name = "mt-ipv6-reachability-prefixes-subtlvs-prefix-sids"
                                                                            self.yang_parent_name = "mt-ipv6-reachability-prefixes-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("mt-ipv6-reachability-prefixes-subtlvs-prefix-sid", ("mt_ipv6_reachability_prefixes_subtlvs_prefix_sid", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsPrefixSids.MtIpv6ReachabilityPrefixesSubtlvsPrefixSid))])
                                                                            self._leafs = OrderedDict()

                                                                            self.mt_ipv6_reachability_prefixes_subtlvs_prefix_sid = YList(self)
                                                                            self._segment_path = lambda: "mt-ipv6-reachability-prefixes-subtlvs-prefix-sids"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsPrefixSids, [], name, value)


                                                                        class MtIpv6ReachabilityPrefixesSubtlvsPrefixSid(Entity):
                                                                            """
                                                                            Prefix Segment\-ID list
                                                                            
                                                                            .. attribute:: value  (key)
                                                                            
                                                                            	Reference to the value of the prefix SID
                                                                            	**type**\: int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                            	State parameters for Prefix\-SID
                                                                            	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsPrefixSids.MtIpv6ReachabilityPrefixesSubtlvsPrefixSid.State>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsPrefixSids.MtIpv6ReachabilityPrefixesSubtlvsPrefixSid, self).__init__()

                                                                                self.yang_name = "mt-ipv6-reachability-prefixes-subtlvs-prefix-sid"
                                                                                self.yang_parent_name = "mt-ipv6-reachability-prefixes-subtlvs-prefix-sids"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = ['value']
                                                                                self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsPrefixSids.MtIpv6ReachabilityPrefixesSubtlvsPrefixSid.State))])
                                                                                self._leafs = OrderedDict([
                                                                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                                                                ])
                                                                                self.value = None

                                                                                self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsPrefixSids.MtIpv6ReachabilityPrefixesSubtlvsPrefixSid.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "mt-ipv6-reachability-prefixes-subtlvs-prefix-sid" + "[value='" + str(self.value) + "']"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsPrefixSids.MtIpv6ReachabilityPrefixesSubtlvsPrefixSid, ['value'], name, value)


                                                                            class State(Entity):
                                                                                """
                                                                                State parameters for Prefix\-SID
                                                                                
                                                                                .. attribute:: value
                                                                                
                                                                                	IGP Prefix\-SID value
                                                                                	**type**\: int
                                                                                
                                                                                	**range:** 0..4294967295
                                                                                
                                                                                .. attribute:: algorithm
                                                                                
                                                                                	Prefix\-SID algorithm to be used for path computation
                                                                                	**type**\: int
                                                                                
                                                                                	**range:** 0..255
                                                                                
                                                                                .. attribute:: flags
                                                                                
                                                                                	Flags associated with Prefix Segment\-ID
                                                                                	**type**\: list of   :py:class:`OpenconfigIsisLspPrefixSidStateFlagsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisLspPrefixSidStateFlagsEnum>`
                                                                                
                                                                                

                                                                                """

                                                                                _prefix = 'clns-isis-oper'
                                                                                _revision = '2018-04-07'

                                                                                def __init__(self):
                                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsPrefixSids.MtIpv6ReachabilityPrefixesSubtlvsPrefixSid.State, self).__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "mt-ipv6-reachability-prefixes-subtlvs-prefix-sid"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                                                                        ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                                                                        ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisLspPrefixSidStateFlagsEnum', '')])),
                                                                                    ])
                                                                                    self.value = None
                                                                                    self.algorithm = None
                                                                                    self.flags = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsPrefixSids.MtIpv6ReachabilityPrefixesSubtlvsPrefixSid.State, [u'value', u'algorithm', u'flags'], name, value)


                                                                    class MtIpv6ReachabilityPrefixesSubtlvsFlags(Entity):
                                                                        """
                                                                        This container defines sub\-TLV 4
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 4
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsFlags.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsFlags, self).__init__()

                                                                            self.yang_name = "mt-ipv6-reachability-prefixes-subtlvs-flags"
                                                                            self.yang_parent_name = "mt-ipv6-reachability-prefixes-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsFlags.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsFlags.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "mt-ipv6-reachability-prefixes-subtlvs-flags"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsFlags, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 4
                                                                            
                                                                            .. attribute:: type
                                                                            
                                                                            	The type of subTLV being described
                                                                            	**type**\: str
                                                                            
                                                                            .. attribute:: flags
                                                                            
                                                                            	Additional prefix reachability flags
                                                                            	**type**\: list of   :py:class:`OpenconfigIsisLspFlagsStateFlagsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OpenconfigIsisLspFlagsStateFlagsEnum>`
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsFlags.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "mt-ipv6-reachability-prefixes-subtlvs-flags"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('type', (YLeaf(YType.str, 'type'), ['str'])),
                                                                                    ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'OpenconfigIsisLspFlagsStateFlagsEnum', '')])),
                                                                                ])
                                                                                self.type = None
                                                                                self.flags = []
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsFlags.State, [u'type', u'flags'], name, value)


                                                                    class MtIpv6ReachabilityPrefixesSubtlvsIpv4SourceRouterId(Entity):
                                                                        """
                                                                        This container defines sub\-TLV
                                                                        11
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 11
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsIpv4SourceRouterId.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsIpv4SourceRouterId, self).__init__()

                                                                            self.yang_name = "mt-ipv6-reachability-prefixes-subtlvs-ipv4-source-router-id"
                                                                            self.yang_parent_name = "mt-ipv6-reachability-prefixes-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsIpv4SourceRouterId.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsIpv4SourceRouterId.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "mt-ipv6-reachability-prefixes-subtlvs-ipv4-source-router-id"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsIpv4SourceRouterId, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 11
                                                                            
                                                                            .. attribute:: type
                                                                            
                                                                            	The type of subTLV being described
                                                                            	**type**\: str
                                                                            
                                                                            .. attribute:: ipv4_source_router_id
                                                                            
                                                                            	IPv4 Source router ID address
                                                                            	**type**\: str
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsIpv4SourceRouterId.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "mt-ipv6-reachability-prefixes-subtlvs-ipv4-source-router-id"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('type', (YLeaf(YType.str, 'type'), ['str'])),
                                                                                    ('ipv4_source_router_id', (YLeaf(YType.str, 'ipv4-source-router-id'), ['str'])),
                                                                                ])
                                                                                self.type = None
                                                                                self.ipv4_source_router_id = None
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsIpv4SourceRouterId.State, [u'type', u'ipv4_source_router_id'], name, value)


                                                                    class MtIpv6ReachabilityPrefixesSubtlvsTag64(Entity):
                                                                        """
                                                                        This container defines sub\-TLV 2
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 2
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsTag64.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsTag64, self).__init__()

                                                                            self.yang_name = "mt-ipv6-reachability-prefixes-subtlvs-tag64"
                                                                            self.yang_parent_name = "mt-ipv6-reachability-prefixes-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsTag64.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsTag64.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "mt-ipv6-reachability-prefixes-subtlvs-tag64"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsTag64, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 2
                                                                            
                                                                            .. attribute:: tag64
                                                                            
                                                                            	List of 64\-bit tags associated with the prefix
                                                                            	**type**\: list of int
                                                                            
                                                                            	**range:** 0..18446744073709551615
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsTag64.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "mt-ipv6-reachability-prefixes-subtlvs-tag64"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('tag64', (YLeafList(YType.uint64, 'tag64'), ['int'])),
                                                                                ])
                                                                                self.tag64 = []
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsTag64.State, [u'tag64'], name, value)


                                                                    class MtIpv6ReachabilityPrefixesSubtlvsIpv6SourceRouterId(Entity):
                                                                        """
                                                                        This container defines sub\-TLV
                                                                        12
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 12
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsIpv6SourceRouterId.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsIpv6SourceRouterId, self).__init__()

                                                                            self.yang_name = "mt-ipv6-reachability-prefixes-subtlvs-ipv6-source-router-id"
                                                                            self.yang_parent_name = "mt-ipv6-reachability-prefixes-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsIpv6SourceRouterId.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsIpv6SourceRouterId.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "mt-ipv6-reachability-prefixes-subtlvs-ipv6-source-router-id"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsIpv6SourceRouterId, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 12
                                                                            
                                                                            .. attribute:: type
                                                                            
                                                                            	The type of subTLV being described
                                                                            	**type**\: str
                                                                            
                                                                            .. attribute:: ipv6_source_router_id
                                                                            
                                                                            	IPv6 Source router ID address
                                                                            	**type**\: str
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsIpv6SourceRouterId.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "mt-ipv6-reachability-prefixes-subtlvs-ipv6-source-router-id"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('type', (YLeaf(YType.str, 'type'), ['str'])),
                                                                                    ('ipv6_source_router_id', (YLeaf(YType.str, 'ipv6-source-router-id'), ['str'])),
                                                                                ])
                                                                                self.type = None
                                                                                self.ipv6_source_router_id = None
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsIpv6SourceRouterId.State, [u'type', u'ipv6_source_router_id'], name, value)


                                                                    class MtIpv6ReachabilityPrefixesSubtlvsTag(Entity):
                                                                        """
                                                                        This container defines sub\-TLV 1
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                        	State parameters of sub\-TLV 1
                                                                        	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsTag.State>`
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsTag, self).__init__()

                                                                            self.yang_name = "mt-ipv6-reachability-prefixes-subtlvs-tag"
                                                                            self.yang_parent_name = "mt-ipv6-reachability-prefixes-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsTag.State))])
                                                                            self._leafs = OrderedDict()

                                                                            self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsTag.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "mt-ipv6-reachability-prefixes-subtlvs-tag"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsTag, [], name, value)


                                                                        class State(Entity):
                                                                            """
                                                                            State parameters of sub\-TLV 1
                                                                            
                                                                            .. attribute:: tag32
                                                                            
                                                                            	List of 32\-bit tags associated with the prefix
                                                                            	**type**\: list of int
                                                                            
                                                                            	**range:** 0..4294967295
                                                                            
                                                                            

                                                                            """

                                                                            _prefix = 'clns-isis-oper'
                                                                            _revision = '2018-04-07'

                                                                            def __init__(self):
                                                                                super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsTag.State, self).__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "mt-ipv6-reachability-prefixes-subtlvs-tag"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('tag32', (YLeafList(YType.uint32, 'tag32'), ['int'])),
                                                                                ])
                                                                                self.tag32 = []
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsTag.State, [u'tag32'], name, value)


                                                                    class MtIpv6ReachabilityPrefixesSubtlvsState(Entity):
                                                                        """
                                                                        State parameters for a prefix
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	The type of subTLV being described
                                                                        	**type**\: str
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsState, self).__init__()

                                                                            self.yang_name = "mt-ipv6-reachability-prefixes-subtlvs-state"
                                                                            self.yang_parent_name = "mt-ipv6-reachability-prefixes-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', (YLeaf(YType.str, 'type'), ['str'])),
                                                                            ])
                                                                            self.type = None
                                                                            self._segment_path = lambda: "mt-ipv6-reachability-prefixes-subtlvs-state"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesSubtlvs.MtIpv6ReachabilityPrefixesSubtlv.MtIpv6ReachabilityPrefixesSubtlvsState, [u'type'], name, value)


                                                            class MtIpv6ReachabilityPrefixesUndefinedSubtlvs(Entity):
                                                                """
                                                                Sub\-TLVs that are not defined in
                                                                the model or not recognised by
                                                                system
                                                                
                                                                .. attribute:: mt_ipv6_reachability_prefixes_undefined_subtlv
                                                                
                                                                	Sub\-TLVs that are not defined in the model or not recognised by system
                                                                	**type**\: list of  		 :py:class:`MtIpv6ReachabilityPrefixesUndefinedSubtlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesUndefinedSubtlvs.MtIpv6ReachabilityPrefixesUndefinedSubtlv>`
                                                                
                                                                

                                                                """

                                                                _prefix = 'clns-isis-oper'
                                                                _revision = '2018-04-07'

                                                                def __init__(self):
                                                                    super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesUndefinedSubtlvs, self).__init__()

                                                                    self.yang_name = "mt-ipv6-reachability-prefixes-undefined-subtlvs"
                                                                    self.yang_parent_name = "mt-ipv6-reachability-prefixe"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("mt-ipv6-reachability-prefixes-undefined-subtlv", ("mt_ipv6_reachability_prefixes_undefined_subtlv", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesUndefinedSubtlvs.MtIpv6ReachabilityPrefixesUndefinedSubtlv))])
                                                                    self._leafs = OrderedDict()

                                                                    self.mt_ipv6_reachability_prefixes_undefined_subtlv = YList(self)
                                                                    self._segment_path = lambda: "mt-ipv6-reachability-prefixes-undefined-subtlvs"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesUndefinedSubtlvs, [], name, value)


                                                                class MtIpv6ReachabilityPrefixesUndefinedSubtlv(Entity):
                                                                    """
                                                                    Sub\-TLVs that are not defined in
                                                                    the model or not recognised by
                                                                    system
                                                                    
                                                                    .. attribute:: type  (key)
                                                                    
                                                                    	Reference to the type of the undefined sub\-TLV
                                                                    	**type**\: int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                    	State parameters of the undefined sub\-TLV
                                                                    	**type**\:  :py:class:`State <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesUndefinedSubtlvs.MtIpv6ReachabilityPrefixesUndefinedSubtlv.State>`
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'clns-isis-oper'
                                                                    _revision = '2018-04-07'

                                                                    def __init__(self):
                                                                        super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesUndefinedSubtlvs.MtIpv6ReachabilityPrefixesUndefinedSubtlv, self).__init__()

                                                                        self.yang_name = "mt-ipv6-reachability-prefixes-undefined-subtlv"
                                                                        self.yang_parent_name = "mt-ipv6-reachability-prefixes-undefined-subtlvs"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = ['type']
                                                                        self._child_classes = OrderedDict([("state", ("state", OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesUndefinedSubtlvs.MtIpv6ReachabilityPrefixesUndefinedSubtlv.State))])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.uint32, 'type'), ['int'])),
                                                                        ])
                                                                        self.type = None

                                                                        self.state = OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesUndefinedSubtlvs.MtIpv6ReachabilityPrefixesUndefinedSubtlv.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._segment_path = lambda: "mt-ipv6-reachability-prefixes-undefined-subtlv" + "[type='" + str(self.type) + "']"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesUndefinedSubtlvs.MtIpv6ReachabilityPrefixesUndefinedSubtlv, ['type'], name, value)


                                                                    class State(Entity):
                                                                        """
                                                                        State parameters of the undefined sub\-TLV
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                        	TLV Type
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: length
                                                                        
                                                                        	TLV length
                                                                        	**type**\: int
                                                                        
                                                                        	**range:** 0..255
                                                                        
                                                                        .. attribute:: value
                                                                        
                                                                        	TLV value
                                                                        	**type**\: str
                                                                        
                                                                        

                                                                        """

                                                                        _prefix = 'clns-isis-oper'
                                                                        _revision = '2018-04-07'

                                                                        def __init__(self):
                                                                            super(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesUndefinedSubtlvs.MtIpv6ReachabilityPrefixesUndefinedSubtlv.State, self).__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "mt-ipv6-reachability-prefixes-undefined-subtlv"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                                                ('length', (YLeaf(YType.uint8, 'length'), ['int'])),
                                                                                ('value', (YLeaf(YType.str, 'value'), ['str'])),
                                                                            ])
                                                                            self.type = None
                                                                            self.length = None
                                                                            self.value = None
                                                                            self._segment_path = lambda: "state"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabases.LinkStateDatabase.Tlvses.Tlvs.MtIpv6Reachability.MtIpv6ReachabilityPrefixes.MtIpv6ReachabilityPrefixe.MtIpv6ReachabilityPrefixesUndefinedSubtlvs.MtIpv6ReachabilityPrefixesUndefinedSubtlv.State, [u'type', u'length', u'value'], name, value)


            class State(Entity):
                """
                Operational state parameters relating to a
                network instance
                
                .. attribute:: name
                
                	An operator\-assigned unique name for the forwarding instance
                	**type**\: str
                
                .. attribute:: type
                
                	The type of network instance
                	**type**\: str
                
                .. attribute:: enabled
                
                	Whether the network instance should be configured to be active on the network element
                	**type**\: bool
                
                .. attribute:: description
                
                	A free\-form string to be used by the network operator to describe the function of this network instance
                	**type**\: str
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2018-04-07'

                def __init__(self):
                    super(OcniIsis.NetworkInstances.NetworkInstance.State, self).__init__()

                    self.yang_name = "state"
                    self.yang_parent_name = "network-instance"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('type', (YLeaf(YType.str, 'type'), ['str'])),
                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ])
                    self.name = None
                    self.type = None
                    self.enabled = None
                    self.description = None
                    self._segment_path = lambda: "state"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(OcniIsis.NetworkInstances.NetworkInstance.State, [u'name', u'type', u'enabled', u'description'], name, value)

    def clone_ptr(self):
        self._top_entity = OcniIsis()
        return self._top_entity

class Isis(Entity):
    """
    isis
    
    .. attribute:: instances
    
    	Per\-instance operational data
    	**type**\:  :py:class:`Instances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances>`
    
    

    """

    _prefix = 'clns-isis-oper'
    _revision = '2018-04-07'

    def __init__(self):
        super(Isis, self).__init__()
        self._top_entity = None

        self.yang_name = "isis"
        self.yang_parent_name = "Cisco-IOS-XR-clns-isis-oper"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self.ylist_key_names = []
        self._child_classes = OrderedDict([("instances", ("instances", Isis.Instances))])
        self._leafs = OrderedDict()

        self.instances = Isis.Instances()
        self.instances.parent = self
        self._children_name_map["instances"] = "instances"
        self._segment_path = lambda: "Cisco-IOS-XR-clns-isis-oper:isis"
        self._is_frozen = True

    def __setattr__(self, name, value):
        self._perform_setattr(Isis, [], name, value)


    class Instances(Entity):
        """
        Per\-instance operational data
        
        .. attribute:: instance
        
        	IS\-IS instance
        	**type**\: list of  		 :py:class:`Instance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance>`
        
        

        """

        _prefix = 'clns-isis-oper'
        _revision = '2018-04-07'

        def __init__(self):
            super(Isis.Instances, self).__init__()

            self.yang_name = "instances"
            self.yang_parent_name = "isis"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("instance", ("instance", Isis.Instances.Instance))])
            self._leafs = OrderedDict()

            self.instance = YList(self)
            self._segment_path = lambda: "instances"
            self._absolute_path = lambda: "Cisco-IOS-XR-clns-isis-oper:isis/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Isis.Instances, [], name, value)


        class Instance(Entity):
            """
            IS\-IS instance
            
            .. attribute:: instance_name  (key)
            
            	Instance identifier
            	**type**\: str
            
            	**length:** 1..36
            
            .. attribute:: neighbors
            
            	Neighbor table
            	**type**\:  :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors>`
            
            .. attribute:: host_names
            
            	Hostname table
            	**type**\:  :py:class:`HostNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.HostNames>`
            
            .. attribute:: statistics_global
            
            	Per\-instance statistics
            	**type**\:  :py:class:`StatisticsGlobal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.StatisticsGlobal>`
            
            .. attribute:: levels
            
            	Level table
            	**type**\:  :py:class:`Levels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels>`
            
            .. attribute:: topologies
            
            	Topology table
            	**type**\:  :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies>`
            
            .. attribute:: nsr_status
            
            	NSR Status information
            	**type**\:  :py:class:`NsrStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus>`
            
            .. attribute:: interfaces
            
            	Interface table
            	**type**\:  :py:class:`Interfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces>`
            
            .. attribute:: checkpoint_adjacencies
            
            	Checkpointed adjacency table
            	**type**\:  :py:class:`CheckpointAdjacencies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.CheckpointAdjacencies>`
            
            .. attribute:: flex_algos
            
            	Flex\-Algo Table
            	**type**\:  :py:class:`FlexAlgos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.FlexAlgos>`
            
            .. attribute:: srms
            
            	Segment Routing Mapping Server operational data
            	**type**\:  :py:class:`Srms <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Srms>`
            
            .. attribute:: error_log
            
            	Log of errors and warnings
            	**type**\:  :py:class:`ErrorLog <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.ErrorLog>`
            
            .. attribute:: checkpoint_interfaces
            
            	Checkpointed interface table
            	**type**\:  :py:class:`CheckpointInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.CheckpointInterfaces>`
            
            .. attribute:: interface_statistics
            
            	Interface statistics table
            	**type**\:  :py:class:`InterfaceStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.InterfaceStatistics>`
            
            .. attribute:: protocol
            
            	Basic protocol information about an IS\-IS instance
            	**type**\:  :py:class:`Protocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Protocol>`
            
            .. attribute:: neighbor_summaries
            
            	Neighbor\-summary table
            	**type**\:  :py:class:`NeighborSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NeighborSummaries>`
            
            .. attribute:: checkpoint_lsps
            
            	Checkpointed LSP table
            	**type**\:  :py:class:`CheckpointLsps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.CheckpointLsps>`
            
            .. attribute:: mesh_groups
            
            	Mesh\-group information
            	**type**\:  :py:class:`MeshGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.MeshGroups>`
            
            .. attribute:: nsr_statistics
            
            	NSR Statistics information
            	**type**\:  :py:class:`NsrStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatistics>`
            
            .. attribute:: checkpoint_te_tunnels
            
            	Checkpointed TE tunnel table
            	**type**\:  :py:class:`CheckpointTeTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.CheckpointTeTunnels>`
            
            

            """

            _prefix = 'clns-isis-oper'
            _revision = '2018-04-07'

            def __init__(self):
                super(Isis.Instances.Instance, self).__init__()

                self.yang_name = "instance"
                self.yang_parent_name = "instances"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['instance_name']
                self._child_classes = OrderedDict([("neighbors", ("neighbors", Isis.Instances.Instance.Neighbors)), ("host-names", ("host_names", Isis.Instances.Instance.HostNames)), ("statistics-global", ("statistics_global", Isis.Instances.Instance.StatisticsGlobal)), ("levels", ("levels", Isis.Instances.Instance.Levels)), ("topologies", ("topologies", Isis.Instances.Instance.Topologies)), ("nsr-status", ("nsr_status", Isis.Instances.Instance.NsrStatus)), ("interfaces", ("interfaces", Isis.Instances.Instance.Interfaces)), ("checkpoint-adjacencies", ("checkpoint_adjacencies", Isis.Instances.Instance.CheckpointAdjacencies)), ("flex-algos", ("flex_algos", Isis.Instances.Instance.FlexAlgos)), ("srms", ("srms", Isis.Instances.Instance.Srms)), ("error-log", ("error_log", Isis.Instances.Instance.ErrorLog)), ("checkpoint-interfaces", ("checkpoint_interfaces", Isis.Instances.Instance.CheckpointInterfaces)), ("interface-statistics", ("interface_statistics", Isis.Instances.Instance.InterfaceStatistics)), ("protocol", ("protocol", Isis.Instances.Instance.Protocol)), ("neighbor-summaries", ("neighbor_summaries", Isis.Instances.Instance.NeighborSummaries)), ("checkpoint-lsps", ("checkpoint_lsps", Isis.Instances.Instance.CheckpointLsps)), ("mesh-groups", ("mesh_groups", Isis.Instances.Instance.MeshGroups)), ("nsr-statistics", ("nsr_statistics", Isis.Instances.Instance.NsrStatistics)), ("checkpoint-te-tunnels", ("checkpoint_te_tunnels", Isis.Instances.Instance.CheckpointTeTunnels))])
                self._leafs = OrderedDict([
                    ('instance_name', (YLeaf(YType.str, 'instance-name'), ['str'])),
                ])
                self.instance_name = None

                self.neighbors = Isis.Instances.Instance.Neighbors()
                self.neighbors.parent = self
                self._children_name_map["neighbors"] = "neighbors"

                self.host_names = Isis.Instances.Instance.HostNames()
                self.host_names.parent = self
                self._children_name_map["host_names"] = "host-names"

                self.statistics_global = Isis.Instances.Instance.StatisticsGlobal()
                self.statistics_global.parent = self
                self._children_name_map["statistics_global"] = "statistics-global"

                self.levels = Isis.Instances.Instance.Levels()
                self.levels.parent = self
                self._children_name_map["levels"] = "levels"

                self.topologies = Isis.Instances.Instance.Topologies()
                self.topologies.parent = self
                self._children_name_map["topologies"] = "topologies"

                self.nsr_status = Isis.Instances.Instance.NsrStatus()
                self.nsr_status.parent = self
                self._children_name_map["nsr_status"] = "nsr-status"

                self.interfaces = Isis.Instances.Instance.Interfaces()
                self.interfaces.parent = self
                self._children_name_map["interfaces"] = "interfaces"

                self.checkpoint_adjacencies = Isis.Instances.Instance.CheckpointAdjacencies()
                self.checkpoint_adjacencies.parent = self
                self._children_name_map["checkpoint_adjacencies"] = "checkpoint-adjacencies"

                self.flex_algos = Isis.Instances.Instance.FlexAlgos()
                self.flex_algos.parent = self
                self._children_name_map["flex_algos"] = "flex-algos"

                self.srms = Isis.Instances.Instance.Srms()
                self.srms.parent = self
                self._children_name_map["srms"] = "srms"

                self.error_log = Isis.Instances.Instance.ErrorLog()
                self.error_log.parent = self
                self._children_name_map["error_log"] = "error-log"

                self.checkpoint_interfaces = Isis.Instances.Instance.CheckpointInterfaces()
                self.checkpoint_interfaces.parent = self
                self._children_name_map["checkpoint_interfaces"] = "checkpoint-interfaces"

                self.interface_statistics = Isis.Instances.Instance.InterfaceStatistics()
                self.interface_statistics.parent = self
                self._children_name_map["interface_statistics"] = "interface-statistics"

                self.protocol = Isis.Instances.Instance.Protocol()
                self.protocol.parent = self
                self._children_name_map["protocol"] = "protocol"

                self.neighbor_summaries = Isis.Instances.Instance.NeighborSummaries()
                self.neighbor_summaries.parent = self
                self._children_name_map["neighbor_summaries"] = "neighbor-summaries"

                self.checkpoint_lsps = Isis.Instances.Instance.CheckpointLsps()
                self.checkpoint_lsps.parent = self
                self._children_name_map["checkpoint_lsps"] = "checkpoint-lsps"

                self.mesh_groups = Isis.Instances.Instance.MeshGroups()
                self.mesh_groups.parent = self
                self._children_name_map["mesh_groups"] = "mesh-groups"

                self.nsr_statistics = Isis.Instances.Instance.NsrStatistics()
                self.nsr_statistics.parent = self
                self._children_name_map["nsr_statistics"] = "nsr-statistics"

                self.checkpoint_te_tunnels = Isis.Instances.Instance.CheckpointTeTunnels()
                self.checkpoint_te_tunnels.parent = self
                self._children_name_map["checkpoint_te_tunnels"] = "checkpoint-te-tunnels"
                self._segment_path = lambda: "instance" + "[instance-name='" + str(self.instance_name) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-clns-isis-oper:isis/instances/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Isis.Instances.Instance, ['instance_name'], name, value)


            class Neighbors(Entity):
                """
                Neighbor table
                
                .. attribute:: neighbor
                
                	A single neighbor router
                	**type**\: list of  		 :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor>`
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2018-04-07'

                def __init__(self):
                    super(Isis.Instances.Instance.Neighbors, self).__init__()

                    self.yang_name = "neighbors"
                    self.yang_parent_name = "instance"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("neighbor", ("neighbor", Isis.Instances.Instance.Neighbors.Neighbor))])
                    self._leafs = OrderedDict()

                    self.neighbor = YList(self)
                    self._segment_path = lambda: "neighbors"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Isis.Instances.Instance.Neighbors, [], name, value)


                class Neighbor(Entity):
                    """
                    A single neighbor router
                    
                    .. attribute:: system_id
                    
                    	System ID
                    	**type**\: str
                    
                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: neighbor_system_id
                    
                    	Neighbor system ID
                    	**type**\: str
                    
                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                    
                    .. attribute:: neighbor_snpa
                    
                    	Neighbor SNPA
                    	**type**\: str
                    
                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                    
                    .. attribute:: local_interface
                    
                    	Local interface
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: neighbor_state
                    
                    	Neighbor (adjacency) state
                    	**type**\:  :py:class:`IsisAdjState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAdjState>`
                    
                    .. attribute:: neighbor_circuit_type
                    
                    	Circuit type
                    	**type**\:  :py:class:`IsisLevels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevels>`
                    
                    .. attribute:: neighbor_ietf_nsf_capable_flag
                    
                    	TRUE if neighbor is IETF\-NSF capable
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: neighbor_media_type
                    
                    	Link media type
                    	**type**\:  :py:class:`IsisMediaClass <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisMediaClass>`
                    
                    .. attribute:: neighbor_holdtime
                    
                    	Time (s) until neighbor declared down if no IIH received
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: neighbor_uptime_valid_flag
                    
                    	TRUE if NeighborUptime is set
                    	**type**\: bool
                    
                    .. attribute:: neighbor_uptime
                    
                    	How long the neighbor has been up (s)
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nsr_standby
                    
                    	ISIS NSR STANDBY
                    	**type**\: bool
                    
                    .. attribute:: neighbor_active_area_address
                    
                    	Active area addresses
                    	**type**\: list of  		 :py:class:`NeighborActiveAreaAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborActiveAreaAddress>`
                    
                    .. attribute:: topologies_supported
                    
                    	Topologies supported by both neighbor and local system
                    	**type**\: list of  		 :py:class:`TopologiesSupported <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.TopologiesSupported>`
                    
                    .. attribute:: neighbor_per_address_family_data
                    
                    	Per address\-family data
                    	**type**\: list of  		 :py:class:`NeighborPerAddressFamilyData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData>`
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2018-04-07'

                    def __init__(self):
                        super(Isis.Instances.Instance.Neighbors.Neighbor, self).__init__()

                        self.yang_name = "neighbor"
                        self.yang_parent_name = "neighbors"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("neighbor-active-area-address", ("neighbor_active_area_address", Isis.Instances.Instance.Neighbors.Neighbor.NeighborActiveAreaAddress)), ("topologies-supported", ("topologies_supported", Isis.Instances.Instance.Neighbors.Neighbor.TopologiesSupported)), ("neighbor-per-address-family-data", ("neighbor_per_address_family_data", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData))])
                        self._leafs = OrderedDict([
                            ('system_id', (YLeaf(YType.str, 'system-id'), ['str'])),
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('neighbor_system_id', (YLeaf(YType.str, 'neighbor-system-id'), ['str'])),
                            ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                            ('local_interface', (YLeaf(YType.str, 'local-interface'), ['str'])),
                            ('neighbor_state', (YLeaf(YType.enumeration, 'neighbor-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisAdjState', '')])),
                            ('neighbor_circuit_type', (YLeaf(YType.enumeration, 'neighbor-circuit-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisLevels', '')])),
                            ('neighbor_ietf_nsf_capable_flag', (YLeaf(YType.uint32, 'neighbor-ietf-nsf-capable-flag'), ['int'])),
                            ('neighbor_media_type', (YLeaf(YType.enumeration, 'neighbor-media-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisMediaClass', '')])),
                            ('neighbor_holdtime', (YLeaf(YType.uint32, 'neighbor-holdtime'), ['int'])),
                            ('neighbor_uptime_valid_flag', (YLeaf(YType.boolean, 'neighbor-uptime-valid-flag'), ['bool'])),
                            ('neighbor_uptime', (YLeaf(YType.uint32, 'neighbor-uptime'), ['int'])),
                            ('nsr_standby', (YLeaf(YType.boolean, 'nsr-standby'), ['bool'])),
                        ])
                        self.system_id = None
                        self.interface_name = None
                        self.neighbor_system_id = None
                        self.neighbor_snpa = None
                        self.local_interface = None
                        self.neighbor_state = None
                        self.neighbor_circuit_type = None
                        self.neighbor_ietf_nsf_capable_flag = None
                        self.neighbor_media_type = None
                        self.neighbor_holdtime = None
                        self.neighbor_uptime_valid_flag = None
                        self.neighbor_uptime = None
                        self.nsr_standby = None

                        self.neighbor_active_area_address = YList(self)
                        self.topologies_supported = YList(self)
                        self.neighbor_per_address_family_data = YList(self)
                        self._segment_path = lambda: "neighbor"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor, ['system_id', 'interface_name', u'neighbor_system_id', u'neighbor_snpa', u'local_interface', u'neighbor_state', u'neighbor_circuit_type', u'neighbor_ietf_nsf_capable_flag', u'neighbor_media_type', u'neighbor_holdtime', u'neighbor_uptime_valid_flag', u'neighbor_uptime', u'nsr_standby'], name, value)


                    class NeighborActiveAreaAddress(Entity):
                        """
                        Active area addresses
                        
                        .. attribute:: entry
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [a\-fA\-F0\-9]{2}(\\.[a\-fA\-F0\-9]{4}){0,6}
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborActiveAreaAddress, self).__init__()

                            self.yang_name = "neighbor-active-area-address"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                            ])
                            self.entry = None
                            self._segment_path = lambda: "neighbor-active-area-address"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborActiveAreaAddress, [u'entry'], name, value)


                    class TopologiesSupported(Entity):
                        """
                        Topologies supported by both neighbor and local
                        system
                        
                        .. attribute:: af_name
                        
                        	AF name
                        	**type**\:  :py:class:`IsisAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAfId>`
                        
                        .. attribute:: saf_name
                        
                        	Sub\-AF name
                        	**type**\:  :py:class:`IsisSubAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisSubAfId>`
                        
                        .. attribute:: vrf_name
                        
                        	VRF Name
                        	**type**\: str
                        
                        .. attribute:: topology_name
                        
                        	Topology Name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.Neighbors.Neighbor.TopologiesSupported, self).__init__()

                            self.yang_name = "topologies-supported"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisAfId', '')])),
                                ('saf_name', (YLeaf(YType.enumeration, 'saf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisSubAfId', '')])),
                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                ('topology_name', (YLeaf(YType.str, 'topology-name'), ['str'])),
                            ])
                            self.af_name = None
                            self.saf_name = None
                            self.vrf_name = None
                            self.topology_name = None
                            self._segment_path = lambda: "topologies-supported"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.TopologiesSupported, [u'af_name', u'saf_name', u'vrf_name', u'topology_name'], name, value)


                    class NeighborPerAddressFamilyData(Entity):
                        """
                        Per address\-family data
                        
                        .. attribute:: ipv4
                        
                        	IPV4 neighbor info
                        	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4>`
                        
                        .. attribute:: ipv6
                        
                        	IPV6 neighbor info
                        	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6>`
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`IsisAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAfId>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData, self).__init__()

                            self.yang_name = "neighbor-per-address-family-data"
                            self.yang_parent_name = "neighbor"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4", ("ipv4", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4)), ("ipv6", ("ipv6", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6))])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisAfId', '')])),
                            ])
                            self.af_name = None

                            self.ipv4 = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4()
                            self.ipv4.parent = self
                            self._children_name_map["ipv4"] = "ipv4"

                            self.ipv6 = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6()
                            self.ipv6.parent = self
                            self._children_name_map["ipv6"] = "ipv6"
                            self._segment_path = lambda: "neighbor-per-address-family-data"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData, [u'af_name'], name, value)


                        class Ipv4(Entity):
                            """
                            IPV4 neighbor info
                            
                            .. attribute:: adjacency_sid
                            
                            	Adjacency SID
                            	**type**\:  :py:class:`AdjacencySid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid>`
                            
                            .. attribute:: non_frr_adjacency_sid
                            
                            	Adjacency SID not eligible for FRR protection
                            	**type**\:  :py:class:`NonFrrAdjacencySid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid>`
                            
                            .. attribute:: next_hop
                            
                            	Adjacency next hop
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: interface_address
                            
                            	Adjacency interface addresses
                            	**type**\: list of  		 :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.InterfaceAddress>`
                            
                            .. attribute:: underlying_adjacency_sid
                            
                            	Per bundle member Adjacency sid
                            	**type**\: list of  		 :py:class:`UnderlyingAdjacencySid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.UnderlyingAdjacencySid>`
                            
                            .. attribute:: underlying_interface
                            
                            	Underlying interface list for bundle interfaces
                            	**type**\: list of  		 :py:class:`UnderlyingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.UnderlyingInterface>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4, self).__init__()

                                self.yang_name = "ipv4"
                                self.yang_parent_name = "neighbor-per-address-family-data"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("adjacency-sid", ("adjacency_sid", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid)), ("non-frr-adjacency-sid", ("non_frr_adjacency_sid", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid)), ("interface-address", ("interface_address", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.InterfaceAddress)), ("underlying-adjacency-sid", ("underlying_adjacency_sid", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.UnderlyingAdjacencySid)), ("underlying-interface", ("underlying_interface", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.UnderlyingInterface))])
                                self._leafs = OrderedDict([
                                    ('next_hop', (YLeaf(YType.str, 'next-hop'), ['str'])),
                                ])
                                self.next_hop = None

                                self.adjacency_sid = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid()
                                self.adjacency_sid.parent = self
                                self._children_name_map["adjacency_sid"] = "adjacency-sid"

                                self.non_frr_adjacency_sid = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid()
                                self.non_frr_adjacency_sid.parent = self
                                self._children_name_map["non_frr_adjacency_sid"] = "non-frr-adjacency-sid"

                                self.interface_address = YList(self)
                                self.underlying_adjacency_sid = YList(self)
                                self.underlying_interface = YList(self)
                                self._segment_path = lambda: "ipv4"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4, [u'next_hop'], name, value)


                            class AdjacencySid(Entity):
                                """
                                Adjacency SID
                                
                                .. attribute:: adjacency_sid_backup
                                
                                	Adjacency SID Backup Info
                                	**type**\:  :py:class:`AdjacencySidBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup>`
                                
                                .. attribute:: adjacency_sid_backup_te
                                
                                	Adjacency SID Backup Info TE
                                	**type**\:  :py:class:`AdjacencySidBackupTe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe>`
                                
                                .. attribute:: adjacency_sid_value
                                
                                	Adjacency SID value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid, self).__init__()

                                    self.yang_name = "adjacency-sid"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("adjacency-sid-backup", ("adjacency_sid_backup", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup)), ("adjacency-sid-backup-te", ("adjacency_sid_backup_te", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe))])
                                    self._leafs = OrderedDict([
                                        ('adjacency_sid_value', (YLeaf(YType.uint32, 'adjacency-sid-value'), ['int'])),
                                    ])
                                    self.adjacency_sid_value = None

                                    self.adjacency_sid_backup = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup()
                                    self.adjacency_sid_backup.parent = self
                                    self._children_name_map["adjacency_sid_backup"] = "adjacency-sid-backup"

                                    self.adjacency_sid_backup_te = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe()
                                    self.adjacency_sid_backup_te.parent = self
                                    self._children_name_map["adjacency_sid_backup_te"] = "adjacency-sid-backup-te"
                                    self._segment_path = lambda: "adjacency-sid"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid, [u'adjacency_sid_value'], name, value)


                                class AdjacencySidBackup(Entity):
                                    """
                                    Adjacency SID Backup Info
                                    
                                    .. attribute:: backup_label_stack_size
                                    
                                    	Number of labels in the backup path label stack
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: backup_node_address
                                    
                                    	Neighbor address used as adjacency backup target
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_nexthop
                                    
                                    	Backup path nexthop address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_interface
                                    
                                    	Backup path interface
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: backup_label_stack
                                    
                                    	Backup path label stack
                                    	**type**\: list of  		 :py:class:`BackupLabelStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup.BackupLabelStack>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup, self).__init__()

                                        self.yang_name = "adjacency-sid-backup"
                                        self.yang_parent_name = "adjacency-sid"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("backup-label-stack", ("backup_label_stack", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup.BackupLabelStack))])
                                        self._leafs = OrderedDict([
                                            ('backup_label_stack_size', (YLeaf(YType.uint8, 'backup-label-stack-size'), ['int'])),
                                            ('backup_node_address', (YLeaf(YType.str, 'backup-node-address'), ['str'])),
                                            ('backup_nexthop', (YLeaf(YType.str, 'backup-nexthop'), ['str'])),
                                            ('backup_interface', (YLeaf(YType.str, 'backup-interface'), ['str'])),
                                        ])
                                        self.backup_label_stack_size = None
                                        self.backup_node_address = None
                                        self.backup_nexthop = None
                                        self.backup_interface = None

                                        self.backup_label_stack = YList(self)
                                        self._segment_path = lambda: "adjacency-sid-backup"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup, [u'backup_label_stack_size', u'backup_node_address', u'backup_nexthop', u'backup_interface'], name, value)


                                    class BackupLabelStack(Entity):
                                        """
                                        Backup path label stack
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup.BackupLabelStack, self).__init__()

                                            self.yang_name = "backup-label-stack"
                                            self.yang_parent_name = "adjacency-sid-backup"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "backup-label-stack"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup.BackupLabelStack, [u'entry'], name, value)


                                class AdjacencySidBackupTe(Entity):
                                    """
                                    Adjacency SID Backup Info TE
                                    
                                    .. attribute:: backup_label_stack_size
                                    
                                    	Number of labels in the backup path label stack
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: backup_node_address
                                    
                                    	Neighbor address used as adjacency backup target
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_nexthop
                                    
                                    	Backup path nexthop address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_interface
                                    
                                    	Backup path interface
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: backup_label_stack
                                    
                                    	Backup path label stack
                                    	**type**\: list of  		 :py:class:`BackupLabelStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe.BackupLabelStack>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe, self).__init__()

                                        self.yang_name = "adjacency-sid-backup-te"
                                        self.yang_parent_name = "adjacency-sid"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("backup-label-stack", ("backup_label_stack", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe.BackupLabelStack))])
                                        self._leafs = OrderedDict([
                                            ('backup_label_stack_size', (YLeaf(YType.uint8, 'backup-label-stack-size'), ['int'])),
                                            ('backup_node_address', (YLeaf(YType.str, 'backup-node-address'), ['str'])),
                                            ('backup_nexthop', (YLeaf(YType.str, 'backup-nexthop'), ['str'])),
                                            ('backup_interface', (YLeaf(YType.str, 'backup-interface'), ['str'])),
                                        ])
                                        self.backup_label_stack_size = None
                                        self.backup_node_address = None
                                        self.backup_nexthop = None
                                        self.backup_interface = None

                                        self.backup_label_stack = YList(self)
                                        self._segment_path = lambda: "adjacency-sid-backup-te"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe, [u'backup_label_stack_size', u'backup_node_address', u'backup_nexthop', u'backup_interface'], name, value)


                                    class BackupLabelStack(Entity):
                                        """
                                        Backup path label stack
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe.BackupLabelStack, self).__init__()

                                            self.yang_name = "backup-label-stack"
                                            self.yang_parent_name = "adjacency-sid-backup-te"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "backup-label-stack"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe.BackupLabelStack, [u'entry'], name, value)


                            class NonFrrAdjacencySid(Entity):
                                """
                                Adjacency SID not eligible for FRR protection
                                
                                .. attribute:: adjacency_sid_backup
                                
                                	Adjacency SID Backup Info
                                	**type**\:  :py:class:`AdjacencySidBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup>`
                                
                                .. attribute:: adjacency_sid_backup_te
                                
                                	Adjacency SID Backup Info TE
                                	**type**\:  :py:class:`AdjacencySidBackupTe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe>`
                                
                                .. attribute:: adjacency_sid_value
                                
                                	Adjacency SID value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid, self).__init__()

                                    self.yang_name = "non-frr-adjacency-sid"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("adjacency-sid-backup", ("adjacency_sid_backup", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup)), ("adjacency-sid-backup-te", ("adjacency_sid_backup_te", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe))])
                                    self._leafs = OrderedDict([
                                        ('adjacency_sid_value', (YLeaf(YType.uint32, 'adjacency-sid-value'), ['int'])),
                                    ])
                                    self.adjacency_sid_value = None

                                    self.adjacency_sid_backup = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup()
                                    self.adjacency_sid_backup.parent = self
                                    self._children_name_map["adjacency_sid_backup"] = "adjacency-sid-backup"

                                    self.adjacency_sid_backup_te = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe()
                                    self.adjacency_sid_backup_te.parent = self
                                    self._children_name_map["adjacency_sid_backup_te"] = "adjacency-sid-backup-te"
                                    self._segment_path = lambda: "non-frr-adjacency-sid"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid, [u'adjacency_sid_value'], name, value)


                                class AdjacencySidBackup(Entity):
                                    """
                                    Adjacency SID Backup Info
                                    
                                    .. attribute:: backup_label_stack_size
                                    
                                    	Number of labels in the backup path label stack
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: backup_node_address
                                    
                                    	Neighbor address used as adjacency backup target
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_nexthop
                                    
                                    	Backup path nexthop address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_interface
                                    
                                    	Backup path interface
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: backup_label_stack
                                    
                                    	Backup path label stack
                                    	**type**\: list of  		 :py:class:`BackupLabelStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup.BackupLabelStack>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup, self).__init__()

                                        self.yang_name = "adjacency-sid-backup"
                                        self.yang_parent_name = "non-frr-adjacency-sid"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("backup-label-stack", ("backup_label_stack", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup.BackupLabelStack))])
                                        self._leafs = OrderedDict([
                                            ('backup_label_stack_size', (YLeaf(YType.uint8, 'backup-label-stack-size'), ['int'])),
                                            ('backup_node_address', (YLeaf(YType.str, 'backup-node-address'), ['str'])),
                                            ('backup_nexthop', (YLeaf(YType.str, 'backup-nexthop'), ['str'])),
                                            ('backup_interface', (YLeaf(YType.str, 'backup-interface'), ['str'])),
                                        ])
                                        self.backup_label_stack_size = None
                                        self.backup_node_address = None
                                        self.backup_nexthop = None
                                        self.backup_interface = None

                                        self.backup_label_stack = YList(self)
                                        self._segment_path = lambda: "adjacency-sid-backup"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup, [u'backup_label_stack_size', u'backup_node_address', u'backup_nexthop', u'backup_interface'], name, value)


                                    class BackupLabelStack(Entity):
                                        """
                                        Backup path label stack
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup.BackupLabelStack, self).__init__()

                                            self.yang_name = "backup-label-stack"
                                            self.yang_parent_name = "adjacency-sid-backup"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "backup-label-stack"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup.BackupLabelStack, [u'entry'], name, value)


                                class AdjacencySidBackupTe(Entity):
                                    """
                                    Adjacency SID Backup Info TE
                                    
                                    .. attribute:: backup_label_stack_size
                                    
                                    	Number of labels in the backup path label stack
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: backup_node_address
                                    
                                    	Neighbor address used as adjacency backup target
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_nexthop
                                    
                                    	Backup path nexthop address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_interface
                                    
                                    	Backup path interface
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: backup_label_stack
                                    
                                    	Backup path label stack
                                    	**type**\: list of  		 :py:class:`BackupLabelStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe.BackupLabelStack>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe, self).__init__()

                                        self.yang_name = "adjacency-sid-backup-te"
                                        self.yang_parent_name = "non-frr-adjacency-sid"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("backup-label-stack", ("backup_label_stack", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe.BackupLabelStack))])
                                        self._leafs = OrderedDict([
                                            ('backup_label_stack_size', (YLeaf(YType.uint8, 'backup-label-stack-size'), ['int'])),
                                            ('backup_node_address', (YLeaf(YType.str, 'backup-node-address'), ['str'])),
                                            ('backup_nexthop', (YLeaf(YType.str, 'backup-nexthop'), ['str'])),
                                            ('backup_interface', (YLeaf(YType.str, 'backup-interface'), ['str'])),
                                        ])
                                        self.backup_label_stack_size = None
                                        self.backup_node_address = None
                                        self.backup_nexthop = None
                                        self.backup_interface = None

                                        self.backup_label_stack = YList(self)
                                        self._segment_path = lambda: "adjacency-sid-backup-te"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe, [u'backup_label_stack_size', u'backup_node_address', u'backup_nexthop', u'backup_interface'], name, value)


                                    class BackupLabelStack(Entity):
                                        """
                                        Backup path label stack
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe.BackupLabelStack, self).__init__()

                                            self.yang_name = "backup-label-stack"
                                            self.yang_parent_name = "adjacency-sid-backup-te"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "backup-label-stack"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe.BackupLabelStack, [u'entry'], name, value)


                            class InterfaceAddress(Entity):
                                """
                                Adjacency interface addresses
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.InterfaceAddress, self).__init__()

                                    self.yang_name = "interface-address"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "interface-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.InterfaceAddress, [u'entry'], name, value)


                            class UnderlyingAdjacencySid(Entity):
                                """
                                Per bundle member Adjacency sid
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.UnderlyingAdjacencySid, self).__init__()

                                    self.yang_name = "underlying-adjacency-sid"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "underlying-adjacency-sid"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.UnderlyingAdjacencySid, [u'entry'], name, value)


                            class UnderlyingInterface(Entity):
                                """
                                Underlying interface list for bundle interfaces
                                
                                .. attribute:: interface_index
                                
                                	Local interface handle
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.UnderlyingInterface, self).__init__()

                                    self.yang_name = "underlying-interface"
                                    self.yang_parent_name = "ipv4"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                    ])
                                    self.interface_index = None
                                    self.interface_name = None
                                    self._segment_path = lambda: "underlying-interface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv4.UnderlyingInterface, [u'interface_index', u'interface_name'], name, value)


                        class Ipv6(Entity):
                            """
                            IPV6 neighbor info
                            
                            .. attribute:: adjacency_sid
                            
                            	Adjacency SID
                            	**type**\:  :py:class:`AdjacencySid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid>`
                            
                            .. attribute:: non_frr_adjacency_sid
                            
                            	Adjacency SID not eligible for FRR protection
                            	**type**\:  :py:class:`NonFrrAdjacencySid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid>`
                            
                            .. attribute:: end_xsid
                            
                            	SRv6 End.X SID
                            	**type**\:  :py:class:`EndXsid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.EndXsid>`
                            
                            .. attribute:: non_frr_end_xsid
                            
                            	SRv6 End.X SID not eligible for FRR protection
                            	**type**\:  :py:class:`NonFrrEndXsid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrEndXsid>`
                            
                            .. attribute:: next_hop
                            
                            	Adjacency next hop
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: interface_address
                            
                            	Adjacency interface addresses
                            	**type**\: list of  		 :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.InterfaceAddress>`
                            
                            .. attribute:: underlying_adjacency_sid
                            
                            	Per bundle member Adjacency sid
                            	**type**\: list of  		 :py:class:`UnderlyingAdjacencySid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.UnderlyingAdjacencySid>`
                            
                            .. attribute:: underlying_interface
                            
                            	Underlying interface list for bundle interfaces
                            	**type**\: list of  		 :py:class:`UnderlyingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.UnderlyingInterface>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6, self).__init__()

                                self.yang_name = "ipv6"
                                self.yang_parent_name = "neighbor-per-address-family-data"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("adjacency-sid", ("adjacency_sid", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid)), ("non-frr-adjacency-sid", ("non_frr_adjacency_sid", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid)), ("end-xsid", ("end_xsid", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.EndXsid)), ("non-frr-end-xsid", ("non_frr_end_xsid", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrEndXsid)), ("interface-address", ("interface_address", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.InterfaceAddress)), ("underlying-adjacency-sid", ("underlying_adjacency_sid", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.UnderlyingAdjacencySid)), ("underlying-interface", ("underlying_interface", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.UnderlyingInterface))])
                                self._leafs = OrderedDict([
                                    ('next_hop', (YLeaf(YType.str, 'next-hop'), ['str'])),
                                ])
                                self.next_hop = None

                                self.adjacency_sid = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid()
                                self.adjacency_sid.parent = self
                                self._children_name_map["adjacency_sid"] = "adjacency-sid"

                                self.non_frr_adjacency_sid = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid()
                                self.non_frr_adjacency_sid.parent = self
                                self._children_name_map["non_frr_adjacency_sid"] = "non-frr-adjacency-sid"

                                self.end_xsid = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.EndXsid()
                                self.end_xsid.parent = self
                                self._children_name_map["end_xsid"] = "end-xsid"

                                self.non_frr_end_xsid = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrEndXsid()
                                self.non_frr_end_xsid.parent = self
                                self._children_name_map["non_frr_end_xsid"] = "non-frr-end-xsid"

                                self.interface_address = YList(self)
                                self.underlying_adjacency_sid = YList(self)
                                self.underlying_interface = YList(self)
                                self._segment_path = lambda: "ipv6"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6, [u'next_hop'], name, value)


                            class AdjacencySid(Entity):
                                """
                                Adjacency SID
                                
                                .. attribute:: adjacency_sid_backup
                                
                                	Adjacency SID Backup Info
                                	**type**\:  :py:class:`AdjacencySidBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup>`
                                
                                .. attribute:: adjacency_sid_backup_te
                                
                                	Adjacency SID Backup Info TE
                                	**type**\:  :py:class:`AdjacencySidBackupTe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe>`
                                
                                .. attribute:: adjacency_sid_value
                                
                                	Adjacency SID value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid, self).__init__()

                                    self.yang_name = "adjacency-sid"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("adjacency-sid-backup", ("adjacency_sid_backup", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup)), ("adjacency-sid-backup-te", ("adjacency_sid_backup_te", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe))])
                                    self._leafs = OrderedDict([
                                        ('adjacency_sid_value', (YLeaf(YType.uint32, 'adjacency-sid-value'), ['int'])),
                                    ])
                                    self.adjacency_sid_value = None

                                    self.adjacency_sid_backup = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup()
                                    self.adjacency_sid_backup.parent = self
                                    self._children_name_map["adjacency_sid_backup"] = "adjacency-sid-backup"

                                    self.adjacency_sid_backup_te = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe()
                                    self.adjacency_sid_backup_te.parent = self
                                    self._children_name_map["adjacency_sid_backup_te"] = "adjacency-sid-backup-te"
                                    self._segment_path = lambda: "adjacency-sid"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid, [u'adjacency_sid_value'], name, value)


                                class AdjacencySidBackup(Entity):
                                    """
                                    Adjacency SID Backup Info
                                    
                                    .. attribute:: backup_label_stack_size
                                    
                                    	Number of labels in the backup path label stack
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: backup_node_address
                                    
                                    	Neighbor address used as adjacency backup target
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_nexthop
                                    
                                    	Backup path nexthop address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_interface
                                    
                                    	Backup path interface
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: backup_label_stack
                                    
                                    	Backup path label stack
                                    	**type**\: list of  		 :py:class:`BackupLabelStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup.BackupLabelStack>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup, self).__init__()

                                        self.yang_name = "adjacency-sid-backup"
                                        self.yang_parent_name = "adjacency-sid"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("backup-label-stack", ("backup_label_stack", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup.BackupLabelStack))])
                                        self._leafs = OrderedDict([
                                            ('backup_label_stack_size', (YLeaf(YType.uint8, 'backup-label-stack-size'), ['int'])),
                                            ('backup_node_address', (YLeaf(YType.str, 'backup-node-address'), ['str'])),
                                            ('backup_nexthop', (YLeaf(YType.str, 'backup-nexthop'), ['str'])),
                                            ('backup_interface', (YLeaf(YType.str, 'backup-interface'), ['str'])),
                                        ])
                                        self.backup_label_stack_size = None
                                        self.backup_node_address = None
                                        self.backup_nexthop = None
                                        self.backup_interface = None

                                        self.backup_label_stack = YList(self)
                                        self._segment_path = lambda: "adjacency-sid-backup"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup, [u'backup_label_stack_size', u'backup_node_address', u'backup_nexthop', u'backup_interface'], name, value)


                                    class BackupLabelStack(Entity):
                                        """
                                        Backup path label stack
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup.BackupLabelStack, self).__init__()

                                            self.yang_name = "backup-label-stack"
                                            self.yang_parent_name = "adjacency-sid-backup"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "backup-label-stack"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup.BackupLabelStack, [u'entry'], name, value)


                                class AdjacencySidBackupTe(Entity):
                                    """
                                    Adjacency SID Backup Info TE
                                    
                                    .. attribute:: backup_label_stack_size
                                    
                                    	Number of labels in the backup path label stack
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: backup_node_address
                                    
                                    	Neighbor address used as adjacency backup target
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_nexthop
                                    
                                    	Backup path nexthop address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_interface
                                    
                                    	Backup path interface
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: backup_label_stack
                                    
                                    	Backup path label stack
                                    	**type**\: list of  		 :py:class:`BackupLabelStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe.BackupLabelStack>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe, self).__init__()

                                        self.yang_name = "adjacency-sid-backup-te"
                                        self.yang_parent_name = "adjacency-sid"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("backup-label-stack", ("backup_label_stack", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe.BackupLabelStack))])
                                        self._leafs = OrderedDict([
                                            ('backup_label_stack_size', (YLeaf(YType.uint8, 'backup-label-stack-size'), ['int'])),
                                            ('backup_node_address', (YLeaf(YType.str, 'backup-node-address'), ['str'])),
                                            ('backup_nexthop', (YLeaf(YType.str, 'backup-nexthop'), ['str'])),
                                            ('backup_interface', (YLeaf(YType.str, 'backup-interface'), ['str'])),
                                        ])
                                        self.backup_label_stack_size = None
                                        self.backup_node_address = None
                                        self.backup_nexthop = None
                                        self.backup_interface = None

                                        self.backup_label_stack = YList(self)
                                        self._segment_path = lambda: "adjacency-sid-backup-te"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe, [u'backup_label_stack_size', u'backup_node_address', u'backup_nexthop', u'backup_interface'], name, value)


                                    class BackupLabelStack(Entity):
                                        """
                                        Backup path label stack
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe.BackupLabelStack, self).__init__()

                                            self.yang_name = "backup-label-stack"
                                            self.yang_parent_name = "adjacency-sid-backup-te"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "backup-label-stack"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe.BackupLabelStack, [u'entry'], name, value)


                            class NonFrrAdjacencySid(Entity):
                                """
                                Adjacency SID not eligible for FRR protection
                                
                                .. attribute:: adjacency_sid_backup
                                
                                	Adjacency SID Backup Info
                                	**type**\:  :py:class:`AdjacencySidBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup>`
                                
                                .. attribute:: adjacency_sid_backup_te
                                
                                	Adjacency SID Backup Info TE
                                	**type**\:  :py:class:`AdjacencySidBackupTe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe>`
                                
                                .. attribute:: adjacency_sid_value
                                
                                	Adjacency SID value
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid, self).__init__()

                                    self.yang_name = "non-frr-adjacency-sid"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("adjacency-sid-backup", ("adjacency_sid_backup", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup)), ("adjacency-sid-backup-te", ("adjacency_sid_backup_te", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe))])
                                    self._leafs = OrderedDict([
                                        ('adjacency_sid_value', (YLeaf(YType.uint32, 'adjacency-sid-value'), ['int'])),
                                    ])
                                    self.adjacency_sid_value = None

                                    self.adjacency_sid_backup = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup()
                                    self.adjacency_sid_backup.parent = self
                                    self._children_name_map["adjacency_sid_backup"] = "adjacency-sid-backup"

                                    self.adjacency_sid_backup_te = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe()
                                    self.adjacency_sid_backup_te.parent = self
                                    self._children_name_map["adjacency_sid_backup_te"] = "adjacency-sid-backup-te"
                                    self._segment_path = lambda: "non-frr-adjacency-sid"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid, [u'adjacency_sid_value'], name, value)


                                class AdjacencySidBackup(Entity):
                                    """
                                    Adjacency SID Backup Info
                                    
                                    .. attribute:: backup_label_stack_size
                                    
                                    	Number of labels in the backup path label stack
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: backup_node_address
                                    
                                    	Neighbor address used as adjacency backup target
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_nexthop
                                    
                                    	Backup path nexthop address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_interface
                                    
                                    	Backup path interface
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: backup_label_stack
                                    
                                    	Backup path label stack
                                    	**type**\: list of  		 :py:class:`BackupLabelStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup.BackupLabelStack>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup, self).__init__()

                                        self.yang_name = "adjacency-sid-backup"
                                        self.yang_parent_name = "non-frr-adjacency-sid"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("backup-label-stack", ("backup_label_stack", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup.BackupLabelStack))])
                                        self._leafs = OrderedDict([
                                            ('backup_label_stack_size', (YLeaf(YType.uint8, 'backup-label-stack-size'), ['int'])),
                                            ('backup_node_address', (YLeaf(YType.str, 'backup-node-address'), ['str'])),
                                            ('backup_nexthop', (YLeaf(YType.str, 'backup-nexthop'), ['str'])),
                                            ('backup_interface', (YLeaf(YType.str, 'backup-interface'), ['str'])),
                                        ])
                                        self.backup_label_stack_size = None
                                        self.backup_node_address = None
                                        self.backup_nexthop = None
                                        self.backup_interface = None

                                        self.backup_label_stack = YList(self)
                                        self._segment_path = lambda: "adjacency-sid-backup"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup, [u'backup_label_stack_size', u'backup_node_address', u'backup_nexthop', u'backup_interface'], name, value)


                                    class BackupLabelStack(Entity):
                                        """
                                        Backup path label stack
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup.BackupLabelStack, self).__init__()

                                            self.yang_name = "backup-label-stack"
                                            self.yang_parent_name = "adjacency-sid-backup"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "backup-label-stack"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup.BackupLabelStack, [u'entry'], name, value)


                                class AdjacencySidBackupTe(Entity):
                                    """
                                    Adjacency SID Backup Info TE
                                    
                                    .. attribute:: backup_label_stack_size
                                    
                                    	Number of labels in the backup path label stack
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: backup_node_address
                                    
                                    	Neighbor address used as adjacency backup target
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_nexthop
                                    
                                    	Backup path nexthop address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_interface
                                    
                                    	Backup path interface
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: backup_label_stack
                                    
                                    	Backup path label stack
                                    	**type**\: list of  		 :py:class:`BackupLabelStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe.BackupLabelStack>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe, self).__init__()

                                        self.yang_name = "adjacency-sid-backup-te"
                                        self.yang_parent_name = "non-frr-adjacency-sid"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("backup-label-stack", ("backup_label_stack", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe.BackupLabelStack))])
                                        self._leafs = OrderedDict([
                                            ('backup_label_stack_size', (YLeaf(YType.uint8, 'backup-label-stack-size'), ['int'])),
                                            ('backup_node_address', (YLeaf(YType.str, 'backup-node-address'), ['str'])),
                                            ('backup_nexthop', (YLeaf(YType.str, 'backup-nexthop'), ['str'])),
                                            ('backup_interface', (YLeaf(YType.str, 'backup-interface'), ['str'])),
                                        ])
                                        self.backup_label_stack_size = None
                                        self.backup_node_address = None
                                        self.backup_nexthop = None
                                        self.backup_interface = None

                                        self.backup_label_stack = YList(self)
                                        self._segment_path = lambda: "adjacency-sid-backup-te"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe, [u'backup_label_stack_size', u'backup_node_address', u'backup_nexthop', u'backup_interface'], name, value)


                                    class BackupLabelStack(Entity):
                                        """
                                        Backup path label stack
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe.BackupLabelStack, self).__init__()

                                            self.yang_name = "backup-label-stack"
                                            self.yang_parent_name = "adjacency-sid-backup-te"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "backup-label-stack"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe.BackupLabelStack, [u'entry'], name, value)


                            class EndXsid(Entity):
                                """
                                SRv6 End.X SID
                                
                                .. attribute:: end_xsid
                                
                                	End.X SID value
                                	**type**\:  :py:class:`EndXsid_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.EndXsid.EndXsid_>`
                                
                                .. attribute:: end_xsid_backup
                                
                                	End.X SID Backup Info
                                	**type**\:  :py:class:`EndXsidBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.EndXsid.EndXsidBackup>`
                                
                                .. attribute:: end_xsid_function
                                
                                	End.X SID Function
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.EndXsid, self).__init__()

                                    self.yang_name = "end-xsid"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("end-xsid", ("end_xsid", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.EndXsid.EndXsid_)), ("end-xsid-backup", ("end_xsid_backup", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.EndXsid.EndXsidBackup))])
                                    self._leafs = OrderedDict([
                                        ('end_xsid_function', (YLeaf(YType.uint16, 'end-xsid-function'), ['int'])),
                                    ])
                                    self.end_xsid_function = None

                                    self.end_xsid = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.EndXsid.EndXsid_()
                                    self.end_xsid.parent = self
                                    self._children_name_map["end_xsid"] = "end-xsid"

                                    self.end_xsid_backup = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.EndXsid.EndXsidBackup()
                                    self.end_xsid_backup.parent = self
                                    self._children_name_map["end_xsid_backup"] = "end-xsid-backup"
                                    self._segment_path = lambda: "end-xsid"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.EndXsid, [u'end_xsid_function'], name, value)


                                class EndXsid_(Entity):
                                    """
                                    End.X SID value
                                    
                                    .. attribute:: prefix
                                    
                                    	prefix
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	prefix length
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.EndXsid.EndXsid_, self).__init__()

                                        self.yang_name = "end-xsid"
                                        self.yang_parent_name = "end-xsid"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                            ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                        ])
                                        self.prefix = None
                                        self.prefix_length = None
                                        self._segment_path = lambda: "end-xsid"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.EndXsid.EndXsid_, [u'prefix', u'prefix_length'], name, value)


                                class EndXsidBackup(Entity):
                                    """
                                    End.X SID Backup Info
                                    
                                    .. attribute:: backup_stack_size
                                    
                                    	Number of SIDs in the backup path stack
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: backup_node_address
                                    
                                    	Neighbor address used as adjacency backup target
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_nexthop
                                    
                                    	Backup path nexthop address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_interface
                                    
                                    	Backup path interface
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: backup_stack
                                    
                                    	Backup path SID stack
                                    	**type**\: list of  		 :py:class:`BackupStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.EndXsid.EndXsidBackup.BackupStack>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.EndXsid.EndXsidBackup, self).__init__()

                                        self.yang_name = "end-xsid-backup"
                                        self.yang_parent_name = "end-xsid"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("backup-stack", ("backup_stack", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.EndXsid.EndXsidBackup.BackupStack))])
                                        self._leafs = OrderedDict([
                                            ('backup_stack_size', (YLeaf(YType.uint8, 'backup-stack-size'), ['int'])),
                                            ('backup_node_address', (YLeaf(YType.str, 'backup-node-address'), ['str'])),
                                            ('backup_nexthop', (YLeaf(YType.str, 'backup-nexthop'), ['str'])),
                                            ('backup_interface', (YLeaf(YType.str, 'backup-interface'), ['str'])),
                                        ])
                                        self.backup_stack_size = None
                                        self.backup_node_address = None
                                        self.backup_nexthop = None
                                        self.backup_interface = None

                                        self.backup_stack = YList(self)
                                        self._segment_path = lambda: "end-xsid-backup"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.EndXsid.EndXsidBackup, [u'backup_stack_size', u'backup_node_address', u'backup_nexthop', u'backup_interface'], name, value)


                                    class BackupStack(Entity):
                                        """
                                        Backup path SID stack
                                        
                                        .. attribute:: prefix
                                        
                                        	prefix
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	prefix length
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.EndXsid.EndXsidBackup.BackupStack, self).__init__()

                                            self.yang_name = "backup-stack"
                                            self.yang_parent_name = "end-xsid-backup"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                            ])
                                            self.prefix = None
                                            self.prefix_length = None
                                            self._segment_path = lambda: "backup-stack"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.EndXsid.EndXsidBackup.BackupStack, [u'prefix', u'prefix_length'], name, value)


                            class NonFrrEndXsid(Entity):
                                """
                                SRv6 End.X SID not eligible for FRR protection
                                
                                .. attribute:: end_xsid
                                
                                	End.X SID value
                                	**type**\:  :py:class:`EndXsid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrEndXsid.EndXsid>`
                                
                                .. attribute:: end_xsid_backup
                                
                                	End.X SID Backup Info
                                	**type**\:  :py:class:`EndXsidBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrEndXsid.EndXsidBackup>`
                                
                                .. attribute:: end_xsid_function
                                
                                	End.X SID Function
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrEndXsid, self).__init__()

                                    self.yang_name = "non-frr-end-xsid"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("end-xsid", ("end_xsid", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrEndXsid.EndXsid)), ("end-xsid-backup", ("end_xsid_backup", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrEndXsid.EndXsidBackup))])
                                    self._leafs = OrderedDict([
                                        ('end_xsid_function', (YLeaf(YType.uint16, 'end-xsid-function'), ['int'])),
                                    ])
                                    self.end_xsid_function = None

                                    self.end_xsid = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrEndXsid.EndXsid()
                                    self.end_xsid.parent = self
                                    self._children_name_map["end_xsid"] = "end-xsid"

                                    self.end_xsid_backup = Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrEndXsid.EndXsidBackup()
                                    self.end_xsid_backup.parent = self
                                    self._children_name_map["end_xsid_backup"] = "end-xsid-backup"
                                    self._segment_path = lambda: "non-frr-end-xsid"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrEndXsid, [u'end_xsid_function'], name, value)


                                class EndXsid(Entity):
                                    """
                                    End.X SID value
                                    
                                    .. attribute:: prefix
                                    
                                    	prefix
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: prefix_length
                                    
                                    	prefix length
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrEndXsid.EndXsid, self).__init__()

                                        self.yang_name = "end-xsid"
                                        self.yang_parent_name = "non-frr-end-xsid"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                            ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                        ])
                                        self.prefix = None
                                        self.prefix_length = None
                                        self._segment_path = lambda: "end-xsid"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrEndXsid.EndXsid, [u'prefix', u'prefix_length'], name, value)


                                class EndXsidBackup(Entity):
                                    """
                                    End.X SID Backup Info
                                    
                                    .. attribute:: backup_stack_size
                                    
                                    	Number of SIDs in the backup path stack
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: backup_node_address
                                    
                                    	Neighbor address used as adjacency backup target
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_nexthop
                                    
                                    	Backup path nexthop address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: backup_interface
                                    
                                    	Backup path interface
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: backup_stack
                                    
                                    	Backup path SID stack
                                    	**type**\: list of  		 :py:class:`BackupStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrEndXsid.EndXsidBackup.BackupStack>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrEndXsid.EndXsidBackup, self).__init__()

                                        self.yang_name = "end-xsid-backup"
                                        self.yang_parent_name = "non-frr-end-xsid"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("backup-stack", ("backup_stack", Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrEndXsid.EndXsidBackup.BackupStack))])
                                        self._leafs = OrderedDict([
                                            ('backup_stack_size', (YLeaf(YType.uint8, 'backup-stack-size'), ['int'])),
                                            ('backup_node_address', (YLeaf(YType.str, 'backup-node-address'), ['str'])),
                                            ('backup_nexthop', (YLeaf(YType.str, 'backup-nexthop'), ['str'])),
                                            ('backup_interface', (YLeaf(YType.str, 'backup-interface'), ['str'])),
                                        ])
                                        self.backup_stack_size = None
                                        self.backup_node_address = None
                                        self.backup_nexthop = None
                                        self.backup_interface = None

                                        self.backup_stack = YList(self)
                                        self._segment_path = lambda: "end-xsid-backup"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrEndXsid.EndXsidBackup, [u'backup_stack_size', u'backup_node_address', u'backup_nexthop', u'backup_interface'], name, value)


                                    class BackupStack(Entity):
                                        """
                                        Backup path SID stack
                                        
                                        .. attribute:: prefix
                                        
                                        	prefix
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	prefix length
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrEndXsid.EndXsidBackup.BackupStack, self).__init__()

                                            self.yang_name = "backup-stack"
                                            self.yang_parent_name = "end-xsid-backup"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                            ])
                                            self.prefix = None
                                            self.prefix_length = None
                                            self._segment_path = lambda: "backup-stack"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.NonFrrEndXsid.EndXsidBackup.BackupStack, [u'prefix', u'prefix_length'], name, value)


                            class InterfaceAddress(Entity):
                                """
                                Adjacency interface addresses
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.InterfaceAddress, self).__init__()

                                    self.yang_name = "interface-address"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "interface-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.InterfaceAddress, [u'entry'], name, value)


                            class UnderlyingAdjacencySid(Entity):
                                """
                                Per bundle member Adjacency sid
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.UnderlyingAdjacencySid, self).__init__()

                                    self.yang_name = "underlying-adjacency-sid"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "underlying-adjacency-sid"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.UnderlyingAdjacencySid, [u'entry'], name, value)


                            class UnderlyingInterface(Entity):
                                """
                                Underlying interface list for bundle interfaces
                                
                                .. attribute:: interface_index
                                
                                	Local interface handle
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.UnderlyingInterface, self).__init__()

                                    self.yang_name = "underlying-interface"
                                    self.yang_parent_name = "ipv6"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                    ])
                                    self.interface_index = None
                                    self.interface_name = None
                                    self._segment_path = lambda: "underlying-interface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Neighbors.Neighbor.NeighborPerAddressFamilyData.Ipv6.UnderlyingInterface, [u'interface_index', u'interface_name'], name, value)


            class HostNames(Entity):
                """
                Hostname table
                
                .. attribute:: host_name
                
                	Hostname table entry
                	**type**\: list of  		 :py:class:`HostName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.HostNames.HostName>`
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2018-04-07'

                def __init__(self):
                    super(Isis.Instances.Instance.HostNames, self).__init__()

                    self.yang_name = "host-names"
                    self.yang_parent_name = "instance"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("host-name", ("host_name", Isis.Instances.Instance.HostNames.HostName))])
                    self._leafs = OrderedDict()

                    self.host_name = YList(self)
                    self._segment_path = lambda: "host-names"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Isis.Instances.Instance.HostNames, [], name, value)


                class HostName(Entity):
                    """
                    Hostname table entry
                    
                    .. attribute:: system_id  (key)
                    
                    	System ID
                    	**type**\: str
                    
                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                    
                    .. attribute:: local_is_flag
                    
                    	TRUE if this is the local IS
                    	**type**\: bool
                    
                    .. attribute:: host_levels
                    
                    	Host levels
                    	**type**\:  :py:class:`IsisLevels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevels>`
                    
                    .. attribute:: host_name
                    
                    	Host name
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2018-04-07'

                    def __init__(self):
                        super(Isis.Instances.Instance.HostNames.HostName, self).__init__()

                        self.yang_name = "host-name"
                        self.yang_parent_name = "host-names"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['system_id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('system_id', (YLeaf(YType.str, 'system-id'), ['str'])),
                            ('local_is_flag', (YLeaf(YType.boolean, 'local-is-flag'), ['bool'])),
                            ('host_levels', (YLeaf(YType.enumeration, 'host-levels'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisLevels', '')])),
                            ('host_name', (YLeaf(YType.str, 'host-name'), ['str'])),
                        ])
                        self.system_id = None
                        self.local_is_flag = None
                        self.host_levels = None
                        self.host_name = None
                        self._segment_path = lambda: "host-name" + "[system-id='" + str(self.system_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Isis.Instances.Instance.HostNames.HostName, ['system_id', u'local_is_flag', u'host_levels', u'host_name'], name, value)


            class StatisticsGlobal(Entity):
                """
                Per\-instance statistics
                
                .. attribute:: statistics
                
                	Statistics
                	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.StatisticsGlobal.Statistics>`
                
                .. attribute:: per_area_data
                
                	Per\-area data
                	**type**\: list of  		 :py:class:`PerAreaData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.StatisticsGlobal.PerAreaData>`
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2018-04-07'

                def __init__(self):
                    super(Isis.Instances.Instance.StatisticsGlobal, self).__init__()

                    self.yang_name = "statistics-global"
                    self.yang_parent_name = "instance"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("statistics", ("statistics", Isis.Instances.Instance.StatisticsGlobal.Statistics)), ("per-area-data", ("per_area_data", Isis.Instances.Instance.StatisticsGlobal.PerAreaData))])
                    self._leafs = OrderedDict()

                    self.statistics = Isis.Instances.Instance.StatisticsGlobal.Statistics()
                    self.statistics.parent = self
                    self._children_name_map["statistics"] = "statistics"

                    self.per_area_data = YList(self)
                    self._segment_path = lambda: "statistics-global"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Isis.Instances.Instance.StatisticsGlobal, [], name, value)


                class Statistics(Entity):
                    """
                    Statistics
                    
                    .. attribute:: avg_hello_process_time
                    
                    	Average hello process time
                    	**type**\:  :py:class:`AvgHelloProcessTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgHelloProcessTime>`
                    
                    .. attribute:: avg_csnp_process_time
                    
                    	Average CSNP process time
                    	**type**\:  :py:class:`AvgCsnpProcessTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgCsnpProcessTime>`
                    
                    .. attribute:: avg_psnp_process_time
                    
                    	Average PSNP process time
                    	**type**\:  :py:class:`AvgPsnpProcessTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgPsnpProcessTime>`
                    
                    .. attribute:: avg_lsp_process_time
                    
                    	Average LSP process time
                    	**type**\:  :py:class:`AvgLspProcessTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgLspProcessTime>`
                    
                    .. attribute:: avg_hello_transmit_time
                    
                    	Average hello transmit time
                    	**type**\:  :py:class:`AvgHelloTransmitTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgHelloTransmitTime>`
                    
                    .. attribute:: avg_csnp_transmit_time
                    
                    	Average CSNP transmit time
                    	**type**\:  :py:class:`AvgCsnpTransmitTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgCsnpTransmitTime>`
                    
                    .. attribute:: avg_psnp_transmit_time
                    
                    	Average PSNP transmit time
                    	**type**\:  :py:class:`AvgPsnpTransmitTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgPsnpTransmitTime>`
                    
                    .. attribute:: avg_lsp_transmit_time
                    
                    	Average LSP transmit time
                    	**type**\:  :py:class:`AvgLspTransmitTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgLspTransmitTime>`
                    
                    .. attribute:: fast_psnp_lookup_count
                    
                    	Fast\-PSNP cache lookups
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: fast_psnp_lookup_hit_count
                    
                    	Fast\-PSNP cache hits
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: fast_csnp_lookup_count
                    
                    	Fast\-CSNP cache lookups
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: fast_csnp_lookup_hit_count
                    
                    	Fast\-CSNP cache hits
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: fast_csnp_cache_update_count
                    
                    	Fast\-CSNP cache updates
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: zero_holdtime_lsp_count
                    
                    	LSPs received with holdtime 0
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_checksum_lsp_count
                    
                    	LSPs received with invalid checksum
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: iih_dropped_count
                    
                    	IIHs dropped \- Not Used
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: lsp_dropped_count
                    
                    	LSPs dropped
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: snp_dropped_count
                    
                    	SNPs dropped
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: maximum_iih_queue_length
                    
                    	Maximum IIH queue length \- Not Used
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: maximum_pdu_queue_length
                    
                    	Maximum update PDU queue length
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pdu_queue_length
                    
                    	Update PDU queue length
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: avg_hello_recv_rate
                    
                    	Average hello receive rate in packets per second
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: packet/s
                    
                    .. attribute:: avg_csnp_recv_rate
                    
                    	Average csnp receive rate in packets per second
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: packet/s
                    
                    .. attribute:: avg_psnp_recv_rate
                    
                    	Average psnp receive rate in packets per second
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: packet/s
                    
                    .. attribute:: avg_lsp_recv_rate
                    
                    	Average LSP receive rate in packets per second
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: packet/s
                    
                    .. attribute:: avg_hello_send_rate
                    
                    	Average hello send rate in packets per second
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: packet/s
                    
                    .. attribute:: avg_csnp_send_rate
                    
                    	Average csnp send rate in packets per second
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: packet/s
                    
                    .. attribute:: avg_psnp_send_rate
                    
                    	Average psnp send rate in packets per second
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: packet/s
                    
                    .. attribute:: avg_lsp_send_rate
                    
                    	Average LSP send rate in packets per second
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: packet/s
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2018-04-07'

                    def __init__(self):
                        super(Isis.Instances.Instance.StatisticsGlobal.Statistics, self).__init__()

                        self.yang_name = "statistics"
                        self.yang_parent_name = "statistics-global"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("avg-hello-process-time", ("avg_hello_process_time", Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgHelloProcessTime)), ("avg-csnp-process-time", ("avg_csnp_process_time", Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgCsnpProcessTime)), ("avg-psnp-process-time", ("avg_psnp_process_time", Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgPsnpProcessTime)), ("avg-lsp-process-time", ("avg_lsp_process_time", Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgLspProcessTime)), ("avg-hello-transmit-time", ("avg_hello_transmit_time", Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgHelloTransmitTime)), ("avg-csnp-transmit-time", ("avg_csnp_transmit_time", Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgCsnpTransmitTime)), ("avg-psnp-transmit-time", ("avg_psnp_transmit_time", Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgPsnpTransmitTime)), ("avg-lsp-transmit-time", ("avg_lsp_transmit_time", Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgLspTransmitTime))])
                        self._leafs = OrderedDict([
                            ('fast_psnp_lookup_count', (YLeaf(YType.uint32, 'fast-psnp-lookup-count'), ['int'])),
                            ('fast_psnp_lookup_hit_count', (YLeaf(YType.uint32, 'fast-psnp-lookup-hit-count'), ['int'])),
                            ('fast_csnp_lookup_count', (YLeaf(YType.uint32, 'fast-csnp-lookup-count'), ['int'])),
                            ('fast_csnp_lookup_hit_count', (YLeaf(YType.uint32, 'fast-csnp-lookup-hit-count'), ['int'])),
                            ('fast_csnp_cache_update_count', (YLeaf(YType.uint32, 'fast-csnp-cache-update-count'), ['int'])),
                            ('zero_holdtime_lsp_count', (YLeaf(YType.uint32, 'zero-holdtime-lsp-count'), ['int'])),
                            ('invalid_checksum_lsp_count', (YLeaf(YType.uint32, 'invalid-checksum-lsp-count'), ['int'])),
                            ('iih_dropped_count', (YLeaf(YType.uint32, 'iih-dropped-count'), ['int'])),
                            ('lsp_dropped_count', (YLeaf(YType.uint32, 'lsp-dropped-count'), ['int'])),
                            ('snp_dropped_count', (YLeaf(YType.uint32, 'snp-dropped-count'), ['int'])),
                            ('maximum_iih_queue_length', (YLeaf(YType.uint32, 'maximum-iih-queue-length'), ['int'])),
                            ('maximum_pdu_queue_length', (YLeaf(YType.uint32, 'maximum-pdu-queue-length'), ['int'])),
                            ('pdu_queue_length', (YLeaf(YType.uint32, 'pdu-queue-length'), ['int'])),
                            ('avg_hello_recv_rate', (YLeaf(YType.uint32, 'avg-hello-recv-rate'), ['int'])),
                            ('avg_csnp_recv_rate', (YLeaf(YType.uint32, 'avg-csnp-recv-rate'), ['int'])),
                            ('avg_psnp_recv_rate', (YLeaf(YType.uint32, 'avg-psnp-recv-rate'), ['int'])),
                            ('avg_lsp_recv_rate', (YLeaf(YType.uint32, 'avg-lsp-recv-rate'), ['int'])),
                            ('avg_hello_send_rate', (YLeaf(YType.uint32, 'avg-hello-send-rate'), ['int'])),
                            ('avg_csnp_send_rate', (YLeaf(YType.uint32, 'avg-csnp-send-rate'), ['int'])),
                            ('avg_psnp_send_rate', (YLeaf(YType.uint32, 'avg-psnp-send-rate'), ['int'])),
                            ('avg_lsp_send_rate', (YLeaf(YType.uint32, 'avg-lsp-send-rate'), ['int'])),
                        ])
                        self.fast_psnp_lookup_count = None
                        self.fast_psnp_lookup_hit_count = None
                        self.fast_csnp_lookup_count = None
                        self.fast_csnp_lookup_hit_count = None
                        self.fast_csnp_cache_update_count = None
                        self.zero_holdtime_lsp_count = None
                        self.invalid_checksum_lsp_count = None
                        self.iih_dropped_count = None
                        self.lsp_dropped_count = None
                        self.snp_dropped_count = None
                        self.maximum_iih_queue_length = None
                        self.maximum_pdu_queue_length = None
                        self.pdu_queue_length = None
                        self.avg_hello_recv_rate = None
                        self.avg_csnp_recv_rate = None
                        self.avg_psnp_recv_rate = None
                        self.avg_lsp_recv_rate = None
                        self.avg_hello_send_rate = None
                        self.avg_csnp_send_rate = None
                        self.avg_psnp_send_rate = None
                        self.avg_lsp_send_rate = None

                        self.avg_hello_process_time = Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgHelloProcessTime()
                        self.avg_hello_process_time.parent = self
                        self._children_name_map["avg_hello_process_time"] = "avg-hello-process-time"

                        self.avg_csnp_process_time = Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgCsnpProcessTime()
                        self.avg_csnp_process_time.parent = self
                        self._children_name_map["avg_csnp_process_time"] = "avg-csnp-process-time"

                        self.avg_psnp_process_time = Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgPsnpProcessTime()
                        self.avg_psnp_process_time.parent = self
                        self._children_name_map["avg_psnp_process_time"] = "avg-psnp-process-time"

                        self.avg_lsp_process_time = Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgLspProcessTime()
                        self.avg_lsp_process_time.parent = self
                        self._children_name_map["avg_lsp_process_time"] = "avg-lsp-process-time"

                        self.avg_hello_transmit_time = Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgHelloTransmitTime()
                        self.avg_hello_transmit_time.parent = self
                        self._children_name_map["avg_hello_transmit_time"] = "avg-hello-transmit-time"

                        self.avg_csnp_transmit_time = Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgCsnpTransmitTime()
                        self.avg_csnp_transmit_time.parent = self
                        self._children_name_map["avg_csnp_transmit_time"] = "avg-csnp-transmit-time"

                        self.avg_psnp_transmit_time = Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgPsnpTransmitTime()
                        self.avg_psnp_transmit_time.parent = self
                        self._children_name_map["avg_psnp_transmit_time"] = "avg-psnp-transmit-time"

                        self.avg_lsp_transmit_time = Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgLspTransmitTime()
                        self.avg_lsp_transmit_time.parent = self
                        self._children_name_map["avg_lsp_transmit_time"] = "avg-lsp-transmit-time"
                        self._segment_path = lambda: "statistics"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Isis.Instances.Instance.StatisticsGlobal.Statistics, [u'fast_psnp_lookup_count', u'fast_psnp_lookup_hit_count', u'fast_csnp_lookup_count', u'fast_csnp_lookup_hit_count', u'fast_csnp_cache_update_count', u'zero_holdtime_lsp_count', u'invalid_checksum_lsp_count', u'iih_dropped_count', u'lsp_dropped_count', u'snp_dropped_count', u'maximum_iih_queue_length', u'maximum_pdu_queue_length', u'pdu_queue_length', u'avg_hello_recv_rate', u'avg_csnp_recv_rate', u'avg_psnp_recv_rate', u'avg_lsp_recv_rate', u'avg_hello_send_rate', u'avg_csnp_send_rate', u'avg_psnp_send_rate', u'avg_lsp_send_rate'], name, value)


                    class AvgHelloProcessTime(Entity):
                        """
                        Average hello process time
                        
                        .. attribute:: seconds
                        
                        	Timestamp value (seconds)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: nano_seconds
                        
                        	Timestamp value (nanoseconds)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: nanosecond
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgHelloProcessTime, self).__init__()

                            self.yang_name = "avg-hello-process-time"
                            self.yang_parent_name = "statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                ('nano_seconds', (YLeaf(YType.uint32, 'nano-seconds'), ['int'])),
                            ])
                            self.seconds = None
                            self.nano_seconds = None
                            self._segment_path = lambda: "avg-hello-process-time"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgHelloProcessTime, [u'seconds', u'nano_seconds'], name, value)


                    class AvgCsnpProcessTime(Entity):
                        """
                        Average CSNP process time
                        
                        .. attribute:: seconds
                        
                        	Timestamp value (seconds)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: nano_seconds
                        
                        	Timestamp value (nanoseconds)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: nanosecond
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgCsnpProcessTime, self).__init__()

                            self.yang_name = "avg-csnp-process-time"
                            self.yang_parent_name = "statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                ('nano_seconds', (YLeaf(YType.uint32, 'nano-seconds'), ['int'])),
                            ])
                            self.seconds = None
                            self.nano_seconds = None
                            self._segment_path = lambda: "avg-csnp-process-time"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgCsnpProcessTime, [u'seconds', u'nano_seconds'], name, value)


                    class AvgPsnpProcessTime(Entity):
                        """
                        Average PSNP process time
                        
                        .. attribute:: seconds
                        
                        	Timestamp value (seconds)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: nano_seconds
                        
                        	Timestamp value (nanoseconds)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: nanosecond
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgPsnpProcessTime, self).__init__()

                            self.yang_name = "avg-psnp-process-time"
                            self.yang_parent_name = "statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                ('nano_seconds', (YLeaf(YType.uint32, 'nano-seconds'), ['int'])),
                            ])
                            self.seconds = None
                            self.nano_seconds = None
                            self._segment_path = lambda: "avg-psnp-process-time"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgPsnpProcessTime, [u'seconds', u'nano_seconds'], name, value)


                    class AvgLspProcessTime(Entity):
                        """
                        Average LSP process time
                        
                        .. attribute:: seconds
                        
                        	Timestamp value (seconds)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: nano_seconds
                        
                        	Timestamp value (nanoseconds)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: nanosecond
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgLspProcessTime, self).__init__()

                            self.yang_name = "avg-lsp-process-time"
                            self.yang_parent_name = "statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                ('nano_seconds', (YLeaf(YType.uint32, 'nano-seconds'), ['int'])),
                            ])
                            self.seconds = None
                            self.nano_seconds = None
                            self._segment_path = lambda: "avg-lsp-process-time"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgLspProcessTime, [u'seconds', u'nano_seconds'], name, value)


                    class AvgHelloTransmitTime(Entity):
                        """
                        Average hello transmit time
                        
                        .. attribute:: seconds
                        
                        	Timestamp value (seconds)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: nano_seconds
                        
                        	Timestamp value (nanoseconds)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: nanosecond
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgHelloTransmitTime, self).__init__()

                            self.yang_name = "avg-hello-transmit-time"
                            self.yang_parent_name = "statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                ('nano_seconds', (YLeaf(YType.uint32, 'nano-seconds'), ['int'])),
                            ])
                            self.seconds = None
                            self.nano_seconds = None
                            self._segment_path = lambda: "avg-hello-transmit-time"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgHelloTransmitTime, [u'seconds', u'nano_seconds'], name, value)


                    class AvgCsnpTransmitTime(Entity):
                        """
                        Average CSNP transmit time
                        
                        .. attribute:: seconds
                        
                        	Timestamp value (seconds)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: nano_seconds
                        
                        	Timestamp value (nanoseconds)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: nanosecond
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgCsnpTransmitTime, self).__init__()

                            self.yang_name = "avg-csnp-transmit-time"
                            self.yang_parent_name = "statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                ('nano_seconds', (YLeaf(YType.uint32, 'nano-seconds'), ['int'])),
                            ])
                            self.seconds = None
                            self.nano_seconds = None
                            self._segment_path = lambda: "avg-csnp-transmit-time"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgCsnpTransmitTime, [u'seconds', u'nano_seconds'], name, value)


                    class AvgPsnpTransmitTime(Entity):
                        """
                        Average PSNP transmit time
                        
                        .. attribute:: seconds
                        
                        	Timestamp value (seconds)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: nano_seconds
                        
                        	Timestamp value (nanoseconds)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: nanosecond
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgPsnpTransmitTime, self).__init__()

                            self.yang_name = "avg-psnp-transmit-time"
                            self.yang_parent_name = "statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                ('nano_seconds', (YLeaf(YType.uint32, 'nano-seconds'), ['int'])),
                            ])
                            self.seconds = None
                            self.nano_seconds = None
                            self._segment_path = lambda: "avg-psnp-transmit-time"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgPsnpTransmitTime, [u'seconds', u'nano_seconds'], name, value)


                    class AvgLspTransmitTime(Entity):
                        """
                        Average LSP transmit time
                        
                        .. attribute:: seconds
                        
                        	Timestamp value (seconds)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: nano_seconds
                        
                        	Timestamp value (nanoseconds)
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: nanosecond
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgLspTransmitTime, self).__init__()

                            self.yang_name = "avg-lsp-transmit-time"
                            self.yang_parent_name = "statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                ('nano_seconds', (YLeaf(YType.uint32, 'nano-seconds'), ['int'])),
                            ])
                            self.seconds = None
                            self.nano_seconds = None
                            self._segment_path = lambda: "avg-lsp-transmit-time"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.StatisticsGlobal.Statistics.AvgLspTransmitTime, [u'seconds', u'nano_seconds'], name, value)


                class PerAreaData(Entity):
                    """
                    Per\-area data
                    
                    .. attribute:: statistics
                    
                    	Statistics
                    	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.StatisticsGlobal.PerAreaData.Statistics>`
                    
                    .. attribute:: level
                    
                    	Level this data applies to
                    	**type**\:  :py:class:`IsisLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevel>`
                    
                    .. attribute:: per_topology_data
                    
                    	Per\-topoogy statistics
                    	**type**\: list of  		 :py:class:`PerTopologyData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.StatisticsGlobal.PerAreaData.PerTopologyData>`
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2018-04-07'

                    def __init__(self):
                        super(Isis.Instances.Instance.StatisticsGlobal.PerAreaData, self).__init__()

                        self.yang_name = "per-area-data"
                        self.yang_parent_name = "statistics-global"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("statistics", ("statistics", Isis.Instances.Instance.StatisticsGlobal.PerAreaData.Statistics)), ("per-topology-data", ("per_topology_data", Isis.Instances.Instance.StatisticsGlobal.PerAreaData.PerTopologyData))])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisLevel', '')])),
                        ])
                        self.level = None

                        self.statistics = Isis.Instances.Instance.StatisticsGlobal.PerAreaData.Statistics()
                        self.statistics.parent = self
                        self._children_name_map["statistics"] = "statistics"

                        self.per_topology_data = YList(self)
                        self._segment_path = lambda: "per-area-data"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Isis.Instances.Instance.StatisticsGlobal.PerAreaData, [u'level'], name, value)


                    class Statistics(Entity):
                        """
                        Statistics
                        
                        .. attribute:: system_lsp_build_count
                        
                        	Number of times system LSP rebuilt
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: system_lsp_refresh_count
                        
                        	Number of times system LSP refreshed
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.StatisticsGlobal.PerAreaData.Statistics, self).__init__()

                            self.yang_name = "statistics"
                            self.yang_parent_name = "per-area-data"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('system_lsp_build_count', (YLeaf(YType.uint32, 'system-lsp-build-count'), ['int'])),
                                ('system_lsp_refresh_count', (YLeaf(YType.uint32, 'system-lsp-refresh-count'), ['int'])),
                            ])
                            self.system_lsp_build_count = None
                            self.system_lsp_refresh_count = None
                            self._segment_path = lambda: "statistics"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.StatisticsGlobal.PerAreaData.Statistics, [u'system_lsp_build_count', u'system_lsp_refresh_count'], name, value)


                    class PerTopologyData(Entity):
                        """
                        Per\-topoogy statistics
                        
                        .. attribute:: id
                        
                        	Topology ID
                        	**type**\:  :py:class:`Id <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.StatisticsGlobal.PerAreaData.PerTopologyData.Id>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.StatisticsGlobal.PerAreaData.PerTopologyData.Statistics>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.StatisticsGlobal.PerAreaData.PerTopologyData, self).__init__()

                            self.yang_name = "per-topology-data"
                            self.yang_parent_name = "per-area-data"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("id", ("id", Isis.Instances.Instance.StatisticsGlobal.PerAreaData.PerTopologyData.Id)), ("statistics", ("statistics", Isis.Instances.Instance.StatisticsGlobal.PerAreaData.PerTopologyData.Statistics))])
                            self._leafs = OrderedDict()

                            self.id = Isis.Instances.Instance.StatisticsGlobal.PerAreaData.PerTopologyData.Id()
                            self.id.parent = self
                            self._children_name_map["id"] = "id"

                            self.statistics = Isis.Instances.Instance.StatisticsGlobal.PerAreaData.PerTopologyData.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"
                            self._segment_path = lambda: "per-topology-data"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.StatisticsGlobal.PerAreaData.PerTopologyData, [], name, value)


                        class Id(Entity):
                            """
                            Topology ID
                            
                            .. attribute:: af_name
                            
                            	AF name
                            	**type**\:  :py:class:`IsisAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAfId>`
                            
                            .. attribute:: saf_name
                            
                            	Sub\-AF name
                            	**type**\:  :py:class:`IsisSubAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisSubAfId>`
                            
                            .. attribute:: vrf_name
                            
                            	VRF Name
                            	**type**\: str
                            
                            .. attribute:: topology_name
                            
                            	Topology Name
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.StatisticsGlobal.PerAreaData.PerTopologyData.Id, self).__init__()

                                self.yang_name = "id"
                                self.yang_parent_name = "per-topology-data"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisAfId', '')])),
                                    ('saf_name', (YLeaf(YType.enumeration, 'saf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisSubAfId', '')])),
                                    ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                    ('topology_name', (YLeaf(YType.str, 'topology-name'), ['str'])),
                                ])
                                self.af_name = None
                                self.saf_name = None
                                self.vrf_name = None
                                self.topology_name = None
                                self._segment_path = lambda: "id"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.StatisticsGlobal.PerAreaData.PerTopologyData.Id, [u'af_name', u'saf_name', u'vrf_name', u'topology_name'], name, value)


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: spf_run_count
                            
                            	Number of full SPF calculations run
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ispf_run_count
                            
                            	Number of ISPF calculations run
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: nhc_run_count
                            
                            	Number of Next Hop Calculations run
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: prc_run_count
                            
                            	Number of PRCs run
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: periodic_run_count
                            
                            	Number of periodic SPF calculations run
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.StatisticsGlobal.PerAreaData.PerTopologyData.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "per-topology-data"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('spf_run_count', (YLeaf(YType.uint32, 'spf-run-count'), ['int'])),
                                    ('ispf_run_count', (YLeaf(YType.uint32, 'ispf-run-count'), ['int'])),
                                    ('nhc_run_count', (YLeaf(YType.uint32, 'nhc-run-count'), ['int'])),
                                    ('prc_run_count', (YLeaf(YType.uint32, 'prc-run-count'), ['int'])),
                                    ('periodic_run_count', (YLeaf(YType.uint32, 'periodic-run-count'), ['int'])),
                                ])
                                self.spf_run_count = None
                                self.ispf_run_count = None
                                self.nhc_run_count = None
                                self.prc_run_count = None
                                self.periodic_run_count = None
                                self._segment_path = lambda: "statistics"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.StatisticsGlobal.PerAreaData.PerTopologyData.Statistics, [u'spf_run_count', u'ispf_run_count', u'nhc_run_count', u'prc_run_count', u'periodic_run_count'], name, value)


            class Levels(Entity):
                """
                Level table
                
                .. attribute:: level
                
                	Per\-level operational data
                	**type**\: list of  		 :py:class:`Level <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level>`
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2018-04-07'

                def __init__(self):
                    super(Isis.Instances.Instance.Levels, self).__init__()

                    self.yang_name = "levels"
                    self.yang_parent_name = "instance"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("level", ("level", Isis.Instances.Instance.Levels.Level))])
                    self._leafs = OrderedDict()

                    self.level = YList(self)
                    self._segment_path = lambda: "levels"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Isis.Instances.Instance.Levels, [], name, value)


                class Level(Entity):
                    """
                    Per\-level operational data
                    
                    .. attribute:: level  (key)
                    
                    	Level
                    	**type**\:  :py:class:`IsisInternalLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_datatypes.IsisInternalLevel>`
                    
                    .. attribute:: adjacency_log
                    
                    	Log of adjacency changes within a single level
                    	**type**\:  :py:class:`AdjacencyLog <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.AdjacencyLog>`
                    
                    .. attribute:: lsp_table_summary
                    
                    	Summary information for one level's LSP database
                    	**type**\:  :py:class:`LspTableSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.LspTableSummary>`
                    
                    .. attribute:: adjacencies
                    
                    	Adjacency table
                    	**type**\:  :py:class:`Adjacencies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies>`
                    
                    .. attribute:: detailed_lsps
                    
                    	Detailed LSP table. Use to retrieve LSPs with TLV content
                    	**type**\:  :py:class:`DetailedLsps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.DetailedLsps>`
                    
                    .. attribute:: lsps
                    
                    	LSP table
                    	**type**\:  :py:class:`Lsps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Lsps>`
                    
                    .. attribute:: lsp_log
                    
                    	LSP\-log for a single level
                    	**type**\:  :py:class:`LspLog <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.LspLog>`
                    
                    .. attribute:: database_log
                    
                    	Database\-log for a single level
                    	**type**\:  :py:class:`DatabaseLog <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.DatabaseLog>`
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2018-04-07'

                    def __init__(self):
                        super(Isis.Instances.Instance.Levels.Level, self).__init__()

                        self.yang_name = "level"
                        self.yang_parent_name = "levels"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['level']
                        self._child_classes = OrderedDict([("adjacency-log", ("adjacency_log", Isis.Instances.Instance.Levels.Level.AdjacencyLog)), ("lsp-table-summary", ("lsp_table_summary", Isis.Instances.Instance.Levels.Level.LspTableSummary)), ("adjacencies", ("adjacencies", Isis.Instances.Instance.Levels.Level.Adjacencies)), ("detailed-lsps", ("detailed_lsps", Isis.Instances.Instance.Levels.Level.DetailedLsps)), ("lsps", ("lsps", Isis.Instances.Instance.Levels.Level.Lsps)), ("lsp-log", ("lsp_log", Isis.Instances.Instance.Levels.Level.LspLog)), ("database-log", ("database_log", Isis.Instances.Instance.Levels.Level.DatabaseLog))])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_datatypes', 'IsisInternalLevel', '')])),
                        ])
                        self.level = None

                        self.adjacency_log = Isis.Instances.Instance.Levels.Level.AdjacencyLog()
                        self.adjacency_log.parent = self
                        self._children_name_map["adjacency_log"] = "adjacency-log"

                        self.lsp_table_summary = Isis.Instances.Instance.Levels.Level.LspTableSummary()
                        self.lsp_table_summary.parent = self
                        self._children_name_map["lsp_table_summary"] = "lsp-table-summary"

                        self.adjacencies = Isis.Instances.Instance.Levels.Level.Adjacencies()
                        self.adjacencies.parent = self
                        self._children_name_map["adjacencies"] = "adjacencies"

                        self.detailed_lsps = Isis.Instances.Instance.Levels.Level.DetailedLsps()
                        self.detailed_lsps.parent = self
                        self._children_name_map["detailed_lsps"] = "detailed-lsps"

                        self.lsps = Isis.Instances.Instance.Levels.Level.Lsps()
                        self.lsps.parent = self
                        self._children_name_map["lsps"] = "lsps"

                        self.lsp_log = Isis.Instances.Instance.Levels.Level.LspLog()
                        self.lsp_log.parent = self
                        self._children_name_map["lsp_log"] = "lsp-log"

                        self.database_log = Isis.Instances.Instance.Levels.Level.DatabaseLog()
                        self.database_log.parent = self
                        self._children_name_map["database_log"] = "database-log"
                        self._segment_path = lambda: "level" + "[level='" + str(self.level) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Isis.Instances.Instance.Levels.Level, ['level'], name, value)


                    class AdjacencyLog(Entity):
                        """
                        Log of adjacency changes within a single
                        level
                        
                        .. attribute:: log_entry
                        
                        	Adjacency Log entries
                        	**type**\: list of  		 :py:class:`LogEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.Levels.Level.AdjacencyLog, self).__init__()

                            self.yang_name = "adjacency-log"
                            self.yang_parent_name = "level"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("log-entry", ("log_entry", Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry))])
                            self._leafs = OrderedDict()

                            self.log_entry = YList(self)
                            self._segment_path = lambda: "adjacency-log"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.Levels.Level.AdjacencyLog, [], name, value)


                        class LogEntry(Entity):
                            """
                            Adjacency Log entries
                            
                            .. attribute:: generic_data
                            
                            	Generic entry data
                            	**type**\:  :py:class:`GenericData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.GenericData>`
                            
                            .. attribute:: adj_log_neighbor_system_id
                            
                            	Neighbor system ID
                            	**type**\: str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\: str
                            
                            .. attribute:: prev_adj_state
                            
                            	Previous adjacency state
                            	**type**\:  :py:class:`IsisAdjState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAdjState>`
                            
                            .. attribute:: cur_adj_state
                            
                            	Current adjacency state
                            	**type**\:  :py:class:`IsisAdjState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAdjState>`
                            
                            .. attribute:: state_reason
                            
                            	Reason adjacency changed state
                            	**type**\:  :py:class:`IsisAdjStateReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAdjStateReason>`
                            
                            .. attribute:: adjacency_per_topology_change
                            
                            	Per\-topology changes
                            	**type**\: list of  		 :py:class:`AdjacencyPerTopologyChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.AdjacencyPerTopologyChange>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry, self).__init__()

                                self.yang_name = "log-entry"
                                self.yang_parent_name = "adjacency-log"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("generic-data", ("generic_data", Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.GenericData)), ("adjacency-per-topology-change", ("adjacency_per_topology_change", Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.AdjacencyPerTopologyChange))])
                                self._leafs = OrderedDict([
                                    ('adj_log_neighbor_system_id', (YLeaf(YType.str, 'adj-log-neighbor-system-id'), ['str'])),
                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                    ('prev_adj_state', (YLeaf(YType.enumeration, 'prev-adj-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisAdjState', '')])),
                                    ('cur_adj_state', (YLeaf(YType.enumeration, 'cur-adj-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisAdjState', '')])),
                                    ('state_reason', (YLeaf(YType.enumeration, 'state-reason'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisAdjStateReason', '')])),
                                ])
                                self.adj_log_neighbor_system_id = None
                                self.interface_name = None
                                self.prev_adj_state = None
                                self.cur_adj_state = None
                                self.state_reason = None

                                self.generic_data = Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.GenericData()
                                self.generic_data.parent = self
                                self._children_name_map["generic_data"] = "generic-data"

                                self.adjacency_per_topology_change = YList(self)
                                self._segment_path = lambda: "log-entry"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry, [u'adj_log_neighbor_system_id', u'interface_name', u'prev_adj_state', u'cur_adj_state', u'state_reason'], name, value)


                            class GenericData(Entity):
                                """
                                Generic entry data
                                
                                .. attribute:: timestamp
                                
                                	Time in UTC relative to Jan 1st, 1970
                                	**type**\:  :py:class:`Timestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.GenericData.Timestamp>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.GenericData, self).__init__()

                                    self.yang_name = "generic-data"
                                    self.yang_parent_name = "log-entry"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("timestamp", ("timestamp", Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.GenericData.Timestamp))])
                                    self._leafs = OrderedDict()

                                    self.timestamp = Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.GenericData.Timestamp()
                                    self.timestamp.parent = self
                                    self._children_name_map["timestamp"] = "timestamp"
                                    self._segment_path = lambda: "generic-data"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.GenericData, [], name, value)


                                class Timestamp(Entity):
                                    """
                                    Time in UTC relative to Jan 1st, 1970
                                    
                                    .. attribute:: seconds
                                    
                                    	Timestamp value (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nano_seconds
                                    
                                    	Timestamp value (nanoseconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.GenericData.Timestamp, self).__init__()

                                        self.yang_name = "timestamp"
                                        self.yang_parent_name = "generic-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nano_seconds', (YLeaf(YType.uint32, 'nano-seconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nano_seconds = None
                                        self._segment_path = lambda: "timestamp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.GenericData.Timestamp, [u'seconds', u'nano_seconds'], name, value)


                            class AdjacencyPerTopologyChange(Entity):
                                """
                                Per\-topology changes
                                
                                .. attribute:: id
                                
                                	Topology ID
                                	**type**\:  :py:class:`Id <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.AdjacencyPerTopologyChange.Id>`
                                
                                .. attribute:: change
                                
                                	Change
                                	**type**\:  :py:class:`IsisAdjTopoChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAdjTopoChange>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.AdjacencyPerTopologyChange, self).__init__()

                                    self.yang_name = "adjacency-per-topology-change"
                                    self.yang_parent_name = "log-entry"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("id", ("id", Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.AdjacencyPerTopologyChange.Id))])
                                    self._leafs = OrderedDict([
                                        ('change', (YLeaf(YType.enumeration, 'change'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisAdjTopoChange', '')])),
                                    ])
                                    self.change = None

                                    self.id = Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.AdjacencyPerTopologyChange.Id()
                                    self.id.parent = self
                                    self._children_name_map["id"] = "id"
                                    self._segment_path = lambda: "adjacency-per-topology-change"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.AdjacencyPerTopologyChange, [u'change'], name, value)


                                class Id(Entity):
                                    """
                                    Topology ID
                                    
                                    .. attribute:: af_name
                                    
                                    	AF name
                                    	**type**\:  :py:class:`IsisAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAfId>`
                                    
                                    .. attribute:: saf_name
                                    
                                    	Sub\-AF name
                                    	**type**\:  :py:class:`IsisSubAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisSubAfId>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	VRF Name
                                    	**type**\: str
                                    
                                    .. attribute:: topology_name
                                    
                                    	Topology Name
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.AdjacencyPerTopologyChange.Id, self).__init__()

                                        self.yang_name = "id"
                                        self.yang_parent_name = "adjacency-per-topology-change"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisAfId', '')])),
                                            ('saf_name', (YLeaf(YType.enumeration, 'saf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisSubAfId', '')])),
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ('topology_name', (YLeaf(YType.str, 'topology-name'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.saf_name = None
                                        self.vrf_name = None
                                        self.topology_name = None
                                        self._segment_path = lambda: "id"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Levels.Level.AdjacencyLog.LogEntry.AdjacencyPerTopologyChange.Id, [u'af_name', u'saf_name', u'vrf_name', u'topology_name'], name, value)


                    class LspTableSummary(Entity):
                        """
                        Summary information for one level's LSP
                        database
                        
                        .. attribute:: fragment0lsp_stats
                        
                        	Statistics for fragment 0 LSPs
                        	**type**\:  :py:class:`Fragment0lspStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats>`
                        
                        .. attribute:: all_fragment_lsp_stats
                        
                        	Statistics for all LSP fragments
                        	**type**\:  :py:class:`AllFragmentLspStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.Levels.Level.LspTableSummary, self).__init__()

                            self.yang_name = "lsp-table-summary"
                            self.yang_parent_name = "level"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("fragment0lsp-stats", ("fragment0lsp_stats", Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats)), ("all-fragment-lsp-stats", ("all_fragment_lsp_stats", Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats))])
                            self._leafs = OrderedDict()

                            self.fragment0lsp_stats = Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats()
                            self.fragment0lsp_stats.parent = self
                            self._children_name_map["fragment0lsp_stats"] = "fragment0lsp-stats"

                            self.all_fragment_lsp_stats = Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats()
                            self.all_fragment_lsp_stats.parent = self
                            self._children_name_map["all_fragment_lsp_stats"] = "all-fragment-lsp-stats"
                            self._segment_path = lambda: "lsp-table-summary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.Levels.Level.LspTableSummary, [], name, value)


                        class Fragment0lspStats(Entity):
                            """
                            Statistics for fragment 0 LSPs
                            
                            .. attribute:: node_counters
                            
                            	Summary by class of node
                            	**type**\:  :py:class:`NodeCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats.NodeCounters>`
                            
                            .. attribute:: per_topology_counter
                            
                            	Per topology counters
                            	**type**\: list of  		 :py:class:`PerTopologyCounter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats.PerTopologyCounter>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats, self).__init__()

                                self.yang_name = "fragment0lsp-stats"
                                self.yang_parent_name = "lsp-table-summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("node-counters", ("node_counters", Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats.NodeCounters)), ("per-topology-counter", ("per_topology_counter", Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats.PerTopologyCounter))])
                                self._leafs = OrderedDict()

                                self.node_counters = Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats.NodeCounters()
                                self.node_counters.parent = self
                                self._children_name_map["node_counters"] = "node-counters"

                                self.per_topology_counter = YList(self)
                                self._segment_path = lambda: "fragment0lsp-stats"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats, [], name, value)


                            class NodeCounters(Entity):
                                """
                                Summary by class of node
                                
                                .. attribute:: route_lsp_count
                                
                                	Router LSPs
                                	**type**\:  :py:class:`RouteLspCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats.NodeCounters.RouteLspCount>`
                                
                                .. attribute:: pseudo_node_lsp_count
                                
                                	Pseudonode LSPs
                                	**type**\:  :py:class:`PseudoNodeLspCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats.NodeCounters.PseudoNodeLspCount>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats.NodeCounters, self).__init__()

                                    self.yang_name = "node-counters"
                                    self.yang_parent_name = "fragment0lsp-stats"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("route-lsp-count", ("route_lsp_count", Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats.NodeCounters.RouteLspCount)), ("pseudo-node-lsp-count", ("pseudo_node_lsp_count", Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats.NodeCounters.PseudoNodeLspCount))])
                                    self._leafs = OrderedDict()

                                    self.route_lsp_count = Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats.NodeCounters.RouteLspCount()
                                    self.route_lsp_count.parent = self
                                    self._children_name_map["route_lsp_count"] = "route-lsp-count"

                                    self.pseudo_node_lsp_count = Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats.NodeCounters.PseudoNodeLspCount()
                                    self.pseudo_node_lsp_count.parent = self
                                    self._children_name_map["pseudo_node_lsp_count"] = "pseudo-node-lsp-count"
                                    self._segment_path = lambda: "node-counters"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats.NodeCounters, [], name, value)


                                class RouteLspCount(Entity):
                                    """
                                    Router LSPs
                                    
                                    .. attribute:: active_lsp_count
                                    
                                    	Number of active LSPs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: purged_lsp_count
                                    
                                    	Number of purged LSPs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats.NodeCounters.RouteLspCount, self).__init__()

                                        self.yang_name = "route-lsp-count"
                                        self.yang_parent_name = "node-counters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('active_lsp_count', (YLeaf(YType.uint32, 'active-lsp-count'), ['int'])),
                                            ('purged_lsp_count', (YLeaf(YType.uint32, 'purged-lsp-count'), ['int'])),
                                        ])
                                        self.active_lsp_count = None
                                        self.purged_lsp_count = None
                                        self._segment_path = lambda: "route-lsp-count"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats.NodeCounters.RouteLspCount, [u'active_lsp_count', u'purged_lsp_count'], name, value)


                                class PseudoNodeLspCount(Entity):
                                    """
                                    Pseudonode LSPs
                                    
                                    .. attribute:: active_lsp_count
                                    
                                    	Number of active LSPs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: purged_lsp_count
                                    
                                    	Number of purged LSPs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats.NodeCounters.PseudoNodeLspCount, self).__init__()

                                        self.yang_name = "pseudo-node-lsp-count"
                                        self.yang_parent_name = "node-counters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('active_lsp_count', (YLeaf(YType.uint32, 'active-lsp-count'), ['int'])),
                                            ('purged_lsp_count', (YLeaf(YType.uint32, 'purged-lsp-count'), ['int'])),
                                        ])
                                        self.active_lsp_count = None
                                        self.purged_lsp_count = None
                                        self._segment_path = lambda: "pseudo-node-lsp-count"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats.NodeCounters.PseudoNodeLspCount, [u'active_lsp_count', u'purged_lsp_count'], name, value)


                            class PerTopologyCounter(Entity):
                                """
                                Per topology counters
                                
                                .. attribute:: id
                                
                                	Topology ID
                                	**type**\:  :py:class:`Id <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats.PerTopologyCounter.Id>`
                                
                                .. attribute:: overloaded_lsp_count
                                
                                	Number of LSPs with their per\-topology overload bit set
                                	**type**\:  :py:class:`OverloadedLspCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats.PerTopologyCounter.OverloadedLspCount>`
                                
                                .. attribute:: attached_lsp_count
                                
                                	Number of LSPs with their per\-topology attached bit set
                                	**type**\:  :py:class:`AttachedLspCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats.PerTopologyCounter.AttachedLspCount>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats.PerTopologyCounter, self).__init__()

                                    self.yang_name = "per-topology-counter"
                                    self.yang_parent_name = "fragment0lsp-stats"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("id", ("id", Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats.PerTopologyCounter.Id)), ("overloaded-lsp-count", ("overloaded_lsp_count", Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats.PerTopologyCounter.OverloadedLspCount)), ("attached-lsp-count", ("attached_lsp_count", Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats.PerTopologyCounter.AttachedLspCount))])
                                    self._leafs = OrderedDict()

                                    self.id = Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats.PerTopologyCounter.Id()
                                    self.id.parent = self
                                    self._children_name_map["id"] = "id"

                                    self.overloaded_lsp_count = Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats.PerTopologyCounter.OverloadedLspCount()
                                    self.overloaded_lsp_count.parent = self
                                    self._children_name_map["overloaded_lsp_count"] = "overloaded-lsp-count"

                                    self.attached_lsp_count = Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats.PerTopologyCounter.AttachedLspCount()
                                    self.attached_lsp_count.parent = self
                                    self._children_name_map["attached_lsp_count"] = "attached-lsp-count"
                                    self._segment_path = lambda: "per-topology-counter"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats.PerTopologyCounter, [], name, value)


                                class Id(Entity):
                                    """
                                    Topology ID
                                    
                                    .. attribute:: af_name
                                    
                                    	AF name
                                    	**type**\:  :py:class:`IsisAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAfId>`
                                    
                                    .. attribute:: saf_name
                                    
                                    	Sub\-AF name
                                    	**type**\:  :py:class:`IsisSubAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisSubAfId>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	VRF Name
                                    	**type**\: str
                                    
                                    .. attribute:: topology_name
                                    
                                    	Topology Name
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats.PerTopologyCounter.Id, self).__init__()

                                        self.yang_name = "id"
                                        self.yang_parent_name = "per-topology-counter"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisAfId', '')])),
                                            ('saf_name', (YLeaf(YType.enumeration, 'saf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisSubAfId', '')])),
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ('topology_name', (YLeaf(YType.str, 'topology-name'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.saf_name = None
                                        self.vrf_name = None
                                        self.topology_name = None
                                        self._segment_path = lambda: "id"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats.PerTopologyCounter.Id, [u'af_name', u'saf_name', u'vrf_name', u'topology_name'], name, value)


                                class OverloadedLspCount(Entity):
                                    """
                                    Number of LSPs with their per\-topology overload
                                    bit set
                                    
                                    .. attribute:: active_lsp_count
                                    
                                    	Number of active LSPs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: purged_lsp_count
                                    
                                    	Number of purged LSPs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats.PerTopologyCounter.OverloadedLspCount, self).__init__()

                                        self.yang_name = "overloaded-lsp-count"
                                        self.yang_parent_name = "per-topology-counter"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('active_lsp_count', (YLeaf(YType.uint32, 'active-lsp-count'), ['int'])),
                                            ('purged_lsp_count', (YLeaf(YType.uint32, 'purged-lsp-count'), ['int'])),
                                        ])
                                        self.active_lsp_count = None
                                        self.purged_lsp_count = None
                                        self._segment_path = lambda: "overloaded-lsp-count"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats.PerTopologyCounter.OverloadedLspCount, [u'active_lsp_count', u'purged_lsp_count'], name, value)


                                class AttachedLspCount(Entity):
                                    """
                                    Number of LSPs with their per\-topology attached
                                    bit set
                                    
                                    .. attribute:: active_lsp_count
                                    
                                    	Number of active LSPs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: purged_lsp_count
                                    
                                    	Number of purged LSPs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats.PerTopologyCounter.AttachedLspCount, self).__init__()

                                        self.yang_name = "attached-lsp-count"
                                        self.yang_parent_name = "per-topology-counter"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('active_lsp_count', (YLeaf(YType.uint32, 'active-lsp-count'), ['int'])),
                                            ('purged_lsp_count', (YLeaf(YType.uint32, 'purged-lsp-count'), ['int'])),
                                        ])
                                        self.active_lsp_count = None
                                        self.purged_lsp_count = None
                                        self._segment_path = lambda: "attached-lsp-count"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Levels.Level.LspTableSummary.Fragment0lspStats.PerTopologyCounter.AttachedLspCount, [u'active_lsp_count', u'purged_lsp_count'], name, value)


                        class AllFragmentLspStats(Entity):
                            """
                            Statistics for all LSP fragments
                            
                            .. attribute:: node_counters
                            
                            	Summary by class of node
                            	**type**\:  :py:class:`NodeCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats.NodeCounters>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats, self).__init__()

                                self.yang_name = "all-fragment-lsp-stats"
                                self.yang_parent_name = "lsp-table-summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("node-counters", ("node_counters", Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats.NodeCounters))])
                                self._leafs = OrderedDict()

                                self.node_counters = Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats.NodeCounters()
                                self.node_counters.parent = self
                                self._children_name_map["node_counters"] = "node-counters"
                                self._segment_path = lambda: "all-fragment-lsp-stats"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats, [], name, value)


                            class NodeCounters(Entity):
                                """
                                Summary by class of node
                                
                                .. attribute:: route_lsp_count
                                
                                	Router LSPs
                                	**type**\:  :py:class:`RouteLspCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats.NodeCounters.RouteLspCount>`
                                
                                .. attribute:: pseudo_node_lsp_count
                                
                                	Pseudonode LSPs
                                	**type**\:  :py:class:`PseudoNodeLspCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats.NodeCounters.PseudoNodeLspCount>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats.NodeCounters, self).__init__()

                                    self.yang_name = "node-counters"
                                    self.yang_parent_name = "all-fragment-lsp-stats"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("route-lsp-count", ("route_lsp_count", Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats.NodeCounters.RouteLspCount)), ("pseudo-node-lsp-count", ("pseudo_node_lsp_count", Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats.NodeCounters.PseudoNodeLspCount))])
                                    self._leafs = OrderedDict()

                                    self.route_lsp_count = Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats.NodeCounters.RouteLspCount()
                                    self.route_lsp_count.parent = self
                                    self._children_name_map["route_lsp_count"] = "route-lsp-count"

                                    self.pseudo_node_lsp_count = Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats.NodeCounters.PseudoNodeLspCount()
                                    self.pseudo_node_lsp_count.parent = self
                                    self._children_name_map["pseudo_node_lsp_count"] = "pseudo-node-lsp-count"
                                    self._segment_path = lambda: "node-counters"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats.NodeCounters, [], name, value)


                                class RouteLspCount(Entity):
                                    """
                                    Router LSPs
                                    
                                    .. attribute:: active_lsp_count
                                    
                                    	Number of active LSPs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: purged_lsp_count
                                    
                                    	Number of purged LSPs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats.NodeCounters.RouteLspCount, self).__init__()

                                        self.yang_name = "route-lsp-count"
                                        self.yang_parent_name = "node-counters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('active_lsp_count', (YLeaf(YType.uint32, 'active-lsp-count'), ['int'])),
                                            ('purged_lsp_count', (YLeaf(YType.uint32, 'purged-lsp-count'), ['int'])),
                                        ])
                                        self.active_lsp_count = None
                                        self.purged_lsp_count = None
                                        self._segment_path = lambda: "route-lsp-count"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats.NodeCounters.RouteLspCount, [u'active_lsp_count', u'purged_lsp_count'], name, value)


                                class PseudoNodeLspCount(Entity):
                                    """
                                    Pseudonode LSPs
                                    
                                    .. attribute:: active_lsp_count
                                    
                                    	Number of active LSPs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: purged_lsp_count
                                    
                                    	Number of purged LSPs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats.NodeCounters.PseudoNodeLspCount, self).__init__()

                                        self.yang_name = "pseudo-node-lsp-count"
                                        self.yang_parent_name = "node-counters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('active_lsp_count', (YLeaf(YType.uint32, 'active-lsp-count'), ['int'])),
                                            ('purged_lsp_count', (YLeaf(YType.uint32, 'purged-lsp-count'), ['int'])),
                                        ])
                                        self.active_lsp_count = None
                                        self.purged_lsp_count = None
                                        self._segment_path = lambda: "pseudo-node-lsp-count"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Levels.Level.LspTableSummary.AllFragmentLspStats.NodeCounters.PseudoNodeLspCount, [u'active_lsp_count', u'purged_lsp_count'], name, value)


                    class Adjacencies(Entity):
                        """
                        Adjacency table
                        
                        .. attribute:: adjacency
                        
                        	A single IS\-IS adjacency
                        	**type**\: list of  		 :py:class:`Adjacency <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.Levels.Level.Adjacencies, self).__init__()

                            self.yang_name = "adjacencies"
                            self.yang_parent_name = "level"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("adjacency", ("adjacency", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency))])
                            self._leafs = OrderedDict()

                            self.adjacency = YList(self)
                            self._segment_path = lambda: "adjacencies"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies, [], name, value)


                        class Adjacency(Entity):
                            """
                            A single IS\-IS adjacency
                            
                            .. attribute:: system_id
                            
                            	System ID
                            	**type**\: str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: adjacency_system_id
                            
                            	Neighbor system ID
                            	**type**\: str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                            
                            .. attribute:: adjacency_snpa
                            
                            	Neighbor SNPA
                            	**type**\: str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                            
                            .. attribute:: adjacency_interface
                            
                            	Local interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: adjacency_media_type
                            
                            	Link media type
                            	**type**\:  :py:class:`IsisMediaClass <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisMediaClass>`
                            
                            .. attribute:: adjacency_state
                            
                            	Adjacency state
                            	**type**\:  :py:class:`IsisAdjState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAdjState>`
                            
                            .. attribute:: adjacency_bfd_state
                            
                            	Adjacency IPv4 BFD state
                            	**type**\:  :py:class:`IsisAdjBfdState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAdjBfdState>`
                            
                            .. attribute:: adjacency_ipv6bfd_state
                            
                            	Adjacency IPv6 BFD state
                            	**type**\:  :py:class:`IsisAdjBfdState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAdjBfdState>`
                            
                            .. attribute:: adj_ipv4bfd_retry_running
                            
                            	Is IPv4 BFD retry timer running
                            	**type**\: bool
                            
                            .. attribute:: adj_ipv6bfd_retry_running
                            
                            	Is IPv6 BFD retry timer running
                            	**type**\: bool
                            
                            .. attribute:: adj_ipv4bfd_retry_exp
                            
                            	Time to expiration of IPv4 BFD retry timer (s)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: adj_ipv6bfd_retry_exp
                            
                            	Time to expiration of IPv6 BFD retry timer (s)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: adj_ipv4bfd_retry_count
                            
                            	IPv4 BFD retry counter
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: adj_ipv6bfd_retry_count
                            
                            	IPv6 BFD retry counter
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: adjacency_uptime_valid_flag
                            
                            	TRUE if AdjacencyUptime is set
                            	**type**\: bool
                            
                            .. attribute:: adjacency_uptime
                            
                            	How long the adjacency has been up (s)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: adjacency_holdtime
                            
                            	Time (s) until adjacency declared down if no IIH received
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: adjacency_checkpoint_object_id
                            
                            	Adjacency checkpoint object ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: adjacency_ietf_nsf_capable_flag
                            
                            	TRUE if neighbor is IETF\-NSF capable
                            	**type**\: bool
                            
                            .. attribute:: adjacency_dispriority
                            
                            	Priority of DIS on this LAN. Valid only if aj\_media\_class is ISIS\_MEDIA\_CLASS\_LAN
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: adjacency_neighbor_priority
                            
                            	Neighbor IS priority. Valid only if aj\_media\_class is ISIS\_MEDIA\_CLASS\_LAN
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: adjacency_local_priority
                            
                            	Local IS priority. Valid only if aj\_media\_class is ISIS\_MEDIA\_CLASS\_LAN
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: local_dis_flag
                            
                            	TRUE if local system is DIS. Valid only if AdjacencyMediaType is ISIS\_MEDIA\_CLASS\_LAN
                            	**type**\: bool
                            
                            .. attribute:: neighbor_dis_flag
                            
                            	TRUE if neighbor is DIS. Valid only if AdjacencyMediaType is ISIS\_MEDIA\_CLASS\_LAN
                            	**type**\: bool
                            
                            .. attribute:: nsr_standby
                            
                            	ISIS NSR STANDBY
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: adjacency_area_address
                            
                            	Area addresses active over this adjacency
                            	**type**\: list of  		 :py:class:`AdjacencyAreaAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyAreaAddress>`
                            
                            .. attribute:: adjacency_topology
                            
                            	Per\-topology data
                            	**type**\: list of  		 :py:class:`AdjacencyTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyTopology>`
                            
                            .. attribute:: adjacency_per_address_family_data
                            
                            	Per\-address\-family data
                            	**type**\: list of  		 :py:class:`AdjacencyPerAddressFamilyData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency, self).__init__()

                                self.yang_name = "adjacency"
                                self.yang_parent_name = "adjacencies"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("adjacency-area-address", ("adjacency_area_address", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyAreaAddress)), ("adjacency-topology", ("adjacency_topology", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyTopology)), ("adjacency-per-address-family-data", ("adjacency_per_address_family_data", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData))])
                                self._leafs = OrderedDict([
                                    ('system_id', (YLeaf(YType.str, 'system-id'), ['str'])),
                                    ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                    ('adjacency_system_id', (YLeaf(YType.str, 'adjacency-system-id'), ['str'])),
                                    ('adjacency_snpa', (YLeaf(YType.str, 'adjacency-snpa'), ['str'])),
                                    ('adjacency_interface', (YLeaf(YType.str, 'adjacency-interface'), ['str'])),
                                    ('adjacency_media_type', (YLeaf(YType.enumeration, 'adjacency-media-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisMediaClass', '')])),
                                    ('adjacency_state', (YLeaf(YType.enumeration, 'adjacency-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisAdjState', '')])),
                                    ('adjacency_bfd_state', (YLeaf(YType.enumeration, 'adjacency-bfd-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisAdjBfdState', '')])),
                                    ('adjacency_ipv6bfd_state', (YLeaf(YType.enumeration, 'adjacency-ipv6bfd-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisAdjBfdState', '')])),
                                    ('adj_ipv4bfd_retry_running', (YLeaf(YType.boolean, 'adj-ipv4bfd-retry-running'), ['bool'])),
                                    ('adj_ipv6bfd_retry_running', (YLeaf(YType.boolean, 'adj-ipv6bfd-retry-running'), ['bool'])),
                                    ('adj_ipv4bfd_retry_exp', (YLeaf(YType.uint32, 'adj-ipv4bfd-retry-exp'), ['int'])),
                                    ('adj_ipv6bfd_retry_exp', (YLeaf(YType.uint32, 'adj-ipv6bfd-retry-exp'), ['int'])),
                                    ('adj_ipv4bfd_retry_count', (YLeaf(YType.uint32, 'adj-ipv4bfd-retry-count'), ['int'])),
                                    ('adj_ipv6bfd_retry_count', (YLeaf(YType.uint32, 'adj-ipv6bfd-retry-count'), ['int'])),
                                    ('adjacency_uptime_valid_flag', (YLeaf(YType.boolean, 'adjacency-uptime-valid-flag'), ['bool'])),
                                    ('adjacency_uptime', (YLeaf(YType.uint32, 'adjacency-uptime'), ['int'])),
                                    ('adjacency_holdtime', (YLeaf(YType.uint32, 'adjacency-holdtime'), ['int'])),
                                    ('adjacency_checkpoint_object_id', (YLeaf(YType.uint32, 'adjacency-checkpoint-object-id'), ['int'])),
                                    ('adjacency_ietf_nsf_capable_flag', (YLeaf(YType.boolean, 'adjacency-ietf-nsf-capable-flag'), ['bool'])),
                                    ('adjacency_dispriority', (YLeaf(YType.uint8, 'adjacency-dispriority'), ['int'])),
                                    ('adjacency_neighbor_priority', (YLeaf(YType.uint8, 'adjacency-neighbor-priority'), ['int'])),
                                    ('adjacency_local_priority', (YLeaf(YType.uint8, 'adjacency-local-priority'), ['int'])),
                                    ('local_dis_flag', (YLeaf(YType.boolean, 'local-dis-flag'), ['bool'])),
                                    ('neighbor_dis_flag', (YLeaf(YType.boolean, 'neighbor-dis-flag'), ['bool'])),
                                    ('nsr_standby', (YLeaf(YType.uint8, 'nsr-standby'), ['int'])),
                                ])
                                self.system_id = None
                                self.interface_name = None
                                self.adjacency_system_id = None
                                self.adjacency_snpa = None
                                self.adjacency_interface = None
                                self.adjacency_media_type = None
                                self.adjacency_state = None
                                self.adjacency_bfd_state = None
                                self.adjacency_ipv6bfd_state = None
                                self.adj_ipv4bfd_retry_running = None
                                self.adj_ipv6bfd_retry_running = None
                                self.adj_ipv4bfd_retry_exp = None
                                self.adj_ipv6bfd_retry_exp = None
                                self.adj_ipv4bfd_retry_count = None
                                self.adj_ipv6bfd_retry_count = None
                                self.adjacency_uptime_valid_flag = None
                                self.adjacency_uptime = None
                                self.adjacency_holdtime = None
                                self.adjacency_checkpoint_object_id = None
                                self.adjacency_ietf_nsf_capable_flag = None
                                self.adjacency_dispriority = None
                                self.adjacency_neighbor_priority = None
                                self.adjacency_local_priority = None
                                self.local_dis_flag = None
                                self.neighbor_dis_flag = None
                                self.nsr_standby = None

                                self.adjacency_area_address = YList(self)
                                self.adjacency_topology = YList(self)
                                self.adjacency_per_address_family_data = YList(self)
                                self._segment_path = lambda: "adjacency"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency, ['system_id', 'interface_name', u'adjacency_system_id', u'adjacency_snpa', u'adjacency_interface', u'adjacency_media_type', u'adjacency_state', u'adjacency_bfd_state', u'adjacency_ipv6bfd_state', u'adj_ipv4bfd_retry_running', u'adj_ipv6bfd_retry_running', u'adj_ipv4bfd_retry_exp', u'adj_ipv6bfd_retry_exp', u'adj_ipv4bfd_retry_count', u'adj_ipv6bfd_retry_count', u'adjacency_uptime_valid_flag', u'adjacency_uptime', u'adjacency_holdtime', u'adjacency_checkpoint_object_id', u'adjacency_ietf_nsf_capable_flag', u'adjacency_dispriority', u'adjacency_neighbor_priority', u'adjacency_local_priority', u'local_dis_flag', u'neighbor_dis_flag', u'nsr_standby'], name, value)


                            class AdjacencyAreaAddress(Entity):
                                """
                                Area addresses active over this adjacency
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{2}(\\.[a\-fA\-F0\-9]{4}){0,6}
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyAreaAddress, self).__init__()

                                    self.yang_name = "adjacency-area-address"
                                    self.yang_parent_name = "adjacency"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "adjacency-area-address"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyAreaAddress, [u'entry'], name, value)


                            class AdjacencyTopology(Entity):
                                """
                                Per\-topology data
                                
                                .. attribute:: id
                                
                                	Topology ID
                                	**type**\:  :py:class:`Id <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyTopology.Id>`
                                
                                .. attribute:: topology_status
                                
                                	Status of topology in adjacency
                                	**type**\:  :py:class:`IsisAdjTopoStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAdjTopoStatus>`
                                
                                .. attribute:: parallel_p2p_link_suppressed_flag
                                
                                	TRUE if suppressed parallel point\-to\-point link
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyTopology, self).__init__()

                                    self.yang_name = "adjacency-topology"
                                    self.yang_parent_name = "adjacency"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("id", ("id", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyTopology.Id))])
                                    self._leafs = OrderedDict([
                                        ('topology_status', (YLeaf(YType.enumeration, 'topology-status'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisAdjTopoStatus', '')])),
                                        ('parallel_p2p_link_suppressed_flag', (YLeaf(YType.boolean, 'parallel-p2p-link-suppressed-flag'), ['bool'])),
                                    ])
                                    self.topology_status = None
                                    self.parallel_p2p_link_suppressed_flag = None

                                    self.id = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyTopology.Id()
                                    self.id.parent = self
                                    self._children_name_map["id"] = "id"
                                    self._segment_path = lambda: "adjacency-topology"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyTopology, [u'topology_status', u'parallel_p2p_link_suppressed_flag'], name, value)


                                class Id(Entity):
                                    """
                                    Topology ID
                                    
                                    .. attribute:: af_name
                                    
                                    	AF name
                                    	**type**\:  :py:class:`IsisAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAfId>`
                                    
                                    .. attribute:: saf_name
                                    
                                    	Sub\-AF name
                                    	**type**\:  :py:class:`IsisSubAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisSubAfId>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	VRF Name
                                    	**type**\: str
                                    
                                    .. attribute:: topology_name
                                    
                                    	Topology Name
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyTopology.Id, self).__init__()

                                        self.yang_name = "id"
                                        self.yang_parent_name = "adjacency-topology"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisAfId', '')])),
                                            ('saf_name', (YLeaf(YType.enumeration, 'saf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisSubAfId', '')])),
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ('topology_name', (YLeaf(YType.str, 'topology-name'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.saf_name = None
                                        self.vrf_name = None
                                        self.topology_name = None
                                        self._segment_path = lambda: "id"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyTopology.Id, [u'af_name', u'saf_name', u'vrf_name', u'topology_name'], name, value)


                            class AdjacencyPerAddressFamilyData(Entity):
                                """
                                Per\-address\-family data
                                
                                .. attribute:: ipv4
                                
                                	IPV4 neighbor info
                                	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4>`
                                
                                .. attribute:: ipv6
                                
                                	IPV6 neighbor info
                                	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6>`
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:  :py:class:`IsisAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAfId>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData, self).__init__()

                                    self.yang_name = "adjacency-per-address-family-data"
                                    self.yang_parent_name = "adjacency"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ipv4", ("ipv4", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4)), ("ipv6", ("ipv6", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6))])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisAfId', '')])),
                                    ])
                                    self.af_name = None

                                    self.ipv4 = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4()
                                    self.ipv4.parent = self
                                    self._children_name_map["ipv4"] = "ipv4"

                                    self.ipv6 = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6()
                                    self.ipv6.parent = self
                                    self._children_name_map["ipv6"] = "ipv6"
                                    self._segment_path = lambda: "adjacency-per-address-family-data"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData, [u'af_name'], name, value)


                                class Ipv4(Entity):
                                    """
                                    IPV4 neighbor info
                                    
                                    .. attribute:: adjacency_sid
                                    
                                    	Adjacency SID
                                    	**type**\:  :py:class:`AdjacencySid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid>`
                                    
                                    .. attribute:: non_frr_adjacency_sid
                                    
                                    	Adjacency SID not eligible for FRR protection
                                    	**type**\:  :py:class:`NonFrrAdjacencySid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid>`
                                    
                                    .. attribute:: next_hop
                                    
                                    	Adjacency next hop
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: interface_address
                                    
                                    	Adjacency interface addresses
                                    	**type**\: list of  		 :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.InterfaceAddress>`
                                    
                                    .. attribute:: underlying_adjacency_sid
                                    
                                    	Per bundle member Adjacency sid
                                    	**type**\: list of  		 :py:class:`UnderlyingAdjacencySid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.UnderlyingAdjacencySid>`
                                    
                                    .. attribute:: underlying_interface
                                    
                                    	Underlying interface list for bundle interfaces
                                    	**type**\: list of  		 :py:class:`UnderlyingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.UnderlyingInterface>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4, self).__init__()

                                        self.yang_name = "ipv4"
                                        self.yang_parent_name = "adjacency-per-address-family-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("adjacency-sid", ("adjacency_sid", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid)), ("non-frr-adjacency-sid", ("non_frr_adjacency_sid", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid)), ("interface-address", ("interface_address", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.InterfaceAddress)), ("underlying-adjacency-sid", ("underlying_adjacency_sid", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.UnderlyingAdjacencySid)), ("underlying-interface", ("underlying_interface", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.UnderlyingInterface))])
                                        self._leafs = OrderedDict([
                                            ('next_hop', (YLeaf(YType.str, 'next-hop'), ['str'])),
                                        ])
                                        self.next_hop = None

                                        self.adjacency_sid = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid()
                                        self.adjacency_sid.parent = self
                                        self._children_name_map["adjacency_sid"] = "adjacency-sid"

                                        self.non_frr_adjacency_sid = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid()
                                        self.non_frr_adjacency_sid.parent = self
                                        self._children_name_map["non_frr_adjacency_sid"] = "non-frr-adjacency-sid"

                                        self.interface_address = YList(self)
                                        self.underlying_adjacency_sid = YList(self)
                                        self.underlying_interface = YList(self)
                                        self._segment_path = lambda: "ipv4"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4, [u'next_hop'], name, value)


                                    class AdjacencySid(Entity):
                                        """
                                        Adjacency SID
                                        
                                        .. attribute:: adjacency_sid_backup
                                        
                                        	Adjacency SID Backup Info
                                        	**type**\:  :py:class:`AdjacencySidBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup>`
                                        
                                        .. attribute:: adjacency_sid_backup_te
                                        
                                        	Adjacency SID Backup Info TE
                                        	**type**\:  :py:class:`AdjacencySidBackupTe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe>`
                                        
                                        .. attribute:: adjacency_sid_value
                                        
                                        	Adjacency SID value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid, self).__init__()

                                            self.yang_name = "adjacency-sid"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("adjacency-sid-backup", ("adjacency_sid_backup", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup)), ("adjacency-sid-backup-te", ("adjacency_sid_backup_te", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe))])
                                            self._leafs = OrderedDict([
                                                ('adjacency_sid_value', (YLeaf(YType.uint32, 'adjacency-sid-value'), ['int'])),
                                            ])
                                            self.adjacency_sid_value = None

                                            self.adjacency_sid_backup = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup()
                                            self.adjacency_sid_backup.parent = self
                                            self._children_name_map["adjacency_sid_backup"] = "adjacency-sid-backup"

                                            self.adjacency_sid_backup_te = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe()
                                            self.adjacency_sid_backup_te.parent = self
                                            self._children_name_map["adjacency_sid_backup_te"] = "adjacency-sid-backup-te"
                                            self._segment_path = lambda: "adjacency-sid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid, [u'adjacency_sid_value'], name, value)


                                        class AdjacencySidBackup(Entity):
                                            """
                                            Adjacency SID Backup Info
                                            
                                            .. attribute:: backup_label_stack_size
                                            
                                            	Number of labels in the backup path label stack
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: backup_node_address
                                            
                                            	Neighbor address used as adjacency backup target
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_nexthop
                                            
                                            	Backup path nexthop address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_interface
                                            
                                            	Backup path interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: backup_label_stack
                                            
                                            	Backup path label stack
                                            	**type**\: list of  		 :py:class:`BackupLabelStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup.BackupLabelStack>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup, self).__init__()

                                                self.yang_name = "adjacency-sid-backup"
                                                self.yang_parent_name = "adjacency-sid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("backup-label-stack", ("backup_label_stack", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup.BackupLabelStack))])
                                                self._leafs = OrderedDict([
                                                    ('backup_label_stack_size', (YLeaf(YType.uint8, 'backup-label-stack-size'), ['int'])),
                                                    ('backup_node_address', (YLeaf(YType.str, 'backup-node-address'), ['str'])),
                                                    ('backup_nexthop', (YLeaf(YType.str, 'backup-nexthop'), ['str'])),
                                                    ('backup_interface', (YLeaf(YType.str, 'backup-interface'), ['str'])),
                                                ])
                                                self.backup_label_stack_size = None
                                                self.backup_node_address = None
                                                self.backup_nexthop = None
                                                self.backup_interface = None

                                                self.backup_label_stack = YList(self)
                                                self._segment_path = lambda: "adjacency-sid-backup"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup, [u'backup_label_stack_size', u'backup_node_address', u'backup_nexthop', u'backup_interface'], name, value)


                                            class BackupLabelStack(Entity):
                                                """
                                                Backup path label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup.BackupLabelStack, self).__init__()

                                                    self.yang_name = "backup-label-stack"
                                                    self.yang_parent_name = "adjacency-sid-backup"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "backup-label-stack"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackup.BackupLabelStack, [u'entry'], name, value)


                                        class AdjacencySidBackupTe(Entity):
                                            """
                                            Adjacency SID Backup Info TE
                                            
                                            .. attribute:: backup_label_stack_size
                                            
                                            	Number of labels in the backup path label stack
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: backup_node_address
                                            
                                            	Neighbor address used as adjacency backup target
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_nexthop
                                            
                                            	Backup path nexthop address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_interface
                                            
                                            	Backup path interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: backup_label_stack
                                            
                                            	Backup path label stack
                                            	**type**\: list of  		 :py:class:`BackupLabelStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe.BackupLabelStack>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe, self).__init__()

                                                self.yang_name = "adjacency-sid-backup-te"
                                                self.yang_parent_name = "adjacency-sid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("backup-label-stack", ("backup_label_stack", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe.BackupLabelStack))])
                                                self._leafs = OrderedDict([
                                                    ('backup_label_stack_size', (YLeaf(YType.uint8, 'backup-label-stack-size'), ['int'])),
                                                    ('backup_node_address', (YLeaf(YType.str, 'backup-node-address'), ['str'])),
                                                    ('backup_nexthop', (YLeaf(YType.str, 'backup-nexthop'), ['str'])),
                                                    ('backup_interface', (YLeaf(YType.str, 'backup-interface'), ['str'])),
                                                ])
                                                self.backup_label_stack_size = None
                                                self.backup_node_address = None
                                                self.backup_nexthop = None
                                                self.backup_interface = None

                                                self.backup_label_stack = YList(self)
                                                self._segment_path = lambda: "adjacency-sid-backup-te"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe, [u'backup_label_stack_size', u'backup_node_address', u'backup_nexthop', u'backup_interface'], name, value)


                                            class BackupLabelStack(Entity):
                                                """
                                                Backup path label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe.BackupLabelStack, self).__init__()

                                                    self.yang_name = "backup-label-stack"
                                                    self.yang_parent_name = "adjacency-sid-backup-te"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "backup-label-stack"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.AdjacencySid.AdjacencySidBackupTe.BackupLabelStack, [u'entry'], name, value)


                                    class NonFrrAdjacencySid(Entity):
                                        """
                                        Adjacency SID not eligible for FRR protection
                                        
                                        .. attribute:: adjacency_sid_backup
                                        
                                        	Adjacency SID Backup Info
                                        	**type**\:  :py:class:`AdjacencySidBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup>`
                                        
                                        .. attribute:: adjacency_sid_backup_te
                                        
                                        	Adjacency SID Backup Info TE
                                        	**type**\:  :py:class:`AdjacencySidBackupTe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe>`
                                        
                                        .. attribute:: adjacency_sid_value
                                        
                                        	Adjacency SID value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid, self).__init__()

                                            self.yang_name = "non-frr-adjacency-sid"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("adjacency-sid-backup", ("adjacency_sid_backup", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup)), ("adjacency-sid-backup-te", ("adjacency_sid_backup_te", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe))])
                                            self._leafs = OrderedDict([
                                                ('adjacency_sid_value', (YLeaf(YType.uint32, 'adjacency-sid-value'), ['int'])),
                                            ])
                                            self.adjacency_sid_value = None

                                            self.adjacency_sid_backup = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup()
                                            self.adjacency_sid_backup.parent = self
                                            self._children_name_map["adjacency_sid_backup"] = "adjacency-sid-backup"

                                            self.adjacency_sid_backup_te = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe()
                                            self.adjacency_sid_backup_te.parent = self
                                            self._children_name_map["adjacency_sid_backup_te"] = "adjacency-sid-backup-te"
                                            self._segment_path = lambda: "non-frr-adjacency-sid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid, [u'adjacency_sid_value'], name, value)


                                        class AdjacencySidBackup(Entity):
                                            """
                                            Adjacency SID Backup Info
                                            
                                            .. attribute:: backup_label_stack_size
                                            
                                            	Number of labels in the backup path label stack
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: backup_node_address
                                            
                                            	Neighbor address used as adjacency backup target
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_nexthop
                                            
                                            	Backup path nexthop address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_interface
                                            
                                            	Backup path interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: backup_label_stack
                                            
                                            	Backup path label stack
                                            	**type**\: list of  		 :py:class:`BackupLabelStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup.BackupLabelStack>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup, self).__init__()

                                                self.yang_name = "adjacency-sid-backup"
                                                self.yang_parent_name = "non-frr-adjacency-sid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("backup-label-stack", ("backup_label_stack", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup.BackupLabelStack))])
                                                self._leafs = OrderedDict([
                                                    ('backup_label_stack_size', (YLeaf(YType.uint8, 'backup-label-stack-size'), ['int'])),
                                                    ('backup_node_address', (YLeaf(YType.str, 'backup-node-address'), ['str'])),
                                                    ('backup_nexthop', (YLeaf(YType.str, 'backup-nexthop'), ['str'])),
                                                    ('backup_interface', (YLeaf(YType.str, 'backup-interface'), ['str'])),
                                                ])
                                                self.backup_label_stack_size = None
                                                self.backup_node_address = None
                                                self.backup_nexthop = None
                                                self.backup_interface = None

                                                self.backup_label_stack = YList(self)
                                                self._segment_path = lambda: "adjacency-sid-backup"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup, [u'backup_label_stack_size', u'backup_node_address', u'backup_nexthop', u'backup_interface'], name, value)


                                            class BackupLabelStack(Entity):
                                                """
                                                Backup path label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup.BackupLabelStack, self).__init__()

                                                    self.yang_name = "backup-label-stack"
                                                    self.yang_parent_name = "adjacency-sid-backup"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "backup-label-stack"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackup.BackupLabelStack, [u'entry'], name, value)


                                        class AdjacencySidBackupTe(Entity):
                                            """
                                            Adjacency SID Backup Info TE
                                            
                                            .. attribute:: backup_label_stack_size
                                            
                                            	Number of labels in the backup path label stack
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: backup_node_address
                                            
                                            	Neighbor address used as adjacency backup target
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_nexthop
                                            
                                            	Backup path nexthop address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_interface
                                            
                                            	Backup path interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: backup_label_stack
                                            
                                            	Backup path label stack
                                            	**type**\: list of  		 :py:class:`BackupLabelStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe.BackupLabelStack>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe, self).__init__()

                                                self.yang_name = "adjacency-sid-backup-te"
                                                self.yang_parent_name = "non-frr-adjacency-sid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("backup-label-stack", ("backup_label_stack", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe.BackupLabelStack))])
                                                self._leafs = OrderedDict([
                                                    ('backup_label_stack_size', (YLeaf(YType.uint8, 'backup-label-stack-size'), ['int'])),
                                                    ('backup_node_address', (YLeaf(YType.str, 'backup-node-address'), ['str'])),
                                                    ('backup_nexthop', (YLeaf(YType.str, 'backup-nexthop'), ['str'])),
                                                    ('backup_interface', (YLeaf(YType.str, 'backup-interface'), ['str'])),
                                                ])
                                                self.backup_label_stack_size = None
                                                self.backup_node_address = None
                                                self.backup_nexthop = None
                                                self.backup_interface = None

                                                self.backup_label_stack = YList(self)
                                                self._segment_path = lambda: "adjacency-sid-backup-te"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe, [u'backup_label_stack_size', u'backup_node_address', u'backup_nexthop', u'backup_interface'], name, value)


                                            class BackupLabelStack(Entity):
                                                """
                                                Backup path label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe.BackupLabelStack, self).__init__()

                                                    self.yang_name = "backup-label-stack"
                                                    self.yang_parent_name = "adjacency-sid-backup-te"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "backup-label-stack"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.NonFrrAdjacencySid.AdjacencySidBackupTe.BackupLabelStack, [u'entry'], name, value)


                                    class InterfaceAddress(Entity):
                                        """
                                        Adjacency interface addresses
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.InterfaceAddress, self).__init__()

                                            self.yang_name = "interface-address"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "interface-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.InterfaceAddress, [u'entry'], name, value)


                                    class UnderlyingAdjacencySid(Entity):
                                        """
                                        Per bundle member Adjacency sid
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.UnderlyingAdjacencySid, self).__init__()

                                            self.yang_name = "underlying-adjacency-sid"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "underlying-adjacency-sid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.UnderlyingAdjacencySid, [u'entry'], name, value)


                                    class UnderlyingInterface(Entity):
                                        """
                                        Underlying interface list for bundle interfaces
                                        
                                        .. attribute:: interface_index
                                        
                                        	Local interface handle
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.UnderlyingInterface, self).__init__()

                                            self.yang_name = "underlying-interface"
                                            self.yang_parent_name = "ipv4"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ])
                                            self.interface_index = None
                                            self.interface_name = None
                                            self._segment_path = lambda: "underlying-interface"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv4.UnderlyingInterface, [u'interface_index', u'interface_name'], name, value)


                                class Ipv6(Entity):
                                    """
                                    IPV6 neighbor info
                                    
                                    .. attribute:: adjacency_sid
                                    
                                    	Adjacency SID
                                    	**type**\:  :py:class:`AdjacencySid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid>`
                                    
                                    .. attribute:: non_frr_adjacency_sid
                                    
                                    	Adjacency SID not eligible for FRR protection
                                    	**type**\:  :py:class:`NonFrrAdjacencySid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid>`
                                    
                                    .. attribute:: end_xsid
                                    
                                    	SRv6 End.X SID
                                    	**type**\:  :py:class:`EndXsid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.EndXsid>`
                                    
                                    .. attribute:: non_frr_end_xsid
                                    
                                    	SRv6 End.X SID not eligible for FRR protection
                                    	**type**\:  :py:class:`NonFrrEndXsid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrEndXsid>`
                                    
                                    .. attribute:: next_hop
                                    
                                    	Adjacency next hop
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: interface_address
                                    
                                    	Adjacency interface addresses
                                    	**type**\: list of  		 :py:class:`InterfaceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.InterfaceAddress>`
                                    
                                    .. attribute:: underlying_adjacency_sid
                                    
                                    	Per bundle member Adjacency sid
                                    	**type**\: list of  		 :py:class:`UnderlyingAdjacencySid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.UnderlyingAdjacencySid>`
                                    
                                    .. attribute:: underlying_interface
                                    
                                    	Underlying interface list for bundle interfaces
                                    	**type**\: list of  		 :py:class:`UnderlyingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.UnderlyingInterface>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6, self).__init__()

                                        self.yang_name = "ipv6"
                                        self.yang_parent_name = "adjacency-per-address-family-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("adjacency-sid", ("adjacency_sid", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid)), ("non-frr-adjacency-sid", ("non_frr_adjacency_sid", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid)), ("end-xsid", ("end_xsid", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.EndXsid)), ("non-frr-end-xsid", ("non_frr_end_xsid", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrEndXsid)), ("interface-address", ("interface_address", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.InterfaceAddress)), ("underlying-adjacency-sid", ("underlying_adjacency_sid", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.UnderlyingAdjacencySid)), ("underlying-interface", ("underlying_interface", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.UnderlyingInterface))])
                                        self._leafs = OrderedDict([
                                            ('next_hop', (YLeaf(YType.str, 'next-hop'), ['str'])),
                                        ])
                                        self.next_hop = None

                                        self.adjacency_sid = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid()
                                        self.adjacency_sid.parent = self
                                        self._children_name_map["adjacency_sid"] = "adjacency-sid"

                                        self.non_frr_adjacency_sid = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid()
                                        self.non_frr_adjacency_sid.parent = self
                                        self._children_name_map["non_frr_adjacency_sid"] = "non-frr-adjacency-sid"

                                        self.end_xsid = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.EndXsid()
                                        self.end_xsid.parent = self
                                        self._children_name_map["end_xsid"] = "end-xsid"

                                        self.non_frr_end_xsid = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrEndXsid()
                                        self.non_frr_end_xsid.parent = self
                                        self._children_name_map["non_frr_end_xsid"] = "non-frr-end-xsid"

                                        self.interface_address = YList(self)
                                        self.underlying_adjacency_sid = YList(self)
                                        self.underlying_interface = YList(self)
                                        self._segment_path = lambda: "ipv6"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6, [u'next_hop'], name, value)


                                    class AdjacencySid(Entity):
                                        """
                                        Adjacency SID
                                        
                                        .. attribute:: adjacency_sid_backup
                                        
                                        	Adjacency SID Backup Info
                                        	**type**\:  :py:class:`AdjacencySidBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup>`
                                        
                                        .. attribute:: adjacency_sid_backup_te
                                        
                                        	Adjacency SID Backup Info TE
                                        	**type**\:  :py:class:`AdjacencySidBackupTe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe>`
                                        
                                        .. attribute:: adjacency_sid_value
                                        
                                        	Adjacency SID value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid, self).__init__()

                                            self.yang_name = "adjacency-sid"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("adjacency-sid-backup", ("adjacency_sid_backup", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup)), ("adjacency-sid-backup-te", ("adjacency_sid_backup_te", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe))])
                                            self._leafs = OrderedDict([
                                                ('adjacency_sid_value', (YLeaf(YType.uint32, 'adjacency-sid-value'), ['int'])),
                                            ])
                                            self.adjacency_sid_value = None

                                            self.adjacency_sid_backup = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup()
                                            self.adjacency_sid_backup.parent = self
                                            self._children_name_map["adjacency_sid_backup"] = "adjacency-sid-backup"

                                            self.adjacency_sid_backup_te = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe()
                                            self.adjacency_sid_backup_te.parent = self
                                            self._children_name_map["adjacency_sid_backup_te"] = "adjacency-sid-backup-te"
                                            self._segment_path = lambda: "adjacency-sid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid, [u'adjacency_sid_value'], name, value)


                                        class AdjacencySidBackup(Entity):
                                            """
                                            Adjacency SID Backup Info
                                            
                                            .. attribute:: backup_label_stack_size
                                            
                                            	Number of labels in the backup path label stack
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: backup_node_address
                                            
                                            	Neighbor address used as adjacency backup target
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_nexthop
                                            
                                            	Backup path nexthop address
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_interface
                                            
                                            	Backup path interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: backup_label_stack
                                            
                                            	Backup path label stack
                                            	**type**\: list of  		 :py:class:`BackupLabelStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup.BackupLabelStack>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup, self).__init__()

                                                self.yang_name = "adjacency-sid-backup"
                                                self.yang_parent_name = "adjacency-sid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("backup-label-stack", ("backup_label_stack", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup.BackupLabelStack))])
                                                self._leafs = OrderedDict([
                                                    ('backup_label_stack_size', (YLeaf(YType.uint8, 'backup-label-stack-size'), ['int'])),
                                                    ('backup_node_address', (YLeaf(YType.str, 'backup-node-address'), ['str'])),
                                                    ('backup_nexthop', (YLeaf(YType.str, 'backup-nexthop'), ['str'])),
                                                    ('backup_interface', (YLeaf(YType.str, 'backup-interface'), ['str'])),
                                                ])
                                                self.backup_label_stack_size = None
                                                self.backup_node_address = None
                                                self.backup_nexthop = None
                                                self.backup_interface = None

                                                self.backup_label_stack = YList(self)
                                                self._segment_path = lambda: "adjacency-sid-backup"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup, [u'backup_label_stack_size', u'backup_node_address', u'backup_nexthop', u'backup_interface'], name, value)


                                            class BackupLabelStack(Entity):
                                                """
                                                Backup path label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup.BackupLabelStack, self).__init__()

                                                    self.yang_name = "backup-label-stack"
                                                    self.yang_parent_name = "adjacency-sid-backup"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "backup-label-stack"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackup.BackupLabelStack, [u'entry'], name, value)


                                        class AdjacencySidBackupTe(Entity):
                                            """
                                            Adjacency SID Backup Info TE
                                            
                                            .. attribute:: backup_label_stack_size
                                            
                                            	Number of labels in the backup path label stack
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: backup_node_address
                                            
                                            	Neighbor address used as adjacency backup target
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_nexthop
                                            
                                            	Backup path nexthop address
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_interface
                                            
                                            	Backup path interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: backup_label_stack
                                            
                                            	Backup path label stack
                                            	**type**\: list of  		 :py:class:`BackupLabelStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe.BackupLabelStack>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe, self).__init__()

                                                self.yang_name = "adjacency-sid-backup-te"
                                                self.yang_parent_name = "adjacency-sid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("backup-label-stack", ("backup_label_stack", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe.BackupLabelStack))])
                                                self._leafs = OrderedDict([
                                                    ('backup_label_stack_size', (YLeaf(YType.uint8, 'backup-label-stack-size'), ['int'])),
                                                    ('backup_node_address', (YLeaf(YType.str, 'backup-node-address'), ['str'])),
                                                    ('backup_nexthop', (YLeaf(YType.str, 'backup-nexthop'), ['str'])),
                                                    ('backup_interface', (YLeaf(YType.str, 'backup-interface'), ['str'])),
                                                ])
                                                self.backup_label_stack_size = None
                                                self.backup_node_address = None
                                                self.backup_nexthop = None
                                                self.backup_interface = None

                                                self.backup_label_stack = YList(self)
                                                self._segment_path = lambda: "adjacency-sid-backup-te"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe, [u'backup_label_stack_size', u'backup_node_address', u'backup_nexthop', u'backup_interface'], name, value)


                                            class BackupLabelStack(Entity):
                                                """
                                                Backup path label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe.BackupLabelStack, self).__init__()

                                                    self.yang_name = "backup-label-stack"
                                                    self.yang_parent_name = "adjacency-sid-backup-te"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "backup-label-stack"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.AdjacencySid.AdjacencySidBackupTe.BackupLabelStack, [u'entry'], name, value)


                                    class NonFrrAdjacencySid(Entity):
                                        """
                                        Adjacency SID not eligible for FRR protection
                                        
                                        .. attribute:: adjacency_sid_backup
                                        
                                        	Adjacency SID Backup Info
                                        	**type**\:  :py:class:`AdjacencySidBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup>`
                                        
                                        .. attribute:: adjacency_sid_backup_te
                                        
                                        	Adjacency SID Backup Info TE
                                        	**type**\:  :py:class:`AdjacencySidBackupTe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe>`
                                        
                                        .. attribute:: adjacency_sid_value
                                        
                                        	Adjacency SID value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid, self).__init__()

                                            self.yang_name = "non-frr-adjacency-sid"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("adjacency-sid-backup", ("adjacency_sid_backup", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup)), ("adjacency-sid-backup-te", ("adjacency_sid_backup_te", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe))])
                                            self._leafs = OrderedDict([
                                                ('adjacency_sid_value', (YLeaf(YType.uint32, 'adjacency-sid-value'), ['int'])),
                                            ])
                                            self.adjacency_sid_value = None

                                            self.adjacency_sid_backup = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup()
                                            self.adjacency_sid_backup.parent = self
                                            self._children_name_map["adjacency_sid_backup"] = "adjacency-sid-backup"

                                            self.adjacency_sid_backup_te = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe()
                                            self.adjacency_sid_backup_te.parent = self
                                            self._children_name_map["adjacency_sid_backup_te"] = "adjacency-sid-backup-te"
                                            self._segment_path = lambda: "non-frr-adjacency-sid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid, [u'adjacency_sid_value'], name, value)


                                        class AdjacencySidBackup(Entity):
                                            """
                                            Adjacency SID Backup Info
                                            
                                            .. attribute:: backup_label_stack_size
                                            
                                            	Number of labels in the backup path label stack
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: backup_node_address
                                            
                                            	Neighbor address used as adjacency backup target
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_nexthop
                                            
                                            	Backup path nexthop address
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_interface
                                            
                                            	Backup path interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: backup_label_stack
                                            
                                            	Backup path label stack
                                            	**type**\: list of  		 :py:class:`BackupLabelStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup.BackupLabelStack>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup, self).__init__()

                                                self.yang_name = "adjacency-sid-backup"
                                                self.yang_parent_name = "non-frr-adjacency-sid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("backup-label-stack", ("backup_label_stack", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup.BackupLabelStack))])
                                                self._leafs = OrderedDict([
                                                    ('backup_label_stack_size', (YLeaf(YType.uint8, 'backup-label-stack-size'), ['int'])),
                                                    ('backup_node_address', (YLeaf(YType.str, 'backup-node-address'), ['str'])),
                                                    ('backup_nexthop', (YLeaf(YType.str, 'backup-nexthop'), ['str'])),
                                                    ('backup_interface', (YLeaf(YType.str, 'backup-interface'), ['str'])),
                                                ])
                                                self.backup_label_stack_size = None
                                                self.backup_node_address = None
                                                self.backup_nexthop = None
                                                self.backup_interface = None

                                                self.backup_label_stack = YList(self)
                                                self._segment_path = lambda: "adjacency-sid-backup"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup, [u'backup_label_stack_size', u'backup_node_address', u'backup_nexthop', u'backup_interface'], name, value)


                                            class BackupLabelStack(Entity):
                                                """
                                                Backup path label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup.BackupLabelStack, self).__init__()

                                                    self.yang_name = "backup-label-stack"
                                                    self.yang_parent_name = "adjacency-sid-backup"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "backup-label-stack"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackup.BackupLabelStack, [u'entry'], name, value)


                                        class AdjacencySidBackupTe(Entity):
                                            """
                                            Adjacency SID Backup Info TE
                                            
                                            .. attribute:: backup_label_stack_size
                                            
                                            	Number of labels in the backup path label stack
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: backup_node_address
                                            
                                            	Neighbor address used as adjacency backup target
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_nexthop
                                            
                                            	Backup path nexthop address
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_interface
                                            
                                            	Backup path interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: backup_label_stack
                                            
                                            	Backup path label stack
                                            	**type**\: list of  		 :py:class:`BackupLabelStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe.BackupLabelStack>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe, self).__init__()

                                                self.yang_name = "adjacency-sid-backup-te"
                                                self.yang_parent_name = "non-frr-adjacency-sid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("backup-label-stack", ("backup_label_stack", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe.BackupLabelStack))])
                                                self._leafs = OrderedDict([
                                                    ('backup_label_stack_size', (YLeaf(YType.uint8, 'backup-label-stack-size'), ['int'])),
                                                    ('backup_node_address', (YLeaf(YType.str, 'backup-node-address'), ['str'])),
                                                    ('backup_nexthop', (YLeaf(YType.str, 'backup-nexthop'), ['str'])),
                                                    ('backup_interface', (YLeaf(YType.str, 'backup-interface'), ['str'])),
                                                ])
                                                self.backup_label_stack_size = None
                                                self.backup_node_address = None
                                                self.backup_nexthop = None
                                                self.backup_interface = None

                                                self.backup_label_stack = YList(self)
                                                self._segment_path = lambda: "adjacency-sid-backup-te"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe, [u'backup_label_stack_size', u'backup_node_address', u'backup_nexthop', u'backup_interface'], name, value)


                                            class BackupLabelStack(Entity):
                                                """
                                                Backup path label stack
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe.BackupLabelStack, self).__init__()

                                                    self.yang_name = "backup-label-stack"
                                                    self.yang_parent_name = "adjacency-sid-backup-te"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "backup-label-stack"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrAdjacencySid.AdjacencySidBackupTe.BackupLabelStack, [u'entry'], name, value)


                                    class EndXsid(Entity):
                                        """
                                        SRv6 End.X SID
                                        
                                        .. attribute:: end_xsid
                                        
                                        	End.X SID value
                                        	**type**\:  :py:class:`EndXsid_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.EndXsid.EndXsid_>`
                                        
                                        .. attribute:: end_xsid_backup
                                        
                                        	End.X SID Backup Info
                                        	**type**\:  :py:class:`EndXsidBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.EndXsid.EndXsidBackup>`
                                        
                                        .. attribute:: end_xsid_function
                                        
                                        	End.X SID Function
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.EndXsid, self).__init__()

                                            self.yang_name = "end-xsid"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("end-xsid", ("end_xsid", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.EndXsid.EndXsid_)), ("end-xsid-backup", ("end_xsid_backup", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.EndXsid.EndXsidBackup))])
                                            self._leafs = OrderedDict([
                                                ('end_xsid_function', (YLeaf(YType.uint16, 'end-xsid-function'), ['int'])),
                                            ])
                                            self.end_xsid_function = None

                                            self.end_xsid = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.EndXsid.EndXsid_()
                                            self.end_xsid.parent = self
                                            self._children_name_map["end_xsid"] = "end-xsid"

                                            self.end_xsid_backup = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.EndXsid.EndXsidBackup()
                                            self.end_xsid_backup.parent = self
                                            self._children_name_map["end_xsid_backup"] = "end-xsid-backup"
                                            self._segment_path = lambda: "end-xsid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.EndXsid, [u'end_xsid_function'], name, value)


                                        class EndXsid_(Entity):
                                            """
                                            End.X SID value
                                            
                                            .. attribute:: prefix
                                            
                                            	prefix
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	prefix length
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.EndXsid.EndXsid_, self).__init__()

                                                self.yang_name = "end-xsid"
                                                self.yang_parent_name = "end-xsid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                    ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                ])
                                                self.prefix = None
                                                self.prefix_length = None
                                                self._segment_path = lambda: "end-xsid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.EndXsid.EndXsid_, [u'prefix', u'prefix_length'], name, value)


                                        class EndXsidBackup(Entity):
                                            """
                                            End.X SID Backup Info
                                            
                                            .. attribute:: backup_stack_size
                                            
                                            	Number of SIDs in the backup path stack
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: backup_node_address
                                            
                                            	Neighbor address used as adjacency backup target
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_nexthop
                                            
                                            	Backup path nexthop address
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_interface
                                            
                                            	Backup path interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: backup_stack
                                            
                                            	Backup path SID stack
                                            	**type**\: list of  		 :py:class:`BackupStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.EndXsid.EndXsidBackup.BackupStack>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.EndXsid.EndXsidBackup, self).__init__()

                                                self.yang_name = "end-xsid-backup"
                                                self.yang_parent_name = "end-xsid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("backup-stack", ("backup_stack", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.EndXsid.EndXsidBackup.BackupStack))])
                                                self._leafs = OrderedDict([
                                                    ('backup_stack_size', (YLeaf(YType.uint8, 'backup-stack-size'), ['int'])),
                                                    ('backup_node_address', (YLeaf(YType.str, 'backup-node-address'), ['str'])),
                                                    ('backup_nexthop', (YLeaf(YType.str, 'backup-nexthop'), ['str'])),
                                                    ('backup_interface', (YLeaf(YType.str, 'backup-interface'), ['str'])),
                                                ])
                                                self.backup_stack_size = None
                                                self.backup_node_address = None
                                                self.backup_nexthop = None
                                                self.backup_interface = None

                                                self.backup_stack = YList(self)
                                                self._segment_path = lambda: "end-xsid-backup"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.EndXsid.EndXsidBackup, [u'backup_stack_size', u'backup_node_address', u'backup_nexthop', u'backup_interface'], name, value)


                                            class BackupStack(Entity):
                                                """
                                                Backup path SID stack
                                                
                                                .. attribute:: prefix
                                                
                                                	prefix
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.EndXsid.EndXsidBackup.BackupStack, self).__init__()

                                                    self.yang_name = "backup-stack"
                                                    self.yang_parent_name = "end-xsid-backup"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                        ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                    ])
                                                    self.prefix = None
                                                    self.prefix_length = None
                                                    self._segment_path = lambda: "backup-stack"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.EndXsid.EndXsidBackup.BackupStack, [u'prefix', u'prefix_length'], name, value)


                                    class NonFrrEndXsid(Entity):
                                        """
                                        SRv6 End.X SID not eligible for FRR protection
                                        
                                        .. attribute:: end_xsid
                                        
                                        	End.X SID value
                                        	**type**\:  :py:class:`EndXsid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrEndXsid.EndXsid>`
                                        
                                        .. attribute:: end_xsid_backup
                                        
                                        	End.X SID Backup Info
                                        	**type**\:  :py:class:`EndXsidBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrEndXsid.EndXsidBackup>`
                                        
                                        .. attribute:: end_xsid_function
                                        
                                        	End.X SID Function
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrEndXsid, self).__init__()

                                            self.yang_name = "non-frr-end-xsid"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("end-xsid", ("end_xsid", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrEndXsid.EndXsid)), ("end-xsid-backup", ("end_xsid_backup", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrEndXsid.EndXsidBackup))])
                                            self._leafs = OrderedDict([
                                                ('end_xsid_function', (YLeaf(YType.uint16, 'end-xsid-function'), ['int'])),
                                            ])
                                            self.end_xsid_function = None

                                            self.end_xsid = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrEndXsid.EndXsid()
                                            self.end_xsid.parent = self
                                            self._children_name_map["end_xsid"] = "end-xsid"

                                            self.end_xsid_backup = Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrEndXsid.EndXsidBackup()
                                            self.end_xsid_backup.parent = self
                                            self._children_name_map["end_xsid_backup"] = "end-xsid-backup"
                                            self._segment_path = lambda: "non-frr-end-xsid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrEndXsid, [u'end_xsid_function'], name, value)


                                        class EndXsid(Entity):
                                            """
                                            End.X SID value
                                            
                                            .. attribute:: prefix
                                            
                                            	prefix
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	prefix length
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrEndXsid.EndXsid, self).__init__()

                                                self.yang_name = "end-xsid"
                                                self.yang_parent_name = "non-frr-end-xsid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                    ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                ])
                                                self.prefix = None
                                                self.prefix_length = None
                                                self._segment_path = lambda: "end-xsid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrEndXsid.EndXsid, [u'prefix', u'prefix_length'], name, value)


                                        class EndXsidBackup(Entity):
                                            """
                                            End.X SID Backup Info
                                            
                                            .. attribute:: backup_stack_size
                                            
                                            	Number of SIDs in the backup path stack
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: backup_node_address
                                            
                                            	Neighbor address used as adjacency backup target
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_nexthop
                                            
                                            	Backup path nexthop address
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: backup_interface
                                            
                                            	Backup path interface
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                            
                                            .. attribute:: backup_stack
                                            
                                            	Backup path SID stack
                                            	**type**\: list of  		 :py:class:`BackupStack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrEndXsid.EndXsidBackup.BackupStack>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrEndXsid.EndXsidBackup, self).__init__()

                                                self.yang_name = "end-xsid-backup"
                                                self.yang_parent_name = "non-frr-end-xsid"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("backup-stack", ("backup_stack", Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrEndXsid.EndXsidBackup.BackupStack))])
                                                self._leafs = OrderedDict([
                                                    ('backup_stack_size', (YLeaf(YType.uint8, 'backup-stack-size'), ['int'])),
                                                    ('backup_node_address', (YLeaf(YType.str, 'backup-node-address'), ['str'])),
                                                    ('backup_nexthop', (YLeaf(YType.str, 'backup-nexthop'), ['str'])),
                                                    ('backup_interface', (YLeaf(YType.str, 'backup-interface'), ['str'])),
                                                ])
                                                self.backup_stack_size = None
                                                self.backup_node_address = None
                                                self.backup_nexthop = None
                                                self.backup_interface = None

                                                self.backup_stack = YList(self)
                                                self._segment_path = lambda: "end-xsid-backup"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrEndXsid.EndXsidBackup, [u'backup_stack_size', u'backup_node_address', u'backup_nexthop', u'backup_interface'], name, value)


                                            class BackupStack(Entity):
                                                """
                                                Backup path SID stack
                                                
                                                .. attribute:: prefix
                                                
                                                	prefix
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrEndXsid.EndXsidBackup.BackupStack, self).__init__()

                                                    self.yang_name = "backup-stack"
                                                    self.yang_parent_name = "end-xsid-backup"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                        ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                    ])
                                                    self.prefix = None
                                                    self.prefix_length = None
                                                    self._segment_path = lambda: "backup-stack"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.NonFrrEndXsid.EndXsidBackup.BackupStack, [u'prefix', u'prefix_length'], name, value)


                                    class InterfaceAddress(Entity):
                                        """
                                        Adjacency interface addresses
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.InterfaceAddress, self).__init__()

                                            self.yang_name = "interface-address"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "interface-address"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.InterfaceAddress, [u'entry'], name, value)


                                    class UnderlyingAdjacencySid(Entity):
                                        """
                                        Per bundle member Adjacency sid
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.UnderlyingAdjacencySid, self).__init__()

                                            self.yang_name = "underlying-adjacency-sid"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "underlying-adjacency-sid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.UnderlyingAdjacencySid, [u'entry'], name, value)


                                    class UnderlyingInterface(Entity):
                                        """
                                        Underlying interface list for bundle interfaces
                                        
                                        .. attribute:: interface_index
                                        
                                        	Local interface handle
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface_name
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.UnderlyingInterface, self).__init__()

                                            self.yang_name = "underlying-interface"
                                            self.yang_parent_name = "ipv6"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                                ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ])
                                            self.interface_index = None
                                            self.interface_name = None
                                            self._segment_path = lambda: "underlying-interface"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Levels.Level.Adjacencies.Adjacency.AdjacencyPerAddressFamilyData.Ipv6.UnderlyingInterface, [u'interface_index', u'interface_name'], name, value)


                    class DetailedLsps(Entity):
                        """
                        Detailed LSP table. Use to retrieve LSPs
                        with TLV content.
                        
                        .. attribute:: detailed_lsp
                        
                        	An IS\-IS LSP with detailed TLV data included
                        	**type**\: list of  		 :py:class:`DetailedLsp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.DetailedLsps.DetailedLsp>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.Levels.Level.DetailedLsps, self).__init__()

                            self.yang_name = "detailed-lsps"
                            self.yang_parent_name = "level"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("detailed-lsp", ("detailed_lsp", Isis.Instances.Instance.Levels.Level.DetailedLsps.DetailedLsp))])
                            self._leafs = OrderedDict()

                            self.detailed_lsp = YList(self)
                            self._segment_path = lambda: "detailed-lsps"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.Levels.Level.DetailedLsps, [], name, value)


                        class DetailedLsp(Entity):
                            """
                            An IS\-IS LSP with detailed TLV data
                            included
                            
                            .. attribute:: lsp_id  (key)
                            
                            	LSP ID
                            	**type**\: str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                            
                            .. attribute:: lsp_header_data
                            
                            	Information from the LSP header
                            	**type**\:  :py:class:`LspHeaderData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.DetailedLsps.DetailedLsp.LspHeaderData>`
                            
                            .. attribute:: lsp_body
                            
                            	LSP as received/sent over the wire, starting from the LSP ID field
                            	**type**\: str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.Levels.Level.DetailedLsps.DetailedLsp, self).__init__()

                                self.yang_name = "detailed-lsp"
                                self.yang_parent_name = "detailed-lsps"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['lsp_id']
                                self._child_classes = OrderedDict([("lsp-header-data", ("lsp_header_data", Isis.Instances.Instance.Levels.Level.DetailedLsps.DetailedLsp.LspHeaderData))])
                                self._leafs = OrderedDict([
                                    ('lsp_id', (YLeaf(YType.str, 'lsp-id'), ['str'])),
                                    ('lsp_body', (YLeaf(YType.str, 'lsp-body'), ['str'])),
                                ])
                                self.lsp_id = None
                                self.lsp_body = None

                                self.lsp_header_data = Isis.Instances.Instance.Levels.Level.DetailedLsps.DetailedLsp.LspHeaderData()
                                self.lsp_header_data.parent = self
                                self._children_name_map["lsp_header_data"] = "lsp-header-data"
                                self._segment_path = lambda: "detailed-lsp" + "[lsp-id='" + str(self.lsp_id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.Levels.Level.DetailedLsps.DetailedLsp, ['lsp_id', u'lsp_body'], name, value)


                            class LspHeaderData(Entity):
                                """
                                Information from the LSP header
                                
                                .. attribute:: lsp_id
                                
                                	The LSP ID
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                
                                .. attribute:: local_lsp_flag
                                
                                	TRUE if this is a locally generated LSP
                                	**type**\: bool
                                
                                .. attribute:: lsp_active_flag
                                
                                	TRUE if this LSP has not expired
                                	**type**\: bool
                                
                                .. attribute:: lsp_holdtime
                                
                                	Time, in seconds, until LSP expiry (if active) or deletion (if expired) 
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: lsp_rcvd_holdtime
                                
                                	Time, in seconds, for the received LSP it will be zero for the local LSP 
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: lsp_sequence_number
                                
                                	The LSP sequence number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsp_checksum
                                
                                	The LSP checksum
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lsp_partition_repair_supported_flag
                                
                                	TRUE if partition repair is supported
                                	**type**\: bool
                                
                                .. attribute:: lsp_attached_flag
                                
                                	TRUE if attached bit is set
                                	**type**\: bool
                                
                                .. attribute:: lsp_overloaded_flag
                                
                                	TRUE if the overload bit is set
                                	**type**\: bool
                                
                                .. attribute:: lsp_nonv1a_flag
                                
                                	TRUE if the LSP is non\-v1a, XXX for testing
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lsp_level
                                
                                	The type of the IS sourcing the LSP
                                	**type**\:  :py:class:`IsisLevels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevels>`
                                
                                .. attribute:: lsp_length
                                
                                	The total length of the LSP
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: max_area_addresses
                                
                                	max area addresses
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: id_length
                                
                                	System Id length
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: version
                                
                                	isis version
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: version2
                                
                                	isis version2
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Levels.Level.DetailedLsps.DetailedLsp.LspHeaderData, self).__init__()

                                    self.yang_name = "lsp-header-data"
                                    self.yang_parent_name = "detailed-lsp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lsp_id', (YLeaf(YType.str, 'lsp-id'), ['str'])),
                                        ('local_lsp_flag', (YLeaf(YType.boolean, 'local-lsp-flag'), ['bool'])),
                                        ('lsp_active_flag', (YLeaf(YType.boolean, 'lsp-active-flag'), ['bool'])),
                                        ('lsp_holdtime', (YLeaf(YType.uint16, 'lsp-holdtime'), ['int'])),
                                        ('lsp_rcvd_holdtime', (YLeaf(YType.uint16, 'lsp-rcvd-holdtime'), ['int'])),
                                        ('lsp_sequence_number', (YLeaf(YType.uint32, 'lsp-sequence-number'), ['int'])),
                                        ('lsp_checksum', (YLeaf(YType.uint16, 'lsp-checksum'), ['int'])),
                                        ('lsp_partition_repair_supported_flag', (YLeaf(YType.boolean, 'lsp-partition-repair-supported-flag'), ['bool'])),
                                        ('lsp_attached_flag', (YLeaf(YType.boolean, 'lsp-attached-flag'), ['bool'])),
                                        ('lsp_overloaded_flag', (YLeaf(YType.boolean, 'lsp-overloaded-flag'), ['bool'])),
                                        ('lsp_nonv1a_flag', (YLeaf(YType.uint16, 'lsp-nonv1a-flag'), ['int'])),
                                        ('lsp_level', (YLeaf(YType.enumeration, 'lsp-level'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisLevels', '')])),
                                        ('lsp_length', (YLeaf(YType.uint16, 'lsp-length'), ['int'])),
                                        ('max_area_addresses', (YLeaf(YType.uint8, 'max-area-addresses'), ['int'])),
                                        ('id_length', (YLeaf(YType.uint8, 'id-length'), ['int'])),
                                        ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                                        ('version2', (YLeaf(YType.uint8, 'version2'), ['int'])),
                                    ])
                                    self.lsp_id = None
                                    self.local_lsp_flag = None
                                    self.lsp_active_flag = None
                                    self.lsp_holdtime = None
                                    self.lsp_rcvd_holdtime = None
                                    self.lsp_sequence_number = None
                                    self.lsp_checksum = None
                                    self.lsp_partition_repair_supported_flag = None
                                    self.lsp_attached_flag = None
                                    self.lsp_overloaded_flag = None
                                    self.lsp_nonv1a_flag = None
                                    self.lsp_level = None
                                    self.lsp_length = None
                                    self.max_area_addresses = None
                                    self.id_length = None
                                    self.version = None
                                    self.version2 = None
                                    self._segment_path = lambda: "lsp-header-data"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Levels.Level.DetailedLsps.DetailedLsp.LspHeaderData, [u'lsp_id', u'local_lsp_flag', u'lsp_active_flag', u'lsp_holdtime', u'lsp_rcvd_holdtime', u'lsp_sequence_number', u'lsp_checksum', u'lsp_partition_repair_supported_flag', u'lsp_attached_flag', u'lsp_overloaded_flag', u'lsp_nonv1a_flag', u'lsp_level', u'lsp_length', u'max_area_addresses', u'id_length', u'version', u'version2'], name, value)


                    class Lsps(Entity):
                        """
                        LSP table
                        
                        .. attribute:: lsp
                        
                        	An IS\-IS LSP (header information only)
                        	**type**\: list of  		 :py:class:`Lsp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Lsps.Lsp>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.Levels.Level.Lsps, self).__init__()

                            self.yang_name = "lsps"
                            self.yang_parent_name = "level"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("lsp", ("lsp", Isis.Instances.Instance.Levels.Level.Lsps.Lsp))])
                            self._leafs = OrderedDict()

                            self.lsp = YList(self)
                            self._segment_path = lambda: "lsps"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.Levels.Level.Lsps, [], name, value)


                        class Lsp(Entity):
                            """
                            An IS\-IS LSP (header information only)
                            
                            .. attribute:: lsp_id  (key)
                            
                            	LSP ID
                            	**type**\: str
                            
                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                            
                            .. attribute:: lsp_header_data
                            
                            	Information from the LSP header
                            	**type**\:  :py:class:`LspHeaderData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.Lsps.Lsp.LspHeaderData>`
                            
                            .. attribute:: lsp_body
                            
                            	LSP as received/sent over the wire, starting from the LSP ID field
                            	**type**\: str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.Levels.Level.Lsps.Lsp, self).__init__()

                                self.yang_name = "lsp"
                                self.yang_parent_name = "lsps"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['lsp_id']
                                self._child_classes = OrderedDict([("lsp-header-data", ("lsp_header_data", Isis.Instances.Instance.Levels.Level.Lsps.Lsp.LspHeaderData))])
                                self._leafs = OrderedDict([
                                    ('lsp_id', (YLeaf(YType.str, 'lsp-id'), ['str'])),
                                    ('lsp_body', (YLeaf(YType.str, 'lsp-body'), ['str'])),
                                ])
                                self.lsp_id = None
                                self.lsp_body = None

                                self.lsp_header_data = Isis.Instances.Instance.Levels.Level.Lsps.Lsp.LspHeaderData()
                                self.lsp_header_data.parent = self
                                self._children_name_map["lsp_header_data"] = "lsp-header-data"
                                self._segment_path = lambda: "lsp" + "[lsp-id='" + str(self.lsp_id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.Levels.Level.Lsps.Lsp, ['lsp_id', u'lsp_body'], name, value)


                            class LspHeaderData(Entity):
                                """
                                Information from the LSP header
                                
                                .. attribute:: lsp_id
                                
                                	The LSP ID
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                
                                .. attribute:: local_lsp_flag
                                
                                	TRUE if this is a locally generated LSP
                                	**type**\: bool
                                
                                .. attribute:: lsp_active_flag
                                
                                	TRUE if this LSP has not expired
                                	**type**\: bool
                                
                                .. attribute:: lsp_holdtime
                                
                                	Time, in seconds, until LSP expiry (if active) or deletion (if expired) 
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: lsp_rcvd_holdtime
                                
                                	Time, in seconds, for the received LSP it will be zero for the local LSP 
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: lsp_sequence_number
                                
                                	The LSP sequence number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsp_checksum
                                
                                	The LSP checksum
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lsp_partition_repair_supported_flag
                                
                                	TRUE if partition repair is supported
                                	**type**\: bool
                                
                                .. attribute:: lsp_attached_flag
                                
                                	TRUE if attached bit is set
                                	**type**\: bool
                                
                                .. attribute:: lsp_overloaded_flag
                                
                                	TRUE if the overload bit is set
                                	**type**\: bool
                                
                                .. attribute:: lsp_nonv1a_flag
                                
                                	TRUE if the LSP is non\-v1a, XXX for testing
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lsp_level
                                
                                	The type of the IS sourcing the LSP
                                	**type**\:  :py:class:`IsisLevels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevels>`
                                
                                .. attribute:: lsp_length
                                
                                	The total length of the LSP
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: max_area_addresses
                                
                                	max area addresses
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: id_length
                                
                                	System Id length
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: version
                                
                                	isis version
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: version2
                                
                                	isis version2
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Levels.Level.Lsps.Lsp.LspHeaderData, self).__init__()

                                    self.yang_name = "lsp-header-data"
                                    self.yang_parent_name = "lsp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lsp_id', (YLeaf(YType.str, 'lsp-id'), ['str'])),
                                        ('local_lsp_flag', (YLeaf(YType.boolean, 'local-lsp-flag'), ['bool'])),
                                        ('lsp_active_flag', (YLeaf(YType.boolean, 'lsp-active-flag'), ['bool'])),
                                        ('lsp_holdtime', (YLeaf(YType.uint16, 'lsp-holdtime'), ['int'])),
                                        ('lsp_rcvd_holdtime', (YLeaf(YType.uint16, 'lsp-rcvd-holdtime'), ['int'])),
                                        ('lsp_sequence_number', (YLeaf(YType.uint32, 'lsp-sequence-number'), ['int'])),
                                        ('lsp_checksum', (YLeaf(YType.uint16, 'lsp-checksum'), ['int'])),
                                        ('lsp_partition_repair_supported_flag', (YLeaf(YType.boolean, 'lsp-partition-repair-supported-flag'), ['bool'])),
                                        ('lsp_attached_flag', (YLeaf(YType.boolean, 'lsp-attached-flag'), ['bool'])),
                                        ('lsp_overloaded_flag', (YLeaf(YType.boolean, 'lsp-overloaded-flag'), ['bool'])),
                                        ('lsp_nonv1a_flag', (YLeaf(YType.uint16, 'lsp-nonv1a-flag'), ['int'])),
                                        ('lsp_level', (YLeaf(YType.enumeration, 'lsp-level'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisLevels', '')])),
                                        ('lsp_length', (YLeaf(YType.uint16, 'lsp-length'), ['int'])),
                                        ('max_area_addresses', (YLeaf(YType.uint8, 'max-area-addresses'), ['int'])),
                                        ('id_length', (YLeaf(YType.uint8, 'id-length'), ['int'])),
                                        ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                                        ('version2', (YLeaf(YType.uint8, 'version2'), ['int'])),
                                    ])
                                    self.lsp_id = None
                                    self.local_lsp_flag = None
                                    self.lsp_active_flag = None
                                    self.lsp_holdtime = None
                                    self.lsp_rcvd_holdtime = None
                                    self.lsp_sequence_number = None
                                    self.lsp_checksum = None
                                    self.lsp_partition_repair_supported_flag = None
                                    self.lsp_attached_flag = None
                                    self.lsp_overloaded_flag = None
                                    self.lsp_nonv1a_flag = None
                                    self.lsp_level = None
                                    self.lsp_length = None
                                    self.max_area_addresses = None
                                    self.id_length = None
                                    self.version = None
                                    self.version2 = None
                                    self._segment_path = lambda: "lsp-header-data"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Levels.Level.Lsps.Lsp.LspHeaderData, [u'lsp_id', u'local_lsp_flag', u'lsp_active_flag', u'lsp_holdtime', u'lsp_rcvd_holdtime', u'lsp_sequence_number', u'lsp_checksum', u'lsp_partition_repair_supported_flag', u'lsp_attached_flag', u'lsp_overloaded_flag', u'lsp_nonv1a_flag', u'lsp_level', u'lsp_length', u'max_area_addresses', u'id_length', u'version', u'version2'], name, value)


                    class LspLog(Entity):
                        """
                        LSP\-log for a single level
                        
                        .. attribute:: log_entry
                        
                        	Log entries
                        	**type**\: list of  		 :py:class:`LogEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.LspLog.LogEntry>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.Levels.Level.LspLog, self).__init__()

                            self.yang_name = "lsp-log"
                            self.yang_parent_name = "level"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("log-entry", ("log_entry", Isis.Instances.Instance.Levels.Level.LspLog.LogEntry))])
                            self._leafs = OrderedDict()

                            self.log_entry = YList(self)
                            self._segment_path = lambda: "lsp-log"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.Levels.Level.LspLog, [], name, value)


                        class LogEntry(Entity):
                            """
                            Log entries
                            
                            .. attribute:: generic_data
                            
                            	Generic entry data
                            	**type**\:  :py:class:`GenericData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.LspLog.LogEntry.GenericData>`
                            
                            .. attribute:: trigger_count
                            
                            	Number of triggers on this run. May not be equal to the number of trigger event types if one or more trigger events has occurred more than once
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: delayed_trigger_count
                            
                            	Number of delayed triggers
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: log_interface
                            
                            	Appropriate interface, if any
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                            
                            .. attribute:: pseudo_node_number
                            
                            	Pseudo\-node number
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: trigger
                            
                            	Triggers applying to this log entry
                            	**type**\: list of  		 :py:class:`Trigger <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.LspLog.LogEntry.Trigger>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.Levels.Level.LspLog.LogEntry, self).__init__()

                                self.yang_name = "log-entry"
                                self.yang_parent_name = "lsp-log"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("generic-data", ("generic_data", Isis.Instances.Instance.Levels.Level.LspLog.LogEntry.GenericData)), ("trigger", ("trigger", Isis.Instances.Instance.Levels.Level.LspLog.LogEntry.Trigger))])
                                self._leafs = OrderedDict([
                                    ('trigger_count', (YLeaf(YType.uint32, 'trigger-count'), ['int'])),
                                    ('delayed_trigger_count', (YLeaf(YType.uint32, 'delayed-trigger-count'), ['int'])),
                                    ('log_interface', (YLeaf(YType.str, 'log-interface'), ['str'])),
                                    ('pseudo_node_number', (YLeaf(YType.uint8, 'pseudo-node-number'), ['int'])),
                                ])
                                self.trigger_count = None
                                self.delayed_trigger_count = None
                                self.log_interface = None
                                self.pseudo_node_number = None

                                self.generic_data = Isis.Instances.Instance.Levels.Level.LspLog.LogEntry.GenericData()
                                self.generic_data.parent = self
                                self._children_name_map["generic_data"] = "generic-data"

                                self.trigger = YList(self)
                                self._segment_path = lambda: "log-entry"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.Levels.Level.LspLog.LogEntry, [u'trigger_count', u'delayed_trigger_count', u'log_interface', u'pseudo_node_number'], name, value)


                            class GenericData(Entity):
                                """
                                Generic entry data
                                
                                .. attribute:: timestamp
                                
                                	Time in UTC relative to Jan 1st, 1970
                                	**type**\:  :py:class:`Timestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.LspLog.LogEntry.GenericData.Timestamp>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Levels.Level.LspLog.LogEntry.GenericData, self).__init__()

                                    self.yang_name = "generic-data"
                                    self.yang_parent_name = "log-entry"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("timestamp", ("timestamp", Isis.Instances.Instance.Levels.Level.LspLog.LogEntry.GenericData.Timestamp))])
                                    self._leafs = OrderedDict()

                                    self.timestamp = Isis.Instances.Instance.Levels.Level.LspLog.LogEntry.GenericData.Timestamp()
                                    self.timestamp.parent = self
                                    self._children_name_map["timestamp"] = "timestamp"
                                    self._segment_path = lambda: "generic-data"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Levels.Level.LspLog.LogEntry.GenericData, [], name, value)


                                class Timestamp(Entity):
                                    """
                                    Time in UTC relative to Jan 1st, 1970
                                    
                                    .. attribute:: seconds
                                    
                                    	Timestamp value (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nano_seconds
                                    
                                    	Timestamp value (nanoseconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Levels.Level.LspLog.LogEntry.GenericData.Timestamp, self).__init__()

                                        self.yang_name = "timestamp"
                                        self.yang_parent_name = "generic-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nano_seconds', (YLeaf(YType.uint32, 'nano-seconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nano_seconds = None
                                        self._segment_path = lambda: "timestamp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Levels.Level.LspLog.LogEntry.GenericData.Timestamp, [u'seconds', u'nano_seconds'], name, value)


                            class Trigger(Entity):
                                """
                                Triggers applying to this log entry.
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\:  :py:class:`IsisLspTrigger <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLspTrigger>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Levels.Level.LspLog.LogEntry.Trigger, self).__init__()

                                    self.yang_name = "trigger"
                                    self.yang_parent_name = "log-entry"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', (YLeaf(YType.enumeration, 'entry'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisLspTrigger', '')])),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "trigger"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Levels.Level.LspLog.LogEntry.Trigger, [u'entry'], name, value)


                    class DatabaseLog(Entity):
                        """
                        Database\-log for a single level
                        
                        .. attribute:: log_entry
                        
                        	Entries
                        	**type**\: list of  		 :py:class:`LogEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.Levels.Level.DatabaseLog, self).__init__()

                            self.yang_name = "database-log"
                            self.yang_parent_name = "level"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("log-entry", ("log_entry", Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry))])
                            self._leafs = OrderedDict()

                            self.log_entry = YList(self)
                            self._segment_path = lambda: "database-log"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.Levels.Level.DatabaseLog, [], name, value)


                        class LogEntry(Entity):
                            """
                            Entries
                            
                            .. attribute:: generic_data
                            
                            	Generic entry data
                            	**type**\:  :py:class:`GenericData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.GenericData>`
                            
                            .. attribute:: new_lsp_entry
                            
                            	Entry being inserted or the updated version of an old entry
                            	**type**\:  :py:class:`NewLspEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.NewLspEntry>`
                            
                            .. attribute:: old_lsp_entry
                            
                            	Entry being replaced
                            	**type**\:  :py:class:`OldLspEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.OldLspEntry>`
                            
                            .. attribute:: lspdb_operation
                            
                            	Operation applying to this entry
                            	**type**\:  :py:class:`IsisLspDbOp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLspDbOp>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry, self).__init__()

                                self.yang_name = "log-entry"
                                self.yang_parent_name = "database-log"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("generic-data", ("generic_data", Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.GenericData)), ("new-lsp-entry", ("new_lsp_entry", Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.NewLspEntry)), ("old-lsp-entry", ("old_lsp_entry", Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.OldLspEntry))])
                                self._leafs = OrderedDict([
                                    ('lspdb_operation', (YLeaf(YType.enumeration, 'lspdb-operation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisLspDbOp', '')])),
                                ])
                                self.lspdb_operation = None

                                self.generic_data = Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.GenericData()
                                self.generic_data.parent = self
                                self._children_name_map["generic_data"] = "generic-data"

                                self.new_lsp_entry = Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.NewLspEntry()
                                self.new_lsp_entry.parent = self
                                self._children_name_map["new_lsp_entry"] = "new-lsp-entry"

                                self.old_lsp_entry = Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.OldLspEntry()
                                self.old_lsp_entry.parent = self
                                self._children_name_map["old_lsp_entry"] = "old-lsp-entry"
                                self._segment_path = lambda: "log-entry"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry, [u'lspdb_operation'], name, value)


                            class GenericData(Entity):
                                """
                                Generic entry data
                                
                                .. attribute:: timestamp
                                
                                	Time in UTC relative to Jan 1st, 1970
                                	**type**\:  :py:class:`Timestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.GenericData.Timestamp>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.GenericData, self).__init__()

                                    self.yang_name = "generic-data"
                                    self.yang_parent_name = "log-entry"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("timestamp", ("timestamp", Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.GenericData.Timestamp))])
                                    self._leafs = OrderedDict()

                                    self.timestamp = Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.GenericData.Timestamp()
                                    self.timestamp.parent = self
                                    self._children_name_map["timestamp"] = "timestamp"
                                    self._segment_path = lambda: "generic-data"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.GenericData, [], name, value)


                                class Timestamp(Entity):
                                    """
                                    Time in UTC relative to Jan 1st, 1970
                                    
                                    .. attribute:: seconds
                                    
                                    	Timestamp value (seconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: nano_seconds
                                    
                                    	Timestamp value (nanoseconds)
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: nanosecond
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.GenericData.Timestamp, self).__init__()

                                        self.yang_name = "timestamp"
                                        self.yang_parent_name = "generic-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                            ('nano_seconds', (YLeaf(YType.uint32, 'nano-seconds'), ['int'])),
                                        ])
                                        self.seconds = None
                                        self.nano_seconds = None
                                        self._segment_path = lambda: "timestamp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.GenericData.Timestamp, [u'seconds', u'nano_seconds'], name, value)


                            class NewLspEntry(Entity):
                                """
                                Entry being inserted or the updated version of
                                an old entry.
                                
                                .. attribute:: lsp_id
                                
                                	The LSP ID
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                
                                .. attribute:: local_lsp_flag
                                
                                	TRUE if this is a locally generated LSP
                                	**type**\: bool
                                
                                .. attribute:: lsp_active_flag
                                
                                	TRUE if this LSP has not expired
                                	**type**\: bool
                                
                                .. attribute:: lsp_holdtime
                                
                                	Time, in seconds, until LSP expiry (if active) or deletion (if expired) 
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: lsp_rcvd_holdtime
                                
                                	Time, in seconds, for the received LSP it will be zero for the local LSP 
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: lsp_sequence_number
                                
                                	The LSP sequence number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsp_checksum
                                
                                	The LSP checksum
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lsp_partition_repair_supported_flag
                                
                                	TRUE if partition repair is supported
                                	**type**\: bool
                                
                                .. attribute:: lsp_attached_flag
                                
                                	TRUE if attached bit is set
                                	**type**\: bool
                                
                                .. attribute:: lsp_overloaded_flag
                                
                                	TRUE if the overload bit is set
                                	**type**\: bool
                                
                                .. attribute:: lsp_nonv1a_flag
                                
                                	TRUE if the LSP is non\-v1a, XXX for testing
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lsp_level
                                
                                	The type of the IS sourcing the LSP
                                	**type**\:  :py:class:`IsisLevels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevels>`
                                
                                .. attribute:: lsp_length
                                
                                	The total length of the LSP
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: max_area_addresses
                                
                                	max area addresses
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: id_length
                                
                                	System Id length
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: version
                                
                                	isis version
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: version2
                                
                                	isis version2
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.NewLspEntry, self).__init__()

                                    self.yang_name = "new-lsp-entry"
                                    self.yang_parent_name = "log-entry"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lsp_id', (YLeaf(YType.str, 'lsp-id'), ['str'])),
                                        ('local_lsp_flag', (YLeaf(YType.boolean, 'local-lsp-flag'), ['bool'])),
                                        ('lsp_active_flag', (YLeaf(YType.boolean, 'lsp-active-flag'), ['bool'])),
                                        ('lsp_holdtime', (YLeaf(YType.uint16, 'lsp-holdtime'), ['int'])),
                                        ('lsp_rcvd_holdtime', (YLeaf(YType.uint16, 'lsp-rcvd-holdtime'), ['int'])),
                                        ('lsp_sequence_number', (YLeaf(YType.uint32, 'lsp-sequence-number'), ['int'])),
                                        ('lsp_checksum', (YLeaf(YType.uint16, 'lsp-checksum'), ['int'])),
                                        ('lsp_partition_repair_supported_flag', (YLeaf(YType.boolean, 'lsp-partition-repair-supported-flag'), ['bool'])),
                                        ('lsp_attached_flag', (YLeaf(YType.boolean, 'lsp-attached-flag'), ['bool'])),
                                        ('lsp_overloaded_flag', (YLeaf(YType.boolean, 'lsp-overloaded-flag'), ['bool'])),
                                        ('lsp_nonv1a_flag', (YLeaf(YType.uint16, 'lsp-nonv1a-flag'), ['int'])),
                                        ('lsp_level', (YLeaf(YType.enumeration, 'lsp-level'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisLevels', '')])),
                                        ('lsp_length', (YLeaf(YType.uint16, 'lsp-length'), ['int'])),
                                        ('max_area_addresses', (YLeaf(YType.uint8, 'max-area-addresses'), ['int'])),
                                        ('id_length', (YLeaf(YType.uint8, 'id-length'), ['int'])),
                                        ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                                        ('version2', (YLeaf(YType.uint8, 'version2'), ['int'])),
                                    ])
                                    self.lsp_id = None
                                    self.local_lsp_flag = None
                                    self.lsp_active_flag = None
                                    self.lsp_holdtime = None
                                    self.lsp_rcvd_holdtime = None
                                    self.lsp_sequence_number = None
                                    self.lsp_checksum = None
                                    self.lsp_partition_repair_supported_flag = None
                                    self.lsp_attached_flag = None
                                    self.lsp_overloaded_flag = None
                                    self.lsp_nonv1a_flag = None
                                    self.lsp_level = None
                                    self.lsp_length = None
                                    self.max_area_addresses = None
                                    self.id_length = None
                                    self.version = None
                                    self.version2 = None
                                    self._segment_path = lambda: "new-lsp-entry"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.NewLspEntry, [u'lsp_id', u'local_lsp_flag', u'lsp_active_flag', u'lsp_holdtime', u'lsp_rcvd_holdtime', u'lsp_sequence_number', u'lsp_checksum', u'lsp_partition_repair_supported_flag', u'lsp_attached_flag', u'lsp_overloaded_flag', u'lsp_nonv1a_flag', u'lsp_level', u'lsp_length', u'max_area_addresses', u'id_length', u'version', u'version2'], name, value)


                            class OldLspEntry(Entity):
                                """
                                Entry being replaced.
                                
                                .. attribute:: lsp_id
                                
                                	The LSP ID
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                
                                .. attribute:: local_lsp_flag
                                
                                	TRUE if this is a locally generated LSP
                                	**type**\: bool
                                
                                .. attribute:: lsp_active_flag
                                
                                	TRUE if this LSP has not expired
                                	**type**\: bool
                                
                                .. attribute:: lsp_holdtime
                                
                                	Time, in seconds, until LSP expiry (if active) or deletion (if expired) 
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: lsp_rcvd_holdtime
                                
                                	Time, in seconds, for the received LSP it will be zero for the local LSP 
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                .. attribute:: lsp_sequence_number
                                
                                	The LSP sequence number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsp_checksum
                                
                                	The LSP checksum
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lsp_partition_repair_supported_flag
                                
                                	TRUE if partition repair is supported
                                	**type**\: bool
                                
                                .. attribute:: lsp_attached_flag
                                
                                	TRUE if attached bit is set
                                	**type**\: bool
                                
                                .. attribute:: lsp_overloaded_flag
                                
                                	TRUE if the overload bit is set
                                	**type**\: bool
                                
                                .. attribute:: lsp_nonv1a_flag
                                
                                	TRUE if the LSP is non\-v1a, XXX for testing
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: lsp_level
                                
                                	The type of the IS sourcing the LSP
                                	**type**\:  :py:class:`IsisLevels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevels>`
                                
                                .. attribute:: lsp_length
                                
                                	The total length of the LSP
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: max_area_addresses
                                
                                	max area addresses
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: id_length
                                
                                	System Id length
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: version
                                
                                	isis version
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: version2
                                
                                	isis version2
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.OldLspEntry, self).__init__()

                                    self.yang_name = "old-lsp-entry"
                                    self.yang_parent_name = "log-entry"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lsp_id', (YLeaf(YType.str, 'lsp-id'), ['str'])),
                                        ('local_lsp_flag', (YLeaf(YType.boolean, 'local-lsp-flag'), ['bool'])),
                                        ('lsp_active_flag', (YLeaf(YType.boolean, 'lsp-active-flag'), ['bool'])),
                                        ('lsp_holdtime', (YLeaf(YType.uint16, 'lsp-holdtime'), ['int'])),
                                        ('lsp_rcvd_holdtime', (YLeaf(YType.uint16, 'lsp-rcvd-holdtime'), ['int'])),
                                        ('lsp_sequence_number', (YLeaf(YType.uint32, 'lsp-sequence-number'), ['int'])),
                                        ('lsp_checksum', (YLeaf(YType.uint16, 'lsp-checksum'), ['int'])),
                                        ('lsp_partition_repair_supported_flag', (YLeaf(YType.boolean, 'lsp-partition-repair-supported-flag'), ['bool'])),
                                        ('lsp_attached_flag', (YLeaf(YType.boolean, 'lsp-attached-flag'), ['bool'])),
                                        ('lsp_overloaded_flag', (YLeaf(YType.boolean, 'lsp-overloaded-flag'), ['bool'])),
                                        ('lsp_nonv1a_flag', (YLeaf(YType.uint16, 'lsp-nonv1a-flag'), ['int'])),
                                        ('lsp_level', (YLeaf(YType.enumeration, 'lsp-level'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisLevels', '')])),
                                        ('lsp_length', (YLeaf(YType.uint16, 'lsp-length'), ['int'])),
                                        ('max_area_addresses', (YLeaf(YType.uint8, 'max-area-addresses'), ['int'])),
                                        ('id_length', (YLeaf(YType.uint8, 'id-length'), ['int'])),
                                        ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                                        ('version2', (YLeaf(YType.uint8, 'version2'), ['int'])),
                                    ])
                                    self.lsp_id = None
                                    self.local_lsp_flag = None
                                    self.lsp_active_flag = None
                                    self.lsp_holdtime = None
                                    self.lsp_rcvd_holdtime = None
                                    self.lsp_sequence_number = None
                                    self.lsp_checksum = None
                                    self.lsp_partition_repair_supported_flag = None
                                    self.lsp_attached_flag = None
                                    self.lsp_overloaded_flag = None
                                    self.lsp_nonv1a_flag = None
                                    self.lsp_level = None
                                    self.lsp_length = None
                                    self.max_area_addresses = None
                                    self.id_length = None
                                    self.version = None
                                    self.version2 = None
                                    self._segment_path = lambda: "old-lsp-entry"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Levels.Level.DatabaseLog.LogEntry.OldLspEntry, [u'lsp_id', u'local_lsp_flag', u'lsp_active_flag', u'lsp_holdtime', u'lsp_rcvd_holdtime', u'lsp_sequence_number', u'lsp_checksum', u'lsp_partition_repair_supported_flag', u'lsp_attached_flag', u'lsp_overloaded_flag', u'lsp_nonv1a_flag', u'lsp_level', u'lsp_length', u'max_area_addresses', u'id_length', u'version', u'version2'], name, value)


            class Topologies(Entity):
                """
                Topology table
                
                .. attribute:: topology
                
                	Per\-topology data
                	**type**\: list of  		 :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology>`
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2018-04-07'

                def __init__(self):
                    super(Isis.Instances.Instance.Topologies, self).__init__()

                    self.yang_name = "topologies"
                    self.yang_parent_name = "instance"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("topology", ("topology", Isis.Instances.Instance.Topologies.Topology))])
                    self._leafs = OrderedDict()

                    self.topology = YList(self)
                    self._segment_path = lambda: "topologies"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Isis.Instances.Instance.Topologies, [], name, value)


                class Topology(Entity):
                    """
                    Per\-topology data
                    
                    .. attribute:: ipv6_flex_route_tables
                    
                    	IPv6 Flex\-Algo local route tables
                    	**type**\:  :py:class:`Ipv6FlexRouteTables <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables>`
                    
                    .. attribute:: frr_summary
                    
                    	FRR summary information for a particular IS\-IS topology
                    	**type**\:  :py:class:`FrrSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.FrrSummary>`
                    
                    .. attribute:: srv6_locators
                    
                    	SRv6 Locator Table
                    	**type**\:  :py:class:`Srv6Locators <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Srv6Locators>`
                    
                    .. attribute:: topology_levels
                    
                    	Per\-topology level table
                    	**type**\:  :py:class:`TopologyLevels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels>`
                    
                    .. attribute:: ipv6_routes
                    
                    	IPv6 local route
                    	**type**\:  :py:class:`Ipv6Routes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes>`
                    
                    .. attribute:: ipv6frr_backups
                    
                    	IPv6 FRR table
                    	**type**\:  :py:class:`Ipv6frrBackups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups>`
                    
                    .. attribute:: ipv4frr_backups
                    
                    	IPv4 FRR table
                    	**type**\:  :py:class:`Ipv4frrBackups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups>`
                    
                    .. attribute:: ipv4_flex_route_tables
                    
                    	IPv4 Flex\-Algo local route tables
                    	**type**\:  :py:class:`Ipv4FlexRouteTables <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables>`
                    
                    .. attribute:: ipv4_routes
                    
                    	IPv4 local route table
                    	**type**\:  :py:class:`Ipv4Routes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes>`
                    
                    .. attribute:: af_name
                    
                    	Address family
                    	**type**\:  :py:class:`IsisAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_datatypes.IsisAddressFamily>`
                    
                    .. attribute:: saf_name
                    
                    	Sub address family
                    	**type**\:  :py:class:`IsisSubAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_datatypes.IsisSubAddressFamily>`
                    
                    .. attribute:: topology_name
                    
                    	Topology Name
                    	**type**\: str
                    
                    	**length:** 1..32
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2018-04-07'

                    def __init__(self):
                        super(Isis.Instances.Instance.Topologies.Topology, self).__init__()

                        self.yang_name = "topology"
                        self.yang_parent_name = "topologies"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ipv6-flex-route-tables", ("ipv6_flex_route_tables", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables)), ("frr-summary", ("frr_summary", Isis.Instances.Instance.Topologies.Topology.FrrSummary)), ("srv6-locators", ("srv6_locators", Isis.Instances.Instance.Topologies.Topology.Srv6Locators)), ("topology-levels", ("topology_levels", Isis.Instances.Instance.Topologies.Topology.TopologyLevels)), ("ipv6-routes", ("ipv6_routes", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes)), ("ipv6frr-backups", ("ipv6frr_backups", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups)), ("ipv4frr-backups", ("ipv4frr_backups", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups)), ("ipv4-flex-route-tables", ("ipv4_flex_route_tables", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables)), ("ipv4-routes", ("ipv4_routes", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes))])
                        self._leafs = OrderedDict([
                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_datatypes', 'IsisAddressFamily', '')])),
                            ('saf_name', (YLeaf(YType.enumeration, 'saf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_datatypes', 'IsisSubAddressFamily', '')])),
                            ('topology_name', (YLeaf(YType.str, 'topology-name'), ['str'])),
                        ])
                        self.af_name = None
                        self.saf_name = None
                        self.topology_name = None

                        self.ipv6_flex_route_tables = Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables()
                        self.ipv6_flex_route_tables.parent = self
                        self._children_name_map["ipv6_flex_route_tables"] = "ipv6-flex-route-tables"

                        self.frr_summary = Isis.Instances.Instance.Topologies.Topology.FrrSummary()
                        self.frr_summary.parent = self
                        self._children_name_map["frr_summary"] = "frr-summary"

                        self.srv6_locators = Isis.Instances.Instance.Topologies.Topology.Srv6Locators()
                        self.srv6_locators.parent = self
                        self._children_name_map["srv6_locators"] = "srv6-locators"

                        self.topology_levels = Isis.Instances.Instance.Topologies.Topology.TopologyLevels()
                        self.topology_levels.parent = self
                        self._children_name_map["topology_levels"] = "topology-levels"

                        self.ipv6_routes = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes()
                        self.ipv6_routes.parent = self
                        self._children_name_map["ipv6_routes"] = "ipv6-routes"

                        self.ipv6frr_backups = Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups()
                        self.ipv6frr_backups.parent = self
                        self._children_name_map["ipv6frr_backups"] = "ipv6frr-backups"

                        self.ipv4frr_backups = Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups()
                        self.ipv4frr_backups.parent = self
                        self._children_name_map["ipv4frr_backups"] = "ipv4frr-backups"

                        self.ipv4_flex_route_tables = Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables()
                        self.ipv4_flex_route_tables.parent = self
                        self._children_name_map["ipv4_flex_route_tables"] = "ipv4-flex-route-tables"

                        self.ipv4_routes = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes()
                        self.ipv4_routes.parent = self
                        self._children_name_map["ipv4_routes"] = "ipv4-routes"
                        self._segment_path = lambda: "topology"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology, ['af_name', 'saf_name', 'topology_name'], name, value)


                    class Ipv6FlexRouteTables(Entity):
                        """
                        IPv6 Flex\-Algo local route tables
                        
                        .. attribute:: ipv6_flex_route_table
                        
                        	IPv6 Flex\-Algo local route table
                        	**type**\: list of  		 :py:class:`Ipv6FlexRouteTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables, self).__init__()

                            self.yang_name = "ipv6-flex-route-tables"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv6-flex-route-table", ("ipv6_flex_route_table", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable))])
                            self._leafs = OrderedDict()

                            self.ipv6_flex_route_table = YList(self)
                            self._segment_path = lambda: "ipv6-flex-route-tables"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables, [], name, value)


                        class Ipv6FlexRouteTable(Entity):
                            """
                            IPv6 Flex\-Algo local route table
                            
                            .. attribute:: flex_alg  (key)
                            
                            	Flex Algo
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ipv6_flex_route
                            
                            	An IPv6 route known to IS\-IS
                            	**type**\: list of  		 :py:class:`Ipv6FlexRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable, self).__init__()

                                self.yang_name = "ipv6-flex-route-table"
                                self.yang_parent_name = "ipv6-flex-route-tables"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['flex_alg']
                                self._child_classes = OrderedDict([("ipv6-flex-route", ("ipv6_flex_route", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute))])
                                self._leafs = OrderedDict([
                                    ('flex_alg', (YLeaf(YType.uint32, 'flex-alg'), ['int'])),
                                ])
                                self.flex_alg = None

                                self.ipv6_flex_route = YList(self)
                                self._segment_path = lambda: "ipv6-flex-route-table" + "[flex-alg='" + str(self.flex_alg) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable, ['flex_alg'], name, value)


                            class Ipv6FlexRoute(Entity):
                                """
                                An IPv6 route known to IS\-IS
                                
                                .. attribute:: prefix
                                
                                	Prefix
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_length
                                
                                	Prefix Length
                                	**type**\: int
                                
                                	**range:** 0..128
                                
                                .. attribute:: connected_status
                                
                                	Status of IS\-IS directly connected routes to the prefix
                                	**type**\:  :py:class:`ConnectedStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.ConnectedStatus>`
                                
                                .. attribute:: redistributed_status
                                
                                	Status of other protocols' routes redistributed into IS\-IS
                                	**type**\:  :py:class:`RedistributedStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.RedistributedStatus>`
                                
                                .. attribute:: native_status
                                
                                	Status of native IS\-IS routes to the prefix
                                	**type**\:  :py:class:`NativeStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus>`
                                
                                .. attribute:: per_level_advertising_detail
                                
                                	Per level details of how the local system advertises the prefix
                                	**type**\: list of  		 :py:class:`PerLevelAdvertisingDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.PerLevelAdvertisingDetail>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute, self).__init__()

                                    self.yang_name = "ipv6-flex-route"
                                    self.yang_parent_name = "ipv6-flex-route-table"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("connected-status", ("connected_status", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.ConnectedStatus)), ("redistributed-status", ("redistributed_status", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.RedistributedStatus)), ("native-status", ("native_status", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus)), ("per-level-advertising-detail", ("per_level_advertising_detail", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.PerLevelAdvertisingDetail))])
                                    self._leafs = OrderedDict([
                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                        ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                    ])
                                    self.prefix = None
                                    self.prefix_length = None

                                    self.connected_status = Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.ConnectedStatus()
                                    self.connected_status.parent = self
                                    self._children_name_map["connected_status"] = "connected-status"

                                    self.redistributed_status = Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.RedistributedStatus()
                                    self.redistributed_status.parent = self
                                    self._children_name_map["redistributed_status"] = "redistributed-status"

                                    self.native_status = Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus()
                                    self.native_status.parent = self
                                    self._children_name_map["native_status"] = "native-status"

                                    self.per_level_advertising_detail = YList(self)
                                    self._segment_path = lambda: "ipv6-flex-route"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute, ['prefix', 'prefix_length'], name, value)


                                class ConnectedStatus(Entity):
                                    """
                                    Status of IS\-IS directly connected routes to the
                                    prefix
                                    
                                    .. attribute:: connected_details
                                    
                                    	Details of the directly connected prefix
                                    	**type**\:  :py:class:`ConnectedDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.ConnectedStatus.ConnectedDetails>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	IsValid
                                    	**type**\:  :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.ConnectedStatus, self).__init__()

                                        self.yang_name = "connected-status"
                                        self.yang_parent_name = "ipv6-flex-route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("connected-details", ("connected_details", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.ConnectedStatus.ConnectedDetails))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', (YLeaf(YType.enumeration, 'is-valid'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisValid', '')])),
                                        ])
                                        self.is_valid = None

                                        self.connected_details = Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.ConnectedStatus.ConnectedDetails()
                                        self.connected_details.parent = self
                                        self._children_name_map["connected_details"] = "connected-details"
                                        self._segment_path = lambda: "connected-status"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.ConnectedStatus, [u'is_valid'], name, value)


                                    class ConnectedDetails(Entity):
                                        """
                                        Details of the directly connected prefix
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.ConnectedStatus.ConnectedDetails.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.ConnectedStatus.ConnectedDetails, self).__init__()

                                            self.yang_name = "connected-details"
                                            self.yang_parent_name = "connected-status"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.ConnectedStatus.ConnectedDetails.Interface))])
                                            self._leafs = OrderedDict()

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "connected-details"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.ConnectedStatus.ConnectedDetails, [], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.ConnectedStatus.ConnectedDetails.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "connected-details"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "interface"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.ConnectedStatus.ConnectedDetails.Interface, [u'entry'], name, value)


                                class RedistributedStatus(Entity):
                                    """
                                    Status of other protocols' routes redistributed
                                    into IS\-IS
                                    
                                    .. attribute:: redistribution_details
                                    
                                    	Per level details of the redistributed route
                                    	**type**\:  :py:class:`RedistributionDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.RedistributedStatus.RedistributionDetails>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	IsValid
                                    	**type**\:  :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.RedistributedStatus, self).__init__()

                                        self.yang_name = "redistributed-status"
                                        self.yang_parent_name = "ipv6-flex-route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("redistribution-details", ("redistribution_details", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.RedistributedStatus.RedistributionDetails))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', (YLeaf(YType.enumeration, 'is-valid'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisValid', '')])),
                                        ])
                                        self.is_valid = None

                                        self.redistribution_details = Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.RedistributedStatus.RedistributionDetails()
                                        self.redistribution_details.parent = self
                                        self._children_name_map["redistribution_details"] = "redistribution-details"
                                        self._segment_path = lambda: "redistributed-status"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.RedistributedStatus, [u'is_valid'], name, value)


                                    class RedistributionDetails(Entity):
                                        """
                                        Per level details of the redistributed route
                                        
                                        .. attribute:: isis_sh_route_redist_detail
                                        
                                        	isis sh route redist detail
                                        	**type**\: list of  		 :py:class:`IsisShRouteRedistDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.RedistributedStatus.RedistributionDetails, self).__init__()

                                            self.yang_name = "redistribution-details"
                                            self.yang_parent_name = "redistributed-status"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("isis-sh-route-redist-detail", ("isis_sh_route_redist_detail", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail))])
                                            self._leafs = OrderedDict()

                                            self.isis_sh_route_redist_detail = YList(self)
                                            self._segment_path = lambda: "redistribution-details"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.RedistributedStatus.RedistributionDetails, [], name, value)


                                        class IsisShRouteRedistDetail(Entity):
                                            """
                                            isis sh route redist detail
                                            
                                            .. attribute:: owner
                                            
                                            	Protocol redistributing the route
                                            	**type**\:  :py:class:`Owner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner>`
                                            
                                            .. attribute:: level
                                            
                                            	Level into which the route is redistributed
                                            	**type**\:  :py:class:`IsisLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevel>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail, self).__init__()

                                                self.yang_name = "isis-sh-route-redist-detail"
                                                self.yang_parent_name = "redistribution-details"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("owner", ("owner", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner))])
                                                self._leafs = OrderedDict([
                                                    ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisLevel', '')])),
                                                ])
                                                self.level = None

                                                self.owner = Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner()
                                                self.owner.parent = self
                                                self._children_name_map["owner"] = "owner"
                                                self._segment_path = lambda: "isis-sh-route-redist-detail"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail, [u'level'], name, value)


                                            class Owner(Entity):
                                                """
                                                Protocol redistributing the route
                                                
                                                .. attribute:: protocol
                                                
                                                	Protocol
                                                	**type**\:  :py:class:`IsisRedistProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisRedistProto>`
                                                
                                                .. attribute:: isis_instance_id
                                                
                                                	IS\-IS instance identifier
                                                	**type**\: str
                                                
                                                .. attribute:: ospf_process_id
                                                
                                                	OSPF process identifier
                                                	**type**\: str
                                                
                                                .. attribute:: ospfv3_process_id
                                                
                                                	OSPFv3 process identifier
                                                	**type**\: str
                                                
                                                .. attribute:: bgp_as_number
                                                
                                                	BGP Autonomous System number
                                                	**type**\: str
                                                
                                                .. attribute:: eigrp_as_number
                                                
                                                	EIGRP Autonomous System number
                                                	**type**\: str
                                                
                                                .. attribute:: application_name
                                                
                                                	Application Name
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner, self).__init__()

                                                    self.yang_name = "owner"
                                                    self.yang_parent_name = "isis-sh-route-redist-detail"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisRedistProto', '')])),
                                                        ('isis_instance_id', (YLeaf(YType.str, 'isis-instance-id'), ['str'])),
                                                        ('ospf_process_id', (YLeaf(YType.str, 'ospf-process-id'), ['str'])),
                                                        ('ospfv3_process_id', (YLeaf(YType.str, 'ospfv3-process-id'), ['str'])),
                                                        ('bgp_as_number', (YLeaf(YType.str, 'bgp-as-number'), ['str'])),
                                                        ('eigrp_as_number', (YLeaf(YType.str, 'eigrp-as-number'), ['str'])),
                                                        ('application_name', (YLeaf(YType.str, 'application-name'), ['str'])),
                                                    ])
                                                    self.protocol = None
                                                    self.isis_instance_id = None
                                                    self.ospf_process_id = None
                                                    self.ospfv3_process_id = None
                                                    self.bgp_as_number = None
                                                    self.eigrp_as_number = None
                                                    self.application_name = None
                                                    self._segment_path = lambda: "owner"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner, [u'protocol', u'isis_instance_id', u'ospf_process_id', u'ospfv3_process_id', u'bgp_as_number', u'eigrp_as_number', u'application_name'], name, value)


                                class NativeStatus(Entity):
                                    """
                                    Status of native IS\-IS routes to the prefix
                                    
                                    .. attribute:: native_details
                                    
                                    	Details of the native route
                                    	**type**\:  :py:class:`NativeDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	IsValid
                                    	**type**\:  :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus, self).__init__()

                                        self.yang_name = "native-status"
                                        self.yang_parent_name = "ipv6-flex-route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("native-details", ("native_details", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', (YLeaf(YType.enumeration, 'is-valid'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisValid', '')])),
                                        ])
                                        self.is_valid = None

                                        self.native_details = Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails()
                                        self.native_details.parent = self
                                        self._children_name_map["native_details"] = "native-details"
                                        self._segment_path = lambda: "native-status"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus, [u'is_valid'], name, value)


                                    class NativeDetails(Entity):
                                        """
                                        Details of the native route
                                        
                                        .. attribute:: primary
                                        
                                        	Primary paths to prefix
                                        	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary>`
                                        
                                        .. attribute:: priority
                                        
                                        	Relative importance of the prefix
                                        	**type**\:  :py:class:`IsisPrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisPrefixPriority>`
                                        
                                        .. attribute:: backup
                                        
                                        	Backup paths to prefix
                                        	**type**\: list of  		 :py:class:`Backup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails, self).__init__()

                                            self.yang_name = "native-details"
                                            self.yang_parent_name = "native-status"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("primary", ("primary", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary)), ("backup", ("backup", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup))])
                                            self._leafs = OrderedDict([
                                                ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisPrefixPriority', '')])),
                                            ])
                                            self.priority = None

                                            self.primary = Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary()
                                            self.primary.parent = self
                                            self._children_name_map["primary"] = "primary"

                                            self.backup = YList(self)
                                            self._segment_path = lambda: "native-details"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails, [u'priority'], name, value)


                                        class Primary(Entity):
                                            """
                                            Primary paths to prefix
                                            
                                            .. attribute:: origin
                                            
                                            	Origin of route
                                            	**type**\:  :py:class:`IsisPrefixOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisPrefixOrigin>`
                                            
                                            .. attribute:: metric
                                            
                                            	Distance to network
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: multicast_metric
                                            
                                            	Multicast\-intact distance to network
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_external_metric
                                            
                                            	Is the metric an external metric?
                                            	**type**\: bool
                                            
                                            .. attribute:: administrative_distance
                                            
                                            	Administrative Distance
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: paths
                                            
                                            	First hops toward the prefix
                                            	**type**\: list of  		 :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Paths>`
                                            
                                            .. attribute:: ucmp_next_hop
                                            
                                            	UCMP first hops toward the prefix
                                            	**type**\: list of  		 :py:class:`UcmpNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.UcmpNextHop>`
                                            
                                            .. attribute:: multicast_path
                                            
                                            	Multicast intact first hops toward the prefix
                                            	**type**\: list of  		 :py:class:`MulticastPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath>`
                                            
                                            .. attribute:: srte_path
                                            
                                            	SR\-TE native first hops toward the prefix
                                            	**type**\: list of  		 :py:class:`SrtePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath>`
                                            
                                            .. attribute:: explicit_path
                                            
                                            	SR microloop avoidance paths
                                            	**type**\: list of  		 :py:class:`ExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath>`
                                            
                                            .. attribute:: source
                                            
                                            	Sources advertising the prefix
                                            	**type**\: list of  		 :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Source>`
                                            
                                            .. attribute:: multicast_source
                                            
                                            	Multicast\-intact sources advertising the prefix
                                            	**type**\: list of  		 :py:class:`MulticastSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastSource>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary, self).__init__()

                                                self.yang_name = "primary"
                                                self.yang_parent_name = "native-details"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("paths", ("paths", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Paths)), ("ucmp-next-hop", ("ucmp_next_hop", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.UcmpNextHop)), ("multicast-path", ("multicast_path", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath)), ("srte-path", ("srte_path", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath)), ("explicit-path", ("explicit_path", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath)), ("source", ("source", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Source)), ("multicast-source", ("multicast_source", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastSource))])
                                                self._leafs = OrderedDict([
                                                    ('origin', (YLeaf(YType.enumeration, 'origin'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisPrefixOrigin', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('multicast_metric', (YLeaf(YType.uint32, 'multicast-metric'), ['int'])),
                                                    ('is_external_metric', (YLeaf(YType.boolean, 'is-external-metric'), ['bool'])),
                                                    ('administrative_distance', (YLeaf(YType.uint16, 'administrative-distance'), ['int'])),
                                                ])
                                                self.origin = None
                                                self.metric = None
                                                self.multicast_metric = None
                                                self.is_external_metric = None
                                                self.administrative_distance = None

                                                self.paths = YList(self)
                                                self.ucmp_next_hop = YList(self)
                                                self.multicast_path = YList(self)
                                                self.srte_path = YList(self)
                                                self.explicit_path = YList(self)
                                                self.source = YList(self)
                                                self.multicast_source = YList(self)
                                                self._segment_path = lambda: "primary"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary, [u'origin', u'metric', u'multicast_metric', u'is_external_metric', u'administrative_distance'], name, value)


                                            class Paths(Entity):
                                                """
                                                First hops toward the prefix
                                                
                                                .. attribute:: frr_backup
                                                
                                                	FRR backup for this path
                                                	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Paths.FrrBackup>`
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: tag
                                                
                                                	Tag associated with the path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_interface
                                                
                                                	Explicit path tunnel interface
                                                	**type**\: str
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_te_tunnel_interface
                                                
                                                	Is path via a TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: is_sr_exclude_tunnel_interface
                                                
                                                	Is path via an SR\-exclude TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: uloop_explicit
                                                
                                                	Uloop Explicit List
                                                	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit>`
                                                
                                                .. attribute:: nnh
                                                
                                                	Next next hops
                                                	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Paths.Nnh>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Paths, self).__init__()

                                                    self.yang_name = "paths"
                                                    self.yang_parent_name = "primary"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Paths.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Paths.Nnh))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                        ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.neighbor_snpa = None
                                                    self.tag = None
                                                    self.tunnel_interface = None
                                                    self.segment_routing_sid_value = None
                                                    self.weight = None
                                                    self.is_te_tunnel_interface = None
                                                    self.is_sr_exclude_tunnel_interface = None

                                                    self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Paths.FrrBackup()
                                                    self.frr_backup.parent = self
                                                    self._children_name_map["frr_backup"] = "frr-backup"

                                                    self.uloop_explicit = YList(self)
                                                    self.nnh = YList(self)
                                                    self._segment_path = lambda: "paths"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Paths, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                                class FrrBackup(Entity):
                                                    """
                                                    FRR backup for this path
                                                    
                                                    .. attribute:: neighbor_id
                                                    
                                                    	Next hop neighbor ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: egress_interface
                                                    
                                                    	Interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Next hop neighbor's forwarding address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: tunnel_egress_interface
                                                    
                                                    	Tunnel interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_snpa
                                                    
                                                    	Next hop neighbor's SNPA
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_system_id
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_id
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: remote_lfa_system_pid
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_pid
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: total_backup_distance
                                                    
                                                    	Distance to the network via this backup path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value
                                                    
                                                    	Segment routing sid value received from first hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: num_sid
                                                    
                                                    	Number of SIDs in TI\-LFA/rLFA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_repair_list_size
                                                    
                                                    	Backup Repair List Size
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tilfa_computation
                                                    
                                                    	Ti LFA computation which provided backup path
                                                    	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                    
                                                    .. attribute:: prefix_source_node_id
                                                    
                                                    	PrefixSourceNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: is_downstream
                                                    
                                                    	Is the backup path via downstream node?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_lc_disjoint
                                                    
                                                    	Is the backup path line card disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_node_protecting
                                                    
                                                    	Is the backup path node protecting?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_primary_path
                                                    
                                                    	Is the backup path an ECMP to the network?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_srlg_disjoint
                                                    
                                                    	Is the backup path SRLG disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_remote_lfa
                                                    
                                                    	Is the backup path via a Remote LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_epcfrr_lfa
                                                    
                                                    	Is the backup path via a TI\-LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_strict_spflfa
                                                    
                                                    	Is the backup path TI\-LFA strict SPF?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_requested
                                                    
                                                    	Is SR TE tunnel requested
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight configured on the interface
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value_entry
                                                    
                                                    	Segment routing sid values for TI\-LFA/rLFA
                                                    	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry>`
                                                    
                                                    .. attribute:: backup_repair
                                                    
                                                    	BAckup Repair List
                                                    	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Paths.FrrBackup, self).__init__()

                                                        self.yang_name = "frr-backup"
                                                        self.yang_parent_name = "paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair))])
                                                        self._leafs = OrderedDict([
                                                            ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                            ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                            ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                            ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                            ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                            ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                            ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                            ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                            ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                            ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                            ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                            ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                            ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                            ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                            ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                            ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                            ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                            ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                            ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                            ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                            ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                            ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                            ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                            ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ])
                                                        self.neighbor_id = None
                                                        self.egress_interface = None
                                                        self.neighbor_address = None
                                                        self.tunnel_egress_interface = None
                                                        self.neighbor_snpa = None
                                                        self.remote_lfa_system_id = None
                                                        self.remote_lfa_router_id = None
                                                        self.remote_lfa_system_pid = None
                                                        self.remote_lfa_router_pid = None
                                                        self.total_backup_distance = None
                                                        self.segment_routing_sid_value = None
                                                        self.num_sid = None
                                                        self.backup_repair_list_size = None
                                                        self.tilfa_computation = None
                                                        self.prefix_source_node_id = None
                                                        self.is_downstream = None
                                                        self.is_lc_disjoint = None
                                                        self.is_node_protecting = None
                                                        self.is_primary_path = None
                                                        self.is_srlg_disjoint = None
                                                        self.is_remote_lfa = None
                                                        self.is_epcfrr_lfa = None
                                                        self.is_strict_spflfa = None
                                                        self.is_tunnel_requested = None
                                                        self.weight = None

                                                        self.segment_routing_sid_value_entry = YList(self)
                                                        self.backup_repair = YList(self)
                                                        self._segment_path = lambda: "frr-backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Paths.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                    class SegmentRoutingSidValueEntry(Entity):
                                                        """
                                                        Segment routing sid values for TI\-LFA/rLFA
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                            self.yang_name = "segment-routing-sid-value-entry"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                    class BackupRepair(Entity):
                                                        """
                                                        BAckup Repair List
                                                        
                                                        .. attribute:: repair_element_node_id
                                                        
                                                        	RepairElementNodeID
                                                        	**type**\: str
                                                        
                                                        .. attribute:: repair_ipv4_addr
                                                        
                                                        	RepairIPv4Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_ipv6_addr
                                                        
                                                        	RepairIPv6Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_label
                                                        
                                                        	Repair Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_element_type
                                                        
                                                        	Repair Element Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_strict_spf_label
                                                        
                                                        	Repair Strict SPF Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair, self).__init__()

                                                            self.yang_name = "backup-repair"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                                ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                                ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                                ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                                ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                                ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                            ])
                                                            self.repair_element_node_id = None
                                                            self.repair_ipv4_addr = None
                                                            self.repair_ipv6_addr = None
                                                            self.repair_label = None
                                                            self.repair_element_type = None
                                                            self.repair_strict_spf_label = None
                                                            self._segment_path = lambda: "backup-repair"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class UloopExplicit(Entity):
                                                    """
                                                    Uloop Explicit List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit, self).__init__()

                                                        self.yang_name = "uloop-explicit"
                                                        self.yang_parent_name = "paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "uloop-explicit"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class Nnh(Entity):
                                                    """
                                                    Next next hops
                                                    
                                                    .. attribute:: link_id_set
                                                    
                                                    	If link\_id is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ipv4_set
                                                    
                                                    	If ipv4 address is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: link_id
                                                    
                                                    	link ID of the next next hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	Ipv4 address of the next next hop
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Paths.Nnh, self).__init__()

                                                        self.yang_name = "nnh"
                                                        self.yang_parent_name = "paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                            ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                            ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ])
                                                        self.link_id_set = None
                                                        self.ipv4_set = None
                                                        self.link_id = None
                                                        self.ipv4_address = None
                                                        self._segment_path = lambda: "nnh"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Paths.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                            class UcmpNextHop(Entity):
                                                """
                                                UCMP first hops toward the prefix
                                                
                                                .. attribute:: frr_backup
                                                
                                                	FRR backup for this path
                                                	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup>`
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: tag
                                                
                                                	Tag associated with the path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: total_ucmp_distance
                                                
                                                	Distance to the network via this UCMP next hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_te_tunnel_interface
                                                
                                                	Is path via a TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: is_sr_exclude_tunnel_interface
                                                
                                                	Is path via an SR\-exclude TE tunnel
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.UcmpNextHop, self).__init__()

                                                    self.yang_name = "ucmp-next-hop"
                                                    self.yang_parent_name = "primary"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('total_ucmp_distance', (YLeaf(YType.uint32, 'total-ucmp-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                        ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.neighbor_snpa = None
                                                    self.tag = None
                                                    self.total_ucmp_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.weight = None
                                                    self.is_te_tunnel_interface = None
                                                    self.is_sr_exclude_tunnel_interface = None

                                                    self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup()
                                                    self.frr_backup.parent = self
                                                    self._children_name_map["frr_backup"] = "frr-backup"
                                                    self._segment_path = lambda: "ucmp-next-hop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.UcmpNextHop, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'total_ucmp_distance', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                                class FrrBackup(Entity):
                                                    """
                                                    FRR backup for this path
                                                    
                                                    .. attribute:: neighbor_id
                                                    
                                                    	Next hop neighbor ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: egress_interface
                                                    
                                                    	Interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Next hop neighbor's forwarding address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: tunnel_egress_interface
                                                    
                                                    	Tunnel interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_snpa
                                                    
                                                    	Next hop neighbor's SNPA
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_system_id
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_id
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: remote_lfa_system_pid
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_pid
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: total_backup_distance
                                                    
                                                    	Distance to the network via this backup path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value
                                                    
                                                    	Segment routing sid value received from first hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: num_sid
                                                    
                                                    	Number of SIDs in TI\-LFA/rLFA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_repair_list_size
                                                    
                                                    	Backup Repair List Size
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tilfa_computation
                                                    
                                                    	Ti LFA computation which provided backup path
                                                    	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                    
                                                    .. attribute:: prefix_source_node_id
                                                    
                                                    	PrefixSourceNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: is_downstream
                                                    
                                                    	Is the backup path via downstream node?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_lc_disjoint
                                                    
                                                    	Is the backup path line card disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_node_protecting
                                                    
                                                    	Is the backup path node protecting?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_primary_path
                                                    
                                                    	Is the backup path an ECMP to the network?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_srlg_disjoint
                                                    
                                                    	Is the backup path SRLG disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_remote_lfa
                                                    
                                                    	Is the backup path via a Remote LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_epcfrr_lfa
                                                    
                                                    	Is the backup path via a TI\-LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_strict_spflfa
                                                    
                                                    	Is the backup path TI\-LFA strict SPF?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_requested
                                                    
                                                    	Is SR TE tunnel requested
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight configured on the interface
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value_entry
                                                    
                                                    	Segment routing sid values for TI\-LFA/rLFA
                                                    	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry>`
                                                    
                                                    .. attribute:: backup_repair
                                                    
                                                    	BAckup Repair List
                                                    	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup, self).__init__()

                                                        self.yang_name = "frr-backup"
                                                        self.yang_parent_name = "ucmp-next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair))])
                                                        self._leafs = OrderedDict([
                                                            ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                            ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                            ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                            ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                            ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                            ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                            ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                            ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                            ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                            ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                            ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                            ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                            ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                            ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                            ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                            ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                            ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                            ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                            ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                            ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                            ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                            ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                            ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                            ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ])
                                                        self.neighbor_id = None
                                                        self.egress_interface = None
                                                        self.neighbor_address = None
                                                        self.tunnel_egress_interface = None
                                                        self.neighbor_snpa = None
                                                        self.remote_lfa_system_id = None
                                                        self.remote_lfa_router_id = None
                                                        self.remote_lfa_system_pid = None
                                                        self.remote_lfa_router_pid = None
                                                        self.total_backup_distance = None
                                                        self.segment_routing_sid_value = None
                                                        self.num_sid = None
                                                        self.backup_repair_list_size = None
                                                        self.tilfa_computation = None
                                                        self.prefix_source_node_id = None
                                                        self.is_downstream = None
                                                        self.is_lc_disjoint = None
                                                        self.is_node_protecting = None
                                                        self.is_primary_path = None
                                                        self.is_srlg_disjoint = None
                                                        self.is_remote_lfa = None
                                                        self.is_epcfrr_lfa = None
                                                        self.is_strict_spflfa = None
                                                        self.is_tunnel_requested = None
                                                        self.weight = None

                                                        self.segment_routing_sid_value_entry = YList(self)
                                                        self.backup_repair = YList(self)
                                                        self._segment_path = lambda: "frr-backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                    class SegmentRoutingSidValueEntry(Entity):
                                                        """
                                                        Segment routing sid values for TI\-LFA/rLFA
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                            self.yang_name = "segment-routing-sid-value-entry"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                    class BackupRepair(Entity):
                                                        """
                                                        BAckup Repair List
                                                        
                                                        .. attribute:: repair_element_node_id
                                                        
                                                        	RepairElementNodeID
                                                        	**type**\: str
                                                        
                                                        .. attribute:: repair_ipv4_addr
                                                        
                                                        	RepairIPv4Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_ipv6_addr
                                                        
                                                        	RepairIPv6Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_label
                                                        
                                                        	Repair Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_element_type
                                                        
                                                        	Repair Element Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_strict_spf_label
                                                        
                                                        	Repair Strict SPF Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair, self).__init__()

                                                            self.yang_name = "backup-repair"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                                ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                                ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                                ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                                ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                                ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                            ])
                                                            self.repair_element_node_id = None
                                                            self.repair_ipv4_addr = None
                                                            self.repair_ipv6_addr = None
                                                            self.repair_label = None
                                                            self.repair_element_type = None
                                                            self.repair_strict_spf_label = None
                                                            self._segment_path = lambda: "backup-repair"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class MulticastPath(Entity):
                                                """
                                                Multicast intact first hops toward the prefix
                                                
                                                .. attribute:: frr_backup
                                                
                                                	FRR backup for this path
                                                	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup>`
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: tag
                                                
                                                	Tag associated with the path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_interface
                                                
                                                	Explicit path tunnel interface
                                                	**type**\: str
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_te_tunnel_interface
                                                
                                                	Is path via a TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: is_sr_exclude_tunnel_interface
                                                
                                                	Is path via an SR\-exclude TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: uloop_explicit
                                                
                                                	Uloop Explicit List
                                                	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit>`
                                                
                                                .. attribute:: nnh
                                                
                                                	Next next hops
                                                	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.Nnh>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath, self).__init__()

                                                    self.yang_name = "multicast-path"
                                                    self.yang_parent_name = "primary"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.Nnh))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                        ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.neighbor_snpa = None
                                                    self.tag = None
                                                    self.tunnel_interface = None
                                                    self.segment_routing_sid_value = None
                                                    self.weight = None
                                                    self.is_te_tunnel_interface = None
                                                    self.is_sr_exclude_tunnel_interface = None

                                                    self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup()
                                                    self.frr_backup.parent = self
                                                    self._children_name_map["frr_backup"] = "frr-backup"

                                                    self.uloop_explicit = YList(self)
                                                    self.nnh = YList(self)
                                                    self._segment_path = lambda: "multicast-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                                class FrrBackup(Entity):
                                                    """
                                                    FRR backup for this path
                                                    
                                                    .. attribute:: neighbor_id
                                                    
                                                    	Next hop neighbor ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: egress_interface
                                                    
                                                    	Interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Next hop neighbor's forwarding address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: tunnel_egress_interface
                                                    
                                                    	Tunnel interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_snpa
                                                    
                                                    	Next hop neighbor's SNPA
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_system_id
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_id
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: remote_lfa_system_pid
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_pid
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: total_backup_distance
                                                    
                                                    	Distance to the network via this backup path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value
                                                    
                                                    	Segment routing sid value received from first hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: num_sid
                                                    
                                                    	Number of SIDs in TI\-LFA/rLFA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_repair_list_size
                                                    
                                                    	Backup Repair List Size
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tilfa_computation
                                                    
                                                    	Ti LFA computation which provided backup path
                                                    	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                    
                                                    .. attribute:: prefix_source_node_id
                                                    
                                                    	PrefixSourceNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: is_downstream
                                                    
                                                    	Is the backup path via downstream node?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_lc_disjoint
                                                    
                                                    	Is the backup path line card disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_node_protecting
                                                    
                                                    	Is the backup path node protecting?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_primary_path
                                                    
                                                    	Is the backup path an ECMP to the network?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_srlg_disjoint
                                                    
                                                    	Is the backup path SRLG disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_remote_lfa
                                                    
                                                    	Is the backup path via a Remote LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_epcfrr_lfa
                                                    
                                                    	Is the backup path via a TI\-LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_strict_spflfa
                                                    
                                                    	Is the backup path TI\-LFA strict SPF?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_requested
                                                    
                                                    	Is SR TE tunnel requested
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight configured on the interface
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value_entry
                                                    
                                                    	Segment routing sid values for TI\-LFA/rLFA
                                                    	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                    
                                                    .. attribute:: backup_repair
                                                    
                                                    	BAckup Repair List
                                                    	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup, self).__init__()

                                                        self.yang_name = "frr-backup"
                                                        self.yang_parent_name = "multicast-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair))])
                                                        self._leafs = OrderedDict([
                                                            ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                            ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                            ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                            ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                            ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                            ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                            ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                            ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                            ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                            ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                            ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                            ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                            ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                            ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                            ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                            ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                            ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                            ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                            ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                            ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                            ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                            ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                            ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                            ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ])
                                                        self.neighbor_id = None
                                                        self.egress_interface = None
                                                        self.neighbor_address = None
                                                        self.tunnel_egress_interface = None
                                                        self.neighbor_snpa = None
                                                        self.remote_lfa_system_id = None
                                                        self.remote_lfa_router_id = None
                                                        self.remote_lfa_system_pid = None
                                                        self.remote_lfa_router_pid = None
                                                        self.total_backup_distance = None
                                                        self.segment_routing_sid_value = None
                                                        self.num_sid = None
                                                        self.backup_repair_list_size = None
                                                        self.tilfa_computation = None
                                                        self.prefix_source_node_id = None
                                                        self.is_downstream = None
                                                        self.is_lc_disjoint = None
                                                        self.is_node_protecting = None
                                                        self.is_primary_path = None
                                                        self.is_srlg_disjoint = None
                                                        self.is_remote_lfa = None
                                                        self.is_epcfrr_lfa = None
                                                        self.is_strict_spflfa = None
                                                        self.is_tunnel_requested = None
                                                        self.weight = None

                                                        self.segment_routing_sid_value_entry = YList(self)
                                                        self.backup_repair = YList(self)
                                                        self._segment_path = lambda: "frr-backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                    class SegmentRoutingSidValueEntry(Entity):
                                                        """
                                                        Segment routing sid values for TI\-LFA/rLFA
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                            self.yang_name = "segment-routing-sid-value-entry"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                    class BackupRepair(Entity):
                                                        """
                                                        BAckup Repair List
                                                        
                                                        .. attribute:: repair_element_node_id
                                                        
                                                        	RepairElementNodeID
                                                        	**type**\: str
                                                        
                                                        .. attribute:: repair_ipv4_addr
                                                        
                                                        	RepairIPv4Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_ipv6_addr
                                                        
                                                        	RepairIPv6Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_label
                                                        
                                                        	Repair Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_element_type
                                                        
                                                        	Repair Element Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_strict_spf_label
                                                        
                                                        	Repair Strict SPF Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair, self).__init__()

                                                            self.yang_name = "backup-repair"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                                ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                                ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                                ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                                ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                                ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                            ])
                                                            self.repair_element_node_id = None
                                                            self.repair_ipv4_addr = None
                                                            self.repair_ipv6_addr = None
                                                            self.repair_label = None
                                                            self.repair_element_type = None
                                                            self.repair_strict_spf_label = None
                                                            self._segment_path = lambda: "backup-repair"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class UloopExplicit(Entity):
                                                    """
                                                    Uloop Explicit List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit, self).__init__()

                                                        self.yang_name = "uloop-explicit"
                                                        self.yang_parent_name = "multicast-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "uloop-explicit"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class Nnh(Entity):
                                                    """
                                                    Next next hops
                                                    
                                                    .. attribute:: link_id_set
                                                    
                                                    	If link\_id is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ipv4_set
                                                    
                                                    	If ipv4 address is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: link_id
                                                    
                                                    	link ID of the next next hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	Ipv4 address of the next next hop
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.Nnh, self).__init__()

                                                        self.yang_name = "nnh"
                                                        self.yang_parent_name = "multicast-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                            ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                            ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ])
                                                        self.link_id_set = None
                                                        self.ipv4_set = None
                                                        self.link_id = None
                                                        self.ipv4_address = None
                                                        self._segment_path = lambda: "nnh"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                            class SrtePath(Entity):
                                                """
                                                SR\-TE native first hops toward the prefix
                                                
                                                .. attribute:: frr_backup
                                                
                                                	FRR backup for this path
                                                	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup>`
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: tag
                                                
                                                	Tag associated with the path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_interface
                                                
                                                	Explicit path tunnel interface
                                                	**type**\: str
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_te_tunnel_interface
                                                
                                                	Is path via a TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: is_sr_exclude_tunnel_interface
                                                
                                                	Is path via an SR\-exclude TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: uloop_explicit
                                                
                                                	Uloop Explicit List
                                                	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit>`
                                                
                                                .. attribute:: nnh
                                                
                                                	Next next hops
                                                	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.Nnh>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath, self).__init__()

                                                    self.yang_name = "srte-path"
                                                    self.yang_parent_name = "primary"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.Nnh))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                        ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.neighbor_snpa = None
                                                    self.tag = None
                                                    self.tunnel_interface = None
                                                    self.segment_routing_sid_value = None
                                                    self.weight = None
                                                    self.is_te_tunnel_interface = None
                                                    self.is_sr_exclude_tunnel_interface = None

                                                    self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup()
                                                    self.frr_backup.parent = self
                                                    self._children_name_map["frr_backup"] = "frr-backup"

                                                    self.uloop_explicit = YList(self)
                                                    self.nnh = YList(self)
                                                    self._segment_path = lambda: "srte-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                                class FrrBackup(Entity):
                                                    """
                                                    FRR backup for this path
                                                    
                                                    .. attribute:: neighbor_id
                                                    
                                                    	Next hop neighbor ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: egress_interface
                                                    
                                                    	Interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Next hop neighbor's forwarding address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: tunnel_egress_interface
                                                    
                                                    	Tunnel interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_snpa
                                                    
                                                    	Next hop neighbor's SNPA
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_system_id
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_id
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: remote_lfa_system_pid
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_pid
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: total_backup_distance
                                                    
                                                    	Distance to the network via this backup path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value
                                                    
                                                    	Segment routing sid value received from first hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: num_sid
                                                    
                                                    	Number of SIDs in TI\-LFA/rLFA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_repair_list_size
                                                    
                                                    	Backup Repair List Size
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tilfa_computation
                                                    
                                                    	Ti LFA computation which provided backup path
                                                    	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                    
                                                    .. attribute:: prefix_source_node_id
                                                    
                                                    	PrefixSourceNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: is_downstream
                                                    
                                                    	Is the backup path via downstream node?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_lc_disjoint
                                                    
                                                    	Is the backup path line card disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_node_protecting
                                                    
                                                    	Is the backup path node protecting?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_primary_path
                                                    
                                                    	Is the backup path an ECMP to the network?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_srlg_disjoint
                                                    
                                                    	Is the backup path SRLG disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_remote_lfa
                                                    
                                                    	Is the backup path via a Remote LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_epcfrr_lfa
                                                    
                                                    	Is the backup path via a TI\-LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_strict_spflfa
                                                    
                                                    	Is the backup path TI\-LFA strict SPF?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_requested
                                                    
                                                    	Is SR TE tunnel requested
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight configured on the interface
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value_entry
                                                    
                                                    	Segment routing sid values for TI\-LFA/rLFA
                                                    	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                    
                                                    .. attribute:: backup_repair
                                                    
                                                    	BAckup Repair List
                                                    	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup, self).__init__()

                                                        self.yang_name = "frr-backup"
                                                        self.yang_parent_name = "srte-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair))])
                                                        self._leafs = OrderedDict([
                                                            ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                            ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                            ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                            ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                            ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                            ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                            ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                            ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                            ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                            ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                            ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                            ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                            ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                            ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                            ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                            ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                            ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                            ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                            ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                            ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                            ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                            ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                            ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                            ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ])
                                                        self.neighbor_id = None
                                                        self.egress_interface = None
                                                        self.neighbor_address = None
                                                        self.tunnel_egress_interface = None
                                                        self.neighbor_snpa = None
                                                        self.remote_lfa_system_id = None
                                                        self.remote_lfa_router_id = None
                                                        self.remote_lfa_system_pid = None
                                                        self.remote_lfa_router_pid = None
                                                        self.total_backup_distance = None
                                                        self.segment_routing_sid_value = None
                                                        self.num_sid = None
                                                        self.backup_repair_list_size = None
                                                        self.tilfa_computation = None
                                                        self.prefix_source_node_id = None
                                                        self.is_downstream = None
                                                        self.is_lc_disjoint = None
                                                        self.is_node_protecting = None
                                                        self.is_primary_path = None
                                                        self.is_srlg_disjoint = None
                                                        self.is_remote_lfa = None
                                                        self.is_epcfrr_lfa = None
                                                        self.is_strict_spflfa = None
                                                        self.is_tunnel_requested = None
                                                        self.weight = None

                                                        self.segment_routing_sid_value_entry = YList(self)
                                                        self.backup_repair = YList(self)
                                                        self._segment_path = lambda: "frr-backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                    class SegmentRoutingSidValueEntry(Entity):
                                                        """
                                                        Segment routing sid values for TI\-LFA/rLFA
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                            self.yang_name = "segment-routing-sid-value-entry"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                    class BackupRepair(Entity):
                                                        """
                                                        BAckup Repair List
                                                        
                                                        .. attribute:: repair_element_node_id
                                                        
                                                        	RepairElementNodeID
                                                        	**type**\: str
                                                        
                                                        .. attribute:: repair_ipv4_addr
                                                        
                                                        	RepairIPv4Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_ipv6_addr
                                                        
                                                        	RepairIPv6Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_label
                                                        
                                                        	Repair Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_element_type
                                                        
                                                        	Repair Element Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_strict_spf_label
                                                        
                                                        	Repair Strict SPF Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair, self).__init__()

                                                            self.yang_name = "backup-repair"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                                ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                                ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                                ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                                ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                                ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                            ])
                                                            self.repair_element_node_id = None
                                                            self.repair_ipv4_addr = None
                                                            self.repair_ipv6_addr = None
                                                            self.repair_label = None
                                                            self.repair_element_type = None
                                                            self.repair_strict_spf_label = None
                                                            self._segment_path = lambda: "backup-repair"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class UloopExplicit(Entity):
                                                    """
                                                    Uloop Explicit List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit, self).__init__()

                                                        self.yang_name = "uloop-explicit"
                                                        self.yang_parent_name = "srte-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "uloop-explicit"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class Nnh(Entity):
                                                    """
                                                    Next next hops
                                                    
                                                    .. attribute:: link_id_set
                                                    
                                                    	If link\_id is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ipv4_set
                                                    
                                                    	If ipv4 address is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: link_id
                                                    
                                                    	link ID of the next next hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	Ipv4 address of the next next hop
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.Nnh, self).__init__()

                                                        self.yang_name = "nnh"
                                                        self.yang_parent_name = "srte-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                            ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                            ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ])
                                                        self.link_id_set = None
                                                        self.ipv4_set = None
                                                        self.link_id = None
                                                        self.ipv4_address = None
                                                        self._segment_path = lambda: "nnh"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                            class ExplicitPath(Entity):
                                                """
                                                SR microloop avoidance paths
                                                
                                                .. attribute:: frr_backup
                                                
                                                	FRR backup for this path
                                                	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup>`
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: tag
                                                
                                                	Tag associated with the path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_interface
                                                
                                                	Explicit path tunnel interface
                                                	**type**\: str
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_te_tunnel_interface
                                                
                                                	Is path via a TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: is_sr_exclude_tunnel_interface
                                                
                                                	Is path via an SR\-exclude TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: uloop_explicit
                                                
                                                	Uloop Explicit List
                                                	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit>`
                                                
                                                .. attribute:: nnh
                                                
                                                	Next next hops
                                                	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.Nnh>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath, self).__init__()

                                                    self.yang_name = "explicit-path"
                                                    self.yang_parent_name = "primary"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.Nnh))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                        ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.neighbor_snpa = None
                                                    self.tag = None
                                                    self.tunnel_interface = None
                                                    self.segment_routing_sid_value = None
                                                    self.weight = None
                                                    self.is_te_tunnel_interface = None
                                                    self.is_sr_exclude_tunnel_interface = None

                                                    self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup()
                                                    self.frr_backup.parent = self
                                                    self._children_name_map["frr_backup"] = "frr-backup"

                                                    self.uloop_explicit = YList(self)
                                                    self.nnh = YList(self)
                                                    self._segment_path = lambda: "explicit-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                                class FrrBackup(Entity):
                                                    """
                                                    FRR backup for this path
                                                    
                                                    .. attribute:: neighbor_id
                                                    
                                                    	Next hop neighbor ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: egress_interface
                                                    
                                                    	Interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Next hop neighbor's forwarding address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: tunnel_egress_interface
                                                    
                                                    	Tunnel interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_snpa
                                                    
                                                    	Next hop neighbor's SNPA
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_system_id
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_id
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: remote_lfa_system_pid
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_pid
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: total_backup_distance
                                                    
                                                    	Distance to the network via this backup path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value
                                                    
                                                    	Segment routing sid value received from first hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: num_sid
                                                    
                                                    	Number of SIDs in TI\-LFA/rLFA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_repair_list_size
                                                    
                                                    	Backup Repair List Size
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tilfa_computation
                                                    
                                                    	Ti LFA computation which provided backup path
                                                    	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                    
                                                    .. attribute:: prefix_source_node_id
                                                    
                                                    	PrefixSourceNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: is_downstream
                                                    
                                                    	Is the backup path via downstream node?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_lc_disjoint
                                                    
                                                    	Is the backup path line card disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_node_protecting
                                                    
                                                    	Is the backup path node protecting?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_primary_path
                                                    
                                                    	Is the backup path an ECMP to the network?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_srlg_disjoint
                                                    
                                                    	Is the backup path SRLG disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_remote_lfa
                                                    
                                                    	Is the backup path via a Remote LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_epcfrr_lfa
                                                    
                                                    	Is the backup path via a TI\-LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_strict_spflfa
                                                    
                                                    	Is the backup path TI\-LFA strict SPF?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_requested
                                                    
                                                    	Is SR TE tunnel requested
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight configured on the interface
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value_entry
                                                    
                                                    	Segment routing sid values for TI\-LFA/rLFA
                                                    	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                    
                                                    .. attribute:: backup_repair
                                                    
                                                    	BAckup Repair List
                                                    	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup, self).__init__()

                                                        self.yang_name = "frr-backup"
                                                        self.yang_parent_name = "explicit-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair))])
                                                        self._leafs = OrderedDict([
                                                            ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                            ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                            ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                            ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                            ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                            ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                            ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                            ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                            ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                            ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                            ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                            ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                            ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                            ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                            ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                            ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                            ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                            ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                            ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                            ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                            ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                            ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                            ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                            ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ])
                                                        self.neighbor_id = None
                                                        self.egress_interface = None
                                                        self.neighbor_address = None
                                                        self.tunnel_egress_interface = None
                                                        self.neighbor_snpa = None
                                                        self.remote_lfa_system_id = None
                                                        self.remote_lfa_router_id = None
                                                        self.remote_lfa_system_pid = None
                                                        self.remote_lfa_router_pid = None
                                                        self.total_backup_distance = None
                                                        self.segment_routing_sid_value = None
                                                        self.num_sid = None
                                                        self.backup_repair_list_size = None
                                                        self.tilfa_computation = None
                                                        self.prefix_source_node_id = None
                                                        self.is_downstream = None
                                                        self.is_lc_disjoint = None
                                                        self.is_node_protecting = None
                                                        self.is_primary_path = None
                                                        self.is_srlg_disjoint = None
                                                        self.is_remote_lfa = None
                                                        self.is_epcfrr_lfa = None
                                                        self.is_strict_spflfa = None
                                                        self.is_tunnel_requested = None
                                                        self.weight = None

                                                        self.segment_routing_sid_value_entry = YList(self)
                                                        self.backup_repair = YList(self)
                                                        self._segment_path = lambda: "frr-backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                    class SegmentRoutingSidValueEntry(Entity):
                                                        """
                                                        Segment routing sid values for TI\-LFA/rLFA
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                            self.yang_name = "segment-routing-sid-value-entry"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                    class BackupRepair(Entity):
                                                        """
                                                        BAckup Repair List
                                                        
                                                        .. attribute:: repair_element_node_id
                                                        
                                                        	RepairElementNodeID
                                                        	**type**\: str
                                                        
                                                        .. attribute:: repair_ipv4_addr
                                                        
                                                        	RepairIPv4Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_ipv6_addr
                                                        
                                                        	RepairIPv6Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_label
                                                        
                                                        	Repair Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_element_type
                                                        
                                                        	Repair Element Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_strict_spf_label
                                                        
                                                        	Repair Strict SPF Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair, self).__init__()

                                                            self.yang_name = "backup-repair"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                                ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                                ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                                ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                                ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                                ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                            ])
                                                            self.repair_element_node_id = None
                                                            self.repair_ipv4_addr = None
                                                            self.repair_ipv6_addr = None
                                                            self.repair_label = None
                                                            self.repair_element_type = None
                                                            self.repair_strict_spf_label = None
                                                            self._segment_path = lambda: "backup-repair"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class UloopExplicit(Entity):
                                                    """
                                                    Uloop Explicit List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit, self).__init__()

                                                        self.yang_name = "uloop-explicit"
                                                        self.yang_parent_name = "explicit-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "uloop-explicit"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class Nnh(Entity):
                                                    """
                                                    Next next hops
                                                    
                                                    .. attribute:: link_id_set
                                                    
                                                    	If link\_id is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ipv4_set
                                                    
                                                    	If ipv4 address is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: link_id
                                                    
                                                    	link ID of the next next hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	Ipv4 address of the next next hop
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.Nnh, self).__init__()

                                                        self.yang_name = "nnh"
                                                        self.yang_parent_name = "explicit-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                            ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                            ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ])
                                                        self.link_id_set = None
                                                        self.ipv4_set = None
                                                        self.link_id = None
                                                        self.ipv4_address = None
                                                        self._segment_path = lambda: "nnh"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                            class Source(Entity):
                                                """
                                                Sources advertising the prefix
                                                
                                                .. attribute:: source_lsp_id
                                                
                                                	ID of the LSP advertising the prefix
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                                
                                                .. attribute:: source_address
                                                
                                                	Source address of the IS advertising the prefix
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tags
                                                
                                                	Tags associated with the prefix item
                                                	**type**\: list of  		 :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Source.Tags>`
                                                
                                                .. attribute:: nodal_sid
                                                
                                                	Nodal SIDs with the prefix item
                                                	**type**\: list of  		 :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Source.NodalSid>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Source, self).__init__()

                                                    self.yang_name = "source"
                                                    self.yang_parent_name = "primary"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tags", ("tags", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Source.Tags)), ("nodal-sid", ("nodal_sid", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Source.NodalSid))])
                                                    self._leafs = OrderedDict([
                                                        ('source_lsp_id', (YLeaf(YType.str, 'source-lsp-id'), ['str'])),
                                                        ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                                    ])
                                                    self.source_lsp_id = None
                                                    self.source_address = None

                                                    self.tags = YList(self)
                                                    self.nodal_sid = YList(self)
                                                    self._segment_path = lambda: "source"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Source, [u'source_lsp_id', u'source_address'], name, value)


                                                class Tags(Entity):
                                                    """
                                                    Tags associated with the prefix item
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Source.Tags, self).__init__()

                                                        self.yang_name = "tags"
                                                        self.yang_parent_name = "source"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "tags"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Source.Tags, [u'entry'], name, value)


                                                class NodalSid(Entity):
                                                    """
                                                    Nodal SIDs with the prefix item
                                                    
                                                    .. attribute:: sid_value
                                                    
                                                    	sid value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rflag
                                                    
                                                    	rflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nflag
                                                    
                                                    	nflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pflag
                                                    
                                                    	pflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: eflag
                                                    
                                                    	eflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: vflag
                                                    
                                                    	vflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: lflag
                                                    
                                                    	lflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: algorithm
                                                    
                                                    	algorithm
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Source.NodalSid, self).__init__()

                                                        self.yang_name = "nodal-sid"
                                                        self.yang_parent_name = "source"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('sid_value', (YLeaf(YType.uint32, 'sid-value'), ['int'])),
                                                            ('rflag', (YLeaf(YType.uint8, 'rflag'), ['int'])),
                                                            ('nflag', (YLeaf(YType.uint8, 'nflag'), ['int'])),
                                                            ('pflag', (YLeaf(YType.uint8, 'pflag'), ['int'])),
                                                            ('eflag', (YLeaf(YType.uint8, 'eflag'), ['int'])),
                                                            ('vflag', (YLeaf(YType.uint8, 'vflag'), ['int'])),
                                                            ('lflag', (YLeaf(YType.uint8, 'lflag'), ['int'])),
                                                            ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                                        ])
                                                        self.sid_value = None
                                                        self.rflag = None
                                                        self.nflag = None
                                                        self.pflag = None
                                                        self.eflag = None
                                                        self.vflag = None
                                                        self.lflag = None
                                                        self.algorithm = None
                                                        self._segment_path = lambda: "nodal-sid"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.Source.NodalSid, [u'sid_value', u'rflag', u'nflag', u'pflag', u'eflag', u'vflag', u'lflag', u'algorithm'], name, value)


                                            class MulticastSource(Entity):
                                                """
                                                Multicast\-intact sources advertising the prefix
                                                
                                                .. attribute:: source_lsp_id
                                                
                                                	ID of the LSP advertising the prefix
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                                
                                                .. attribute:: source_address
                                                
                                                	Source address of the IS advertising the prefix
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tags
                                                
                                                	Tags associated with the prefix item
                                                	**type**\: list of  		 :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastSource.Tags>`
                                                
                                                .. attribute:: nodal_sid
                                                
                                                	Nodal SIDs with the prefix item
                                                	**type**\: list of  		 :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastSource, self).__init__()

                                                    self.yang_name = "multicast-source"
                                                    self.yang_parent_name = "primary"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tags", ("tags", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastSource.Tags)), ("nodal-sid", ("nodal_sid", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid))])
                                                    self._leafs = OrderedDict([
                                                        ('source_lsp_id', (YLeaf(YType.str, 'source-lsp-id'), ['str'])),
                                                        ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                                    ])
                                                    self.source_lsp_id = None
                                                    self.source_address = None

                                                    self.tags = YList(self)
                                                    self.nodal_sid = YList(self)
                                                    self._segment_path = lambda: "multicast-source"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastSource, [u'source_lsp_id', u'source_address'], name, value)


                                                class Tags(Entity):
                                                    """
                                                    Tags associated with the prefix item
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastSource.Tags, self).__init__()

                                                        self.yang_name = "tags"
                                                        self.yang_parent_name = "multicast-source"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "tags"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastSource.Tags, [u'entry'], name, value)


                                                class NodalSid(Entity):
                                                    """
                                                    Nodal SIDs with the prefix item
                                                    
                                                    .. attribute:: sid_value
                                                    
                                                    	sid value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rflag
                                                    
                                                    	rflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nflag
                                                    
                                                    	nflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pflag
                                                    
                                                    	pflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: eflag
                                                    
                                                    	eflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: vflag
                                                    
                                                    	vflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: lflag
                                                    
                                                    	lflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: algorithm
                                                    
                                                    	algorithm
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid, self).__init__()

                                                        self.yang_name = "nodal-sid"
                                                        self.yang_parent_name = "multicast-source"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('sid_value', (YLeaf(YType.uint32, 'sid-value'), ['int'])),
                                                            ('rflag', (YLeaf(YType.uint8, 'rflag'), ['int'])),
                                                            ('nflag', (YLeaf(YType.uint8, 'nflag'), ['int'])),
                                                            ('pflag', (YLeaf(YType.uint8, 'pflag'), ['int'])),
                                                            ('eflag', (YLeaf(YType.uint8, 'eflag'), ['int'])),
                                                            ('vflag', (YLeaf(YType.uint8, 'vflag'), ['int'])),
                                                            ('lflag', (YLeaf(YType.uint8, 'lflag'), ['int'])),
                                                            ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                                        ])
                                                        self.sid_value = None
                                                        self.rflag = None
                                                        self.nflag = None
                                                        self.pflag = None
                                                        self.eflag = None
                                                        self.vflag = None
                                                        self.lflag = None
                                                        self.algorithm = None
                                                        self._segment_path = lambda: "nodal-sid"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid, [u'sid_value', u'rflag', u'nflag', u'pflag', u'eflag', u'vflag', u'lflag', u'algorithm'], name, value)


                                        class Backup(Entity):
                                            """
                                            Backup paths to prefix
                                            
                                            .. attribute:: origin
                                            
                                            	Origin of route
                                            	**type**\:  :py:class:`IsisPrefixOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisPrefixOrigin>`
                                            
                                            .. attribute:: metric
                                            
                                            	Distance to network
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: multicast_metric
                                            
                                            	Multicast\-intact distance to network
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_external_metric
                                            
                                            	Is the metric an external metric?
                                            	**type**\: bool
                                            
                                            .. attribute:: administrative_distance
                                            
                                            	Administrative Distance
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: paths
                                            
                                            	First hops toward the prefix
                                            	**type**\: list of  		 :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Paths>`
                                            
                                            .. attribute:: ucmp_next_hop
                                            
                                            	UCMP first hops toward the prefix
                                            	**type**\: list of  		 :py:class:`UcmpNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.UcmpNextHop>`
                                            
                                            .. attribute:: multicast_path
                                            
                                            	Multicast intact first hops toward the prefix
                                            	**type**\: list of  		 :py:class:`MulticastPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath>`
                                            
                                            .. attribute:: srte_path
                                            
                                            	SR\-TE native first hops toward the prefix
                                            	**type**\: list of  		 :py:class:`SrtePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath>`
                                            
                                            .. attribute:: explicit_path
                                            
                                            	SR microloop avoidance paths
                                            	**type**\: list of  		 :py:class:`ExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath>`
                                            
                                            .. attribute:: source
                                            
                                            	Sources advertising the prefix
                                            	**type**\: list of  		 :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Source>`
                                            
                                            .. attribute:: multicast_source
                                            
                                            	Multicast\-intact sources advertising the prefix
                                            	**type**\: list of  		 :py:class:`MulticastSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastSource>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup, self).__init__()

                                                self.yang_name = "backup"
                                                self.yang_parent_name = "native-details"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("paths", ("paths", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Paths)), ("ucmp-next-hop", ("ucmp_next_hop", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.UcmpNextHop)), ("multicast-path", ("multicast_path", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath)), ("srte-path", ("srte_path", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath)), ("explicit-path", ("explicit_path", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath)), ("source", ("source", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Source)), ("multicast-source", ("multicast_source", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastSource))])
                                                self._leafs = OrderedDict([
                                                    ('origin', (YLeaf(YType.enumeration, 'origin'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisPrefixOrigin', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('multicast_metric', (YLeaf(YType.uint32, 'multicast-metric'), ['int'])),
                                                    ('is_external_metric', (YLeaf(YType.boolean, 'is-external-metric'), ['bool'])),
                                                    ('administrative_distance', (YLeaf(YType.uint16, 'administrative-distance'), ['int'])),
                                                ])
                                                self.origin = None
                                                self.metric = None
                                                self.multicast_metric = None
                                                self.is_external_metric = None
                                                self.administrative_distance = None

                                                self.paths = YList(self)
                                                self.ucmp_next_hop = YList(self)
                                                self.multicast_path = YList(self)
                                                self.srte_path = YList(self)
                                                self.explicit_path = YList(self)
                                                self.source = YList(self)
                                                self.multicast_source = YList(self)
                                                self._segment_path = lambda: "backup"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup, [u'origin', u'metric', u'multicast_metric', u'is_external_metric', u'administrative_distance'], name, value)


                                            class Paths(Entity):
                                                """
                                                First hops toward the prefix
                                                
                                                .. attribute:: frr_backup
                                                
                                                	FRR backup for this path
                                                	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Paths.FrrBackup>`
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: tag
                                                
                                                	Tag associated with the path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_interface
                                                
                                                	Explicit path tunnel interface
                                                	**type**\: str
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_te_tunnel_interface
                                                
                                                	Is path via a TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: is_sr_exclude_tunnel_interface
                                                
                                                	Is path via an SR\-exclude TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: uloop_explicit
                                                
                                                	Uloop Explicit List
                                                	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit>`
                                                
                                                .. attribute:: nnh
                                                
                                                	Next next hops
                                                	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Paths.Nnh>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Paths, self).__init__()

                                                    self.yang_name = "paths"
                                                    self.yang_parent_name = "backup"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Paths.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Paths.Nnh))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                        ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.neighbor_snpa = None
                                                    self.tag = None
                                                    self.tunnel_interface = None
                                                    self.segment_routing_sid_value = None
                                                    self.weight = None
                                                    self.is_te_tunnel_interface = None
                                                    self.is_sr_exclude_tunnel_interface = None

                                                    self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Paths.FrrBackup()
                                                    self.frr_backup.parent = self
                                                    self._children_name_map["frr_backup"] = "frr-backup"

                                                    self.uloop_explicit = YList(self)
                                                    self.nnh = YList(self)
                                                    self._segment_path = lambda: "paths"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Paths, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                                class FrrBackup(Entity):
                                                    """
                                                    FRR backup for this path
                                                    
                                                    .. attribute:: neighbor_id
                                                    
                                                    	Next hop neighbor ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: egress_interface
                                                    
                                                    	Interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Next hop neighbor's forwarding address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: tunnel_egress_interface
                                                    
                                                    	Tunnel interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_snpa
                                                    
                                                    	Next hop neighbor's SNPA
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_system_id
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_id
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: remote_lfa_system_pid
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_pid
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: total_backup_distance
                                                    
                                                    	Distance to the network via this backup path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value
                                                    
                                                    	Segment routing sid value received from first hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: num_sid
                                                    
                                                    	Number of SIDs in TI\-LFA/rLFA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_repair_list_size
                                                    
                                                    	Backup Repair List Size
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tilfa_computation
                                                    
                                                    	Ti LFA computation which provided backup path
                                                    	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                    
                                                    .. attribute:: prefix_source_node_id
                                                    
                                                    	PrefixSourceNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: is_downstream
                                                    
                                                    	Is the backup path via downstream node?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_lc_disjoint
                                                    
                                                    	Is the backup path line card disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_node_protecting
                                                    
                                                    	Is the backup path node protecting?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_primary_path
                                                    
                                                    	Is the backup path an ECMP to the network?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_srlg_disjoint
                                                    
                                                    	Is the backup path SRLG disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_remote_lfa
                                                    
                                                    	Is the backup path via a Remote LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_epcfrr_lfa
                                                    
                                                    	Is the backup path via a TI\-LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_strict_spflfa
                                                    
                                                    	Is the backup path TI\-LFA strict SPF?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_requested
                                                    
                                                    	Is SR TE tunnel requested
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight configured on the interface
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value_entry
                                                    
                                                    	Segment routing sid values for TI\-LFA/rLFA
                                                    	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry>`
                                                    
                                                    .. attribute:: backup_repair
                                                    
                                                    	BAckup Repair List
                                                    	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Paths.FrrBackup, self).__init__()

                                                        self.yang_name = "frr-backup"
                                                        self.yang_parent_name = "paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair))])
                                                        self._leafs = OrderedDict([
                                                            ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                            ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                            ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                            ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                            ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                            ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                            ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                            ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                            ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                            ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                            ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                            ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                            ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                            ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                            ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                            ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                            ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                            ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                            ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                            ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                            ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                            ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                            ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                            ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ])
                                                        self.neighbor_id = None
                                                        self.egress_interface = None
                                                        self.neighbor_address = None
                                                        self.tunnel_egress_interface = None
                                                        self.neighbor_snpa = None
                                                        self.remote_lfa_system_id = None
                                                        self.remote_lfa_router_id = None
                                                        self.remote_lfa_system_pid = None
                                                        self.remote_lfa_router_pid = None
                                                        self.total_backup_distance = None
                                                        self.segment_routing_sid_value = None
                                                        self.num_sid = None
                                                        self.backup_repair_list_size = None
                                                        self.tilfa_computation = None
                                                        self.prefix_source_node_id = None
                                                        self.is_downstream = None
                                                        self.is_lc_disjoint = None
                                                        self.is_node_protecting = None
                                                        self.is_primary_path = None
                                                        self.is_srlg_disjoint = None
                                                        self.is_remote_lfa = None
                                                        self.is_epcfrr_lfa = None
                                                        self.is_strict_spflfa = None
                                                        self.is_tunnel_requested = None
                                                        self.weight = None

                                                        self.segment_routing_sid_value_entry = YList(self)
                                                        self.backup_repair = YList(self)
                                                        self._segment_path = lambda: "frr-backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Paths.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                    class SegmentRoutingSidValueEntry(Entity):
                                                        """
                                                        Segment routing sid values for TI\-LFA/rLFA
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                            self.yang_name = "segment-routing-sid-value-entry"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                    class BackupRepair(Entity):
                                                        """
                                                        BAckup Repair List
                                                        
                                                        .. attribute:: repair_element_node_id
                                                        
                                                        	RepairElementNodeID
                                                        	**type**\: str
                                                        
                                                        .. attribute:: repair_ipv4_addr
                                                        
                                                        	RepairIPv4Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_ipv6_addr
                                                        
                                                        	RepairIPv6Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_label
                                                        
                                                        	Repair Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_element_type
                                                        
                                                        	Repair Element Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_strict_spf_label
                                                        
                                                        	Repair Strict SPF Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair, self).__init__()

                                                            self.yang_name = "backup-repair"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                                ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                                ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                                ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                                ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                                ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                            ])
                                                            self.repair_element_node_id = None
                                                            self.repair_ipv4_addr = None
                                                            self.repair_ipv6_addr = None
                                                            self.repair_label = None
                                                            self.repair_element_type = None
                                                            self.repair_strict_spf_label = None
                                                            self._segment_path = lambda: "backup-repair"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class UloopExplicit(Entity):
                                                    """
                                                    Uloop Explicit List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit, self).__init__()

                                                        self.yang_name = "uloop-explicit"
                                                        self.yang_parent_name = "paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "uloop-explicit"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class Nnh(Entity):
                                                    """
                                                    Next next hops
                                                    
                                                    .. attribute:: link_id_set
                                                    
                                                    	If link\_id is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ipv4_set
                                                    
                                                    	If ipv4 address is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: link_id
                                                    
                                                    	link ID of the next next hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	Ipv4 address of the next next hop
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Paths.Nnh, self).__init__()

                                                        self.yang_name = "nnh"
                                                        self.yang_parent_name = "paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                            ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                            ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ])
                                                        self.link_id_set = None
                                                        self.ipv4_set = None
                                                        self.link_id = None
                                                        self.ipv4_address = None
                                                        self._segment_path = lambda: "nnh"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Paths.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                            class UcmpNextHop(Entity):
                                                """
                                                UCMP first hops toward the prefix
                                                
                                                .. attribute:: frr_backup
                                                
                                                	FRR backup for this path
                                                	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup>`
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: tag
                                                
                                                	Tag associated with the path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: total_ucmp_distance
                                                
                                                	Distance to the network via this UCMP next hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_te_tunnel_interface
                                                
                                                	Is path via a TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: is_sr_exclude_tunnel_interface
                                                
                                                	Is path via an SR\-exclude TE tunnel
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.UcmpNextHop, self).__init__()

                                                    self.yang_name = "ucmp-next-hop"
                                                    self.yang_parent_name = "backup"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('total_ucmp_distance', (YLeaf(YType.uint32, 'total-ucmp-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                        ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.neighbor_snpa = None
                                                    self.tag = None
                                                    self.total_ucmp_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.weight = None
                                                    self.is_te_tunnel_interface = None
                                                    self.is_sr_exclude_tunnel_interface = None

                                                    self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup()
                                                    self.frr_backup.parent = self
                                                    self._children_name_map["frr_backup"] = "frr-backup"
                                                    self._segment_path = lambda: "ucmp-next-hop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.UcmpNextHop, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'total_ucmp_distance', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                                class FrrBackup(Entity):
                                                    """
                                                    FRR backup for this path
                                                    
                                                    .. attribute:: neighbor_id
                                                    
                                                    	Next hop neighbor ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: egress_interface
                                                    
                                                    	Interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Next hop neighbor's forwarding address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: tunnel_egress_interface
                                                    
                                                    	Tunnel interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_snpa
                                                    
                                                    	Next hop neighbor's SNPA
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_system_id
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_id
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: remote_lfa_system_pid
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_pid
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: total_backup_distance
                                                    
                                                    	Distance to the network via this backup path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value
                                                    
                                                    	Segment routing sid value received from first hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: num_sid
                                                    
                                                    	Number of SIDs in TI\-LFA/rLFA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_repair_list_size
                                                    
                                                    	Backup Repair List Size
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tilfa_computation
                                                    
                                                    	Ti LFA computation which provided backup path
                                                    	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                    
                                                    .. attribute:: prefix_source_node_id
                                                    
                                                    	PrefixSourceNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: is_downstream
                                                    
                                                    	Is the backup path via downstream node?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_lc_disjoint
                                                    
                                                    	Is the backup path line card disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_node_protecting
                                                    
                                                    	Is the backup path node protecting?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_primary_path
                                                    
                                                    	Is the backup path an ECMP to the network?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_srlg_disjoint
                                                    
                                                    	Is the backup path SRLG disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_remote_lfa
                                                    
                                                    	Is the backup path via a Remote LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_epcfrr_lfa
                                                    
                                                    	Is the backup path via a TI\-LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_strict_spflfa
                                                    
                                                    	Is the backup path TI\-LFA strict SPF?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_requested
                                                    
                                                    	Is SR TE tunnel requested
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight configured on the interface
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value_entry
                                                    
                                                    	Segment routing sid values for TI\-LFA/rLFA
                                                    	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry>`
                                                    
                                                    .. attribute:: backup_repair
                                                    
                                                    	BAckup Repair List
                                                    	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup, self).__init__()

                                                        self.yang_name = "frr-backup"
                                                        self.yang_parent_name = "ucmp-next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair))])
                                                        self._leafs = OrderedDict([
                                                            ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                            ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                            ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                            ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                            ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                            ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                            ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                            ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                            ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                            ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                            ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                            ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                            ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                            ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                            ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                            ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                            ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                            ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                            ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                            ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                            ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                            ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                            ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                            ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ])
                                                        self.neighbor_id = None
                                                        self.egress_interface = None
                                                        self.neighbor_address = None
                                                        self.tunnel_egress_interface = None
                                                        self.neighbor_snpa = None
                                                        self.remote_lfa_system_id = None
                                                        self.remote_lfa_router_id = None
                                                        self.remote_lfa_system_pid = None
                                                        self.remote_lfa_router_pid = None
                                                        self.total_backup_distance = None
                                                        self.segment_routing_sid_value = None
                                                        self.num_sid = None
                                                        self.backup_repair_list_size = None
                                                        self.tilfa_computation = None
                                                        self.prefix_source_node_id = None
                                                        self.is_downstream = None
                                                        self.is_lc_disjoint = None
                                                        self.is_node_protecting = None
                                                        self.is_primary_path = None
                                                        self.is_srlg_disjoint = None
                                                        self.is_remote_lfa = None
                                                        self.is_epcfrr_lfa = None
                                                        self.is_strict_spflfa = None
                                                        self.is_tunnel_requested = None
                                                        self.weight = None

                                                        self.segment_routing_sid_value_entry = YList(self)
                                                        self.backup_repair = YList(self)
                                                        self._segment_path = lambda: "frr-backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                    class SegmentRoutingSidValueEntry(Entity):
                                                        """
                                                        Segment routing sid values for TI\-LFA/rLFA
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                            self.yang_name = "segment-routing-sid-value-entry"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                    class BackupRepair(Entity):
                                                        """
                                                        BAckup Repair List
                                                        
                                                        .. attribute:: repair_element_node_id
                                                        
                                                        	RepairElementNodeID
                                                        	**type**\: str
                                                        
                                                        .. attribute:: repair_ipv4_addr
                                                        
                                                        	RepairIPv4Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_ipv6_addr
                                                        
                                                        	RepairIPv6Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_label
                                                        
                                                        	Repair Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_element_type
                                                        
                                                        	Repair Element Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_strict_spf_label
                                                        
                                                        	Repair Strict SPF Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair, self).__init__()

                                                            self.yang_name = "backup-repair"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                                ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                                ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                                ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                                ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                                ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                            ])
                                                            self.repair_element_node_id = None
                                                            self.repair_ipv4_addr = None
                                                            self.repair_ipv6_addr = None
                                                            self.repair_label = None
                                                            self.repair_element_type = None
                                                            self.repair_strict_spf_label = None
                                                            self._segment_path = lambda: "backup-repair"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class MulticastPath(Entity):
                                                """
                                                Multicast intact first hops toward the prefix
                                                
                                                .. attribute:: frr_backup
                                                
                                                	FRR backup for this path
                                                	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup>`
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: tag
                                                
                                                	Tag associated with the path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_interface
                                                
                                                	Explicit path tunnel interface
                                                	**type**\: str
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_te_tunnel_interface
                                                
                                                	Is path via a TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: is_sr_exclude_tunnel_interface
                                                
                                                	Is path via an SR\-exclude TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: uloop_explicit
                                                
                                                	Uloop Explicit List
                                                	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit>`
                                                
                                                .. attribute:: nnh
                                                
                                                	Next next hops
                                                	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.Nnh>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath, self).__init__()

                                                    self.yang_name = "multicast-path"
                                                    self.yang_parent_name = "backup"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.Nnh))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                        ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.neighbor_snpa = None
                                                    self.tag = None
                                                    self.tunnel_interface = None
                                                    self.segment_routing_sid_value = None
                                                    self.weight = None
                                                    self.is_te_tunnel_interface = None
                                                    self.is_sr_exclude_tunnel_interface = None

                                                    self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup()
                                                    self.frr_backup.parent = self
                                                    self._children_name_map["frr_backup"] = "frr-backup"

                                                    self.uloop_explicit = YList(self)
                                                    self.nnh = YList(self)
                                                    self._segment_path = lambda: "multicast-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                                class FrrBackup(Entity):
                                                    """
                                                    FRR backup for this path
                                                    
                                                    .. attribute:: neighbor_id
                                                    
                                                    	Next hop neighbor ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: egress_interface
                                                    
                                                    	Interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Next hop neighbor's forwarding address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: tunnel_egress_interface
                                                    
                                                    	Tunnel interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_snpa
                                                    
                                                    	Next hop neighbor's SNPA
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_system_id
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_id
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: remote_lfa_system_pid
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_pid
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: total_backup_distance
                                                    
                                                    	Distance to the network via this backup path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value
                                                    
                                                    	Segment routing sid value received from first hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: num_sid
                                                    
                                                    	Number of SIDs in TI\-LFA/rLFA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_repair_list_size
                                                    
                                                    	Backup Repair List Size
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tilfa_computation
                                                    
                                                    	Ti LFA computation which provided backup path
                                                    	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                    
                                                    .. attribute:: prefix_source_node_id
                                                    
                                                    	PrefixSourceNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: is_downstream
                                                    
                                                    	Is the backup path via downstream node?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_lc_disjoint
                                                    
                                                    	Is the backup path line card disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_node_protecting
                                                    
                                                    	Is the backup path node protecting?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_primary_path
                                                    
                                                    	Is the backup path an ECMP to the network?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_srlg_disjoint
                                                    
                                                    	Is the backup path SRLG disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_remote_lfa
                                                    
                                                    	Is the backup path via a Remote LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_epcfrr_lfa
                                                    
                                                    	Is the backup path via a TI\-LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_strict_spflfa
                                                    
                                                    	Is the backup path TI\-LFA strict SPF?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_requested
                                                    
                                                    	Is SR TE tunnel requested
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight configured on the interface
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value_entry
                                                    
                                                    	Segment routing sid values for TI\-LFA/rLFA
                                                    	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                    
                                                    .. attribute:: backup_repair
                                                    
                                                    	BAckup Repair List
                                                    	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup, self).__init__()

                                                        self.yang_name = "frr-backup"
                                                        self.yang_parent_name = "multicast-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair))])
                                                        self._leafs = OrderedDict([
                                                            ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                            ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                            ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                            ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                            ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                            ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                            ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                            ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                            ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                            ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                            ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                            ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                            ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                            ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                            ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                            ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                            ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                            ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                            ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                            ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                            ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                            ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                            ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                            ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ])
                                                        self.neighbor_id = None
                                                        self.egress_interface = None
                                                        self.neighbor_address = None
                                                        self.tunnel_egress_interface = None
                                                        self.neighbor_snpa = None
                                                        self.remote_lfa_system_id = None
                                                        self.remote_lfa_router_id = None
                                                        self.remote_lfa_system_pid = None
                                                        self.remote_lfa_router_pid = None
                                                        self.total_backup_distance = None
                                                        self.segment_routing_sid_value = None
                                                        self.num_sid = None
                                                        self.backup_repair_list_size = None
                                                        self.tilfa_computation = None
                                                        self.prefix_source_node_id = None
                                                        self.is_downstream = None
                                                        self.is_lc_disjoint = None
                                                        self.is_node_protecting = None
                                                        self.is_primary_path = None
                                                        self.is_srlg_disjoint = None
                                                        self.is_remote_lfa = None
                                                        self.is_epcfrr_lfa = None
                                                        self.is_strict_spflfa = None
                                                        self.is_tunnel_requested = None
                                                        self.weight = None

                                                        self.segment_routing_sid_value_entry = YList(self)
                                                        self.backup_repair = YList(self)
                                                        self._segment_path = lambda: "frr-backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                    class SegmentRoutingSidValueEntry(Entity):
                                                        """
                                                        Segment routing sid values for TI\-LFA/rLFA
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                            self.yang_name = "segment-routing-sid-value-entry"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                    class BackupRepair(Entity):
                                                        """
                                                        BAckup Repair List
                                                        
                                                        .. attribute:: repair_element_node_id
                                                        
                                                        	RepairElementNodeID
                                                        	**type**\: str
                                                        
                                                        .. attribute:: repair_ipv4_addr
                                                        
                                                        	RepairIPv4Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_ipv6_addr
                                                        
                                                        	RepairIPv6Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_label
                                                        
                                                        	Repair Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_element_type
                                                        
                                                        	Repair Element Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_strict_spf_label
                                                        
                                                        	Repair Strict SPF Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair, self).__init__()

                                                            self.yang_name = "backup-repair"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                                ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                                ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                                ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                                ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                                ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                            ])
                                                            self.repair_element_node_id = None
                                                            self.repair_ipv4_addr = None
                                                            self.repair_ipv6_addr = None
                                                            self.repair_label = None
                                                            self.repair_element_type = None
                                                            self.repair_strict_spf_label = None
                                                            self._segment_path = lambda: "backup-repair"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class UloopExplicit(Entity):
                                                    """
                                                    Uloop Explicit List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit, self).__init__()

                                                        self.yang_name = "uloop-explicit"
                                                        self.yang_parent_name = "multicast-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "uloop-explicit"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class Nnh(Entity):
                                                    """
                                                    Next next hops
                                                    
                                                    .. attribute:: link_id_set
                                                    
                                                    	If link\_id is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ipv4_set
                                                    
                                                    	If ipv4 address is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: link_id
                                                    
                                                    	link ID of the next next hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	Ipv4 address of the next next hop
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.Nnh, self).__init__()

                                                        self.yang_name = "nnh"
                                                        self.yang_parent_name = "multicast-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                            ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                            ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ])
                                                        self.link_id_set = None
                                                        self.ipv4_set = None
                                                        self.link_id = None
                                                        self.ipv4_address = None
                                                        self._segment_path = lambda: "nnh"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                            class SrtePath(Entity):
                                                """
                                                SR\-TE native first hops toward the prefix
                                                
                                                .. attribute:: frr_backup
                                                
                                                	FRR backup for this path
                                                	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup>`
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: tag
                                                
                                                	Tag associated with the path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_interface
                                                
                                                	Explicit path tunnel interface
                                                	**type**\: str
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_te_tunnel_interface
                                                
                                                	Is path via a TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: is_sr_exclude_tunnel_interface
                                                
                                                	Is path via an SR\-exclude TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: uloop_explicit
                                                
                                                	Uloop Explicit List
                                                	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit>`
                                                
                                                .. attribute:: nnh
                                                
                                                	Next next hops
                                                	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.Nnh>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath, self).__init__()

                                                    self.yang_name = "srte-path"
                                                    self.yang_parent_name = "backup"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.Nnh))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                        ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.neighbor_snpa = None
                                                    self.tag = None
                                                    self.tunnel_interface = None
                                                    self.segment_routing_sid_value = None
                                                    self.weight = None
                                                    self.is_te_tunnel_interface = None
                                                    self.is_sr_exclude_tunnel_interface = None

                                                    self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup()
                                                    self.frr_backup.parent = self
                                                    self._children_name_map["frr_backup"] = "frr-backup"

                                                    self.uloop_explicit = YList(self)
                                                    self.nnh = YList(self)
                                                    self._segment_path = lambda: "srte-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                                class FrrBackup(Entity):
                                                    """
                                                    FRR backup for this path
                                                    
                                                    .. attribute:: neighbor_id
                                                    
                                                    	Next hop neighbor ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: egress_interface
                                                    
                                                    	Interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Next hop neighbor's forwarding address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: tunnel_egress_interface
                                                    
                                                    	Tunnel interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_snpa
                                                    
                                                    	Next hop neighbor's SNPA
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_system_id
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_id
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: remote_lfa_system_pid
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_pid
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: total_backup_distance
                                                    
                                                    	Distance to the network via this backup path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value
                                                    
                                                    	Segment routing sid value received from first hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: num_sid
                                                    
                                                    	Number of SIDs in TI\-LFA/rLFA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_repair_list_size
                                                    
                                                    	Backup Repair List Size
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tilfa_computation
                                                    
                                                    	Ti LFA computation which provided backup path
                                                    	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                    
                                                    .. attribute:: prefix_source_node_id
                                                    
                                                    	PrefixSourceNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: is_downstream
                                                    
                                                    	Is the backup path via downstream node?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_lc_disjoint
                                                    
                                                    	Is the backup path line card disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_node_protecting
                                                    
                                                    	Is the backup path node protecting?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_primary_path
                                                    
                                                    	Is the backup path an ECMP to the network?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_srlg_disjoint
                                                    
                                                    	Is the backup path SRLG disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_remote_lfa
                                                    
                                                    	Is the backup path via a Remote LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_epcfrr_lfa
                                                    
                                                    	Is the backup path via a TI\-LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_strict_spflfa
                                                    
                                                    	Is the backup path TI\-LFA strict SPF?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_requested
                                                    
                                                    	Is SR TE tunnel requested
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight configured on the interface
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value_entry
                                                    
                                                    	Segment routing sid values for TI\-LFA/rLFA
                                                    	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                    
                                                    .. attribute:: backup_repair
                                                    
                                                    	BAckup Repair List
                                                    	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup, self).__init__()

                                                        self.yang_name = "frr-backup"
                                                        self.yang_parent_name = "srte-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair))])
                                                        self._leafs = OrderedDict([
                                                            ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                            ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                            ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                            ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                            ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                            ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                            ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                            ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                            ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                            ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                            ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                            ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                            ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                            ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                            ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                            ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                            ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                            ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                            ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                            ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                            ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                            ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                            ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                            ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ])
                                                        self.neighbor_id = None
                                                        self.egress_interface = None
                                                        self.neighbor_address = None
                                                        self.tunnel_egress_interface = None
                                                        self.neighbor_snpa = None
                                                        self.remote_lfa_system_id = None
                                                        self.remote_lfa_router_id = None
                                                        self.remote_lfa_system_pid = None
                                                        self.remote_lfa_router_pid = None
                                                        self.total_backup_distance = None
                                                        self.segment_routing_sid_value = None
                                                        self.num_sid = None
                                                        self.backup_repair_list_size = None
                                                        self.tilfa_computation = None
                                                        self.prefix_source_node_id = None
                                                        self.is_downstream = None
                                                        self.is_lc_disjoint = None
                                                        self.is_node_protecting = None
                                                        self.is_primary_path = None
                                                        self.is_srlg_disjoint = None
                                                        self.is_remote_lfa = None
                                                        self.is_epcfrr_lfa = None
                                                        self.is_strict_spflfa = None
                                                        self.is_tunnel_requested = None
                                                        self.weight = None

                                                        self.segment_routing_sid_value_entry = YList(self)
                                                        self.backup_repair = YList(self)
                                                        self._segment_path = lambda: "frr-backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                    class SegmentRoutingSidValueEntry(Entity):
                                                        """
                                                        Segment routing sid values for TI\-LFA/rLFA
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                            self.yang_name = "segment-routing-sid-value-entry"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                    class BackupRepair(Entity):
                                                        """
                                                        BAckup Repair List
                                                        
                                                        .. attribute:: repair_element_node_id
                                                        
                                                        	RepairElementNodeID
                                                        	**type**\: str
                                                        
                                                        .. attribute:: repair_ipv4_addr
                                                        
                                                        	RepairIPv4Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_ipv6_addr
                                                        
                                                        	RepairIPv6Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_label
                                                        
                                                        	Repair Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_element_type
                                                        
                                                        	Repair Element Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_strict_spf_label
                                                        
                                                        	Repair Strict SPF Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair, self).__init__()

                                                            self.yang_name = "backup-repair"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                                ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                                ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                                ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                                ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                                ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                            ])
                                                            self.repair_element_node_id = None
                                                            self.repair_ipv4_addr = None
                                                            self.repair_ipv6_addr = None
                                                            self.repair_label = None
                                                            self.repair_element_type = None
                                                            self.repair_strict_spf_label = None
                                                            self._segment_path = lambda: "backup-repair"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class UloopExplicit(Entity):
                                                    """
                                                    Uloop Explicit List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit, self).__init__()

                                                        self.yang_name = "uloop-explicit"
                                                        self.yang_parent_name = "srte-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "uloop-explicit"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class Nnh(Entity):
                                                    """
                                                    Next next hops
                                                    
                                                    .. attribute:: link_id_set
                                                    
                                                    	If link\_id is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ipv4_set
                                                    
                                                    	If ipv4 address is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: link_id
                                                    
                                                    	link ID of the next next hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	Ipv4 address of the next next hop
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.Nnh, self).__init__()

                                                        self.yang_name = "nnh"
                                                        self.yang_parent_name = "srte-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                            ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                            ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ])
                                                        self.link_id_set = None
                                                        self.ipv4_set = None
                                                        self.link_id = None
                                                        self.ipv4_address = None
                                                        self._segment_path = lambda: "nnh"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                            class ExplicitPath(Entity):
                                                """
                                                SR microloop avoidance paths
                                                
                                                .. attribute:: frr_backup
                                                
                                                	FRR backup for this path
                                                	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup>`
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: tag
                                                
                                                	Tag associated with the path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_interface
                                                
                                                	Explicit path tunnel interface
                                                	**type**\: str
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_te_tunnel_interface
                                                
                                                	Is path via a TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: is_sr_exclude_tunnel_interface
                                                
                                                	Is path via an SR\-exclude TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: uloop_explicit
                                                
                                                	Uloop Explicit List
                                                	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit>`
                                                
                                                .. attribute:: nnh
                                                
                                                	Next next hops
                                                	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.Nnh>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath, self).__init__()

                                                    self.yang_name = "explicit-path"
                                                    self.yang_parent_name = "backup"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.Nnh))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                        ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.neighbor_snpa = None
                                                    self.tag = None
                                                    self.tunnel_interface = None
                                                    self.segment_routing_sid_value = None
                                                    self.weight = None
                                                    self.is_te_tunnel_interface = None
                                                    self.is_sr_exclude_tunnel_interface = None

                                                    self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup()
                                                    self.frr_backup.parent = self
                                                    self._children_name_map["frr_backup"] = "frr-backup"

                                                    self.uloop_explicit = YList(self)
                                                    self.nnh = YList(self)
                                                    self._segment_path = lambda: "explicit-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                                class FrrBackup(Entity):
                                                    """
                                                    FRR backup for this path
                                                    
                                                    .. attribute:: neighbor_id
                                                    
                                                    	Next hop neighbor ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: egress_interface
                                                    
                                                    	Interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Next hop neighbor's forwarding address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: tunnel_egress_interface
                                                    
                                                    	Tunnel interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_snpa
                                                    
                                                    	Next hop neighbor's SNPA
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_system_id
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_id
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: remote_lfa_system_pid
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_pid
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: total_backup_distance
                                                    
                                                    	Distance to the network via this backup path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value
                                                    
                                                    	Segment routing sid value received from first hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: num_sid
                                                    
                                                    	Number of SIDs in TI\-LFA/rLFA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_repair_list_size
                                                    
                                                    	Backup Repair List Size
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tilfa_computation
                                                    
                                                    	Ti LFA computation which provided backup path
                                                    	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                    
                                                    .. attribute:: prefix_source_node_id
                                                    
                                                    	PrefixSourceNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: is_downstream
                                                    
                                                    	Is the backup path via downstream node?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_lc_disjoint
                                                    
                                                    	Is the backup path line card disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_node_protecting
                                                    
                                                    	Is the backup path node protecting?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_primary_path
                                                    
                                                    	Is the backup path an ECMP to the network?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_srlg_disjoint
                                                    
                                                    	Is the backup path SRLG disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_remote_lfa
                                                    
                                                    	Is the backup path via a Remote LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_epcfrr_lfa
                                                    
                                                    	Is the backup path via a TI\-LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_strict_spflfa
                                                    
                                                    	Is the backup path TI\-LFA strict SPF?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_requested
                                                    
                                                    	Is SR TE tunnel requested
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight configured on the interface
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value_entry
                                                    
                                                    	Segment routing sid values for TI\-LFA/rLFA
                                                    	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                    
                                                    .. attribute:: backup_repair
                                                    
                                                    	BAckup Repair List
                                                    	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup, self).__init__()

                                                        self.yang_name = "frr-backup"
                                                        self.yang_parent_name = "explicit-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair))])
                                                        self._leafs = OrderedDict([
                                                            ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                            ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                            ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                            ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                            ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                            ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                            ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                            ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                            ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                            ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                            ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                            ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                            ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                            ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                            ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                            ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                            ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                            ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                            ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                            ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                            ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                            ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                            ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                            ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ])
                                                        self.neighbor_id = None
                                                        self.egress_interface = None
                                                        self.neighbor_address = None
                                                        self.tunnel_egress_interface = None
                                                        self.neighbor_snpa = None
                                                        self.remote_lfa_system_id = None
                                                        self.remote_lfa_router_id = None
                                                        self.remote_lfa_system_pid = None
                                                        self.remote_lfa_router_pid = None
                                                        self.total_backup_distance = None
                                                        self.segment_routing_sid_value = None
                                                        self.num_sid = None
                                                        self.backup_repair_list_size = None
                                                        self.tilfa_computation = None
                                                        self.prefix_source_node_id = None
                                                        self.is_downstream = None
                                                        self.is_lc_disjoint = None
                                                        self.is_node_protecting = None
                                                        self.is_primary_path = None
                                                        self.is_srlg_disjoint = None
                                                        self.is_remote_lfa = None
                                                        self.is_epcfrr_lfa = None
                                                        self.is_strict_spflfa = None
                                                        self.is_tunnel_requested = None
                                                        self.weight = None

                                                        self.segment_routing_sid_value_entry = YList(self)
                                                        self.backup_repair = YList(self)
                                                        self._segment_path = lambda: "frr-backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                    class SegmentRoutingSidValueEntry(Entity):
                                                        """
                                                        Segment routing sid values for TI\-LFA/rLFA
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                            self.yang_name = "segment-routing-sid-value-entry"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                    class BackupRepair(Entity):
                                                        """
                                                        BAckup Repair List
                                                        
                                                        .. attribute:: repair_element_node_id
                                                        
                                                        	RepairElementNodeID
                                                        	**type**\: str
                                                        
                                                        .. attribute:: repair_ipv4_addr
                                                        
                                                        	RepairIPv4Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_ipv6_addr
                                                        
                                                        	RepairIPv6Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_label
                                                        
                                                        	Repair Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_element_type
                                                        
                                                        	Repair Element Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_strict_spf_label
                                                        
                                                        	Repair Strict SPF Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair, self).__init__()

                                                            self.yang_name = "backup-repair"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                                ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                                ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                                ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                                ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                                ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                            ])
                                                            self.repair_element_node_id = None
                                                            self.repair_ipv4_addr = None
                                                            self.repair_ipv6_addr = None
                                                            self.repair_label = None
                                                            self.repair_element_type = None
                                                            self.repair_strict_spf_label = None
                                                            self._segment_path = lambda: "backup-repair"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class UloopExplicit(Entity):
                                                    """
                                                    Uloop Explicit List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit, self).__init__()

                                                        self.yang_name = "uloop-explicit"
                                                        self.yang_parent_name = "explicit-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "uloop-explicit"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class Nnh(Entity):
                                                    """
                                                    Next next hops
                                                    
                                                    .. attribute:: link_id_set
                                                    
                                                    	If link\_id is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ipv4_set
                                                    
                                                    	If ipv4 address is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: link_id
                                                    
                                                    	link ID of the next next hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	Ipv4 address of the next next hop
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.Nnh, self).__init__()

                                                        self.yang_name = "nnh"
                                                        self.yang_parent_name = "explicit-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                            ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                            ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ])
                                                        self.link_id_set = None
                                                        self.ipv4_set = None
                                                        self.link_id = None
                                                        self.ipv4_address = None
                                                        self._segment_path = lambda: "nnh"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                            class Source(Entity):
                                                """
                                                Sources advertising the prefix
                                                
                                                .. attribute:: source_lsp_id
                                                
                                                	ID of the LSP advertising the prefix
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                                
                                                .. attribute:: source_address
                                                
                                                	Source address of the IS advertising the prefix
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tags
                                                
                                                	Tags associated with the prefix item
                                                	**type**\: list of  		 :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Source.Tags>`
                                                
                                                .. attribute:: nodal_sid
                                                
                                                	Nodal SIDs with the prefix item
                                                	**type**\: list of  		 :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Source.NodalSid>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Source, self).__init__()

                                                    self.yang_name = "source"
                                                    self.yang_parent_name = "backup"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tags", ("tags", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Source.Tags)), ("nodal-sid", ("nodal_sid", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Source.NodalSid))])
                                                    self._leafs = OrderedDict([
                                                        ('source_lsp_id', (YLeaf(YType.str, 'source-lsp-id'), ['str'])),
                                                        ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                                    ])
                                                    self.source_lsp_id = None
                                                    self.source_address = None

                                                    self.tags = YList(self)
                                                    self.nodal_sid = YList(self)
                                                    self._segment_path = lambda: "source"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Source, [u'source_lsp_id', u'source_address'], name, value)


                                                class Tags(Entity):
                                                    """
                                                    Tags associated with the prefix item
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Source.Tags, self).__init__()

                                                        self.yang_name = "tags"
                                                        self.yang_parent_name = "source"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "tags"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Source.Tags, [u'entry'], name, value)


                                                class NodalSid(Entity):
                                                    """
                                                    Nodal SIDs with the prefix item
                                                    
                                                    .. attribute:: sid_value
                                                    
                                                    	sid value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rflag
                                                    
                                                    	rflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nflag
                                                    
                                                    	nflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pflag
                                                    
                                                    	pflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: eflag
                                                    
                                                    	eflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: vflag
                                                    
                                                    	vflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: lflag
                                                    
                                                    	lflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: algorithm
                                                    
                                                    	algorithm
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Source.NodalSid, self).__init__()

                                                        self.yang_name = "nodal-sid"
                                                        self.yang_parent_name = "source"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('sid_value', (YLeaf(YType.uint32, 'sid-value'), ['int'])),
                                                            ('rflag', (YLeaf(YType.uint8, 'rflag'), ['int'])),
                                                            ('nflag', (YLeaf(YType.uint8, 'nflag'), ['int'])),
                                                            ('pflag', (YLeaf(YType.uint8, 'pflag'), ['int'])),
                                                            ('eflag', (YLeaf(YType.uint8, 'eflag'), ['int'])),
                                                            ('vflag', (YLeaf(YType.uint8, 'vflag'), ['int'])),
                                                            ('lflag', (YLeaf(YType.uint8, 'lflag'), ['int'])),
                                                            ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                                        ])
                                                        self.sid_value = None
                                                        self.rflag = None
                                                        self.nflag = None
                                                        self.pflag = None
                                                        self.eflag = None
                                                        self.vflag = None
                                                        self.lflag = None
                                                        self.algorithm = None
                                                        self._segment_path = lambda: "nodal-sid"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.Source.NodalSid, [u'sid_value', u'rflag', u'nflag', u'pflag', u'eflag', u'vflag', u'lflag', u'algorithm'], name, value)


                                            class MulticastSource(Entity):
                                                """
                                                Multicast\-intact sources advertising the prefix
                                                
                                                .. attribute:: source_lsp_id
                                                
                                                	ID of the LSP advertising the prefix
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                                
                                                .. attribute:: source_address
                                                
                                                	Source address of the IS advertising the prefix
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tags
                                                
                                                	Tags associated with the prefix item
                                                	**type**\: list of  		 :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastSource.Tags>`
                                                
                                                .. attribute:: nodal_sid
                                                
                                                	Nodal SIDs with the prefix item
                                                	**type**\: list of  		 :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastSource, self).__init__()

                                                    self.yang_name = "multicast-source"
                                                    self.yang_parent_name = "backup"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tags", ("tags", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastSource.Tags)), ("nodal-sid", ("nodal_sid", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid))])
                                                    self._leafs = OrderedDict([
                                                        ('source_lsp_id', (YLeaf(YType.str, 'source-lsp-id'), ['str'])),
                                                        ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                                    ])
                                                    self.source_lsp_id = None
                                                    self.source_address = None

                                                    self.tags = YList(self)
                                                    self.nodal_sid = YList(self)
                                                    self._segment_path = lambda: "multicast-source"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastSource, [u'source_lsp_id', u'source_address'], name, value)


                                                class Tags(Entity):
                                                    """
                                                    Tags associated with the prefix item
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastSource.Tags, self).__init__()

                                                        self.yang_name = "tags"
                                                        self.yang_parent_name = "multicast-source"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "tags"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastSource.Tags, [u'entry'], name, value)


                                                class NodalSid(Entity):
                                                    """
                                                    Nodal SIDs with the prefix item
                                                    
                                                    .. attribute:: sid_value
                                                    
                                                    	sid value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rflag
                                                    
                                                    	rflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nflag
                                                    
                                                    	nflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pflag
                                                    
                                                    	pflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: eflag
                                                    
                                                    	eflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: vflag
                                                    
                                                    	vflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: lflag
                                                    
                                                    	lflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: algorithm
                                                    
                                                    	algorithm
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid, self).__init__()

                                                        self.yang_name = "nodal-sid"
                                                        self.yang_parent_name = "multicast-source"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('sid_value', (YLeaf(YType.uint32, 'sid-value'), ['int'])),
                                                            ('rflag', (YLeaf(YType.uint8, 'rflag'), ['int'])),
                                                            ('nflag', (YLeaf(YType.uint8, 'nflag'), ['int'])),
                                                            ('pflag', (YLeaf(YType.uint8, 'pflag'), ['int'])),
                                                            ('eflag', (YLeaf(YType.uint8, 'eflag'), ['int'])),
                                                            ('vflag', (YLeaf(YType.uint8, 'vflag'), ['int'])),
                                                            ('lflag', (YLeaf(YType.uint8, 'lflag'), ['int'])),
                                                            ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                                        ])
                                                        self.sid_value = None
                                                        self.rflag = None
                                                        self.nflag = None
                                                        self.pflag = None
                                                        self.eflag = None
                                                        self.vflag = None
                                                        self.lflag = None
                                                        self.algorithm = None
                                                        self._segment_path = lambda: "nodal-sid"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid, [u'sid_value', u'rflag', u'nflag', u'pflag', u'eflag', u'vflag', u'lflag', u'algorithm'], name, value)


                                class PerLevelAdvertisingDetail(Entity):
                                    """
                                    Per level details of how the local system
                                    advertises the prefix
                                    
                                    .. attribute:: summarization_status
                                    
                                    	Status of summarization for the prefix
                                    	**type**\:  :py:class:`SummarizationStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.PerLevelAdvertisingDetail.SummarizationStatus>`
                                    
                                    .. attribute:: level
                                    
                                    	Level in which the prefix is advertised
                                    	**type**\:  :py:class:`IsisLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevel>`
                                    
                                    .. attribute:: advertising_origin
                                    
                                    	The origin of the advertisement
                                    	**type**\:  :py:class:`IsisShRouteAdvOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisShRouteAdvOrigin>`
                                    
                                    .. attribute:: metric
                                    
                                    	Metric with which the prefix is advertised
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_propagated
                                    
                                    	Has the prefix been propagated from another level?
                                    	**type**\: bool
                                    
                                    .. attribute:: is_external_metric
                                    
                                    	Is the metric an external metric?
                                    	**type**\: bool
                                    
                                    .. attribute:: is_external_reachability
                                    
                                    	Is the prefix external to the IS\-IS domain?
                                    	**type**\: bool
                                    
                                    .. attribute:: is_interarea
                                    
                                    	Is the up/down bit set?
                                    	**type**\: bool
                                    
                                    .. attribute:: tags
                                    
                                    	Tags associated with the prefix
                                    	**type**\: list of  		 :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.PerLevelAdvertisingDetail.Tags>`
                                    
                                    .. attribute:: nodal_sid
                                    
                                    	Nodal SIDs with the prefix item
                                    	**type**\: list of  		 :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.PerLevelAdvertisingDetail.NodalSid>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.PerLevelAdvertisingDetail, self).__init__()

                                        self.yang_name = "per-level-advertising-detail"
                                        self.yang_parent_name = "ipv6-flex-route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("summarization-status", ("summarization_status", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.PerLevelAdvertisingDetail.SummarizationStatus)), ("tags", ("tags", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.PerLevelAdvertisingDetail.Tags)), ("nodal-sid", ("nodal_sid", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.PerLevelAdvertisingDetail.NodalSid))])
                                        self._leafs = OrderedDict([
                                            ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisLevel', '')])),
                                            ('advertising_origin', (YLeaf(YType.enumeration, 'advertising-origin'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisShRouteAdvOrigin', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('is_propagated', (YLeaf(YType.boolean, 'is-propagated'), ['bool'])),
                                            ('is_external_metric', (YLeaf(YType.boolean, 'is-external-metric'), ['bool'])),
                                            ('is_external_reachability', (YLeaf(YType.boolean, 'is-external-reachability'), ['bool'])),
                                            ('is_interarea', (YLeaf(YType.boolean, 'is-interarea'), ['bool'])),
                                        ])
                                        self.level = None
                                        self.advertising_origin = None
                                        self.metric = None
                                        self.is_propagated = None
                                        self.is_external_metric = None
                                        self.is_external_reachability = None
                                        self.is_interarea = None

                                        self.summarization_status = Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.PerLevelAdvertisingDetail.SummarizationStatus()
                                        self.summarization_status.parent = self
                                        self._children_name_map["summarization_status"] = "summarization-status"

                                        self.tags = YList(self)
                                        self.nodal_sid = YList(self)
                                        self._segment_path = lambda: "per-level-advertising-detail"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.PerLevelAdvertisingDetail, [u'level', u'advertising_origin', u'metric', u'is_propagated', u'is_external_metric', u'is_external_reachability', u'is_interarea'], name, value)


                                    class SummarizationStatus(Entity):
                                        """
                                        Status of summarization for the prefix
                                        
                                        .. attribute:: summary_prefix
                                        
                                        	Summarizing Prefix
                                        	**type**\:  :py:class:`SummaryPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	IsValid
                                        	**type**\:  :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.PerLevelAdvertisingDetail.SummarizationStatus, self).__init__()

                                            self.yang_name = "summarization-status"
                                            self.yang_parent_name = "per-level-advertising-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("summary-prefix", ("summary_prefix", Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', (YLeaf(YType.enumeration, 'is-valid'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisValid', '')])),
                                            ])
                                            self.is_valid = None

                                            self.summary_prefix = Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix()
                                            self.summary_prefix.parent = self
                                            self._children_name_map["summary_prefix"] = "summary-prefix"
                                            self._segment_path = lambda: "summarization-status"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.PerLevelAdvertisingDetail.SummarizationStatus, [u'is_valid'], name, value)


                                        class SummaryPrefix(Entity):
                                            """
                                            Summarizing Prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	prefix
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	prefix length
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix, self).__init__()

                                                self.yang_name = "summary-prefix"
                                                self.yang_parent_name = "summarization-status"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                    ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                ])
                                                self.prefix = None
                                                self.prefix_length = None
                                                self._segment_path = lambda: "summary-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix, [u'prefix', u'prefix_length'], name, value)


                                    class Tags(Entity):
                                        """
                                        Tags associated with the prefix
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.PerLevelAdvertisingDetail.Tags, self).__init__()

                                            self.yang_name = "tags"
                                            self.yang_parent_name = "per-level-advertising-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "tags"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.PerLevelAdvertisingDetail.Tags, [u'entry'], name, value)


                                    class NodalSid(Entity):
                                        """
                                        Nodal SIDs with the prefix item
                                        
                                        .. attribute:: sid_value
                                        
                                        	sid value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rflag
                                        
                                        	rflag
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nflag
                                        
                                        	nflag
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: pflag
                                        
                                        	pflag
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: eflag
                                        
                                        	eflag
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vflag
                                        
                                        	vflag
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: lflag
                                        
                                        	lflag
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: algorithm
                                        
                                        	algorithm
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.PerLevelAdvertisingDetail.NodalSid, self).__init__()

                                            self.yang_name = "nodal-sid"
                                            self.yang_parent_name = "per-level-advertising-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('sid_value', (YLeaf(YType.uint32, 'sid-value'), ['int'])),
                                                ('rflag', (YLeaf(YType.uint8, 'rflag'), ['int'])),
                                                ('nflag', (YLeaf(YType.uint8, 'nflag'), ['int'])),
                                                ('pflag', (YLeaf(YType.uint8, 'pflag'), ['int'])),
                                                ('eflag', (YLeaf(YType.uint8, 'eflag'), ['int'])),
                                                ('vflag', (YLeaf(YType.uint8, 'vflag'), ['int'])),
                                                ('lflag', (YLeaf(YType.uint8, 'lflag'), ['int'])),
                                                ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                            ])
                                            self.sid_value = None
                                            self.rflag = None
                                            self.nflag = None
                                            self.pflag = None
                                            self.eflag = None
                                            self.vflag = None
                                            self.lflag = None
                                            self.algorithm = None
                                            self._segment_path = lambda: "nodal-sid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6FlexRouteTables.Ipv6FlexRouteTable.Ipv6FlexRoute.PerLevelAdvertisingDetail.NodalSid, [u'sid_value', u'rflag', u'nflag', u'pflag', u'eflag', u'vflag', u'lflag', u'algorithm'], name, value)


                    class FrrSummary(Entity):
                        """
                        FRR summary information for a particular
                        IS\-IS topology
                        
                        .. attribute:: level1_prefixes
                        
                        	FRR summary for prefixes reachable in L1
                        	**type**\:  :py:class:`Level1Prefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes>`
                        
                        .. attribute:: level2_prefixes
                        
                        	FRR summary for prefixes reachable in L2
                        	**type**\:  :py:class:`Level2Prefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes>`
                        
                        .. attribute:: unreachable_prefixes
                        
                        	Unreachable prefixes
                        	**type**\:  :py:class:`UnreachablePrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.FrrSummary.UnreachablePrefixes>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.Topologies.Topology.FrrSummary, self).__init__()

                            self.yang_name = "frr-summary"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("level1-prefixes", ("level1_prefixes", Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes)), ("level2-prefixes", ("level2_prefixes", Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes)), ("unreachable-prefixes", ("unreachable_prefixes", Isis.Instances.Instance.Topologies.Topology.FrrSummary.UnreachablePrefixes))])
                            self._leafs = OrderedDict()

                            self.level1_prefixes = Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes()
                            self.level1_prefixes.parent = self
                            self._children_name_map["level1_prefixes"] = "level1-prefixes"

                            self.level2_prefixes = Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes()
                            self.level2_prefixes.parent = self
                            self._children_name_map["level2_prefixes"] = "level2-prefixes"

                            self.unreachable_prefixes = Isis.Instances.Instance.Topologies.Topology.FrrSummary.UnreachablePrefixes()
                            self.unreachable_prefixes.parent = self
                            self._children_name_map["unreachable_prefixes"] = "unreachable-prefixes"
                            self._segment_path = lambda: "frr-summary"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.FrrSummary, [], name, value)


                        class Level1Prefixes(Entity):
                            """
                            FRR summary for prefixes reachable in L1
                            
                            .. attribute:: all_paths_protected
                            
                            	Number of prefixes with all paths having FRR backup
                            	**type**\:  :py:class:`AllPathsProtected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes.AllPathsProtected>`
                            
                            .. attribute:: some_paths_protected
                            
                            	Number of prefixes with some paths having FRR backup
                            	**type**\:  :py:class:`SomePathsProtected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes.SomePathsProtected>`
                            
                            .. attribute:: unprotected
                            
                            	Number of reachable prefixes without FRR backup
                            	**type**\:  :py:class:`Unprotected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes.Unprotected>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes, self).__init__()

                                self.yang_name = "level1-prefixes"
                                self.yang_parent_name = "frr-summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("all-paths-protected", ("all_paths_protected", Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes.AllPathsProtected)), ("some-paths-protected", ("some_paths_protected", Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes.SomePathsProtected)), ("unprotected", ("unprotected", Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes.Unprotected))])
                                self._leafs = OrderedDict()

                                self.all_paths_protected = Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes.AllPathsProtected()
                                self.all_paths_protected.parent = self
                                self._children_name_map["all_paths_protected"] = "all-paths-protected"

                                self.some_paths_protected = Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes.SomePathsProtected()
                                self.some_paths_protected.parent = self
                                self._children_name_map["some_paths_protected"] = "some-paths-protected"

                                self.unprotected = Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes.Unprotected()
                                self.unprotected.parent = self
                                self._children_name_map["unprotected"] = "unprotected"
                                self._segment_path = lambda: "level1-prefixes"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes, [], name, value)


                            class AllPathsProtected(Entity):
                                """
                                Number of prefixes with all paths having FRR
                                backup
                                
                                .. attribute:: critical
                                
                                	Critical priority
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: high
                                
                                	High priority
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: medium
                                
                                	Medium priority
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low
                                
                                	Low priority
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes.AllPathsProtected, self).__init__()

                                    self.yang_name = "all-paths-protected"
                                    self.yang_parent_name = "level1-prefixes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('critical', (YLeaf(YType.uint32, 'critical'), ['int'])),
                                        ('high', (YLeaf(YType.uint32, 'high'), ['int'])),
                                        ('medium', (YLeaf(YType.uint32, 'medium'), ['int'])),
                                        ('low', (YLeaf(YType.uint32, 'low'), ['int'])),
                                    ])
                                    self.critical = None
                                    self.high = None
                                    self.medium = None
                                    self.low = None
                                    self._segment_path = lambda: "all-paths-protected"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes.AllPathsProtected, [u'critical', u'high', u'medium', u'low'], name, value)


                            class SomePathsProtected(Entity):
                                """
                                Number of prefixes with some paths having FRR
                                backup
                                
                                .. attribute:: critical
                                
                                	Critical priority
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: high
                                
                                	High priority
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: medium
                                
                                	Medium priority
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low
                                
                                	Low priority
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes.SomePathsProtected, self).__init__()

                                    self.yang_name = "some-paths-protected"
                                    self.yang_parent_name = "level1-prefixes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('critical', (YLeaf(YType.uint32, 'critical'), ['int'])),
                                        ('high', (YLeaf(YType.uint32, 'high'), ['int'])),
                                        ('medium', (YLeaf(YType.uint32, 'medium'), ['int'])),
                                        ('low', (YLeaf(YType.uint32, 'low'), ['int'])),
                                    ])
                                    self.critical = None
                                    self.high = None
                                    self.medium = None
                                    self.low = None
                                    self._segment_path = lambda: "some-paths-protected"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes.SomePathsProtected, [u'critical', u'high', u'medium', u'low'], name, value)


                            class Unprotected(Entity):
                                """
                                Number of reachable prefixes without FRR backup
                                
                                .. attribute:: critical
                                
                                	Critical priority
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: high
                                
                                	High priority
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: medium
                                
                                	Medium priority
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low
                                
                                	Low priority
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes.Unprotected, self).__init__()

                                    self.yang_name = "unprotected"
                                    self.yang_parent_name = "level1-prefixes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('critical', (YLeaf(YType.uint32, 'critical'), ['int'])),
                                        ('high', (YLeaf(YType.uint32, 'high'), ['int'])),
                                        ('medium', (YLeaf(YType.uint32, 'medium'), ['int'])),
                                        ('low', (YLeaf(YType.uint32, 'low'), ['int'])),
                                    ])
                                    self.critical = None
                                    self.high = None
                                    self.medium = None
                                    self.low = None
                                    self._segment_path = lambda: "unprotected"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level1Prefixes.Unprotected, [u'critical', u'high', u'medium', u'low'], name, value)


                        class Level2Prefixes(Entity):
                            """
                            FRR summary for prefixes reachable in L2
                            
                            .. attribute:: all_paths_protected
                            
                            	Number of prefixes with all paths having FRR backup
                            	**type**\:  :py:class:`AllPathsProtected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes.AllPathsProtected>`
                            
                            .. attribute:: some_paths_protected
                            
                            	Number of prefixes with some paths having FRR backup
                            	**type**\:  :py:class:`SomePathsProtected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes.SomePathsProtected>`
                            
                            .. attribute:: unprotected
                            
                            	Number of reachable prefixes without FRR backup
                            	**type**\:  :py:class:`Unprotected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes.Unprotected>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes, self).__init__()

                                self.yang_name = "level2-prefixes"
                                self.yang_parent_name = "frr-summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("all-paths-protected", ("all_paths_protected", Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes.AllPathsProtected)), ("some-paths-protected", ("some_paths_protected", Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes.SomePathsProtected)), ("unprotected", ("unprotected", Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes.Unprotected))])
                                self._leafs = OrderedDict()

                                self.all_paths_protected = Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes.AllPathsProtected()
                                self.all_paths_protected.parent = self
                                self._children_name_map["all_paths_protected"] = "all-paths-protected"

                                self.some_paths_protected = Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes.SomePathsProtected()
                                self.some_paths_protected.parent = self
                                self._children_name_map["some_paths_protected"] = "some-paths-protected"

                                self.unprotected = Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes.Unprotected()
                                self.unprotected.parent = self
                                self._children_name_map["unprotected"] = "unprotected"
                                self._segment_path = lambda: "level2-prefixes"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes, [], name, value)


                            class AllPathsProtected(Entity):
                                """
                                Number of prefixes with all paths having FRR
                                backup
                                
                                .. attribute:: critical
                                
                                	Critical priority
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: high
                                
                                	High priority
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: medium
                                
                                	Medium priority
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low
                                
                                	Low priority
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes.AllPathsProtected, self).__init__()

                                    self.yang_name = "all-paths-protected"
                                    self.yang_parent_name = "level2-prefixes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('critical', (YLeaf(YType.uint32, 'critical'), ['int'])),
                                        ('high', (YLeaf(YType.uint32, 'high'), ['int'])),
                                        ('medium', (YLeaf(YType.uint32, 'medium'), ['int'])),
                                        ('low', (YLeaf(YType.uint32, 'low'), ['int'])),
                                    ])
                                    self.critical = None
                                    self.high = None
                                    self.medium = None
                                    self.low = None
                                    self._segment_path = lambda: "all-paths-protected"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes.AllPathsProtected, [u'critical', u'high', u'medium', u'low'], name, value)


                            class SomePathsProtected(Entity):
                                """
                                Number of prefixes with some paths having FRR
                                backup
                                
                                .. attribute:: critical
                                
                                	Critical priority
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: high
                                
                                	High priority
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: medium
                                
                                	Medium priority
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low
                                
                                	Low priority
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes.SomePathsProtected, self).__init__()

                                    self.yang_name = "some-paths-protected"
                                    self.yang_parent_name = "level2-prefixes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('critical', (YLeaf(YType.uint32, 'critical'), ['int'])),
                                        ('high', (YLeaf(YType.uint32, 'high'), ['int'])),
                                        ('medium', (YLeaf(YType.uint32, 'medium'), ['int'])),
                                        ('low', (YLeaf(YType.uint32, 'low'), ['int'])),
                                    ])
                                    self.critical = None
                                    self.high = None
                                    self.medium = None
                                    self.low = None
                                    self._segment_path = lambda: "some-paths-protected"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes.SomePathsProtected, [u'critical', u'high', u'medium', u'low'], name, value)


                            class Unprotected(Entity):
                                """
                                Number of reachable prefixes without FRR backup
                                
                                .. attribute:: critical
                                
                                	Critical priority
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: high
                                
                                	High priority
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: medium
                                
                                	Medium priority
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low
                                
                                	Low priority
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes.Unprotected, self).__init__()

                                    self.yang_name = "unprotected"
                                    self.yang_parent_name = "level2-prefixes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('critical', (YLeaf(YType.uint32, 'critical'), ['int'])),
                                        ('high', (YLeaf(YType.uint32, 'high'), ['int'])),
                                        ('medium', (YLeaf(YType.uint32, 'medium'), ['int'])),
                                        ('low', (YLeaf(YType.uint32, 'low'), ['int'])),
                                    ])
                                    self.critical = None
                                    self.high = None
                                    self.medium = None
                                    self.low = None
                                    self._segment_path = lambda: "unprotected"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.FrrSummary.Level2Prefixes.Unprotected, [u'critical', u'high', u'medium', u'low'], name, value)


                        class UnreachablePrefixes(Entity):
                            """
                            Unreachable prefixes
                            
                            .. attribute:: critical
                            
                            	Critical priority
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: high
                            
                            	High priority
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: medium
                            
                            	Medium priority
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: low
                            
                            	Low priority
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.Topologies.Topology.FrrSummary.UnreachablePrefixes, self).__init__()

                                self.yang_name = "unreachable-prefixes"
                                self.yang_parent_name = "frr-summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('critical', (YLeaf(YType.uint32, 'critical'), ['int'])),
                                    ('high', (YLeaf(YType.uint32, 'high'), ['int'])),
                                    ('medium', (YLeaf(YType.uint32, 'medium'), ['int'])),
                                    ('low', (YLeaf(YType.uint32, 'low'), ['int'])),
                                ])
                                self.critical = None
                                self.high = None
                                self.medium = None
                                self.low = None
                                self._segment_path = lambda: "unreachable-prefixes"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.FrrSummary.UnreachablePrefixes, [u'critical', u'high', u'medium', u'low'], name, value)


                    class Srv6Locators(Entity):
                        """
                        SRv6 Locator Table
                        
                        .. attribute:: srv6_locator
                        
                        	An SRv6 Locator
                        	**type**\: list of  		 :py:class:`Srv6Locator <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Srv6Locators.Srv6Locator>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.Topologies.Topology.Srv6Locators, self).__init__()

                            self.yang_name = "srv6-locators"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("srv6-locator", ("srv6_locator", Isis.Instances.Instance.Topologies.Topology.Srv6Locators.Srv6Locator))])
                            self._leafs = OrderedDict()

                            self.srv6_locator = YList(self)
                            self._segment_path = lambda: "srv6-locators"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Srv6Locators, [], name, value)


                        class Srv6Locator(Entity):
                            """
                            An SRv6 Locator
                            
                            .. attribute:: prefix
                            
                            	Prefix
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length
                            
                            	Prefix Length
                            	**type**\: int
                            
                            	**range:** 0..128
                            
                            .. attribute:: locator_name
                            
                            	LocatorName
                            	**type**\: str
                            
                            .. attribute:: locator_id
                            
                            	LocatorID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: locator_format
                            
                            	LocatorFormat
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: locator_flags
                            
                            	LocatorFlags
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: number_of_reserved_opcodes
                            
                            	NumberOfReservedOpcodes
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: opcode
                            
                            	Reserved Opcodes
                            	**type**\: list of  		 :py:class:`Opcode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Srv6Locators.Srv6Locator.Opcode>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.Topologies.Topology.Srv6Locators.Srv6Locator, self).__init__()

                                self.yang_name = "srv6-locator"
                                self.yang_parent_name = "srv6-locators"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("opcode", ("opcode", Isis.Instances.Instance.Topologies.Topology.Srv6Locators.Srv6Locator.Opcode))])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                    ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                    ('locator_name', (YLeaf(YType.str, 'locator-name'), ['str'])),
                                    ('locator_id', (YLeaf(YType.uint32, 'locator-id'), ['int'])),
                                    ('locator_format', (YLeaf(YType.uint32, 'locator-format'), ['int'])),
                                    ('locator_flags', (YLeaf(YType.uint16, 'locator-flags'), ['int'])),
                                    ('number_of_reserved_opcodes', (YLeaf(YType.uint8, 'number-of-reserved-opcodes'), ['int'])),
                                ])
                                self.prefix = None
                                self.prefix_length = None
                                self.locator_name = None
                                self.locator_id = None
                                self.locator_format = None
                                self.locator_flags = None
                                self.number_of_reserved_opcodes = None

                                self.opcode = YList(self)
                                self._segment_path = lambda: "srv6-locator"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Srv6Locators.Srv6Locator, ['prefix', 'prefix_length', u'locator_name', u'locator_id', u'locator_format', u'locator_flags', u'number_of_reserved_opcodes'], name, value)


                            class Opcode(Entity):
                                """
                                Reserved Opcodes
                                
                                .. attribute:: function_type
                                
                                	FunctionType
                                	**type**\:  :py:class:`Srv6EndFunction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Srv6EndFunction>`
                                
                                .. attribute:: function_opcode
                                
                                	FunctionOpcode
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.Srv6Locators.Srv6Locator.Opcode, self).__init__()

                                    self.yang_name = "opcode"
                                    self.yang_parent_name = "srv6-locator"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('function_type', (YLeaf(YType.enumeration, 'function-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'Srv6EndFunction', '')])),
                                        ('function_opcode', (YLeaf(YType.uint16, 'function-opcode'), ['int'])),
                                    ])
                                    self.function_type = None
                                    self.function_opcode = None
                                    self._segment_path = lambda: "opcode"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Srv6Locators.Srv6Locator.Opcode, [u'function_type', u'function_opcode'], name, value)


                    class TopologyLevels(Entity):
                        """
                        Per\-topology level table
                        
                        .. attribute:: topology_level
                        
                        	Per\-level topology operational data
                        	**type**\: list of  		 :py:class:`TopologyLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels, self).__init__()

                            self.yang_name = "topology-levels"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("topology-level", ("topology_level", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel))])
                            self._leafs = OrderedDict()

                            self.topology_level = YList(self)
                            self._segment_path = lambda: "topology-levels"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels, [], name, value)


                        class TopologyLevel(Entity):
                            """
                            Per\-level topology operational data
                            
                            .. attribute:: level  (key)
                            
                            	Level
                            	**type**\:  :py:class:`IsisInternalLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_datatypes.IsisInternalLevel>`
                            
                            .. attribute:: te_advertisements
                            
                            	TE advertisements for a single level and topology. Only available within the IPv4 Unicast topology
                            	**type**\:  :py:class:`TeAdvertisements <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements>`
                            
                            .. attribute:: te_adjacency_log
                            
                            	TE adjacency\-log for a single level and topology. Only available within the IPv4 Unicast topology
                            	**type**\:  :py:class:`TeAdjacencyLog <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog>`
                            
                            .. attribute:: spf_log
                            
                            	Log of route calculations for a single level and topology
                            	**type**\:  :py:class:`SpfLog <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog>`
                            
                            .. attribute:: te_tunnels
                            
                            	TE tunnels table. Only available within the IPv4 Unicast topology
                            	**type**\:  :py:class:`TeTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeTunnels>`
                            
                            .. attribute:: ipv4_link_topologies
                            
                            	IPv4 IS Topology table
                            	**type**\:  :py:class:`Ipv4LinkTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies>`
                            
                            .. attribute:: topology_summary
                            
                            	Summary information for a particular IS Topology
                            	**type**\:  :py:class:`TopologySummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TopologySummary>`
                            
                            .. attribute:: ipv6_link_topologies
                            
                            	IPv6 IS Topology table
                            	**type**\:  :py:class:`Ipv6LinkTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel, self).__init__()

                                self.yang_name = "topology-level"
                                self.yang_parent_name = "topology-levels"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['level']
                                self._child_classes = OrderedDict([("te-advertisements", ("te_advertisements", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements)), ("te-adjacency-log", ("te_adjacency_log", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog)), ("spf-log", ("spf_log", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog)), ("te-tunnels", ("te_tunnels", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeTunnels)), ("ipv4-link-topologies", ("ipv4_link_topologies", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies)), ("topology-summary", ("topology_summary", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TopologySummary)), ("ipv6-link-topologies", ("ipv6_link_topologies", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies))])
                                self._leafs = OrderedDict([
                                    ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_datatypes', 'IsisInternalLevel', '')])),
                                ])
                                self.level = None

                                self.te_advertisements = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements()
                                self.te_advertisements.parent = self
                                self._children_name_map["te_advertisements"] = "te-advertisements"

                                self.te_adjacency_log = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog()
                                self.te_adjacency_log.parent = self
                                self._children_name_map["te_adjacency_log"] = "te-adjacency-log"

                                self.spf_log = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog()
                                self.spf_log.parent = self
                                self._children_name_map["spf_log"] = "spf-log"

                                self.te_tunnels = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeTunnels()
                                self.te_tunnels.parent = self
                                self._children_name_map["te_tunnels"] = "te-tunnels"

                                self.ipv4_link_topologies = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies()
                                self.ipv4_link_topologies.parent = self
                                self._children_name_map["ipv4_link_topologies"] = "ipv4-link-topologies"

                                self.topology_summary = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TopologySummary()
                                self.topology_summary.parent = self
                                self._children_name_map["topology_summary"] = "topology-summary"

                                self.ipv6_link_topologies = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies()
                                self.ipv6_link_topologies.parent = self
                                self._children_name_map["ipv6_link_topologies"] = "ipv6-link-topologies"
                                self._segment_path = lambda: "topology-level" + "[level='" + str(self.level) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel, ['level'], name, value)


                            class TeAdvertisements(Entity):
                                """
                                TE advertisements for a single level and
                                topology. Only available within the IPv4
                                Unicast topology.
                                
                                .. attribute:: tepceadv
                                
                                	TE PCE advertisements
                                	**type**\:  :py:class:`Tepceadv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.Tepceadv>`
                                
                                .. attribute:: te_adv_data_present
                                
                                	Indicates whether any TE advertisements are present
                                	**type**\: bool
                                
                                .. attribute:: te_system_id
                                
                                	Local system ID
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                
                                .. attribute:: te_local_router_id
                                
                                	Local TE router ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: te_adv
                                
                                	List of TE advertisement entries
                                	**type**\: list of  		 :py:class:`TeAdv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements, self).__init__()

                                    self.yang_name = "te-advertisements"
                                    self.yang_parent_name = "topology-level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("tepceadv", ("tepceadv", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.Tepceadv)), ("te-adv", ("te_adv", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv))])
                                    self._leafs = OrderedDict([
                                        ('te_adv_data_present', (YLeaf(YType.boolean, 'te-adv-data-present'), ['bool'])),
                                        ('te_system_id', (YLeaf(YType.str, 'te-system-id'), ['str'])),
                                        ('te_local_router_id', (YLeaf(YType.str, 'te-local-router-id'), ['str'])),
                                    ])
                                    self.te_adv_data_present = None
                                    self.te_system_id = None
                                    self.te_local_router_id = None

                                    self.tepceadv = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.Tepceadv()
                                    self.tepceadv.parent = self
                                    self._children_name_map["tepceadv"] = "tepceadv"

                                    self.te_adv = YList(self)
                                    self._segment_path = lambda: "te-advertisements"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements, [u'te_adv_data_present', u'te_system_id', u'te_local_router_id'], name, value)


                                class Tepceadv(Entity):
                                    """
                                    TE PCE advertisements
                                    
                                    .. attribute:: pce_adv_data_present
                                    
                                    	Indicates whether any PCE advertisements are present
                                    	**type**\: bool
                                    
                                    .. attribute:: pce_flooding_scope
                                    
                                    	Flooding scope for PCE advertisement
                                    	**type**\:  :py:class:`IsisShTePceFloodingScope <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisShTePceFloodingScope>`
                                    
                                    .. attribute:: pce_address_ipv4
                                    
                                    	IPv4 PCE address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pce_path_scope_bits
                                    
                                    	PCE path scope bits
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: pce_path_scope_prefs
                                    
                                    	PCE path scope preferences
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.Tepceadv, self).__init__()

                                        self.yang_name = "tepceadv"
                                        self.yang_parent_name = "te-advertisements"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pce_adv_data_present', (YLeaf(YType.boolean, 'pce-adv-data-present'), ['bool'])),
                                            ('pce_flooding_scope', (YLeaf(YType.enumeration, 'pce-flooding-scope'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisShTePceFloodingScope', '')])),
                                            ('pce_address_ipv4', (YLeaf(YType.str, 'pce-address-ipv4'), ['str'])),
                                            ('pce_path_scope_bits', (YLeaf(YType.uint8, 'pce-path-scope-bits'), ['int'])),
                                            ('pce_path_scope_prefs', (YLeaf(YType.uint16, 'pce-path-scope-prefs'), ['int'])),
                                        ])
                                        self.pce_adv_data_present = None
                                        self.pce_flooding_scope = None
                                        self.pce_address_ipv4 = None
                                        self.pce_path_scope_bits = None
                                        self.pce_path_scope_prefs = None
                                        self._segment_path = lambda: "tepceadv"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.Tepceadv, [u'pce_adv_data_present', u'pce_flooding_scope', u'pce_address_ipv4', u'pce_path_scope_bits', u'pce_path_scope_prefs'], name, value)


                                class TeAdv(Entity):
                                    """
                                    List of TE advertisement entries
                                    
                                    .. attribute:: te_neighbor_system_id
                                    
                                    	Neighbor system ID
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                    
                                    .. attribute:: link_type
                                    
                                    	Link type
                                    	**type**\:  :py:class:`IsisShTeLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisShTeLink>`
                                    
                                    .. attribute:: local_ip_address
                                    
                                    	Local IP address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: te_neighbor_ip_address
                                    
                                    	Neighbor IP address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: te_metric
                                    
                                    	TE metric
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: te_physical_link_bandwidth
                                    
                                    	Physical link bandwidth
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: te_reserved_link_bandwidth
                                    
                                    	Reservable link bandwidth in global pool
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: te_subpool_reserved_link_bandwidth
                                    
                                    	Reservable link bandwidth in subpool
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: te_affinity
                                    
                                    	Affinity bits
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: te_ext_admin_num
                                    
                                    	TE Ext Admin Number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: te_sub_tlv_data_present
                                    
                                    	Indicates whether any TE sub TLVs are present
                                    	**type**\: bool
                                    
                                    .. attribute:: te_transmitted_bandwidth
                                    
                                    	Bandwidth in use in global pool
                                    	**type**\: list of  		 :py:class:`TeTransmittedBandwidth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv.TeTransmittedBandwidth>`
                                    
                                    .. attribute:: te_subpool_transmitted_bandwidth
                                    
                                    	Bandwidth in use in subpool
                                    	**type**\: list of  		 :py:class:`TeSubpoolTransmittedBandwidth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv.TeSubpoolTransmittedBandwidth>`
                                    
                                    .. attribute:: te_ext_admin_sub
                                    
                                    	TE Extended Admin Group
                                    	**type**\: list of  		 :py:class:`TeExtAdminSub <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv.TeExtAdminSub>`
                                    
                                    .. attribute:: te_sub_tlv
                                    
                                    	List of TE sub TLVs
                                    	**type**\: list of  		 :py:class:`TeSubTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv.TeSubTlv>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv, self).__init__()

                                        self.yang_name = "te-adv"
                                        self.yang_parent_name = "te-advertisements"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("te-transmitted-bandwidth", ("te_transmitted_bandwidth", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv.TeTransmittedBandwidth)), ("te-subpool-transmitted-bandwidth", ("te_subpool_transmitted_bandwidth", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv.TeSubpoolTransmittedBandwidth)), ("te-ext-admin-sub", ("te_ext_admin_sub", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv.TeExtAdminSub)), ("te-sub-tlv", ("te_sub_tlv", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv.TeSubTlv))])
                                        self._leafs = OrderedDict([
                                            ('te_neighbor_system_id', (YLeaf(YType.str, 'te-neighbor-system-id'), ['str'])),
                                            ('link_type', (YLeaf(YType.enumeration, 'link-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisShTeLink', '')])),
                                            ('local_ip_address', (YLeaf(YType.str, 'local-ip-address'), ['str'])),
                                            ('te_neighbor_ip_address', (YLeaf(YType.str, 'te-neighbor-ip-address'), ['str'])),
                                            ('te_metric', (YLeaf(YType.uint32, 'te-metric'), ['int'])),
                                            ('te_physical_link_bandwidth', (YLeaf(YType.uint32, 'te-physical-link-bandwidth'), ['int'])),
                                            ('te_reserved_link_bandwidth', (YLeaf(YType.uint32, 'te-reserved-link-bandwidth'), ['int'])),
                                            ('te_subpool_reserved_link_bandwidth', (YLeaf(YType.uint32, 'te-subpool-reserved-link-bandwidth'), ['int'])),
                                            ('te_affinity', (YLeaf(YType.uint32, 'te-affinity'), ['int'])),
                                            ('te_ext_admin_num', (YLeaf(YType.uint32, 'te-ext-admin-num'), ['int'])),
                                            ('te_sub_tlv_data_present', (YLeaf(YType.boolean, 'te-sub-tlv-data-present'), ['bool'])),
                                        ])
                                        self.te_neighbor_system_id = None
                                        self.link_type = None
                                        self.local_ip_address = None
                                        self.te_neighbor_ip_address = None
                                        self.te_metric = None
                                        self.te_physical_link_bandwidth = None
                                        self.te_reserved_link_bandwidth = None
                                        self.te_subpool_reserved_link_bandwidth = None
                                        self.te_affinity = None
                                        self.te_ext_admin_num = None
                                        self.te_sub_tlv_data_present = None

                                        self.te_transmitted_bandwidth = YList(self)
                                        self.te_subpool_transmitted_bandwidth = YList(self)
                                        self.te_ext_admin_sub = YList(self)
                                        self.te_sub_tlv = YList(self)
                                        self._segment_path = lambda: "te-adv"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv, [u'te_neighbor_system_id', u'link_type', u'local_ip_address', u'te_neighbor_ip_address', u'te_metric', u'te_physical_link_bandwidth', u'te_reserved_link_bandwidth', u'te_subpool_reserved_link_bandwidth', u'te_affinity', u'te_ext_admin_num', u'te_sub_tlv_data_present'], name, value)


                                    class TeTransmittedBandwidth(Entity):
                                        """
                                        Bandwidth in use in global pool
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv.TeTransmittedBandwidth, self).__init__()

                                            self.yang_name = "te-transmitted-bandwidth"
                                            self.yang_parent_name = "te-adv"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "te-transmitted-bandwidth"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv.TeTransmittedBandwidth, [u'entry'], name, value)


                                    class TeSubpoolTransmittedBandwidth(Entity):
                                        """
                                        Bandwidth in use in subpool
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv.TeSubpoolTransmittedBandwidth, self).__init__()

                                            self.yang_name = "te-subpool-transmitted-bandwidth"
                                            self.yang_parent_name = "te-adv"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "te-subpool-transmitted-bandwidth"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv.TeSubpoolTransmittedBandwidth, [u'entry'], name, value)


                                    class TeExtAdminSub(Entity):
                                        """
                                        TE Extended Admin Group
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv.TeExtAdminSub, self).__init__()

                                            self.yang_name = "te-ext-admin-sub"
                                            self.yang_parent_name = "te-adv"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "te-ext-admin-sub"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv.TeExtAdminSub, [u'entry'], name, value)


                                    class TeSubTlv(Entity):
                                        """
                                        List of TE sub TLVs
                                        
                                        .. attribute:: te_sub_tlv_type
                                        
                                        	Type of sub TLV
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: te_sub_tlv_length
                                        
                                        	Length of sub TLV
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: te_sub_tlv_value
                                        
                                        	Value of sub TLV
                                        	**type**\: str
                                        
                                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv.TeSubTlv, self).__init__()

                                            self.yang_name = "te-sub-tlv"
                                            self.yang_parent_name = "te-adv"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('te_sub_tlv_type', (YLeaf(YType.uint16, 'te-sub-tlv-type'), ['int'])),
                                                ('te_sub_tlv_length', (YLeaf(YType.uint16, 'te-sub-tlv-length'), ['int'])),
                                                ('te_sub_tlv_value', (YLeaf(YType.str, 'te-sub-tlv-value'), ['str'])),
                                            ])
                                            self.te_sub_tlv_type = None
                                            self.te_sub_tlv_length = None
                                            self.te_sub_tlv_value = None
                                            self._segment_path = lambda: "te-sub-tlv"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdvertisements.TeAdv.TeSubTlv, [u'te_sub_tlv_type', u'te_sub_tlv_length', u'te_sub_tlv_value'], name, value)


                            class TeAdjacencyLog(Entity):
                                """
                                TE adjacency\-log for a single level and
                                topology. Only available within the IPv4
                                Unicast topology.
                                
                                .. attribute:: log_entry
                                
                                	Log entries
                                	**type**\: list of  		 :py:class:`LogEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog.LogEntry>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog, self).__init__()

                                    self.yang_name = "te-adjacency-log"
                                    self.yang_parent_name = "topology-level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("log-entry", ("log_entry", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog.LogEntry))])
                                    self._leafs = OrderedDict()

                                    self.log_entry = YList(self)
                                    self._segment_path = lambda: "te-adjacency-log"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog, [], name, value)


                                class LogEntry(Entity):
                                    """
                                    Log entries
                                    
                                    .. attribute:: generic_data
                                    
                                    	Generic entry data
                                    	**type**\:  :py:class:`GenericData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog.LogEntry.GenericData>`
                                    
                                    .. attribute:: neighbor_ip_address
                                    
                                    	Neighbor ip address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: status
                                    
                                    	Up (TRUE) or down
                                    	**type**\: bool
                                    
                                    .. attribute:: log_interface
                                    
                                    	Interface
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: te_log_neighbor_system_id
                                    
                                    	Neighbor system ID
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog.LogEntry, self).__init__()

                                        self.yang_name = "log-entry"
                                        self.yang_parent_name = "te-adjacency-log"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("generic-data", ("generic_data", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog.LogEntry.GenericData))])
                                        self._leafs = OrderedDict([
                                            ('neighbor_ip_address', (YLeaf(YType.str, 'neighbor-ip-address'), ['str'])),
                                            ('status', (YLeaf(YType.boolean, 'status'), ['bool'])),
                                            ('log_interface', (YLeaf(YType.str, 'log-interface'), ['str'])),
                                            ('te_log_neighbor_system_id', (YLeaf(YType.str, 'te-log-neighbor-system-id'), ['str'])),
                                        ])
                                        self.neighbor_ip_address = None
                                        self.status = None
                                        self.log_interface = None
                                        self.te_log_neighbor_system_id = None

                                        self.generic_data = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog.LogEntry.GenericData()
                                        self.generic_data.parent = self
                                        self._children_name_map["generic_data"] = "generic-data"
                                        self._segment_path = lambda: "log-entry"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog.LogEntry, [u'neighbor_ip_address', u'status', u'log_interface', u'te_log_neighbor_system_id'], name, value)


                                    class GenericData(Entity):
                                        """
                                        Generic entry data
                                        
                                        .. attribute:: timestamp
                                        
                                        	Time in UTC relative to Jan 1st, 1970
                                        	**type**\:  :py:class:`Timestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog.LogEntry.GenericData.Timestamp>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog.LogEntry.GenericData, self).__init__()

                                            self.yang_name = "generic-data"
                                            self.yang_parent_name = "log-entry"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("timestamp", ("timestamp", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog.LogEntry.GenericData.Timestamp))])
                                            self._leafs = OrderedDict()

                                            self.timestamp = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog.LogEntry.GenericData.Timestamp()
                                            self.timestamp.parent = self
                                            self._children_name_map["timestamp"] = "timestamp"
                                            self._segment_path = lambda: "generic-data"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog.LogEntry.GenericData, [], name, value)


                                        class Timestamp(Entity):
                                            """
                                            Time in UTC relative to Jan 1st, 1970
                                            
                                            .. attribute:: seconds
                                            
                                            	Timestamp value (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nano_seconds
                                            
                                            	Timestamp value (nanoseconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog.LogEntry.GenericData.Timestamp, self).__init__()

                                                self.yang_name = "timestamp"
                                                self.yang_parent_name = "generic-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nano_seconds', (YLeaf(YType.uint32, 'nano-seconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nano_seconds = None
                                                self._segment_path = lambda: "timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeAdjacencyLog.LogEntry.GenericData.Timestamp, [u'seconds', u'nano_seconds'], name, value)


                            class SpfLog(Entity):
                                """
                                Log of route calculations for a single
                                level and topology
                                
                                .. attribute:: log_entry
                                
                                	SPF Log entries
                                	**type**\: list of  		 :py:class:`LogEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog, self).__init__()

                                    self.yang_name = "spf-log"
                                    self.yang_parent_name = "topology-level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("log-entry", ("log_entry", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry))])
                                    self._leafs = OrderedDict()

                                    self.log_entry = YList(self)
                                    self._segment_path = lambda: "spf-log"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog, [], name, value)


                                class LogEntry(Entity):
                                    """
                                    SPF Log entries
                                    
                                    .. attribute:: generic_data
                                    
                                    	Generic entry data
                                    	**type**\:  :py:class:`GenericData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.GenericData>`
                                    
                                    .. attribute:: triggers
                                    
                                    	Trigger information
                                    	**type**\:  :py:class:`Triggers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers>`
                                    
                                    .. attribute:: spt_calculation_statistics
                                    
                                    	Statistics for the SPT calculation phase
                                    	**type**\:  :py:class:`SptCalculationStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.SptCalculationStatistics>`
                                    
                                    .. attribute:: route_update_statistics
                                    
                                    	Statistics for the route update phase
                                    	**type**\:  :py:class:`RouteUpdateStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics>`
                                    
                                    .. attribute:: class_
                                    
                                    	Type of calculation
                                    	**type**\:  :py:class:`IsisSpfClass <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisSpfClass>`
                                    
                                    .. attribute:: wait_enforced
                                    
                                    	Time between the first trigger and the start of the route calculation, in milliseconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: next_wait_interval
                                    
                                    	Minimum time from end of this route calculation until the start of the next, in milliseconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: updated_lsp_count
                                    
                                    	Number of LSPs which arrived during the route calculation
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry, self).__init__()

                                        self.yang_name = "log-entry"
                                        self.yang_parent_name = "spf-log"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("generic-data", ("generic_data", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.GenericData)), ("triggers", ("triggers", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers)), ("spt-calculation-statistics", ("spt_calculation_statistics", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.SptCalculationStatistics)), ("route-update-statistics", ("route_update_statistics", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics))])
                                        self._leafs = OrderedDict([
                                            ('class_', (YLeaf(YType.enumeration, 'class'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisSpfClass', '')])),
                                            ('wait_enforced', (YLeaf(YType.uint32, 'wait-enforced'), ['int'])),
                                            ('next_wait_interval', (YLeaf(YType.uint32, 'next-wait-interval'), ['int'])),
                                            ('updated_lsp_count', (YLeaf(YType.uint32, 'updated-lsp-count'), ['int'])),
                                        ])
                                        self.class_ = None
                                        self.wait_enforced = None
                                        self.next_wait_interval = None
                                        self.updated_lsp_count = None

                                        self.generic_data = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.GenericData()
                                        self.generic_data.parent = self
                                        self._children_name_map["generic_data"] = "generic-data"

                                        self.triggers = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers()
                                        self.triggers.parent = self
                                        self._children_name_map["triggers"] = "triggers"

                                        self.spt_calculation_statistics = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.SptCalculationStatistics()
                                        self.spt_calculation_statistics.parent = self
                                        self._children_name_map["spt_calculation_statistics"] = "spt-calculation-statistics"

                                        self.route_update_statistics = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics()
                                        self.route_update_statistics.parent = self
                                        self._children_name_map["route_update_statistics"] = "route-update-statistics"
                                        self._segment_path = lambda: "log-entry"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry, [u'class_', u'wait_enforced', u'next_wait_interval', u'updated_lsp_count'], name, value)


                                    class GenericData(Entity):
                                        """
                                        Generic entry data.
                                        
                                        .. attribute:: timestamp
                                        
                                        	Time in UTC relative to Jan 1st, 1970
                                        	**type**\:  :py:class:`Timestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.GenericData.Timestamp>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.GenericData, self).__init__()

                                            self.yang_name = "generic-data"
                                            self.yang_parent_name = "log-entry"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("timestamp", ("timestamp", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.GenericData.Timestamp))])
                                            self._leafs = OrderedDict()

                                            self.timestamp = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.GenericData.Timestamp()
                                            self.timestamp.parent = self
                                            self._children_name_map["timestamp"] = "timestamp"
                                            self._segment_path = lambda: "generic-data"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.GenericData, [], name, value)


                                        class Timestamp(Entity):
                                            """
                                            Time in UTC relative to Jan 1st, 1970
                                            
                                            .. attribute:: seconds
                                            
                                            	Timestamp value (seconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: nano_seconds
                                            
                                            	Timestamp value (nanoseconds)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: nanosecond
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.GenericData.Timestamp, self).__init__()

                                                self.yang_name = "timestamp"
                                                self.yang_parent_name = "generic-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                                    ('nano_seconds', (YLeaf(YType.uint32, 'nano-seconds'), ['int'])),
                                                ])
                                                self.seconds = None
                                                self.nano_seconds = None
                                                self._segment_path = lambda: "timestamp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.GenericData.Timestamp, [u'seconds', u'nano_seconds'], name, value)


                                    class Triggers(Entity):
                                        """
                                        Trigger information
                                        
                                        .. attribute:: trigger_prefix
                                        
                                        	ID of a changed prefix in the first trigger LSP, if any
                                        	**type**\:  :py:class:`TriggerPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.TriggerPrefix>`
                                        
                                        .. attribute:: unique_trigger_count
                                        
                                        	Number of unique triggers on this run
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: first_trigger_lsp_id
                                        
                                        	ID of the first LSP to trigger the calculation, if any
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                        
                                        .. attribute:: trigger_link
                                        
                                        	ID of a changed link in the first trigger LSP, if any
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}
                                        
                                        .. attribute:: trigger_next_hop_id
                                        
                                        	ID of a changed next hop, if any
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                        
                                        .. attribute:: is_sr_uloop_calculation
                                        
                                        	Is this SR micro loop calculation?
                                        	**type**\: bool
                                        
                                        .. attribute:: is_sr_uloop_link_down
                                        
                                        	Is this SR micro loop calculation for link down?
                                        	**type**\: bool
                                        
                                        .. attribute:: trigger
                                        
                                        	Triggers applying to this log entry
                                        	**type**\: list of  		 :py:class:`Trigger <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.Trigger>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers, self).__init__()

                                            self.yang_name = "triggers"
                                            self.yang_parent_name = "log-entry"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("trigger-prefix", ("trigger_prefix", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.TriggerPrefix)), ("trigger", ("trigger", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.Trigger))])
                                            self._leafs = OrderedDict([
                                                ('unique_trigger_count', (YLeaf(YType.uint32, 'unique-trigger-count'), ['int'])),
                                                ('first_trigger_lsp_id', (YLeaf(YType.str, 'first-trigger-lsp-id'), ['str'])),
                                                ('trigger_link', (YLeaf(YType.str, 'trigger-link'), ['str'])),
                                                ('trigger_next_hop_id', (YLeaf(YType.str, 'trigger-next-hop-id'), ['str'])),
                                                ('is_sr_uloop_calculation', (YLeaf(YType.boolean, 'is-sr-uloop-calculation'), ['bool'])),
                                                ('is_sr_uloop_link_down', (YLeaf(YType.boolean, 'is-sr-uloop-link-down'), ['bool'])),
                                            ])
                                            self.unique_trigger_count = None
                                            self.first_trigger_lsp_id = None
                                            self.trigger_link = None
                                            self.trigger_next_hop_id = None
                                            self.is_sr_uloop_calculation = None
                                            self.is_sr_uloop_link_down = None

                                            self.trigger_prefix = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.TriggerPrefix()
                                            self.trigger_prefix.parent = self
                                            self._children_name_map["trigger_prefix"] = "trigger-prefix"

                                            self.trigger = YList(self)
                                            self._segment_path = lambda: "triggers"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers, [u'unique_trigger_count', u'first_trigger_lsp_id', u'trigger_link', u'trigger_next_hop_id', u'is_sr_uloop_calculation', u'is_sr_uloop_link_down'], name, value)


                                        class TriggerPrefix(Entity):
                                            """
                                            ID of a changed prefix in the first trigger LSP,
                                            if any
                                            
                                            .. attribute:: ipv4
                                            
                                            	ipv4
                                            	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.TriggerPrefix.Ipv4>`
                                            
                                            .. attribute:: ipv6
                                            
                                            	ipv6
                                            	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.TriggerPrefix.Ipv6>`
                                            
                                            .. attribute:: af_name
                                            
                                            	AFName
                                            	**type**\:  :py:class:`IsisAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAfId>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.TriggerPrefix, self).__init__()

                                                self.yang_name = "trigger-prefix"
                                                self.yang_parent_name = "triggers"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ipv4", ("ipv4", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.TriggerPrefix.Ipv4)), ("ipv6", ("ipv6", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.TriggerPrefix.Ipv6))])
                                                self._leafs = OrderedDict([
                                                    ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisAfId', '')])),
                                                ])
                                                self.af_name = None

                                                self.ipv4 = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.TriggerPrefix.Ipv4()
                                                self.ipv4.parent = self
                                                self._children_name_map["ipv4"] = "ipv4"

                                                self.ipv6 = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.TriggerPrefix.Ipv6()
                                                self.ipv6.parent = self
                                                self._children_name_map["ipv6"] = "ipv6"
                                                self._segment_path = lambda: "trigger-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.TriggerPrefix, [u'af_name'], name, value)


                                            class Ipv4(Entity):
                                                """
                                                ipv4
                                                
                                                .. attribute:: prefix
                                                
                                                	prefix
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.TriggerPrefix.Ipv4, self).__init__()

                                                    self.yang_name = "ipv4"
                                                    self.yang_parent_name = "trigger-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                        ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                    ])
                                                    self.prefix = None
                                                    self.prefix_length = None
                                                    self._segment_path = lambda: "ipv4"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.TriggerPrefix.Ipv4, [u'prefix', u'prefix_length'], name, value)


                                            class Ipv6(Entity):
                                                """
                                                ipv6
                                                
                                                .. attribute:: prefix
                                                
                                                	prefix
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	prefix length
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.TriggerPrefix.Ipv6, self).__init__()

                                                    self.yang_name = "ipv6"
                                                    self.yang_parent_name = "trigger-prefix"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                        ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                    ])
                                                    self.prefix = None
                                                    self.prefix_length = None
                                                    self._segment_path = lambda: "ipv6"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.TriggerPrefix.Ipv6, [u'prefix', u'prefix_length'], name, value)


                                        class Trigger(Entity):
                                            """
                                            Triggers applying to this log entry
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\:  :py:class:`IsisSpfTrigger <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisSpfTrigger>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.Trigger, self).__init__()

                                                self.yang_name = "trigger"
                                                self.yang_parent_name = "triggers"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.enumeration, 'entry'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisSpfTrigger', '')])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "trigger"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.Triggers.Trigger, [u'entry'], name, value)


                                    class SptCalculationStatistics(Entity):
                                        """
                                        Statistics for the SPT calculation phase
                                        
                                        .. attribute:: duration
                                        
                                        	Duration of the SPT calculation
                                        	**type**\:  :py:class:`Duration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.SptCalculationStatistics.Duration>`
                                        
                                        .. attribute:: node_counts
                                        
                                        	Node counts
                                        	**type**\:  :py:class:`NodeCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.SptCalculationStatistics.NodeCounts>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.SptCalculationStatistics, self).__init__()

                                            self.yang_name = "spt-calculation-statistics"
                                            self.yang_parent_name = "log-entry"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("duration", ("duration", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.SptCalculationStatistics.Duration)), ("node-counts", ("node_counts", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.SptCalculationStatistics.NodeCounts))])
                                            self._leafs = OrderedDict()

                                            self.duration = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.SptCalculationStatistics.Duration()
                                            self.duration.parent = self
                                            self._children_name_map["duration"] = "duration"

                                            self.node_counts = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.SptCalculationStatistics.NodeCounts()
                                            self.node_counts.parent = self
                                            self._children_name_map["node_counts"] = "node-counts"
                                            self._segment_path = lambda: "spt-calculation-statistics"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.SptCalculationStatistics, [], name, value)


                                        class Duration(Entity):
                                            """
                                            Duration of the SPT calculation
                                            
                                            .. attribute:: real_duration
                                            
                                            	Real time duration in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: cpu_duration
                                            
                                            	CPU time duration in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.SptCalculationStatistics.Duration, self).__init__()

                                                self.yang_name = "duration"
                                                self.yang_parent_name = "spt-calculation-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('real_duration', (YLeaf(YType.uint32, 'real-duration'), ['int'])),
                                                    ('cpu_duration', (YLeaf(YType.uint32, 'cpu-duration'), ['int'])),
                                                ])
                                                self.real_duration = None
                                                self.cpu_duration = None
                                                self._segment_path = lambda: "duration"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.SptCalculationStatistics.Duration, [u'real_duration', u'cpu_duration'], name, value)


                                        class NodeCounts(Entity):
                                            """
                                            Node counts
                                            
                                            .. attribute:: unreachable
                                            
                                            	Number of unreachable nodes in the database
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: reachable
                                            
                                            	Number of reachable nodes in the database
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: added
                                            
                                            	Number of nodes added to the SPT
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: deleted
                                            
                                            	Number of nodes deleted from the SPT
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: modified
                                            
                                            	Number of modified nodes (first hop and/or metric change)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: touched
                                            
                                            	Number of nodes touched whilst calculating the SPT
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.SptCalculationStatistics.NodeCounts, self).__init__()

                                                self.yang_name = "node-counts"
                                                self.yang_parent_name = "spt-calculation-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('unreachable', (YLeaf(YType.uint32, 'unreachable'), ['int'])),
                                                    ('reachable', (YLeaf(YType.uint32, 'reachable'), ['int'])),
                                                    ('added', (YLeaf(YType.uint32, 'added'), ['int'])),
                                                    ('deleted', (YLeaf(YType.uint32, 'deleted'), ['int'])),
                                                    ('modified', (YLeaf(YType.uint32, 'modified'), ['int'])),
                                                    ('touched', (YLeaf(YType.uint32, 'touched'), ['int'])),
                                                ])
                                                self.unreachable = None
                                                self.reachable = None
                                                self.added = None
                                                self.deleted = None
                                                self.modified = None
                                                self.touched = None
                                                self._segment_path = lambda: "node-counts"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.SptCalculationStatistics.NodeCounts, [u'unreachable', u'reachable', u'added', u'deleted', u'modified', u'touched'], name, value)


                                    class RouteUpdateStatistics(Entity):
                                        """
                                        Statistics for the route update phase
                                        
                                        .. attribute:: duration
                                        
                                        	Duration of the routing table update
                                        	**type**\:  :py:class:`Duration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.Duration>`
                                        
                                        .. attribute:: duration_breakdown
                                        
                                        	Breakdown of the time taken by the routing table update
                                        	**type**\:  :py:class:`DurationBreakdown <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown>`
                                        
                                        .. attribute:: node_counts
                                        
                                        	Node counts
                                        	**type**\:  :py:class:`NodeCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.NodeCounts>`
                                        
                                        .. attribute:: item_counts
                                        
                                        	Prefix item counts
                                        	**type**\:  :py:class:`ItemCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts>`
                                        
                                        .. attribute:: route_counts
                                        
                                        	Distinct prefix counts
                                        	**type**\:  :py:class:`RouteCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts>`
                                        
                                        .. attribute:: rib_batch_counts
                                        
                                        	Number of RIB batches sent
                                        	**type**\:  :py:class:`RibBatchCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RibBatchCounts>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics, self).__init__()

                                            self.yang_name = "route-update-statistics"
                                            self.yang_parent_name = "log-entry"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("duration", ("duration", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.Duration)), ("duration-breakdown", ("duration_breakdown", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown)), ("node-counts", ("node_counts", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.NodeCounts)), ("item-counts", ("item_counts", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts)), ("route-counts", ("route_counts", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts)), ("rib-batch-counts", ("rib_batch_counts", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RibBatchCounts))])
                                            self._leafs = OrderedDict()

                                            self.duration = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.Duration()
                                            self.duration.parent = self
                                            self._children_name_map["duration"] = "duration"

                                            self.duration_breakdown = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown()
                                            self.duration_breakdown.parent = self
                                            self._children_name_map["duration_breakdown"] = "duration-breakdown"

                                            self.node_counts = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.NodeCounts()
                                            self.node_counts.parent = self
                                            self._children_name_map["node_counts"] = "node-counts"

                                            self.item_counts = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts()
                                            self.item_counts.parent = self
                                            self._children_name_map["item_counts"] = "item-counts"

                                            self.route_counts = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts()
                                            self.route_counts.parent = self
                                            self._children_name_map["route_counts"] = "route-counts"

                                            self.rib_batch_counts = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RibBatchCounts()
                                            self.rib_batch_counts.parent = self
                                            self._children_name_map["rib_batch_counts"] = "rib-batch-counts"
                                            self._segment_path = lambda: "route-update-statistics"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics, [], name, value)


                                        class Duration(Entity):
                                            """
                                            Duration of the routing table update
                                            
                                            .. attribute:: real_duration
                                            
                                            	Real time duration in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            .. attribute:: cpu_duration
                                            
                                            	CPU time duration in milliseconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: millisecond
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.Duration, self).__init__()

                                                self.yang_name = "duration"
                                                self.yang_parent_name = "route-update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('real_duration', (YLeaf(YType.uint32, 'real-duration'), ['int'])),
                                                    ('cpu_duration', (YLeaf(YType.uint32, 'cpu-duration'), ['int'])),
                                                ])
                                                self.real_duration = None
                                                self.cpu_duration = None
                                                self._segment_path = lambda: "duration"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.Duration, [u'real_duration', u'cpu_duration'], name, value)


                                        class DurationBreakdown(Entity):
                                            """
                                            Breakdown of the time taken by the routing table
                                            update
                                            
                                            .. attribute:: local_rib_update
                                            
                                            	Time to update IS\-IS's local RIB
                                            	**type**\:  :py:class:`LocalRibUpdate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate>`
                                            
                                            .. attribute:: global_rib_build
                                            
                                            	Time to build the update to send to the global RIB
                                            	**type**\:  :py:class:`GlobalRibBuild <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild>`
                                            
                                            .. attribute:: global_rib_send
                                            
                                            	Time to send the update to the global RIB
                                            	**type**\:  :py:class:`GlobalRibSend <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown, self).__init__()

                                                self.yang_name = "duration-breakdown"
                                                self.yang_parent_name = "route-update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("local-rib-update", ("local_rib_update", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate)), ("global-rib-build", ("global_rib_build", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild)), ("global-rib-send", ("global_rib_send", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend))])
                                                self._leafs = OrderedDict()

                                                self.local_rib_update = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate()
                                                self.local_rib_update.parent = self
                                                self._children_name_map["local_rib_update"] = "local-rib-update"

                                                self.global_rib_build = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild()
                                                self.global_rib_build.parent = self
                                                self._children_name_map["global_rib_build"] = "global-rib-build"

                                                self.global_rib_send = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend()
                                                self.global_rib_send.parent = self
                                                self._children_name_map["global_rib_send"] = "global-rib-send"
                                                self._segment_path = lambda: "duration-breakdown"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown, [], name, value)


                                            class LocalRibUpdate(Entity):
                                                """
                                                Time to update IS\-IS's local RIB
                                                
                                                .. attribute:: critical
                                                
                                                	Critical priority
                                                	**type**\:  :py:class:`Critical <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.Critical>`
                                                
                                                .. attribute:: high
                                                
                                                	High priority
                                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.High>`
                                                
                                                .. attribute:: medium
                                                
                                                	Medium priority
                                                	**type**\:  :py:class:`Medium <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.Medium>`
                                                
                                                .. attribute:: low
                                                
                                                	Low priority
                                                	**type**\:  :py:class:`Low <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.Low>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate, self).__init__()

                                                    self.yang_name = "local-rib-update"
                                                    self.yang_parent_name = "duration-breakdown"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("critical", ("critical", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.Critical)), ("high", ("high", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.High)), ("medium", ("medium", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.Medium)), ("low", ("low", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.Low))])
                                                    self._leafs = OrderedDict()

                                                    self.critical = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.Critical()
                                                    self.critical.parent = self
                                                    self._children_name_map["critical"] = "critical"

                                                    self.high = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.High()
                                                    self.high.parent = self
                                                    self._children_name_map["high"] = "high"

                                                    self.medium = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.Medium()
                                                    self.medium.parent = self
                                                    self._children_name_map["medium"] = "medium"

                                                    self.low = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.Low()
                                                    self.low.parent = self
                                                    self._children_name_map["low"] = "low"
                                                    self._segment_path = lambda: "local-rib-update"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate, [], name, value)


                                                class Critical(Entity):
                                                    """
                                                    Critical priority
                                                    
                                                    .. attribute:: real_duration
                                                    
                                                    	Real time duration in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    .. attribute:: cpu_duration
                                                    
                                                    	CPU time duration in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.Critical, self).__init__()

                                                        self.yang_name = "critical"
                                                        self.yang_parent_name = "local-rib-update"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('real_duration', (YLeaf(YType.uint32, 'real-duration'), ['int'])),
                                                            ('cpu_duration', (YLeaf(YType.uint32, 'cpu-duration'), ['int'])),
                                                        ])
                                                        self.real_duration = None
                                                        self.cpu_duration = None
                                                        self._segment_path = lambda: "critical"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.Critical, [u'real_duration', u'cpu_duration'], name, value)


                                                class High(Entity):
                                                    """
                                                    High priority
                                                    
                                                    .. attribute:: real_duration
                                                    
                                                    	Real time duration in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    .. attribute:: cpu_duration
                                                    
                                                    	CPU time duration in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.High, self).__init__()

                                                        self.yang_name = "high"
                                                        self.yang_parent_name = "local-rib-update"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('real_duration', (YLeaf(YType.uint32, 'real-duration'), ['int'])),
                                                            ('cpu_duration', (YLeaf(YType.uint32, 'cpu-duration'), ['int'])),
                                                        ])
                                                        self.real_duration = None
                                                        self.cpu_duration = None
                                                        self._segment_path = lambda: "high"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.High, [u'real_duration', u'cpu_duration'], name, value)


                                                class Medium(Entity):
                                                    """
                                                    Medium priority
                                                    
                                                    .. attribute:: real_duration
                                                    
                                                    	Real time duration in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    .. attribute:: cpu_duration
                                                    
                                                    	CPU time duration in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.Medium, self).__init__()

                                                        self.yang_name = "medium"
                                                        self.yang_parent_name = "local-rib-update"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('real_duration', (YLeaf(YType.uint32, 'real-duration'), ['int'])),
                                                            ('cpu_duration', (YLeaf(YType.uint32, 'cpu-duration'), ['int'])),
                                                        ])
                                                        self.real_duration = None
                                                        self.cpu_duration = None
                                                        self._segment_path = lambda: "medium"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.Medium, [u'real_duration', u'cpu_duration'], name, value)


                                                class Low(Entity):
                                                    """
                                                    Low priority
                                                    
                                                    .. attribute:: real_duration
                                                    
                                                    	Real time duration in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    .. attribute:: cpu_duration
                                                    
                                                    	CPU time duration in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.Low, self).__init__()

                                                        self.yang_name = "low"
                                                        self.yang_parent_name = "local-rib-update"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('real_duration', (YLeaf(YType.uint32, 'real-duration'), ['int'])),
                                                            ('cpu_duration', (YLeaf(YType.uint32, 'cpu-duration'), ['int'])),
                                                        ])
                                                        self.real_duration = None
                                                        self.cpu_duration = None
                                                        self._segment_path = lambda: "low"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.LocalRibUpdate.Low, [u'real_duration', u'cpu_duration'], name, value)


                                            class GlobalRibBuild(Entity):
                                                """
                                                Time to build the update to send to the global
                                                RIB
                                                
                                                .. attribute:: critical
                                                
                                                	Critical priority
                                                	**type**\:  :py:class:`Critical <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.Critical>`
                                                
                                                .. attribute:: high
                                                
                                                	High priority
                                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.High>`
                                                
                                                .. attribute:: medium
                                                
                                                	Medium priority
                                                	**type**\:  :py:class:`Medium <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.Medium>`
                                                
                                                .. attribute:: low
                                                
                                                	Low priority
                                                	**type**\:  :py:class:`Low <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.Low>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild, self).__init__()

                                                    self.yang_name = "global-rib-build"
                                                    self.yang_parent_name = "duration-breakdown"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("critical", ("critical", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.Critical)), ("high", ("high", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.High)), ("medium", ("medium", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.Medium)), ("low", ("low", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.Low))])
                                                    self._leafs = OrderedDict()

                                                    self.critical = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.Critical()
                                                    self.critical.parent = self
                                                    self._children_name_map["critical"] = "critical"

                                                    self.high = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.High()
                                                    self.high.parent = self
                                                    self._children_name_map["high"] = "high"

                                                    self.medium = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.Medium()
                                                    self.medium.parent = self
                                                    self._children_name_map["medium"] = "medium"

                                                    self.low = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.Low()
                                                    self.low.parent = self
                                                    self._children_name_map["low"] = "low"
                                                    self._segment_path = lambda: "global-rib-build"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild, [], name, value)


                                                class Critical(Entity):
                                                    """
                                                    Critical priority
                                                    
                                                    .. attribute:: real_duration
                                                    
                                                    	Real time duration in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    .. attribute:: cpu_duration
                                                    
                                                    	CPU time duration in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.Critical, self).__init__()

                                                        self.yang_name = "critical"
                                                        self.yang_parent_name = "global-rib-build"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('real_duration', (YLeaf(YType.uint32, 'real-duration'), ['int'])),
                                                            ('cpu_duration', (YLeaf(YType.uint32, 'cpu-duration'), ['int'])),
                                                        ])
                                                        self.real_duration = None
                                                        self.cpu_duration = None
                                                        self._segment_path = lambda: "critical"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.Critical, [u'real_duration', u'cpu_duration'], name, value)


                                                class High(Entity):
                                                    """
                                                    High priority
                                                    
                                                    .. attribute:: real_duration
                                                    
                                                    	Real time duration in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    .. attribute:: cpu_duration
                                                    
                                                    	CPU time duration in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.High, self).__init__()

                                                        self.yang_name = "high"
                                                        self.yang_parent_name = "global-rib-build"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('real_duration', (YLeaf(YType.uint32, 'real-duration'), ['int'])),
                                                            ('cpu_duration', (YLeaf(YType.uint32, 'cpu-duration'), ['int'])),
                                                        ])
                                                        self.real_duration = None
                                                        self.cpu_duration = None
                                                        self._segment_path = lambda: "high"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.High, [u'real_duration', u'cpu_duration'], name, value)


                                                class Medium(Entity):
                                                    """
                                                    Medium priority
                                                    
                                                    .. attribute:: real_duration
                                                    
                                                    	Real time duration in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    .. attribute:: cpu_duration
                                                    
                                                    	CPU time duration in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.Medium, self).__init__()

                                                        self.yang_name = "medium"
                                                        self.yang_parent_name = "global-rib-build"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('real_duration', (YLeaf(YType.uint32, 'real-duration'), ['int'])),
                                                            ('cpu_duration', (YLeaf(YType.uint32, 'cpu-duration'), ['int'])),
                                                        ])
                                                        self.real_duration = None
                                                        self.cpu_duration = None
                                                        self._segment_path = lambda: "medium"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.Medium, [u'real_duration', u'cpu_duration'], name, value)


                                                class Low(Entity):
                                                    """
                                                    Low priority
                                                    
                                                    .. attribute:: real_duration
                                                    
                                                    	Real time duration in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    .. attribute:: cpu_duration
                                                    
                                                    	CPU time duration in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.Low, self).__init__()

                                                        self.yang_name = "low"
                                                        self.yang_parent_name = "global-rib-build"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('real_duration', (YLeaf(YType.uint32, 'real-duration'), ['int'])),
                                                            ('cpu_duration', (YLeaf(YType.uint32, 'cpu-duration'), ['int'])),
                                                        ])
                                                        self.real_duration = None
                                                        self.cpu_duration = None
                                                        self._segment_path = lambda: "low"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibBuild.Low, [u'real_duration', u'cpu_duration'], name, value)


                                            class GlobalRibSend(Entity):
                                                """
                                                Time to send the update to the global RIB
                                                
                                                .. attribute:: critical
                                                
                                                	Critical priority
                                                	**type**\:  :py:class:`Critical <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.Critical>`
                                                
                                                .. attribute:: high
                                                
                                                	High priority
                                                	**type**\:  :py:class:`High <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.High>`
                                                
                                                .. attribute:: medium
                                                
                                                	Medium priority
                                                	**type**\:  :py:class:`Medium <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.Medium>`
                                                
                                                .. attribute:: low
                                                
                                                	Low priority
                                                	**type**\:  :py:class:`Low <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.Low>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend, self).__init__()

                                                    self.yang_name = "global-rib-send"
                                                    self.yang_parent_name = "duration-breakdown"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("critical", ("critical", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.Critical)), ("high", ("high", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.High)), ("medium", ("medium", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.Medium)), ("low", ("low", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.Low))])
                                                    self._leafs = OrderedDict()

                                                    self.critical = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.Critical()
                                                    self.critical.parent = self
                                                    self._children_name_map["critical"] = "critical"

                                                    self.high = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.High()
                                                    self.high.parent = self
                                                    self._children_name_map["high"] = "high"

                                                    self.medium = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.Medium()
                                                    self.medium.parent = self
                                                    self._children_name_map["medium"] = "medium"

                                                    self.low = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.Low()
                                                    self.low.parent = self
                                                    self._children_name_map["low"] = "low"
                                                    self._segment_path = lambda: "global-rib-send"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend, [], name, value)


                                                class Critical(Entity):
                                                    """
                                                    Critical priority
                                                    
                                                    .. attribute:: real_duration
                                                    
                                                    	Real time duration in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    .. attribute:: cpu_duration
                                                    
                                                    	CPU time duration in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.Critical, self).__init__()

                                                        self.yang_name = "critical"
                                                        self.yang_parent_name = "global-rib-send"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('real_duration', (YLeaf(YType.uint32, 'real-duration'), ['int'])),
                                                            ('cpu_duration', (YLeaf(YType.uint32, 'cpu-duration'), ['int'])),
                                                        ])
                                                        self.real_duration = None
                                                        self.cpu_duration = None
                                                        self._segment_path = lambda: "critical"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.Critical, [u'real_duration', u'cpu_duration'], name, value)


                                                class High(Entity):
                                                    """
                                                    High priority
                                                    
                                                    .. attribute:: real_duration
                                                    
                                                    	Real time duration in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    .. attribute:: cpu_duration
                                                    
                                                    	CPU time duration in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.High, self).__init__()

                                                        self.yang_name = "high"
                                                        self.yang_parent_name = "global-rib-send"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('real_duration', (YLeaf(YType.uint32, 'real-duration'), ['int'])),
                                                            ('cpu_duration', (YLeaf(YType.uint32, 'cpu-duration'), ['int'])),
                                                        ])
                                                        self.real_duration = None
                                                        self.cpu_duration = None
                                                        self._segment_path = lambda: "high"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.High, [u'real_duration', u'cpu_duration'], name, value)


                                                class Medium(Entity):
                                                    """
                                                    Medium priority
                                                    
                                                    .. attribute:: real_duration
                                                    
                                                    	Real time duration in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    .. attribute:: cpu_duration
                                                    
                                                    	CPU time duration in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.Medium, self).__init__()

                                                        self.yang_name = "medium"
                                                        self.yang_parent_name = "global-rib-send"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('real_duration', (YLeaf(YType.uint32, 'real-duration'), ['int'])),
                                                            ('cpu_duration', (YLeaf(YType.uint32, 'cpu-duration'), ['int'])),
                                                        ])
                                                        self.real_duration = None
                                                        self.cpu_duration = None
                                                        self._segment_path = lambda: "medium"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.Medium, [u'real_duration', u'cpu_duration'], name, value)


                                                class Low(Entity):
                                                    """
                                                    Low priority
                                                    
                                                    .. attribute:: real_duration
                                                    
                                                    	Real time duration in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    .. attribute:: cpu_duration
                                                    
                                                    	CPU time duration in milliseconds
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.Low, self).__init__()

                                                        self.yang_name = "low"
                                                        self.yang_parent_name = "global-rib-send"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('real_duration', (YLeaf(YType.uint32, 'real-duration'), ['int'])),
                                                            ('cpu_duration', (YLeaf(YType.uint32, 'cpu-duration'), ['int'])),
                                                        ])
                                                        self.real_duration = None
                                                        self.cpu_duration = None
                                                        self._segment_path = lambda: "low"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.DurationBreakdown.GlobalRibSend.Low, [u'real_duration', u'cpu_duration'], name, value)


                                        class NodeCounts(Entity):
                                            """
                                            Node counts
                                            
                                            .. attribute:: per_priority_touched
                                            
                                            	Per\-priority count of nodes considered during route update
                                            	**type**\:  :py:class:`PerPriorityTouched <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.NodeCounts.PerPriorityTouched>`
                                            
                                            .. attribute:: total_touched
                                            
                                            	Total number of nodes considered during route update
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.NodeCounts, self).__init__()

                                                self.yang_name = "node-counts"
                                                self.yang_parent_name = "route-update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("per-priority-touched", ("per_priority_touched", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.NodeCounts.PerPriorityTouched))])
                                                self._leafs = OrderedDict([
                                                    ('total_touched', (YLeaf(YType.uint32, 'total-touched'), ['int'])),
                                                ])
                                                self.total_touched = None

                                                self.per_priority_touched = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.NodeCounts.PerPriorityTouched()
                                                self.per_priority_touched.parent = self
                                                self._children_name_map["per_priority_touched"] = "per-priority-touched"
                                                self._segment_path = lambda: "node-counts"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.NodeCounts, [u'total_touched'], name, value)


                                            class PerPriorityTouched(Entity):
                                                """
                                                Per\-priority count of nodes considered during
                                                route update
                                                
                                                .. attribute:: critical
                                                
                                                	Critical priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: high
                                                
                                                	High priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: medium
                                                
                                                	Medium priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: low
                                                
                                                	Low priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.NodeCounts.PerPriorityTouched, self).__init__()

                                                    self.yang_name = "per-priority-touched"
                                                    self.yang_parent_name = "node-counts"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('critical', (YLeaf(YType.uint32, 'critical'), ['int'])),
                                                        ('high', (YLeaf(YType.uint32, 'high'), ['int'])),
                                                        ('medium', (YLeaf(YType.uint32, 'medium'), ['int'])),
                                                        ('low', (YLeaf(YType.uint32, 'low'), ['int'])),
                                                    ])
                                                    self.critical = None
                                                    self.high = None
                                                    self.medium = None
                                                    self.low = None
                                                    self._segment_path = lambda: "per-priority-touched"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.NodeCounts.PerPriorityTouched, [u'critical', u'high', u'medium', u'low'], name, value)


                                        class ItemCounts(Entity):
                                            """
                                            Prefix item counts
                                            
                                            .. attribute:: unreachable
                                            
                                            	Number of unreachable prefixes in the database
                                            	**type**\:  :py:class:`Unreachable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Unreachable>`
                                            
                                            .. attribute:: reachable
                                            
                                            	Number of reachable prefixes in the database
                                            	**type**\:  :py:class:`Reachable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Reachable>`
                                            
                                            .. attribute:: added
                                            
                                            	Number of prefixes added during calculation
                                            	**type**\:  :py:class:`Added <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Added>`
                                            
                                            .. attribute:: deleted
                                            
                                            	Number of prefixes deleted during calculation
                                            	**type**\:  :py:class:`Deleted <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Deleted>`
                                            
                                            .. attribute:: modified
                                            
                                            	Number of prefixes modified, i.e. a first hop and/or metric change
                                            	**type**\:  :py:class:`Modified <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Modified>`
                                            
                                            .. attribute:: touched
                                            
                                            	Number of prefixes considered whilst updating the routing table
                                            	**type**\:  :py:class:`Touched <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Touched>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts, self).__init__()

                                                self.yang_name = "item-counts"
                                                self.yang_parent_name = "route-update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("unreachable", ("unreachable", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Unreachable)), ("reachable", ("reachable", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Reachable)), ("added", ("added", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Added)), ("deleted", ("deleted", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Deleted)), ("modified", ("modified", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Modified)), ("touched", ("touched", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Touched))])
                                                self._leafs = OrderedDict()

                                                self.unreachable = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Unreachable()
                                                self.unreachable.parent = self
                                                self._children_name_map["unreachable"] = "unreachable"

                                                self.reachable = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Reachable()
                                                self.reachable.parent = self
                                                self._children_name_map["reachable"] = "reachable"

                                                self.added = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Added()
                                                self.added.parent = self
                                                self._children_name_map["added"] = "added"

                                                self.deleted = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Deleted()
                                                self.deleted.parent = self
                                                self._children_name_map["deleted"] = "deleted"

                                                self.modified = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Modified()
                                                self.modified.parent = self
                                                self._children_name_map["modified"] = "modified"

                                                self.touched = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Touched()
                                                self.touched.parent = self
                                                self._children_name_map["touched"] = "touched"
                                                self._segment_path = lambda: "item-counts"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts, [], name, value)


                                            class Unreachable(Entity):
                                                """
                                                Number of unreachable prefixes in the database
                                                
                                                .. attribute:: critical
                                                
                                                	Critical priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: high
                                                
                                                	High priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: medium
                                                
                                                	Medium priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: low
                                                
                                                	Low priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Unreachable, self).__init__()

                                                    self.yang_name = "unreachable"
                                                    self.yang_parent_name = "item-counts"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('critical', (YLeaf(YType.uint32, 'critical'), ['int'])),
                                                        ('high', (YLeaf(YType.uint32, 'high'), ['int'])),
                                                        ('medium', (YLeaf(YType.uint32, 'medium'), ['int'])),
                                                        ('low', (YLeaf(YType.uint32, 'low'), ['int'])),
                                                    ])
                                                    self.critical = None
                                                    self.high = None
                                                    self.medium = None
                                                    self.low = None
                                                    self._segment_path = lambda: "unreachable"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Unreachable, [u'critical', u'high', u'medium', u'low'], name, value)


                                            class Reachable(Entity):
                                                """
                                                Number of reachable prefixes in the database
                                                
                                                .. attribute:: critical
                                                
                                                	Critical priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: high
                                                
                                                	High priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: medium
                                                
                                                	Medium priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: low
                                                
                                                	Low priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Reachable, self).__init__()

                                                    self.yang_name = "reachable"
                                                    self.yang_parent_name = "item-counts"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('critical', (YLeaf(YType.uint32, 'critical'), ['int'])),
                                                        ('high', (YLeaf(YType.uint32, 'high'), ['int'])),
                                                        ('medium', (YLeaf(YType.uint32, 'medium'), ['int'])),
                                                        ('low', (YLeaf(YType.uint32, 'low'), ['int'])),
                                                    ])
                                                    self.critical = None
                                                    self.high = None
                                                    self.medium = None
                                                    self.low = None
                                                    self._segment_path = lambda: "reachable"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Reachable, [u'critical', u'high', u'medium', u'low'], name, value)


                                            class Added(Entity):
                                                """
                                                Number of prefixes added during calculation
                                                
                                                .. attribute:: critical
                                                
                                                	Critical priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: high
                                                
                                                	High priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: medium
                                                
                                                	Medium priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: low
                                                
                                                	Low priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Added, self).__init__()

                                                    self.yang_name = "added"
                                                    self.yang_parent_name = "item-counts"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('critical', (YLeaf(YType.uint32, 'critical'), ['int'])),
                                                        ('high', (YLeaf(YType.uint32, 'high'), ['int'])),
                                                        ('medium', (YLeaf(YType.uint32, 'medium'), ['int'])),
                                                        ('low', (YLeaf(YType.uint32, 'low'), ['int'])),
                                                    ])
                                                    self.critical = None
                                                    self.high = None
                                                    self.medium = None
                                                    self.low = None
                                                    self._segment_path = lambda: "added"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Added, [u'critical', u'high', u'medium', u'low'], name, value)


                                            class Deleted(Entity):
                                                """
                                                Number of prefixes deleted during calculation
                                                
                                                .. attribute:: critical
                                                
                                                	Critical priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: high
                                                
                                                	High priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: medium
                                                
                                                	Medium priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: low
                                                
                                                	Low priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Deleted, self).__init__()

                                                    self.yang_name = "deleted"
                                                    self.yang_parent_name = "item-counts"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('critical', (YLeaf(YType.uint32, 'critical'), ['int'])),
                                                        ('high', (YLeaf(YType.uint32, 'high'), ['int'])),
                                                        ('medium', (YLeaf(YType.uint32, 'medium'), ['int'])),
                                                        ('low', (YLeaf(YType.uint32, 'low'), ['int'])),
                                                    ])
                                                    self.critical = None
                                                    self.high = None
                                                    self.medium = None
                                                    self.low = None
                                                    self._segment_path = lambda: "deleted"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Deleted, [u'critical', u'high', u'medium', u'low'], name, value)


                                            class Modified(Entity):
                                                """
                                                Number of prefixes modified, i.e. a first hop
                                                and/or metric change
                                                
                                                .. attribute:: critical
                                                
                                                	Critical priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: high
                                                
                                                	High priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: medium
                                                
                                                	Medium priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: low
                                                
                                                	Low priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Modified, self).__init__()

                                                    self.yang_name = "modified"
                                                    self.yang_parent_name = "item-counts"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('critical', (YLeaf(YType.uint32, 'critical'), ['int'])),
                                                        ('high', (YLeaf(YType.uint32, 'high'), ['int'])),
                                                        ('medium', (YLeaf(YType.uint32, 'medium'), ['int'])),
                                                        ('low', (YLeaf(YType.uint32, 'low'), ['int'])),
                                                    ])
                                                    self.critical = None
                                                    self.high = None
                                                    self.medium = None
                                                    self.low = None
                                                    self._segment_path = lambda: "modified"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Modified, [u'critical', u'high', u'medium', u'low'], name, value)


                                            class Touched(Entity):
                                                """
                                                Number of prefixes considered whilst updating
                                                the routing table
                                                
                                                .. attribute:: critical
                                                
                                                	Critical priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: high
                                                
                                                	High priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: medium
                                                
                                                	Medium priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: low
                                                
                                                	Low priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Touched, self).__init__()

                                                    self.yang_name = "touched"
                                                    self.yang_parent_name = "item-counts"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('critical', (YLeaf(YType.uint32, 'critical'), ['int'])),
                                                        ('high', (YLeaf(YType.uint32, 'high'), ['int'])),
                                                        ('medium', (YLeaf(YType.uint32, 'medium'), ['int'])),
                                                        ('low', (YLeaf(YType.uint32, 'low'), ['int'])),
                                                    ])
                                                    self.critical = None
                                                    self.high = None
                                                    self.medium = None
                                                    self.low = None
                                                    self._segment_path = lambda: "touched"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.ItemCounts.Touched, [u'critical', u'high', u'medium', u'low'], name, value)


                                        class RouteCounts(Entity):
                                            """
                                            Distinct prefix counts
                                            
                                            .. attribute:: unreachable
                                            
                                            	Number of unreachable prefixes in the database
                                            	**type**\:  :py:class:`Unreachable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Unreachable>`
                                            
                                            .. attribute:: reachable
                                            
                                            	Number of reachable prefixes in the database
                                            	**type**\:  :py:class:`Reachable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Reachable>`
                                            
                                            .. attribute:: added
                                            
                                            	Number of prefixes added during calculation
                                            	**type**\:  :py:class:`Added <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Added>`
                                            
                                            .. attribute:: deleted
                                            
                                            	Number of prefixes deleted during calculation
                                            	**type**\:  :py:class:`Deleted <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Deleted>`
                                            
                                            .. attribute:: modified
                                            
                                            	Number of prefixes modified, i.e. a first hop and/or metric change
                                            	**type**\:  :py:class:`Modified <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Modified>`
                                            
                                            .. attribute:: touched
                                            
                                            	Number of prefixes considered whilst updating the routing table
                                            	**type**\:  :py:class:`Touched <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Touched>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts, self).__init__()

                                                self.yang_name = "route-counts"
                                                self.yang_parent_name = "route-update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("unreachable", ("unreachable", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Unreachable)), ("reachable", ("reachable", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Reachable)), ("added", ("added", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Added)), ("deleted", ("deleted", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Deleted)), ("modified", ("modified", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Modified)), ("touched", ("touched", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Touched))])
                                                self._leafs = OrderedDict()

                                                self.unreachable = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Unreachable()
                                                self.unreachable.parent = self
                                                self._children_name_map["unreachable"] = "unreachable"

                                                self.reachable = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Reachable()
                                                self.reachable.parent = self
                                                self._children_name_map["reachable"] = "reachable"

                                                self.added = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Added()
                                                self.added.parent = self
                                                self._children_name_map["added"] = "added"

                                                self.deleted = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Deleted()
                                                self.deleted.parent = self
                                                self._children_name_map["deleted"] = "deleted"

                                                self.modified = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Modified()
                                                self.modified.parent = self
                                                self._children_name_map["modified"] = "modified"

                                                self.touched = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Touched()
                                                self.touched.parent = self
                                                self._children_name_map["touched"] = "touched"
                                                self._segment_path = lambda: "route-counts"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts, [], name, value)


                                            class Unreachable(Entity):
                                                """
                                                Number of unreachable prefixes in the database
                                                
                                                .. attribute:: critical
                                                
                                                	Critical priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: high
                                                
                                                	High priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: medium
                                                
                                                	Medium priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: low
                                                
                                                	Low priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Unreachable, self).__init__()

                                                    self.yang_name = "unreachable"
                                                    self.yang_parent_name = "route-counts"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('critical', (YLeaf(YType.uint32, 'critical'), ['int'])),
                                                        ('high', (YLeaf(YType.uint32, 'high'), ['int'])),
                                                        ('medium', (YLeaf(YType.uint32, 'medium'), ['int'])),
                                                        ('low', (YLeaf(YType.uint32, 'low'), ['int'])),
                                                    ])
                                                    self.critical = None
                                                    self.high = None
                                                    self.medium = None
                                                    self.low = None
                                                    self._segment_path = lambda: "unreachable"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Unreachable, [u'critical', u'high', u'medium', u'low'], name, value)


                                            class Reachable(Entity):
                                                """
                                                Number of reachable prefixes in the database
                                                
                                                .. attribute:: critical
                                                
                                                	Critical priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: high
                                                
                                                	High priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: medium
                                                
                                                	Medium priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: low
                                                
                                                	Low priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Reachable, self).__init__()

                                                    self.yang_name = "reachable"
                                                    self.yang_parent_name = "route-counts"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('critical', (YLeaf(YType.uint32, 'critical'), ['int'])),
                                                        ('high', (YLeaf(YType.uint32, 'high'), ['int'])),
                                                        ('medium', (YLeaf(YType.uint32, 'medium'), ['int'])),
                                                        ('low', (YLeaf(YType.uint32, 'low'), ['int'])),
                                                    ])
                                                    self.critical = None
                                                    self.high = None
                                                    self.medium = None
                                                    self.low = None
                                                    self._segment_path = lambda: "reachable"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Reachable, [u'critical', u'high', u'medium', u'low'], name, value)


                                            class Added(Entity):
                                                """
                                                Number of prefixes added during calculation
                                                
                                                .. attribute:: critical
                                                
                                                	Critical priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: high
                                                
                                                	High priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: medium
                                                
                                                	Medium priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: low
                                                
                                                	Low priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Added, self).__init__()

                                                    self.yang_name = "added"
                                                    self.yang_parent_name = "route-counts"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('critical', (YLeaf(YType.uint32, 'critical'), ['int'])),
                                                        ('high', (YLeaf(YType.uint32, 'high'), ['int'])),
                                                        ('medium', (YLeaf(YType.uint32, 'medium'), ['int'])),
                                                        ('low', (YLeaf(YType.uint32, 'low'), ['int'])),
                                                    ])
                                                    self.critical = None
                                                    self.high = None
                                                    self.medium = None
                                                    self.low = None
                                                    self._segment_path = lambda: "added"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Added, [u'critical', u'high', u'medium', u'low'], name, value)


                                            class Deleted(Entity):
                                                """
                                                Number of prefixes deleted during calculation
                                                
                                                .. attribute:: critical
                                                
                                                	Critical priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: high
                                                
                                                	High priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: medium
                                                
                                                	Medium priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: low
                                                
                                                	Low priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Deleted, self).__init__()

                                                    self.yang_name = "deleted"
                                                    self.yang_parent_name = "route-counts"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('critical', (YLeaf(YType.uint32, 'critical'), ['int'])),
                                                        ('high', (YLeaf(YType.uint32, 'high'), ['int'])),
                                                        ('medium', (YLeaf(YType.uint32, 'medium'), ['int'])),
                                                        ('low', (YLeaf(YType.uint32, 'low'), ['int'])),
                                                    ])
                                                    self.critical = None
                                                    self.high = None
                                                    self.medium = None
                                                    self.low = None
                                                    self._segment_path = lambda: "deleted"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Deleted, [u'critical', u'high', u'medium', u'low'], name, value)


                                            class Modified(Entity):
                                                """
                                                Number of prefixes modified, i.e. a first hop
                                                and/or metric change
                                                
                                                .. attribute:: critical
                                                
                                                	Critical priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: high
                                                
                                                	High priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: medium
                                                
                                                	Medium priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: low
                                                
                                                	Low priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Modified, self).__init__()

                                                    self.yang_name = "modified"
                                                    self.yang_parent_name = "route-counts"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('critical', (YLeaf(YType.uint32, 'critical'), ['int'])),
                                                        ('high', (YLeaf(YType.uint32, 'high'), ['int'])),
                                                        ('medium', (YLeaf(YType.uint32, 'medium'), ['int'])),
                                                        ('low', (YLeaf(YType.uint32, 'low'), ['int'])),
                                                    ])
                                                    self.critical = None
                                                    self.high = None
                                                    self.medium = None
                                                    self.low = None
                                                    self._segment_path = lambda: "modified"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Modified, [u'critical', u'high', u'medium', u'low'], name, value)


                                            class Touched(Entity):
                                                """
                                                Number of prefixes considered whilst updating
                                                the routing table
                                                
                                                .. attribute:: critical
                                                
                                                	Critical priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: high
                                                
                                                	High priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: medium
                                                
                                                	Medium priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: low
                                                
                                                	Low priority
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Touched, self).__init__()

                                                    self.yang_name = "touched"
                                                    self.yang_parent_name = "route-counts"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('critical', (YLeaf(YType.uint32, 'critical'), ['int'])),
                                                        ('high', (YLeaf(YType.uint32, 'high'), ['int'])),
                                                        ('medium', (YLeaf(YType.uint32, 'medium'), ['int'])),
                                                        ('low', (YLeaf(YType.uint32, 'low'), ['int'])),
                                                    ])
                                                    self.critical = None
                                                    self.high = None
                                                    self.medium = None
                                                    self.low = None
                                                    self._segment_path = lambda: "touched"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RouteCounts.Touched, [u'critical', u'high', u'medium', u'low'], name, value)


                                        class RibBatchCounts(Entity):
                                            """
                                            Number of RIB batches sent
                                            
                                            .. attribute:: critical
                                            
                                            	Critical priority
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: high
                                            
                                            	High priority
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: medium
                                            
                                            	Medium priority
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: low
                                            
                                            	Low priority
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RibBatchCounts, self).__init__()

                                                self.yang_name = "rib-batch-counts"
                                                self.yang_parent_name = "route-update-statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('critical', (YLeaf(YType.uint32, 'critical'), ['int'])),
                                                    ('high', (YLeaf(YType.uint32, 'high'), ['int'])),
                                                    ('medium', (YLeaf(YType.uint32, 'medium'), ['int'])),
                                                    ('low', (YLeaf(YType.uint32, 'low'), ['int'])),
                                                ])
                                                self.critical = None
                                                self.high = None
                                                self.medium = None
                                                self.low = None
                                                self._segment_path = lambda: "rib-batch-counts"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.SpfLog.LogEntry.RouteUpdateStatistics.RibBatchCounts, [u'critical', u'high', u'medium', u'low'], name, value)


                            class TeTunnels(Entity):
                                """
                                TE tunnels table. Only available within
                                the IPv4 Unicast topology.
                                
                                .. attribute:: te_tunnel
                                
                                	A single TE tunnel advertized by IS\-IS
                                	**type**\: list of  		 :py:class:`TeTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeTunnels.TeTunnel>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeTunnels, self).__init__()

                                    self.yang_name = "te-tunnels"
                                    self.yang_parent_name = "topology-level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("te-tunnel", ("te_tunnel", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeTunnels.TeTunnel))])
                                    self._leafs = OrderedDict()

                                    self.te_tunnel = YList(self)
                                    self._segment_path = lambda: "te-tunnels"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeTunnels, [], name, value)


                                class TeTunnel(Entity):
                                    """
                                    A single TE tunnel advertized by IS\-IS
                                    
                                    .. attribute:: system_id
                                    
                                    	System ID
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                    
                                    .. attribute:: interface_name
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: te_system_id
                                    
                                    	Destination system ID
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                    
                                    .. attribute:: te_interface
                                    
                                    	Tunnel interface
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                                    
                                    .. attribute:: te_bandwidth
                                    
                                    	Tunnel bandwidth
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: teigp_metric
                                    
                                    	Tunnel metric
                                    	**type**\: int
                                    
                                    	**range:** \-2147483648..2147483647
                                    
                                    .. attribute:: te_next_hop_ip_address
                                    
                                    	Tunnel next\-hop IP address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: te_mode_type
                                    
                                    	Tunnel metric mode
                                    	**type**\:  :py:class:`IsisMetricMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisMetricMode>`
                                    
                                    .. attribute:: teipv4fa_enabled
                                    
                                    	Indicates whether MPLS TE IPv4 forwarding adjacency is enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: teipv6fa_enabled
                                    
                                    	Indicates whether MPLS TE IPv6 forwarding adjacency is enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: teipv4aa_enabled
                                    
                                    	Indicates whether MPLS TE IPv4 autoroute announce is enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: teipv6aa_enabled
                                    
                                    	Indicates whether MPLS TE IPv6 autoroute announce is enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: te_checkpoint_object_id
                                    
                                    	Tunnel checkpoint object ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: te_segment_routing_enabled
                                    
                                    	Indicates whether MPLS TE segment routing is enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: te_segment_routing_strict_spf
                                    
                                    	Indicates whether MPLS TE segment routing strict SPF is enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: te_segment_routing_exclude
                                    
                                    	Indicates whether Segment routing labeled traffic exclusion is enabled
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeTunnels.TeTunnel, self).__init__()

                                        self.yang_name = "te-tunnel"
                                        self.yang_parent_name = "te-tunnels"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('system_id', (YLeaf(YType.str, 'system-id'), ['str'])),
                                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                            ('te_system_id', (YLeaf(YType.str, 'te-system-id'), ['str'])),
                                            ('te_interface', (YLeaf(YType.str, 'te-interface'), ['str'])),
                                            ('te_bandwidth', (YLeaf(YType.uint32, 'te-bandwidth'), ['int'])),
                                            ('teigp_metric', (YLeaf(YType.int32, 'teigp-metric'), ['int'])),
                                            ('te_next_hop_ip_address', (YLeaf(YType.str, 'te-next-hop-ip-address'), ['str'])),
                                            ('te_mode_type', (YLeaf(YType.enumeration, 'te-mode-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisMetricMode', '')])),
                                            ('teipv4fa_enabled', (YLeaf(YType.boolean, 'teipv4fa-enabled'), ['bool'])),
                                            ('teipv6fa_enabled', (YLeaf(YType.boolean, 'teipv6fa-enabled'), ['bool'])),
                                            ('teipv4aa_enabled', (YLeaf(YType.boolean, 'teipv4aa-enabled'), ['bool'])),
                                            ('teipv6aa_enabled', (YLeaf(YType.boolean, 'teipv6aa-enabled'), ['bool'])),
                                            ('te_checkpoint_object_id', (YLeaf(YType.uint32, 'te-checkpoint-object-id'), ['int'])),
                                            ('te_segment_routing_enabled', (YLeaf(YType.boolean, 'te-segment-routing-enabled'), ['bool'])),
                                            ('te_segment_routing_strict_spf', (YLeaf(YType.boolean, 'te-segment-routing-strict-spf'), ['bool'])),
                                            ('te_segment_routing_exclude', (YLeaf(YType.boolean, 'te-segment-routing-exclude'), ['bool'])),
                                        ])
                                        self.system_id = None
                                        self.interface_name = None
                                        self.te_system_id = None
                                        self.te_interface = None
                                        self.te_bandwidth = None
                                        self.teigp_metric = None
                                        self.te_next_hop_ip_address = None
                                        self.te_mode_type = None
                                        self.teipv4fa_enabled = None
                                        self.teipv6fa_enabled = None
                                        self.teipv4aa_enabled = None
                                        self.teipv6aa_enabled = None
                                        self.te_checkpoint_object_id = None
                                        self.te_segment_routing_enabled = None
                                        self.te_segment_routing_strict_spf = None
                                        self.te_segment_routing_exclude = None
                                        self._segment_path = lambda: "te-tunnel"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TeTunnels.TeTunnel, ['system_id', 'interface_name', u'te_system_id', u'te_interface', u'te_bandwidth', u'teigp_metric', u'te_next_hop_ip_address', u'te_mode_type', u'teipv4fa_enabled', u'teipv6fa_enabled', u'teipv4aa_enabled', u'teipv6aa_enabled', u'te_checkpoint_object_id', u'te_segment_routing_enabled', u'te_segment_routing_strict_spf', u'te_segment_routing_exclude'], name, value)


                            class Ipv4LinkTopologies(Entity):
                                """
                                IPv4 IS Topology table
                                
                                .. attribute:: ipv4_link_topology
                                
                                	An IS in an IPv4 Link Topology
                                	**type**\: list of  		 :py:class:`Ipv4LinkTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies, self).__init__()

                                    self.yang_name = "ipv4-link-topologies"
                                    self.yang_parent_name = "topology-level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ipv4-link-topology", ("ipv4_link_topology", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology))])
                                    self._leafs = OrderedDict()

                                    self.ipv4_link_topology = YList(self)
                                    self._segment_path = lambda: "ipv4-link-topologies"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies, [], name, value)


                                class Ipv4LinkTopology(Entity):
                                    """
                                    An IS in an IPv4 Link Topology
                                    
                                    .. attribute:: system_id  (key)
                                    
                                    	System ID
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                    
                                    .. attribute:: reachability_status
                                    
                                    	Is the IS reachable, and, if so, its status within the SPT
                                    	**type**\:  :py:class:`ReachabilityStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus>`
                                    
                                    .. attribute:: advertised_prefix_item_counts
                                    
                                    	Per\-priority counts of prefix items advertised by the IS
                                    	**type**\:  :py:class:`AdvertisedPrefixItemCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.AdvertisedPrefixItemCounts>`
                                    
                                    .. attribute:: source_address
                                    
                                    	Source Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: is_participant
                                    
                                    	Does the IS participate in the topology?
                                    	**type**\: bool
                                    
                                    .. attribute:: is_overloaded
                                    
                                    	Is the IS overloaded?
                                    	**type**\: bool
                                    
                                    .. attribute:: is_attached
                                    
                                    	Is the IS attached?
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology, self).__init__()

                                        self.yang_name = "ipv4-link-topology"
                                        self.yang_parent_name = "ipv4-link-topologies"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['system_id']
                                        self._child_classes = OrderedDict([("reachability-status", ("reachability_status", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus)), ("advertised-prefix-item-counts", ("advertised_prefix_item_counts", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.AdvertisedPrefixItemCounts))])
                                        self._leafs = OrderedDict([
                                            ('system_id', (YLeaf(YType.str, 'system-id'), ['str'])),
                                            ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                            ('is_participant', (YLeaf(YType.boolean, 'is-participant'), ['bool'])),
                                            ('is_overloaded', (YLeaf(YType.boolean, 'is-overloaded'), ['bool'])),
                                            ('is_attached', (YLeaf(YType.boolean, 'is-attached'), ['bool'])),
                                        ])
                                        self.system_id = None
                                        self.source_address = None
                                        self.is_participant = None
                                        self.is_overloaded = None
                                        self.is_attached = None

                                        self.reachability_status = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus()
                                        self.reachability_status.parent = self
                                        self._children_name_map["reachability_status"] = "reachability-status"

                                        self.advertised_prefix_item_counts = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.AdvertisedPrefixItemCounts()
                                        self.advertised_prefix_item_counts.parent = self
                                        self._children_name_map["advertised_prefix_item_counts"] = "advertised-prefix-item-counts"
                                        self._segment_path = lambda: "ipv4-link-topology" + "[system-id='" + str(self.system_id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology, ['system_id', u'source_address', u'is_participant', u'is_overloaded', u'is_attached'], name, value)


                                    class ReachabilityStatus(Entity):
                                        """
                                        Is the IS reachable, and, if so, its status
                                        within the SPT
                                        
                                        .. attribute:: reachable_details
                                        
                                        	Status of the IS within the SPT
                                        	**type**\:  :py:class:`ReachableDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails>`
                                        
                                        .. attribute:: reachable_status
                                        
                                        	ReachableStatus
                                        	**type**\:  :py:class:`IsisReachable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisReachable>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus, self).__init__()

                                            self.yang_name = "reachability-status"
                                            self.yang_parent_name = "ipv4-link-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("reachable-details", ("reachable_details", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails))])
                                            self._leafs = OrderedDict([
                                                ('reachable_status', (YLeaf(YType.enumeration, 'reachable-status'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisReachable', '')])),
                                            ])
                                            self.reachable_status = None

                                            self.reachable_details = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails()
                                            self.reachable_details.parent = self
                                            self._children_name_map["reachable_details"] = "reachable-details"
                                            self._segment_path = lambda: "reachability-status"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus, [u'reachable_status'], name, value)


                                        class ReachableDetails(Entity):
                                            """
                                            Status of the IS within the SPT
                                            
                                            .. attribute:: root_distance
                                            
                                            	Distance to the IS
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: multicast_root_distance
                                            
                                            	Distance to the IS
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: paths
                                            
                                            	First hops towards the IS
                                            	**type**\: list of  		 :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths>`
                                            
                                            .. attribute:: multicast_path
                                            
                                            	Multicast intact first hops towards the IS
                                            	**type**\: list of  		 :py:class:`MulticastPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath>`
                                            
                                            .. attribute:: parent_
                                            
                                            	Parents of the IS within the SPT
                                            	**type**\: list of  		 :py:class:`Parent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Parent>`
                                            
                                            .. attribute:: children_
                                            
                                            	Children of the IS within the SPT
                                            	**type**\: list of  		 :py:class:`Children <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Children>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails, self).__init__()

                                                self.yang_name = "reachable-details"
                                                self.yang_parent_name = "reachability-status"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("paths", ("paths", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths)), ("multicast-path", ("multicast_path", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath)), ("parent", ("parent_", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Parent)), ("children", ("children_", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Children))])
                                                self._leafs = OrderedDict([
                                                    ('root_distance', (YLeaf(YType.uint32, 'root-distance'), ['int'])),
                                                    ('multicast_root_distance', (YLeaf(YType.uint32, 'multicast-root-distance'), ['int'])),
                                                ])
                                                self.root_distance = None
                                                self.multicast_root_distance = None

                                                self.paths = YList(self)
                                                self.multicast_path = YList(self)
                                                self.parent_ = YList(self)
                                                self.children_ = YList(self)
                                                self._segment_path = lambda: "reachable-details"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails, [u'root_distance', u'multicast_root_distance'], name, value)


                                            class Paths(Entity):
                                                """
                                                First hops towards the IS
                                                
                                                .. attribute:: frr_backup
                                                
                                                	FRR backup for this path
                                                	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup>`
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: tag
                                                
                                                	Tag associated with the path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_interface
                                                
                                                	Explicit path tunnel interface
                                                	**type**\: str
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_te_tunnel_interface
                                                
                                                	Is path via a TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: is_sr_exclude_tunnel_interface
                                                
                                                	Is path via an SR\-exclude TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: uloop_explicit
                                                
                                                	Uloop Explicit List
                                                	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.UloopExplicit>`
                                                
                                                .. attribute:: nnh
                                                
                                                	Next next hops
                                                	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.Nnh>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths, self).__init__()

                                                    self.yang_name = "paths"
                                                    self.yang_parent_name = "reachable-details"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.Nnh))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                        ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.neighbor_snpa = None
                                                    self.tag = None
                                                    self.tunnel_interface = None
                                                    self.segment_routing_sid_value = None
                                                    self.weight = None
                                                    self.is_te_tunnel_interface = None
                                                    self.is_sr_exclude_tunnel_interface = None

                                                    self.frr_backup = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup()
                                                    self.frr_backup.parent = self
                                                    self._children_name_map["frr_backup"] = "frr-backup"

                                                    self.uloop_explicit = YList(self)
                                                    self.nnh = YList(self)
                                                    self._segment_path = lambda: "paths"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                                class FrrBackup(Entity):
                                                    """
                                                    FRR backup for this path
                                                    
                                                    .. attribute:: neighbor_id
                                                    
                                                    	Next hop neighbor ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: egress_interface
                                                    
                                                    	Interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Next hop neighbor's forwarding address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: tunnel_egress_interface
                                                    
                                                    	Tunnel Interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_snpa
                                                    
                                                    	Next hop neighbor's SNPA
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_system_id
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_id
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: remote_lfa_system_pid
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_pid
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: total_backup_distance
                                                    
                                                    	Distance to the network via this backup path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value
                                                    
                                                    	Segment routing sid value received from first hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: num_sid
                                                    
                                                    	Number of SIDs in TI\-LFA/rLFA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_repair_list_size
                                                    
                                                    	Backup Repair List Size
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tilfa_computation
                                                    
                                                    	Ti LFA computation which provided backup path
                                                    	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                    
                                                    .. attribute:: prefix_source_node_id
                                                    
                                                    	PrefixSourceNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: is_downstream
                                                    
                                                    	Is the backup path via downstream node?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_lc_disjoint
                                                    
                                                    	Is the backup path line card disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_node_protecting
                                                    
                                                    	Is the backup path node protecting?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_primary_path
                                                    
                                                    	Is the backup path an ECMP to the network?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_srlg_disjoint
                                                    
                                                    	Is the backup path SRLG disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_remote_lfa
                                                    
                                                    	Is the backup path via a Remote LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_epcfrr_lfa
                                                    
                                                    	Is the backup path via a TI\-LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_strict_spflfa
                                                    
                                                    	Is the backup path TI\-LFA strict SPF?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_requested
                                                    
                                                    	Is SR TE tunnel requested
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight configured on the interface
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value_entry
                                                    
                                                    	Segment routing sid values for TI\-LFA/rLFA
                                                    	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup.SegmentRoutingSidValueEntry>`
                                                    
                                                    .. attribute:: backup_repair
                                                    
                                                    	Backup Repair List
                                                    	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup.BackupRepair>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup, self).__init__()

                                                        self.yang_name = "frr-backup"
                                                        self.yang_parent_name = "paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup.BackupRepair))])
                                                        self._leafs = OrderedDict([
                                                            ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                            ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                            ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                            ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                            ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                            ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                            ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                            ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                            ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                            ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                            ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                            ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                            ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                            ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                            ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                            ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                            ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                            ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                            ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                            ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                            ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                            ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                            ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                            ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ])
                                                        self.neighbor_id = None
                                                        self.egress_interface = None
                                                        self.neighbor_address = None
                                                        self.tunnel_egress_interface = None
                                                        self.neighbor_snpa = None
                                                        self.remote_lfa_system_id = None
                                                        self.remote_lfa_router_id = None
                                                        self.remote_lfa_system_pid = None
                                                        self.remote_lfa_router_pid = None
                                                        self.total_backup_distance = None
                                                        self.segment_routing_sid_value = None
                                                        self.num_sid = None
                                                        self.backup_repair_list_size = None
                                                        self.tilfa_computation = None
                                                        self.prefix_source_node_id = None
                                                        self.is_downstream = None
                                                        self.is_lc_disjoint = None
                                                        self.is_node_protecting = None
                                                        self.is_primary_path = None
                                                        self.is_srlg_disjoint = None
                                                        self.is_remote_lfa = None
                                                        self.is_epcfrr_lfa = None
                                                        self.is_strict_spflfa = None
                                                        self.is_tunnel_requested = None
                                                        self.weight = None

                                                        self.segment_routing_sid_value_entry = YList(self)
                                                        self.backup_repair = YList(self)
                                                        self._segment_path = lambda: "frr-backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                    class SegmentRoutingSidValueEntry(Entity):
                                                        """
                                                        Segment routing sid values for TI\-LFA/rLFA
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                            self.yang_name = "segment-routing-sid-value-entry"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                    class BackupRepair(Entity):
                                                        """
                                                        Backup Repair List
                                                        
                                                        .. attribute:: repair_element_node_id
                                                        
                                                        	RepairElementNodeID
                                                        	**type**\: str
                                                        
                                                        .. attribute:: repair_ipv4_addr
                                                        
                                                        	RepairIPv4Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_ipv6_addr
                                                        
                                                        	RepairIPv6Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_label
                                                        
                                                        	Repair Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_element_type
                                                        
                                                        	Repair Element Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_strict_spf_label
                                                        
                                                        	Repair Strict SPF Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup.BackupRepair, self).__init__()

                                                            self.yang_name = "backup-repair"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                                ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                                ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                                ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                                ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                                ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                            ])
                                                            self.repair_element_node_id = None
                                                            self.repair_ipv4_addr = None
                                                            self.repair_ipv6_addr = None
                                                            self.repair_label = None
                                                            self.repair_element_type = None
                                                            self.repair_strict_spf_label = None
                                                            self._segment_path = lambda: "backup-repair"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class UloopExplicit(Entity):
                                                    """
                                                    Uloop Explicit List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.UloopExplicit, self).__init__()

                                                        self.yang_name = "uloop-explicit"
                                                        self.yang_parent_name = "paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "uloop-explicit"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class Nnh(Entity):
                                                    """
                                                    Next next hops
                                                    
                                                    .. attribute:: link_id_set
                                                    
                                                    	If link\_id is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ipv4_set
                                                    
                                                    	If ipv4 address is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: link_id
                                                    
                                                    	link ID of the next next hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	Ipv4 address of the next next hop
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.Nnh, self).__init__()

                                                        self.yang_name = "nnh"
                                                        self.yang_parent_name = "paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                            ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                            ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ])
                                                        self.link_id_set = None
                                                        self.ipv4_set = None
                                                        self.link_id = None
                                                        self.ipv4_address = None
                                                        self._segment_path = lambda: "nnh"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Paths.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                            class MulticastPath(Entity):
                                                """
                                                Multicast intact first hops towards the IS
                                                
                                                .. attribute:: frr_backup
                                                
                                                	FRR backup for this path
                                                	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup>`
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: tag
                                                
                                                	Tag associated with the path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_interface
                                                
                                                	Explicit path tunnel interface
                                                	**type**\: str
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_te_tunnel_interface
                                                
                                                	Is path via a TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: is_sr_exclude_tunnel_interface
                                                
                                                	Is path via an SR\-exclude TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: uloop_explicit
                                                
                                                	Uloop Explicit List
                                                	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.UloopExplicit>`
                                                
                                                .. attribute:: nnh
                                                
                                                	Next next hops
                                                	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.Nnh>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath, self).__init__()

                                                    self.yang_name = "multicast-path"
                                                    self.yang_parent_name = "reachable-details"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.Nnh))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                        ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.neighbor_snpa = None
                                                    self.tag = None
                                                    self.tunnel_interface = None
                                                    self.segment_routing_sid_value = None
                                                    self.weight = None
                                                    self.is_te_tunnel_interface = None
                                                    self.is_sr_exclude_tunnel_interface = None

                                                    self.frr_backup = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup()
                                                    self.frr_backup.parent = self
                                                    self._children_name_map["frr_backup"] = "frr-backup"

                                                    self.uloop_explicit = YList(self)
                                                    self.nnh = YList(self)
                                                    self._segment_path = lambda: "multicast-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                                class FrrBackup(Entity):
                                                    """
                                                    FRR backup for this path
                                                    
                                                    .. attribute:: neighbor_id
                                                    
                                                    	Next hop neighbor ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: egress_interface
                                                    
                                                    	Interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Next hop neighbor's forwarding address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: tunnel_egress_interface
                                                    
                                                    	Tunnel Interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_snpa
                                                    
                                                    	Next hop neighbor's SNPA
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_system_id
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_id
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: remote_lfa_system_pid
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_pid
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: total_backup_distance
                                                    
                                                    	Distance to the network via this backup path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value
                                                    
                                                    	Segment routing sid value received from first hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: num_sid
                                                    
                                                    	Number of SIDs in TI\-LFA/rLFA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_repair_list_size
                                                    
                                                    	Backup Repair List Size
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tilfa_computation
                                                    
                                                    	Ti LFA computation which provided backup path
                                                    	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                    
                                                    .. attribute:: prefix_source_node_id
                                                    
                                                    	PrefixSourceNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: is_downstream
                                                    
                                                    	Is the backup path via downstream node?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_lc_disjoint
                                                    
                                                    	Is the backup path line card disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_node_protecting
                                                    
                                                    	Is the backup path node protecting?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_primary_path
                                                    
                                                    	Is the backup path an ECMP to the network?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_srlg_disjoint
                                                    
                                                    	Is the backup path SRLG disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_remote_lfa
                                                    
                                                    	Is the backup path via a Remote LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_epcfrr_lfa
                                                    
                                                    	Is the backup path via a TI\-LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_strict_spflfa
                                                    
                                                    	Is the backup path TI\-LFA strict SPF?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_requested
                                                    
                                                    	Is SR TE tunnel requested
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight configured on the interface
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value_entry
                                                    
                                                    	Segment routing sid values for TI\-LFA/rLFA
                                                    	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                    
                                                    .. attribute:: backup_repair
                                                    
                                                    	Backup Repair List
                                                    	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup.BackupRepair>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup, self).__init__()

                                                        self.yang_name = "frr-backup"
                                                        self.yang_parent_name = "multicast-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup.BackupRepair))])
                                                        self._leafs = OrderedDict([
                                                            ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                            ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                            ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                            ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                            ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                            ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                            ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                            ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                            ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                            ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                            ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                            ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                            ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                            ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                            ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                            ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                            ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                            ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                            ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                            ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                            ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                            ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                            ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                            ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ])
                                                        self.neighbor_id = None
                                                        self.egress_interface = None
                                                        self.neighbor_address = None
                                                        self.tunnel_egress_interface = None
                                                        self.neighbor_snpa = None
                                                        self.remote_lfa_system_id = None
                                                        self.remote_lfa_router_id = None
                                                        self.remote_lfa_system_pid = None
                                                        self.remote_lfa_router_pid = None
                                                        self.total_backup_distance = None
                                                        self.segment_routing_sid_value = None
                                                        self.num_sid = None
                                                        self.backup_repair_list_size = None
                                                        self.tilfa_computation = None
                                                        self.prefix_source_node_id = None
                                                        self.is_downstream = None
                                                        self.is_lc_disjoint = None
                                                        self.is_node_protecting = None
                                                        self.is_primary_path = None
                                                        self.is_srlg_disjoint = None
                                                        self.is_remote_lfa = None
                                                        self.is_epcfrr_lfa = None
                                                        self.is_strict_spflfa = None
                                                        self.is_tunnel_requested = None
                                                        self.weight = None

                                                        self.segment_routing_sid_value_entry = YList(self)
                                                        self.backup_repair = YList(self)
                                                        self._segment_path = lambda: "frr-backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                    class SegmentRoutingSidValueEntry(Entity):
                                                        """
                                                        Segment routing sid values for TI\-LFA/rLFA
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                            self.yang_name = "segment-routing-sid-value-entry"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                    class BackupRepair(Entity):
                                                        """
                                                        Backup Repair List
                                                        
                                                        .. attribute:: repair_element_node_id
                                                        
                                                        	RepairElementNodeID
                                                        	**type**\: str
                                                        
                                                        .. attribute:: repair_ipv4_addr
                                                        
                                                        	RepairIPv4Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_ipv6_addr
                                                        
                                                        	RepairIPv6Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_label
                                                        
                                                        	Repair Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_element_type
                                                        
                                                        	Repair Element Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_strict_spf_label
                                                        
                                                        	Repair Strict SPF Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup.BackupRepair, self).__init__()

                                                            self.yang_name = "backup-repair"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                                ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                                ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                                ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                                ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                                ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                            ])
                                                            self.repair_element_node_id = None
                                                            self.repair_ipv4_addr = None
                                                            self.repair_ipv6_addr = None
                                                            self.repair_label = None
                                                            self.repair_element_type = None
                                                            self.repair_strict_spf_label = None
                                                            self._segment_path = lambda: "backup-repair"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class UloopExplicit(Entity):
                                                    """
                                                    Uloop Explicit List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.UloopExplicit, self).__init__()

                                                        self.yang_name = "uloop-explicit"
                                                        self.yang_parent_name = "multicast-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "uloop-explicit"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class Nnh(Entity):
                                                    """
                                                    Next next hops
                                                    
                                                    .. attribute:: link_id_set
                                                    
                                                    	If link\_id is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ipv4_set
                                                    
                                                    	If ipv4 address is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: link_id
                                                    
                                                    	link ID of the next next hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	Ipv4 address of the next next hop
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.Nnh, self).__init__()

                                                        self.yang_name = "nnh"
                                                        self.yang_parent_name = "multicast-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                            ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                            ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ])
                                                        self.link_id_set = None
                                                        self.ipv4_set = None
                                                        self.link_id = None
                                                        self.ipv4_address = None
                                                        self._segment_path = lambda: "nnh"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                            class Parent(Entity):
                                                """
                                                Parents of the IS within the SPT
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: intermediate_pseudonode
                                                
                                                	Pseudonode between system and its neighbor
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Parent, self).__init__()

                                                    self.yang_name = "parent"
                                                    self.yang_parent_name = "reachable-details"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('intermediate_pseudonode', (YLeaf(YType.str, 'intermediate-pseudonode'), ['str'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.intermediate_pseudonode = None
                                                    self._segment_path = lambda: "parent"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Parent, [u'neighbor_id', u'intermediate_pseudonode'], name, value)


                                            class Children(Entity):
                                                """
                                                Children of the IS within the SPT
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: intermediate_pseudonode
                                                
                                                	Pseudonode between system and its neighbor
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Children, self).__init__()

                                                    self.yang_name = "children"
                                                    self.yang_parent_name = "reachable-details"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('intermediate_pseudonode', (YLeaf(YType.str, 'intermediate-pseudonode'), ['str'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.intermediate_pseudonode = None
                                                    self._segment_path = lambda: "children"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.ReachabilityStatus.ReachableDetails.Children, [u'neighbor_id', u'intermediate_pseudonode'], name, value)


                                    class AdvertisedPrefixItemCounts(Entity):
                                        """
                                        Per\-priority counts of prefix items advertised
                                        by the IS
                                        
                                        .. attribute:: critical
                                        
                                        	Critical priority
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: high
                                        
                                        	High priority
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: medium
                                        
                                        	Medium priority
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: low
                                        
                                        	Low priority
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.AdvertisedPrefixItemCounts, self).__init__()

                                            self.yang_name = "advertised-prefix-item-counts"
                                            self.yang_parent_name = "ipv4-link-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('critical', (YLeaf(YType.uint32, 'critical'), ['int'])),
                                                ('high', (YLeaf(YType.uint32, 'high'), ['int'])),
                                                ('medium', (YLeaf(YType.uint32, 'medium'), ['int'])),
                                                ('low', (YLeaf(YType.uint32, 'low'), ['int'])),
                                            ])
                                            self.critical = None
                                            self.high = None
                                            self.medium = None
                                            self.low = None
                                            self._segment_path = lambda: "advertised-prefix-item-counts"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv4LinkTopologies.Ipv4LinkTopology.AdvertisedPrefixItemCounts, [u'critical', u'high', u'medium', u'low'], name, value)


                            class TopologySummary(Entity):
                                """
                                Summary information for a particular IS
                                Topology
                                
                                .. attribute:: router_node_count
                                
                                	Node Counts for System nodes
                                	**type**\:  :py:class:`RouterNodeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TopologySummary.RouterNodeCount>`
                                
                                .. attribute:: pseudonode_node_count
                                
                                	Node Counts for Pseudonode nodes
                                	**type**\:  :py:class:`PseudonodeNodeCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TopologySummary.PseudonodeNodeCount>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TopologySummary, self).__init__()

                                    self.yang_name = "topology-summary"
                                    self.yang_parent_name = "topology-level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("router-node-count", ("router_node_count", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TopologySummary.RouterNodeCount)), ("pseudonode-node-count", ("pseudonode_node_count", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TopologySummary.PseudonodeNodeCount))])
                                    self._leafs = OrderedDict()

                                    self.router_node_count = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TopologySummary.RouterNodeCount()
                                    self.router_node_count.parent = self
                                    self._children_name_map["router_node_count"] = "router-node-count"

                                    self.pseudonode_node_count = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TopologySummary.PseudonodeNodeCount()
                                    self.pseudonode_node_count.parent = self
                                    self._children_name_map["pseudonode_node_count"] = "pseudonode-node-count"
                                    self._segment_path = lambda: "topology-summary"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TopologySummary, [], name, value)


                                class RouterNodeCount(Entity):
                                    """
                                    Node Counts for System nodes
                                    
                                    .. attribute:: reachable_node_count
                                    
                                    	Number of nodes reachable in SPT
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: unreachable_node_count
                                    
                                    	Number of nodes unreachable in SPT
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: unreachable_participant_node_count
                                    
                                    	Number of participating nodes unreachable in SPT
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TopologySummary.RouterNodeCount, self).__init__()

                                        self.yang_name = "router-node-count"
                                        self.yang_parent_name = "topology-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('reachable_node_count', (YLeaf(YType.uint32, 'reachable-node-count'), ['int'])),
                                            ('unreachable_node_count', (YLeaf(YType.uint32, 'unreachable-node-count'), ['int'])),
                                            ('unreachable_participant_node_count', (YLeaf(YType.uint32, 'unreachable-participant-node-count'), ['int'])),
                                        ])
                                        self.reachable_node_count = None
                                        self.unreachable_node_count = None
                                        self.unreachable_participant_node_count = None
                                        self._segment_path = lambda: "router-node-count"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TopologySummary.RouterNodeCount, [u'reachable_node_count', u'unreachable_node_count', u'unreachable_participant_node_count'], name, value)


                                class PseudonodeNodeCount(Entity):
                                    """
                                    Node Counts for Pseudonode nodes
                                    
                                    .. attribute:: reachable_node_count
                                    
                                    	Number of nodes reachable in SPT
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: unreachable_node_count
                                    
                                    	Number of nodes unreachable in SPT
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: unreachable_participant_node_count
                                    
                                    	Number of participating nodes unreachable in SPT
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TopologySummary.PseudonodeNodeCount, self).__init__()

                                        self.yang_name = "pseudonode-node-count"
                                        self.yang_parent_name = "topology-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('reachable_node_count', (YLeaf(YType.uint32, 'reachable-node-count'), ['int'])),
                                            ('unreachable_node_count', (YLeaf(YType.uint32, 'unreachable-node-count'), ['int'])),
                                            ('unreachable_participant_node_count', (YLeaf(YType.uint32, 'unreachable-participant-node-count'), ['int'])),
                                        ])
                                        self.reachable_node_count = None
                                        self.unreachable_node_count = None
                                        self.unreachable_participant_node_count = None
                                        self._segment_path = lambda: "pseudonode-node-count"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.TopologySummary.PseudonodeNodeCount, [u'reachable_node_count', u'unreachable_node_count', u'unreachable_participant_node_count'], name, value)


                            class Ipv6LinkTopologies(Entity):
                                """
                                IPv6 IS Topology table
                                
                                .. attribute:: ipv6_link_topology
                                
                                	An IS in an IPv6 Link Topology
                                	**type**\: list of  		 :py:class:`Ipv6LinkTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies, self).__init__()

                                    self.yang_name = "ipv6-link-topologies"
                                    self.yang_parent_name = "topology-level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ipv6-link-topology", ("ipv6_link_topology", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology))])
                                    self._leafs = OrderedDict()

                                    self.ipv6_link_topology = YList(self)
                                    self._segment_path = lambda: "ipv6-link-topologies"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies, [], name, value)


                                class Ipv6LinkTopology(Entity):
                                    """
                                    An IS in an IPv6 Link Topology
                                    
                                    .. attribute:: system_id  (key)
                                    
                                    	System ID
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                    
                                    .. attribute:: reachability_status
                                    
                                    	Is the IS reachable, and, if so, its status within the SPT
                                    	**type**\:  :py:class:`ReachabilityStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus>`
                                    
                                    .. attribute:: advertised_prefix_item_counts
                                    
                                    	Per\-priority counts of prefix items advertised by the IS
                                    	**type**\:  :py:class:`AdvertisedPrefixItemCounts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.AdvertisedPrefixItemCounts>`
                                    
                                    .. attribute:: source_address
                                    
                                    	Source Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: is_participant
                                    
                                    	Does the IS participate in the topology?
                                    	**type**\: bool
                                    
                                    .. attribute:: is_overloaded
                                    
                                    	Is the IS overloaded?
                                    	**type**\: bool
                                    
                                    .. attribute:: is_attached
                                    
                                    	Is the IS attached?
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology, self).__init__()

                                        self.yang_name = "ipv6-link-topology"
                                        self.yang_parent_name = "ipv6-link-topologies"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['system_id']
                                        self._child_classes = OrderedDict([("reachability-status", ("reachability_status", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus)), ("advertised-prefix-item-counts", ("advertised_prefix_item_counts", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.AdvertisedPrefixItemCounts))])
                                        self._leafs = OrderedDict([
                                            ('system_id', (YLeaf(YType.str, 'system-id'), ['str'])),
                                            ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                            ('is_participant', (YLeaf(YType.boolean, 'is-participant'), ['bool'])),
                                            ('is_overloaded', (YLeaf(YType.boolean, 'is-overloaded'), ['bool'])),
                                            ('is_attached', (YLeaf(YType.boolean, 'is-attached'), ['bool'])),
                                        ])
                                        self.system_id = None
                                        self.source_address = None
                                        self.is_participant = None
                                        self.is_overloaded = None
                                        self.is_attached = None

                                        self.reachability_status = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus()
                                        self.reachability_status.parent = self
                                        self._children_name_map["reachability_status"] = "reachability-status"

                                        self.advertised_prefix_item_counts = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.AdvertisedPrefixItemCounts()
                                        self.advertised_prefix_item_counts.parent = self
                                        self._children_name_map["advertised_prefix_item_counts"] = "advertised-prefix-item-counts"
                                        self._segment_path = lambda: "ipv6-link-topology" + "[system-id='" + str(self.system_id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology, ['system_id', u'source_address', u'is_participant', u'is_overloaded', u'is_attached'], name, value)


                                    class ReachabilityStatus(Entity):
                                        """
                                        Is the IS reachable, and, if so, its status
                                        within the SPT
                                        
                                        .. attribute:: reachable_details
                                        
                                        	Status of the IS within the SPT
                                        	**type**\:  :py:class:`ReachableDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails>`
                                        
                                        .. attribute:: reachable_status
                                        
                                        	ReachableStatus
                                        	**type**\:  :py:class:`IsisReachable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisReachable>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus, self).__init__()

                                            self.yang_name = "reachability-status"
                                            self.yang_parent_name = "ipv6-link-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("reachable-details", ("reachable_details", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails))])
                                            self._leafs = OrderedDict([
                                                ('reachable_status', (YLeaf(YType.enumeration, 'reachable-status'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisReachable', '')])),
                                            ])
                                            self.reachable_status = None

                                            self.reachable_details = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails()
                                            self.reachable_details.parent = self
                                            self._children_name_map["reachable_details"] = "reachable-details"
                                            self._segment_path = lambda: "reachability-status"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus, [u'reachable_status'], name, value)


                                        class ReachableDetails(Entity):
                                            """
                                            Status of the IS within the SPT
                                            
                                            .. attribute:: root_distance
                                            
                                            	Distance to the IS
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: multicast_root_distance
                                            
                                            	Distance to the IS
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: paths
                                            
                                            	First hops towards the IS
                                            	**type**\: list of  		 :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths>`
                                            
                                            .. attribute:: multicast_path
                                            
                                            	Multicast intact first hops towards the IS
                                            	**type**\: list of  		 :py:class:`MulticastPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath>`
                                            
                                            .. attribute:: parent_
                                            
                                            	Parents of the IS within the SPT
                                            	**type**\: list of  		 :py:class:`Parent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Parent>`
                                            
                                            .. attribute:: children_
                                            
                                            	Children of the IS within the SPT
                                            	**type**\: list of  		 :py:class:`Children <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Children>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails, self).__init__()

                                                self.yang_name = "reachable-details"
                                                self.yang_parent_name = "reachability-status"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("paths", ("paths", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths)), ("multicast-path", ("multicast_path", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath)), ("parent", ("parent_", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Parent)), ("children", ("children_", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Children))])
                                                self._leafs = OrderedDict([
                                                    ('root_distance', (YLeaf(YType.uint32, 'root-distance'), ['int'])),
                                                    ('multicast_root_distance', (YLeaf(YType.uint32, 'multicast-root-distance'), ['int'])),
                                                ])
                                                self.root_distance = None
                                                self.multicast_root_distance = None

                                                self.paths = YList(self)
                                                self.multicast_path = YList(self)
                                                self.parent_ = YList(self)
                                                self.children_ = YList(self)
                                                self._segment_path = lambda: "reachable-details"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails, [u'root_distance', u'multicast_root_distance'], name, value)


                                            class Paths(Entity):
                                                """
                                                First hops towards the IS
                                                
                                                .. attribute:: frr_backup
                                                
                                                	FRR backup for this path
                                                	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup>`
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: tag
                                                
                                                	Tag associated with the path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_interface
                                                
                                                	Explicit path tunnel interface
                                                	**type**\: str
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_te_tunnel_interface
                                                
                                                	Is path via a TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: is_sr_exclude_tunnel_interface
                                                
                                                	Is path via an SR\-exclude TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: uloop_explicit
                                                
                                                	Uloop Explicit List
                                                	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.UloopExplicit>`
                                                
                                                .. attribute:: nnh
                                                
                                                	Next next hops
                                                	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.Nnh>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths, self).__init__()

                                                    self.yang_name = "paths"
                                                    self.yang_parent_name = "reachable-details"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.Nnh))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                        ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.neighbor_snpa = None
                                                    self.tag = None
                                                    self.tunnel_interface = None
                                                    self.segment_routing_sid_value = None
                                                    self.weight = None
                                                    self.is_te_tunnel_interface = None
                                                    self.is_sr_exclude_tunnel_interface = None

                                                    self.frr_backup = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup()
                                                    self.frr_backup.parent = self
                                                    self._children_name_map["frr_backup"] = "frr-backup"

                                                    self.uloop_explicit = YList(self)
                                                    self.nnh = YList(self)
                                                    self._segment_path = lambda: "paths"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                                class FrrBackup(Entity):
                                                    """
                                                    FRR backup for this path
                                                    
                                                    .. attribute:: neighbor_id
                                                    
                                                    	Next hop neighbor ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: egress_interface
                                                    
                                                    	Interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Next hop neighbor's forwarding address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: tunnel_egress_interface
                                                    
                                                    	Tunnel interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_snpa
                                                    
                                                    	Next hop neighbor's SNPA
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_system_id
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_id
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: remote_lfa_system_pid
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_pid
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: total_backup_distance
                                                    
                                                    	Distance to the network via this backup path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value
                                                    
                                                    	Segment routing sid value received from first hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: num_sid
                                                    
                                                    	Number of SIDs in TI\-LFA/rLFA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_repair_list_size
                                                    
                                                    	Backup Repair List Size
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tilfa_computation
                                                    
                                                    	Ti LFA computation which provided backup path
                                                    	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                    
                                                    .. attribute:: prefix_source_node_id
                                                    
                                                    	PrefixSourceNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: is_downstream
                                                    
                                                    	Is the backup path via downstream node?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_lc_disjoint
                                                    
                                                    	Is the backup path line card disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_node_protecting
                                                    
                                                    	Is the backup path node protecting?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_primary_path
                                                    
                                                    	Is the backup path an ECMP to the network?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_srlg_disjoint
                                                    
                                                    	Is the backup path SRLG disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_remote_lfa
                                                    
                                                    	Is the backup path via a Remote LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_epcfrr_lfa
                                                    
                                                    	Is the backup path via a TI\-LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_strict_spflfa
                                                    
                                                    	Is the backup path TI\-LFA strict SPF?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_requested
                                                    
                                                    	Is SR TE tunnel requested
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight configured on the interface
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value_entry
                                                    
                                                    	Segment routing sid values for TI\-LFA/rLFA
                                                    	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup.SegmentRoutingSidValueEntry>`
                                                    
                                                    .. attribute:: backup_repair
                                                    
                                                    	BAckup Repair List
                                                    	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup.BackupRepair>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup, self).__init__()

                                                        self.yang_name = "frr-backup"
                                                        self.yang_parent_name = "paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup.BackupRepair))])
                                                        self._leafs = OrderedDict([
                                                            ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                            ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                            ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                            ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                            ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                            ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                            ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                            ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                            ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                            ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                            ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                            ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                            ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                            ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                            ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                            ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                            ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                            ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                            ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                            ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                            ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                            ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                            ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                            ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ])
                                                        self.neighbor_id = None
                                                        self.egress_interface = None
                                                        self.neighbor_address = None
                                                        self.tunnel_egress_interface = None
                                                        self.neighbor_snpa = None
                                                        self.remote_lfa_system_id = None
                                                        self.remote_lfa_router_id = None
                                                        self.remote_lfa_system_pid = None
                                                        self.remote_lfa_router_pid = None
                                                        self.total_backup_distance = None
                                                        self.segment_routing_sid_value = None
                                                        self.num_sid = None
                                                        self.backup_repair_list_size = None
                                                        self.tilfa_computation = None
                                                        self.prefix_source_node_id = None
                                                        self.is_downstream = None
                                                        self.is_lc_disjoint = None
                                                        self.is_node_protecting = None
                                                        self.is_primary_path = None
                                                        self.is_srlg_disjoint = None
                                                        self.is_remote_lfa = None
                                                        self.is_epcfrr_lfa = None
                                                        self.is_strict_spflfa = None
                                                        self.is_tunnel_requested = None
                                                        self.weight = None

                                                        self.segment_routing_sid_value_entry = YList(self)
                                                        self.backup_repair = YList(self)
                                                        self._segment_path = lambda: "frr-backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                    class SegmentRoutingSidValueEntry(Entity):
                                                        """
                                                        Segment routing sid values for TI\-LFA/rLFA
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                            self.yang_name = "segment-routing-sid-value-entry"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                    class BackupRepair(Entity):
                                                        """
                                                        BAckup Repair List
                                                        
                                                        .. attribute:: repair_element_node_id
                                                        
                                                        	RepairElementNodeID
                                                        	**type**\: str
                                                        
                                                        .. attribute:: repair_ipv4_addr
                                                        
                                                        	RepairIPv4Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_ipv6_addr
                                                        
                                                        	RepairIPv6Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_label
                                                        
                                                        	Repair Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_element_type
                                                        
                                                        	Repair Element Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_strict_spf_label
                                                        
                                                        	Repair Strict SPF Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup.BackupRepair, self).__init__()

                                                            self.yang_name = "backup-repair"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                                ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                                ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                                ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                                ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                                ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                            ])
                                                            self.repair_element_node_id = None
                                                            self.repair_ipv4_addr = None
                                                            self.repair_ipv6_addr = None
                                                            self.repair_label = None
                                                            self.repair_element_type = None
                                                            self.repair_strict_spf_label = None
                                                            self._segment_path = lambda: "backup-repair"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class UloopExplicit(Entity):
                                                    """
                                                    Uloop Explicit List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.UloopExplicit, self).__init__()

                                                        self.yang_name = "uloop-explicit"
                                                        self.yang_parent_name = "paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "uloop-explicit"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class Nnh(Entity):
                                                    """
                                                    Next next hops
                                                    
                                                    .. attribute:: link_id_set
                                                    
                                                    	If link\_id is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ipv4_set
                                                    
                                                    	If ipv4 address is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: link_id
                                                    
                                                    	link ID of the next next hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	Ipv4 address of the next next hop
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.Nnh, self).__init__()

                                                        self.yang_name = "nnh"
                                                        self.yang_parent_name = "paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                            ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                            ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ])
                                                        self.link_id_set = None
                                                        self.ipv4_set = None
                                                        self.link_id = None
                                                        self.ipv4_address = None
                                                        self._segment_path = lambda: "nnh"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Paths.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                            class MulticastPath(Entity):
                                                """
                                                Multicast intact first hops towards the IS
                                                
                                                .. attribute:: frr_backup
                                                
                                                	FRR backup for this path
                                                	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup>`
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: tag
                                                
                                                	Tag associated with the path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_interface
                                                
                                                	Explicit path tunnel interface
                                                	**type**\: str
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_te_tunnel_interface
                                                
                                                	Is path via a TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: is_sr_exclude_tunnel_interface
                                                
                                                	Is path via an SR\-exclude TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: uloop_explicit
                                                
                                                	Uloop Explicit List
                                                	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.UloopExplicit>`
                                                
                                                .. attribute:: nnh
                                                
                                                	Next next hops
                                                	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.Nnh>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath, self).__init__()

                                                    self.yang_name = "multicast-path"
                                                    self.yang_parent_name = "reachable-details"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.Nnh))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                        ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.neighbor_snpa = None
                                                    self.tag = None
                                                    self.tunnel_interface = None
                                                    self.segment_routing_sid_value = None
                                                    self.weight = None
                                                    self.is_te_tunnel_interface = None
                                                    self.is_sr_exclude_tunnel_interface = None

                                                    self.frr_backup = Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup()
                                                    self.frr_backup.parent = self
                                                    self._children_name_map["frr_backup"] = "frr-backup"

                                                    self.uloop_explicit = YList(self)
                                                    self.nnh = YList(self)
                                                    self._segment_path = lambda: "multicast-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                                class FrrBackup(Entity):
                                                    """
                                                    FRR backup for this path
                                                    
                                                    .. attribute:: neighbor_id
                                                    
                                                    	Next hop neighbor ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: egress_interface
                                                    
                                                    	Interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Next hop neighbor's forwarding address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: tunnel_egress_interface
                                                    
                                                    	Tunnel interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_snpa
                                                    
                                                    	Next hop neighbor's SNPA
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_system_id
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_id
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: remote_lfa_system_pid
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_pid
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: total_backup_distance
                                                    
                                                    	Distance to the network via this backup path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value
                                                    
                                                    	Segment routing sid value received from first hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: num_sid
                                                    
                                                    	Number of SIDs in TI\-LFA/rLFA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_repair_list_size
                                                    
                                                    	Backup Repair List Size
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tilfa_computation
                                                    
                                                    	Ti LFA computation which provided backup path
                                                    	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                    
                                                    .. attribute:: prefix_source_node_id
                                                    
                                                    	PrefixSourceNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: is_downstream
                                                    
                                                    	Is the backup path via downstream node?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_lc_disjoint
                                                    
                                                    	Is the backup path line card disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_node_protecting
                                                    
                                                    	Is the backup path node protecting?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_primary_path
                                                    
                                                    	Is the backup path an ECMP to the network?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_srlg_disjoint
                                                    
                                                    	Is the backup path SRLG disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_remote_lfa
                                                    
                                                    	Is the backup path via a Remote LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_epcfrr_lfa
                                                    
                                                    	Is the backup path via a TI\-LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_strict_spflfa
                                                    
                                                    	Is the backup path TI\-LFA strict SPF?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_requested
                                                    
                                                    	Is SR TE tunnel requested
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight configured on the interface
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value_entry
                                                    
                                                    	Segment routing sid values for TI\-LFA/rLFA
                                                    	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                    
                                                    .. attribute:: backup_repair
                                                    
                                                    	BAckup Repair List
                                                    	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup.BackupRepair>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup, self).__init__()

                                                        self.yang_name = "frr-backup"
                                                        self.yang_parent_name = "multicast-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup.BackupRepair))])
                                                        self._leafs = OrderedDict([
                                                            ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                            ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                            ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                            ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                            ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                            ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                            ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                            ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                            ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                            ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                            ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                            ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                            ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                            ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                            ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                            ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                            ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                            ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                            ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                            ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                            ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                            ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                            ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                            ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ])
                                                        self.neighbor_id = None
                                                        self.egress_interface = None
                                                        self.neighbor_address = None
                                                        self.tunnel_egress_interface = None
                                                        self.neighbor_snpa = None
                                                        self.remote_lfa_system_id = None
                                                        self.remote_lfa_router_id = None
                                                        self.remote_lfa_system_pid = None
                                                        self.remote_lfa_router_pid = None
                                                        self.total_backup_distance = None
                                                        self.segment_routing_sid_value = None
                                                        self.num_sid = None
                                                        self.backup_repair_list_size = None
                                                        self.tilfa_computation = None
                                                        self.prefix_source_node_id = None
                                                        self.is_downstream = None
                                                        self.is_lc_disjoint = None
                                                        self.is_node_protecting = None
                                                        self.is_primary_path = None
                                                        self.is_srlg_disjoint = None
                                                        self.is_remote_lfa = None
                                                        self.is_epcfrr_lfa = None
                                                        self.is_strict_spflfa = None
                                                        self.is_tunnel_requested = None
                                                        self.weight = None

                                                        self.segment_routing_sid_value_entry = YList(self)
                                                        self.backup_repair = YList(self)
                                                        self._segment_path = lambda: "frr-backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                    class SegmentRoutingSidValueEntry(Entity):
                                                        """
                                                        Segment routing sid values for TI\-LFA/rLFA
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                            self.yang_name = "segment-routing-sid-value-entry"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                    class BackupRepair(Entity):
                                                        """
                                                        BAckup Repair List
                                                        
                                                        .. attribute:: repair_element_node_id
                                                        
                                                        	RepairElementNodeID
                                                        	**type**\: str
                                                        
                                                        .. attribute:: repair_ipv4_addr
                                                        
                                                        	RepairIPv4Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_ipv6_addr
                                                        
                                                        	RepairIPv6Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_label
                                                        
                                                        	Repair Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_element_type
                                                        
                                                        	Repair Element Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_strict_spf_label
                                                        
                                                        	Repair Strict SPF Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup.BackupRepair, self).__init__()

                                                            self.yang_name = "backup-repair"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                                ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                                ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                                ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                                ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                                ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                            ])
                                                            self.repair_element_node_id = None
                                                            self.repair_ipv4_addr = None
                                                            self.repair_ipv6_addr = None
                                                            self.repair_label = None
                                                            self.repair_element_type = None
                                                            self.repair_strict_spf_label = None
                                                            self._segment_path = lambda: "backup-repair"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class UloopExplicit(Entity):
                                                    """
                                                    Uloop Explicit List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.UloopExplicit, self).__init__()

                                                        self.yang_name = "uloop-explicit"
                                                        self.yang_parent_name = "multicast-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "uloop-explicit"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class Nnh(Entity):
                                                    """
                                                    Next next hops
                                                    
                                                    .. attribute:: link_id_set
                                                    
                                                    	If link\_id is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ipv4_set
                                                    
                                                    	If ipv4 address is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: link_id
                                                    
                                                    	link ID of the next next hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	Ipv4 address of the next next hop
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.Nnh, self).__init__()

                                                        self.yang_name = "nnh"
                                                        self.yang_parent_name = "multicast-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                            ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                            ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ])
                                                        self.link_id_set = None
                                                        self.ipv4_set = None
                                                        self.link_id = None
                                                        self.ipv4_address = None
                                                        self._segment_path = lambda: "nnh"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.MulticastPath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                            class Parent(Entity):
                                                """
                                                Parents of the IS within the SPT
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: intermediate_pseudonode
                                                
                                                	Pseudonode between system and its neighbor
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Parent, self).__init__()

                                                    self.yang_name = "parent"
                                                    self.yang_parent_name = "reachable-details"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('intermediate_pseudonode', (YLeaf(YType.str, 'intermediate-pseudonode'), ['str'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.intermediate_pseudonode = None
                                                    self._segment_path = lambda: "parent"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Parent, [u'neighbor_id', u'intermediate_pseudonode'], name, value)


                                            class Children(Entity):
                                                """
                                                Children of the IS within the SPT
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: intermediate_pseudonode
                                                
                                                	Pseudonode between system and its neighbor
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Children, self).__init__()

                                                    self.yang_name = "children"
                                                    self.yang_parent_name = "reachable-details"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('intermediate_pseudonode', (YLeaf(YType.str, 'intermediate-pseudonode'), ['str'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.intermediate_pseudonode = None
                                                    self._segment_path = lambda: "children"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.ReachabilityStatus.ReachableDetails.Children, [u'neighbor_id', u'intermediate_pseudonode'], name, value)


                                    class AdvertisedPrefixItemCounts(Entity):
                                        """
                                        Per\-priority counts of prefix items advertised
                                        by the IS
                                        
                                        .. attribute:: critical
                                        
                                        	Critical priority
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: high
                                        
                                        	High priority
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: medium
                                        
                                        	Medium priority
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: low
                                        
                                        	Low priority
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.AdvertisedPrefixItemCounts, self).__init__()

                                            self.yang_name = "advertised-prefix-item-counts"
                                            self.yang_parent_name = "ipv6-link-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('critical', (YLeaf(YType.uint32, 'critical'), ['int'])),
                                                ('high', (YLeaf(YType.uint32, 'high'), ['int'])),
                                                ('medium', (YLeaf(YType.uint32, 'medium'), ['int'])),
                                                ('low', (YLeaf(YType.uint32, 'low'), ['int'])),
                                            ])
                                            self.critical = None
                                            self.high = None
                                            self.medium = None
                                            self.low = None
                                            self._segment_path = lambda: "advertised-prefix-item-counts"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.TopologyLevels.TopologyLevel.Ipv6LinkTopologies.Ipv6LinkTopology.AdvertisedPrefixItemCounts, [u'critical', u'high', u'medium', u'low'], name, value)


                    class Ipv6Routes(Entity):
                        """
                        IPv6 local route
                        
                        .. attribute:: ipv6_route
                        
                        	An IPv6 route known to IS\-IS
                        	**type**\: list of  		 :py:class:`Ipv6Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes, self).__init__()

                            self.yang_name = "ipv6-routes"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv6-route", ("ipv6_route", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route))])
                            self._leafs = OrderedDict()

                            self.ipv6_route = YList(self)
                            self._segment_path = lambda: "ipv6-routes"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes, [], name, value)


                        class Ipv6Route(Entity):
                            """
                            An IPv6 route known to IS\-IS
                            
                            .. attribute:: prefix
                            
                            	Prefix
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length
                            
                            	Prefix Length
                            	**type**\: int
                            
                            	**range:** 0..128
                            
                            .. attribute:: connected_status
                            
                            	Status of IS\-IS directly connected routes to the prefix
                            	**type**\:  :py:class:`ConnectedStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.ConnectedStatus>`
                            
                            .. attribute:: redistributed_status
                            
                            	Status of other protocols' routes redistributed into IS\-IS
                            	**type**\:  :py:class:`RedistributedStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus>`
                            
                            .. attribute:: native_status
                            
                            	Status of native IS\-IS routes to the prefix
                            	**type**\:  :py:class:`NativeStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus>`
                            
                            .. attribute:: per_level_advertising_detail
                            
                            	Per level details of how the local system advertises the prefix
                            	**type**\: list of  		 :py:class:`PerLevelAdvertisingDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route, self).__init__()

                                self.yang_name = "ipv6-route"
                                self.yang_parent_name = "ipv6-routes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("connected-status", ("connected_status", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.ConnectedStatus)), ("redistributed-status", ("redistributed_status", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus)), ("native-status", ("native_status", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus)), ("per-level-advertising-detail", ("per_level_advertising_detail", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail))])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                    ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                ])
                                self.prefix = None
                                self.prefix_length = None

                                self.connected_status = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.ConnectedStatus()
                                self.connected_status.parent = self
                                self._children_name_map["connected_status"] = "connected-status"

                                self.redistributed_status = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus()
                                self.redistributed_status.parent = self
                                self._children_name_map["redistributed_status"] = "redistributed-status"

                                self.native_status = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus()
                                self.native_status.parent = self
                                self._children_name_map["native_status"] = "native-status"

                                self.per_level_advertising_detail = YList(self)
                                self._segment_path = lambda: "ipv6-route"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route, ['prefix', 'prefix_length'], name, value)


                            class ConnectedStatus(Entity):
                                """
                                Status of IS\-IS directly connected routes to the
                                prefix
                                
                                .. attribute:: connected_details
                                
                                	Details of the directly connected prefix
                                	**type**\:  :py:class:`ConnectedDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.ConnectedStatus.ConnectedDetails>`
                                
                                .. attribute:: is_valid
                                
                                	IsValid
                                	**type**\:  :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.ConnectedStatus, self).__init__()

                                    self.yang_name = "connected-status"
                                    self.yang_parent_name = "ipv6-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("connected-details", ("connected_details", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.ConnectedStatus.ConnectedDetails))])
                                    self._leafs = OrderedDict([
                                        ('is_valid', (YLeaf(YType.enumeration, 'is-valid'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisValid', '')])),
                                    ])
                                    self.is_valid = None

                                    self.connected_details = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.ConnectedStatus.ConnectedDetails()
                                    self.connected_details.parent = self
                                    self._children_name_map["connected_details"] = "connected-details"
                                    self._segment_path = lambda: "connected-status"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.ConnectedStatus, [u'is_valid'], name, value)


                                class ConnectedDetails(Entity):
                                    """
                                    Details of the directly connected prefix
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.ConnectedStatus.ConnectedDetails.Interface>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.ConnectedStatus.ConnectedDetails, self).__init__()

                                        self.yang_name = "connected-details"
                                        self.yang_parent_name = "connected-status"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface", ("interface", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.ConnectedStatus.ConnectedDetails.Interface))])
                                        self._leafs = OrderedDict()

                                        self.interface = YList(self)
                                        self._segment_path = lambda: "connected-details"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.ConnectedStatus.ConnectedDetails, [], name, value)


                                    class Interface(Entity):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.ConnectedStatus.ConnectedDetails.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "connected-details"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "interface"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.ConnectedStatus.ConnectedDetails.Interface, [u'entry'], name, value)


                            class RedistributedStatus(Entity):
                                """
                                Status of other protocols' routes redistributed
                                into IS\-IS
                                
                                .. attribute:: redistribution_details
                                
                                	Per level details of the redistributed route
                                	**type**\:  :py:class:`RedistributionDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus.RedistributionDetails>`
                                
                                .. attribute:: is_valid
                                
                                	IsValid
                                	**type**\:  :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus, self).__init__()

                                    self.yang_name = "redistributed-status"
                                    self.yang_parent_name = "ipv6-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("redistribution-details", ("redistribution_details", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus.RedistributionDetails))])
                                    self._leafs = OrderedDict([
                                        ('is_valid', (YLeaf(YType.enumeration, 'is-valid'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisValid', '')])),
                                    ])
                                    self.is_valid = None

                                    self.redistribution_details = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus.RedistributionDetails()
                                    self.redistribution_details.parent = self
                                    self._children_name_map["redistribution_details"] = "redistribution-details"
                                    self._segment_path = lambda: "redistributed-status"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus, [u'is_valid'], name, value)


                                class RedistributionDetails(Entity):
                                    """
                                    Per level details of the redistributed route
                                    
                                    .. attribute:: isis_sh_route_redist_detail
                                    
                                    	isis sh route redist detail
                                    	**type**\: list of  		 :py:class:`IsisShRouteRedistDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus.RedistributionDetails, self).__init__()

                                        self.yang_name = "redistribution-details"
                                        self.yang_parent_name = "redistributed-status"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("isis-sh-route-redist-detail", ("isis_sh_route_redist_detail", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail))])
                                        self._leafs = OrderedDict()

                                        self.isis_sh_route_redist_detail = YList(self)
                                        self._segment_path = lambda: "redistribution-details"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus.RedistributionDetails, [], name, value)


                                    class IsisShRouteRedistDetail(Entity):
                                        """
                                        isis sh route redist detail
                                        
                                        .. attribute:: owner
                                        
                                        	Protocol redistributing the route
                                        	**type**\:  :py:class:`Owner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner>`
                                        
                                        .. attribute:: level
                                        
                                        	Level into which the route is redistributed
                                        	**type**\:  :py:class:`IsisLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevel>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail, self).__init__()

                                            self.yang_name = "isis-sh-route-redist-detail"
                                            self.yang_parent_name = "redistribution-details"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("owner", ("owner", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner))])
                                            self._leafs = OrderedDict([
                                                ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisLevel', '')])),
                                            ])
                                            self.level = None

                                            self.owner = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner()
                                            self.owner.parent = self
                                            self._children_name_map["owner"] = "owner"
                                            self._segment_path = lambda: "isis-sh-route-redist-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail, [u'level'], name, value)


                                        class Owner(Entity):
                                            """
                                            Protocol redistributing the route
                                            
                                            .. attribute:: protocol
                                            
                                            	Protocol
                                            	**type**\:  :py:class:`IsisRedistProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisRedistProto>`
                                            
                                            .. attribute:: isis_instance_id
                                            
                                            	IS\-IS instance identifier
                                            	**type**\: str
                                            
                                            .. attribute:: ospf_process_id
                                            
                                            	OSPF process identifier
                                            	**type**\: str
                                            
                                            .. attribute:: ospfv3_process_id
                                            
                                            	OSPFv3 process identifier
                                            	**type**\: str
                                            
                                            .. attribute:: bgp_as_number
                                            
                                            	BGP Autonomous System number
                                            	**type**\: str
                                            
                                            .. attribute:: eigrp_as_number
                                            
                                            	EIGRP Autonomous System number
                                            	**type**\: str
                                            
                                            .. attribute:: application_name
                                            
                                            	Application Name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner, self).__init__()

                                                self.yang_name = "owner"
                                                self.yang_parent_name = "isis-sh-route-redist-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisRedistProto', '')])),
                                                    ('isis_instance_id', (YLeaf(YType.str, 'isis-instance-id'), ['str'])),
                                                    ('ospf_process_id', (YLeaf(YType.str, 'ospf-process-id'), ['str'])),
                                                    ('ospfv3_process_id', (YLeaf(YType.str, 'ospfv3-process-id'), ['str'])),
                                                    ('bgp_as_number', (YLeaf(YType.str, 'bgp-as-number'), ['str'])),
                                                    ('eigrp_as_number', (YLeaf(YType.str, 'eigrp-as-number'), ['str'])),
                                                    ('application_name', (YLeaf(YType.str, 'application-name'), ['str'])),
                                                ])
                                                self.protocol = None
                                                self.isis_instance_id = None
                                                self.ospf_process_id = None
                                                self.ospfv3_process_id = None
                                                self.bgp_as_number = None
                                                self.eigrp_as_number = None
                                                self.application_name = None
                                                self._segment_path = lambda: "owner"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner, [u'protocol', u'isis_instance_id', u'ospf_process_id', u'ospfv3_process_id', u'bgp_as_number', u'eigrp_as_number', u'application_name'], name, value)


                            class NativeStatus(Entity):
                                """
                                Status of native IS\-IS routes to the prefix
                                
                                .. attribute:: native_details
                                
                                	Details of the native route
                                	**type**\:  :py:class:`NativeDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails>`
                                
                                .. attribute:: is_valid
                                
                                	IsValid
                                	**type**\:  :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus, self).__init__()

                                    self.yang_name = "native-status"
                                    self.yang_parent_name = "ipv6-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("native-details", ("native_details", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails))])
                                    self._leafs = OrderedDict([
                                        ('is_valid', (YLeaf(YType.enumeration, 'is-valid'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisValid', '')])),
                                    ])
                                    self.is_valid = None

                                    self.native_details = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails()
                                    self.native_details.parent = self
                                    self._children_name_map["native_details"] = "native-details"
                                    self._segment_path = lambda: "native-status"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus, [u'is_valid'], name, value)


                                class NativeDetails(Entity):
                                    """
                                    Details of the native route
                                    
                                    .. attribute:: primary
                                    
                                    	Primary paths to prefix
                                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary>`
                                    
                                    .. attribute:: priority
                                    
                                    	Relative importance of the prefix
                                    	**type**\:  :py:class:`IsisPrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisPrefixPriority>`
                                    
                                    .. attribute:: backup
                                    
                                    	Backup paths to prefix
                                    	**type**\: list of  		 :py:class:`Backup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails, self).__init__()

                                        self.yang_name = "native-details"
                                        self.yang_parent_name = "native-status"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("primary", ("primary", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary)), ("backup", ("backup", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup))])
                                        self._leafs = OrderedDict([
                                            ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisPrefixPriority', '')])),
                                        ])
                                        self.priority = None

                                        self.primary = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary()
                                        self.primary.parent = self
                                        self._children_name_map["primary"] = "primary"

                                        self.backup = YList(self)
                                        self._segment_path = lambda: "native-details"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails, [u'priority'], name, value)


                                    class Primary(Entity):
                                        """
                                        Primary paths to prefix
                                        
                                        .. attribute:: origin
                                        
                                        	Origin of route
                                        	**type**\:  :py:class:`IsisPrefixOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisPrefixOrigin>`
                                        
                                        .. attribute:: metric
                                        
                                        	Distance to network
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multicast_metric
                                        
                                        	Multicast\-intact distance to network
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_external_metric
                                        
                                        	Is the metric an external metric?
                                        	**type**\: bool
                                        
                                        .. attribute:: administrative_distance
                                        
                                        	Administrative Distance
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: paths
                                        
                                        	First hops toward the prefix
                                        	**type**\: list of  		 :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths>`
                                        
                                        .. attribute:: ucmp_next_hop
                                        
                                        	UCMP first hops toward the prefix
                                        	**type**\: list of  		 :py:class:`UcmpNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop>`
                                        
                                        .. attribute:: multicast_path
                                        
                                        	Multicast intact first hops toward the prefix
                                        	**type**\: list of  		 :py:class:`MulticastPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath>`
                                        
                                        .. attribute:: srte_path
                                        
                                        	SR\-TE native first hops toward the prefix
                                        	**type**\: list of  		 :py:class:`SrtePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath>`
                                        
                                        .. attribute:: explicit_path
                                        
                                        	SR microloop avoidance paths
                                        	**type**\: list of  		 :py:class:`ExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath>`
                                        
                                        .. attribute:: source
                                        
                                        	Sources advertising the prefix
                                        	**type**\: list of  		 :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Source>`
                                        
                                        .. attribute:: multicast_source
                                        
                                        	Multicast\-intact sources advertising the prefix
                                        	**type**\: list of  		 :py:class:`MulticastSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastSource>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary, self).__init__()

                                            self.yang_name = "primary"
                                            self.yang_parent_name = "native-details"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("paths", ("paths", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths)), ("ucmp-next-hop", ("ucmp_next_hop", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop)), ("multicast-path", ("multicast_path", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath)), ("srte-path", ("srte_path", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath)), ("explicit-path", ("explicit_path", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath)), ("source", ("source", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Source)), ("multicast-source", ("multicast_source", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastSource))])
                                            self._leafs = OrderedDict([
                                                ('origin', (YLeaf(YType.enumeration, 'origin'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisPrefixOrigin', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('multicast_metric', (YLeaf(YType.uint32, 'multicast-metric'), ['int'])),
                                                ('is_external_metric', (YLeaf(YType.boolean, 'is-external-metric'), ['bool'])),
                                                ('administrative_distance', (YLeaf(YType.uint16, 'administrative-distance'), ['int'])),
                                            ])
                                            self.origin = None
                                            self.metric = None
                                            self.multicast_metric = None
                                            self.is_external_metric = None
                                            self.administrative_distance = None

                                            self.paths = YList(self)
                                            self.ucmp_next_hop = YList(self)
                                            self.multicast_path = YList(self)
                                            self.srte_path = YList(self)
                                            self.explicit_path = YList(self)
                                            self.source = YList(self)
                                            self.multicast_source = YList(self)
                                            self._segment_path = lambda: "primary"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary, [u'origin', u'metric', u'multicast_metric', u'is_external_metric', u'administrative_distance'], name, value)


                                        class Paths(Entity):
                                            """
                                            First hops toward the prefix
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\: str
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit>`
                                            
                                            .. attribute:: nnh
                                            
                                            	Next next hops
                                            	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.Nnh>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths, self).__init__()

                                                self.yang_name = "paths"
                                                self.yang_parent_name = "primary"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.Nnh))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.tunnel_interface = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"

                                                self.uloop_explicit = YList(self)
                                                self.nnh = YList(self)
                                                self._segment_path = lambda: "paths"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                        ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                        ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                        ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                        ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                        ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                    ])
                                                    self.repair_element_node_id = None
                                                    self.repair_ipv4_addr = None
                                                    self.repair_ipv6_addr = None
                                                    self.repair_label = None
                                                    self.repair_element_type = None
                                                    self.repair_strict_spf_label = None
                                                    self._segment_path = lambda: "uloop-explicit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class Nnh(Entity):
                                                """
                                                Next next hops
                                                
                                                .. attribute:: link_id_set
                                                
                                                	If link\_id is given
                                                	**type**\: bool
                                                
                                                .. attribute:: ipv4_set
                                                
                                                	If ipv4 address is given
                                                	**type**\: bool
                                                
                                                .. attribute:: link_id
                                                
                                                	link ID of the next next hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	Ipv4 address of the next next hop
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.Nnh, self).__init__()

                                                    self.yang_name = "nnh"
                                                    self.yang_parent_name = "paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                        ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                        ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ])
                                                    self.link_id_set = None
                                                    self.ipv4_set = None
                                                    self.link_id = None
                                                    self.ipv4_address = None
                                                    self._segment_path = lambda: "nnh"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Paths.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                        class UcmpNextHop(Entity):
                                            """
                                            UCMP first hops toward the prefix
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: total_ucmp_distance
                                            
                                            	Distance to the network via this UCMP next hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop, self).__init__()

                                                self.yang_name = "ucmp-next-hop"
                                                self.yang_parent_name = "primary"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('total_ucmp_distance', (YLeaf(YType.uint32, 'total-ucmp-distance'), ['int'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.total_ucmp_distance = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._segment_path = lambda: "ucmp-next-hop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'total_ucmp_distance', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "ucmp-next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                        class MulticastPath(Entity):
                                            """
                                            Multicast intact first hops toward the prefix
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\: str
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit>`
                                            
                                            .. attribute:: nnh
                                            
                                            	Next next hops
                                            	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.Nnh>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath, self).__init__()

                                                self.yang_name = "multicast-path"
                                                self.yang_parent_name = "primary"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.Nnh))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.tunnel_interface = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"

                                                self.uloop_explicit = YList(self)
                                                self.nnh = YList(self)
                                                self._segment_path = lambda: "multicast-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "multicast-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "multicast-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                        ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                        ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                        ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                        ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                        ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                    ])
                                                    self.repair_element_node_id = None
                                                    self.repair_ipv4_addr = None
                                                    self.repair_ipv6_addr = None
                                                    self.repair_label = None
                                                    self.repair_element_type = None
                                                    self.repair_strict_spf_label = None
                                                    self._segment_path = lambda: "uloop-explicit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class Nnh(Entity):
                                                """
                                                Next next hops
                                                
                                                .. attribute:: link_id_set
                                                
                                                	If link\_id is given
                                                	**type**\: bool
                                                
                                                .. attribute:: ipv4_set
                                                
                                                	If ipv4 address is given
                                                	**type**\: bool
                                                
                                                .. attribute:: link_id
                                                
                                                	link ID of the next next hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	Ipv4 address of the next next hop
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.Nnh, self).__init__()

                                                    self.yang_name = "nnh"
                                                    self.yang_parent_name = "multicast-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                        ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                        ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ])
                                                    self.link_id_set = None
                                                    self.ipv4_set = None
                                                    self.link_id = None
                                                    self.ipv4_address = None
                                                    self._segment_path = lambda: "nnh"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastPath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                        class SrtePath(Entity):
                                            """
                                            SR\-TE native first hops toward the prefix
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\: str
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit>`
                                            
                                            .. attribute:: nnh
                                            
                                            	Next next hops
                                            	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.Nnh>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath, self).__init__()

                                                self.yang_name = "srte-path"
                                                self.yang_parent_name = "primary"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.Nnh))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.tunnel_interface = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"

                                                self.uloop_explicit = YList(self)
                                                self.nnh = YList(self)
                                                self._segment_path = lambda: "srte-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "srte-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "srte-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                        ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                        ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                        ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                        ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                        ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                    ])
                                                    self.repair_element_node_id = None
                                                    self.repair_ipv4_addr = None
                                                    self.repair_ipv6_addr = None
                                                    self.repair_label = None
                                                    self.repair_element_type = None
                                                    self.repair_strict_spf_label = None
                                                    self._segment_path = lambda: "uloop-explicit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class Nnh(Entity):
                                                """
                                                Next next hops
                                                
                                                .. attribute:: link_id_set
                                                
                                                	If link\_id is given
                                                	**type**\: bool
                                                
                                                .. attribute:: ipv4_set
                                                
                                                	If ipv4 address is given
                                                	**type**\: bool
                                                
                                                .. attribute:: link_id
                                                
                                                	link ID of the next next hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	Ipv4 address of the next next hop
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.Nnh, self).__init__()

                                                    self.yang_name = "nnh"
                                                    self.yang_parent_name = "srte-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                        ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                        ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ])
                                                    self.link_id_set = None
                                                    self.ipv4_set = None
                                                    self.link_id = None
                                                    self.ipv4_address = None
                                                    self._segment_path = lambda: "nnh"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.SrtePath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                        class ExplicitPath(Entity):
                                            """
                                            SR microloop avoidance paths
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\: str
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit>`
                                            
                                            .. attribute:: nnh
                                            
                                            	Next next hops
                                            	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.Nnh>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath, self).__init__()

                                                self.yang_name = "explicit-path"
                                                self.yang_parent_name = "primary"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.Nnh))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.tunnel_interface = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"

                                                self.uloop_explicit = YList(self)
                                                self.nnh = YList(self)
                                                self._segment_path = lambda: "explicit-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "explicit-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "explicit-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                        ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                        ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                        ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                        ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                        ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                    ])
                                                    self.repair_element_node_id = None
                                                    self.repair_ipv4_addr = None
                                                    self.repair_ipv6_addr = None
                                                    self.repair_label = None
                                                    self.repair_element_type = None
                                                    self.repair_strict_spf_label = None
                                                    self._segment_path = lambda: "uloop-explicit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class Nnh(Entity):
                                                """
                                                Next next hops
                                                
                                                .. attribute:: link_id_set
                                                
                                                	If link\_id is given
                                                	**type**\: bool
                                                
                                                .. attribute:: ipv4_set
                                                
                                                	If ipv4 address is given
                                                	**type**\: bool
                                                
                                                .. attribute:: link_id
                                                
                                                	link ID of the next next hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	Ipv4 address of the next next hop
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.Nnh, self).__init__()

                                                    self.yang_name = "nnh"
                                                    self.yang_parent_name = "explicit-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                        ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                        ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ])
                                                    self.link_id_set = None
                                                    self.ipv4_set = None
                                                    self.link_id = None
                                                    self.ipv4_address = None
                                                    self._segment_path = lambda: "nnh"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.ExplicitPath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                        class Source(Entity):
                                            """
                                            Sources advertising the prefix
                                            
                                            .. attribute:: source_lsp_id
                                            
                                            	ID of the LSP advertising the prefix
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                            
                                            .. attribute:: source_address
                                            
                                            	Source address of the IS advertising the prefix
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: tags
                                            
                                            	Tags associated with the prefix item
                                            	**type**\: list of  		 :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Source.Tags>`
                                            
                                            .. attribute:: nodal_sid
                                            
                                            	Nodal SIDs with the prefix item
                                            	**type**\: list of  		 :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Source.NodalSid>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "primary"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tags", ("tags", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Source.Tags)), ("nodal-sid", ("nodal_sid", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Source.NodalSid))])
                                                self._leafs = OrderedDict([
                                                    ('source_lsp_id', (YLeaf(YType.str, 'source-lsp-id'), ['str'])),
                                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                                ])
                                                self.source_lsp_id = None
                                                self.source_address = None

                                                self.tags = YList(self)
                                                self.nodal_sid = YList(self)
                                                self._segment_path = lambda: "source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Source, [u'source_lsp_id', u'source_address'], name, value)


                                            class Tags(Entity):
                                                """
                                                Tags associated with the prefix item
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Source.Tags, self).__init__()

                                                    self.yang_name = "tags"
                                                    self.yang_parent_name = "source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "tags"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Source.Tags, [u'entry'], name, value)


                                            class NodalSid(Entity):
                                                """
                                                Nodal SIDs with the prefix item
                                                
                                                .. attribute:: sid_value
                                                
                                                	sid value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rflag
                                                
                                                	rflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nflag
                                                
                                                	nflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pflag
                                                
                                                	pflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: eflag
                                                
                                                	eflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: vflag
                                                
                                                	vflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: lflag
                                                
                                                	lflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: algorithm
                                                
                                                	algorithm
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Source.NodalSid, self).__init__()

                                                    self.yang_name = "nodal-sid"
                                                    self.yang_parent_name = "source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('sid_value', (YLeaf(YType.uint32, 'sid-value'), ['int'])),
                                                        ('rflag', (YLeaf(YType.uint8, 'rflag'), ['int'])),
                                                        ('nflag', (YLeaf(YType.uint8, 'nflag'), ['int'])),
                                                        ('pflag', (YLeaf(YType.uint8, 'pflag'), ['int'])),
                                                        ('eflag', (YLeaf(YType.uint8, 'eflag'), ['int'])),
                                                        ('vflag', (YLeaf(YType.uint8, 'vflag'), ['int'])),
                                                        ('lflag', (YLeaf(YType.uint8, 'lflag'), ['int'])),
                                                        ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                                    ])
                                                    self.sid_value = None
                                                    self.rflag = None
                                                    self.nflag = None
                                                    self.pflag = None
                                                    self.eflag = None
                                                    self.vflag = None
                                                    self.lflag = None
                                                    self.algorithm = None
                                                    self._segment_path = lambda: "nodal-sid"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.Source.NodalSid, [u'sid_value', u'rflag', u'nflag', u'pflag', u'eflag', u'vflag', u'lflag', u'algorithm'], name, value)


                                        class MulticastSource(Entity):
                                            """
                                            Multicast\-intact sources advertising the prefix
                                            
                                            .. attribute:: source_lsp_id
                                            
                                            	ID of the LSP advertising the prefix
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                            
                                            .. attribute:: source_address
                                            
                                            	Source address of the IS advertising the prefix
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: tags
                                            
                                            	Tags associated with the prefix item
                                            	**type**\: list of  		 :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastSource.Tags>`
                                            
                                            .. attribute:: nodal_sid
                                            
                                            	Nodal SIDs with the prefix item
                                            	**type**\: list of  		 :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastSource, self).__init__()

                                                self.yang_name = "multicast-source"
                                                self.yang_parent_name = "primary"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tags", ("tags", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastSource.Tags)), ("nodal-sid", ("nodal_sid", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid))])
                                                self._leafs = OrderedDict([
                                                    ('source_lsp_id', (YLeaf(YType.str, 'source-lsp-id'), ['str'])),
                                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                                ])
                                                self.source_lsp_id = None
                                                self.source_address = None

                                                self.tags = YList(self)
                                                self.nodal_sid = YList(self)
                                                self._segment_path = lambda: "multicast-source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastSource, [u'source_lsp_id', u'source_address'], name, value)


                                            class Tags(Entity):
                                                """
                                                Tags associated with the prefix item
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastSource.Tags, self).__init__()

                                                    self.yang_name = "tags"
                                                    self.yang_parent_name = "multicast-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "tags"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastSource.Tags, [u'entry'], name, value)


                                            class NodalSid(Entity):
                                                """
                                                Nodal SIDs with the prefix item
                                                
                                                .. attribute:: sid_value
                                                
                                                	sid value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rflag
                                                
                                                	rflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nflag
                                                
                                                	nflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pflag
                                                
                                                	pflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: eflag
                                                
                                                	eflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: vflag
                                                
                                                	vflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: lflag
                                                
                                                	lflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: algorithm
                                                
                                                	algorithm
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid, self).__init__()

                                                    self.yang_name = "nodal-sid"
                                                    self.yang_parent_name = "multicast-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('sid_value', (YLeaf(YType.uint32, 'sid-value'), ['int'])),
                                                        ('rflag', (YLeaf(YType.uint8, 'rflag'), ['int'])),
                                                        ('nflag', (YLeaf(YType.uint8, 'nflag'), ['int'])),
                                                        ('pflag', (YLeaf(YType.uint8, 'pflag'), ['int'])),
                                                        ('eflag', (YLeaf(YType.uint8, 'eflag'), ['int'])),
                                                        ('vflag', (YLeaf(YType.uint8, 'vflag'), ['int'])),
                                                        ('lflag', (YLeaf(YType.uint8, 'lflag'), ['int'])),
                                                        ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                                    ])
                                                    self.sid_value = None
                                                    self.rflag = None
                                                    self.nflag = None
                                                    self.pflag = None
                                                    self.eflag = None
                                                    self.vflag = None
                                                    self.lflag = None
                                                    self.algorithm = None
                                                    self._segment_path = lambda: "nodal-sid"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid, [u'sid_value', u'rflag', u'nflag', u'pflag', u'eflag', u'vflag', u'lflag', u'algorithm'], name, value)


                                    class Backup(Entity):
                                        """
                                        Backup paths to prefix
                                        
                                        .. attribute:: origin
                                        
                                        	Origin of route
                                        	**type**\:  :py:class:`IsisPrefixOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisPrefixOrigin>`
                                        
                                        .. attribute:: metric
                                        
                                        	Distance to network
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multicast_metric
                                        
                                        	Multicast\-intact distance to network
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_external_metric
                                        
                                        	Is the metric an external metric?
                                        	**type**\: bool
                                        
                                        .. attribute:: administrative_distance
                                        
                                        	Administrative Distance
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: paths
                                        
                                        	First hops toward the prefix
                                        	**type**\: list of  		 :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths>`
                                        
                                        .. attribute:: ucmp_next_hop
                                        
                                        	UCMP first hops toward the prefix
                                        	**type**\: list of  		 :py:class:`UcmpNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop>`
                                        
                                        .. attribute:: multicast_path
                                        
                                        	Multicast intact first hops toward the prefix
                                        	**type**\: list of  		 :py:class:`MulticastPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath>`
                                        
                                        .. attribute:: srte_path
                                        
                                        	SR\-TE native first hops toward the prefix
                                        	**type**\: list of  		 :py:class:`SrtePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath>`
                                        
                                        .. attribute:: explicit_path
                                        
                                        	SR microloop avoidance paths
                                        	**type**\: list of  		 :py:class:`ExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath>`
                                        
                                        .. attribute:: source
                                        
                                        	Sources advertising the prefix
                                        	**type**\: list of  		 :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Source>`
                                        
                                        .. attribute:: multicast_source
                                        
                                        	Multicast\-intact sources advertising the prefix
                                        	**type**\: list of  		 :py:class:`MulticastSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastSource>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup, self).__init__()

                                            self.yang_name = "backup"
                                            self.yang_parent_name = "native-details"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("paths", ("paths", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths)), ("ucmp-next-hop", ("ucmp_next_hop", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop)), ("multicast-path", ("multicast_path", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath)), ("srte-path", ("srte_path", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath)), ("explicit-path", ("explicit_path", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath)), ("source", ("source", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Source)), ("multicast-source", ("multicast_source", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastSource))])
                                            self._leafs = OrderedDict([
                                                ('origin', (YLeaf(YType.enumeration, 'origin'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisPrefixOrigin', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('multicast_metric', (YLeaf(YType.uint32, 'multicast-metric'), ['int'])),
                                                ('is_external_metric', (YLeaf(YType.boolean, 'is-external-metric'), ['bool'])),
                                                ('administrative_distance', (YLeaf(YType.uint16, 'administrative-distance'), ['int'])),
                                            ])
                                            self.origin = None
                                            self.metric = None
                                            self.multicast_metric = None
                                            self.is_external_metric = None
                                            self.administrative_distance = None

                                            self.paths = YList(self)
                                            self.ucmp_next_hop = YList(self)
                                            self.multicast_path = YList(self)
                                            self.srte_path = YList(self)
                                            self.explicit_path = YList(self)
                                            self.source = YList(self)
                                            self.multicast_source = YList(self)
                                            self._segment_path = lambda: "backup"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup, [u'origin', u'metric', u'multicast_metric', u'is_external_metric', u'administrative_distance'], name, value)


                                        class Paths(Entity):
                                            """
                                            First hops toward the prefix
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\: str
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit>`
                                            
                                            .. attribute:: nnh
                                            
                                            	Next next hops
                                            	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.Nnh>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths, self).__init__()

                                                self.yang_name = "paths"
                                                self.yang_parent_name = "backup"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.Nnh))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.tunnel_interface = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"

                                                self.uloop_explicit = YList(self)
                                                self.nnh = YList(self)
                                                self._segment_path = lambda: "paths"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                        ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                        ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                        ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                        ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                        ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                    ])
                                                    self.repair_element_node_id = None
                                                    self.repair_ipv4_addr = None
                                                    self.repair_ipv6_addr = None
                                                    self.repair_label = None
                                                    self.repair_element_type = None
                                                    self.repair_strict_spf_label = None
                                                    self._segment_path = lambda: "uloop-explicit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class Nnh(Entity):
                                                """
                                                Next next hops
                                                
                                                .. attribute:: link_id_set
                                                
                                                	If link\_id is given
                                                	**type**\: bool
                                                
                                                .. attribute:: ipv4_set
                                                
                                                	If ipv4 address is given
                                                	**type**\: bool
                                                
                                                .. attribute:: link_id
                                                
                                                	link ID of the next next hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	Ipv4 address of the next next hop
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.Nnh, self).__init__()

                                                    self.yang_name = "nnh"
                                                    self.yang_parent_name = "paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                        ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                        ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ])
                                                    self.link_id_set = None
                                                    self.ipv4_set = None
                                                    self.link_id = None
                                                    self.ipv4_address = None
                                                    self._segment_path = lambda: "nnh"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Paths.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                        class UcmpNextHop(Entity):
                                            """
                                            UCMP first hops toward the prefix
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: total_ucmp_distance
                                            
                                            	Distance to the network via this UCMP next hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop, self).__init__()

                                                self.yang_name = "ucmp-next-hop"
                                                self.yang_parent_name = "backup"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('total_ucmp_distance', (YLeaf(YType.uint32, 'total-ucmp-distance'), ['int'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.total_ucmp_distance = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._segment_path = lambda: "ucmp-next-hop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'total_ucmp_distance', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "ucmp-next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                        class MulticastPath(Entity):
                                            """
                                            Multicast intact first hops toward the prefix
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\: str
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit>`
                                            
                                            .. attribute:: nnh
                                            
                                            	Next next hops
                                            	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.Nnh>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath, self).__init__()

                                                self.yang_name = "multicast-path"
                                                self.yang_parent_name = "backup"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.Nnh))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.tunnel_interface = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"

                                                self.uloop_explicit = YList(self)
                                                self.nnh = YList(self)
                                                self._segment_path = lambda: "multicast-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "multicast-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "multicast-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                        ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                        ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                        ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                        ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                        ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                    ])
                                                    self.repair_element_node_id = None
                                                    self.repair_ipv4_addr = None
                                                    self.repair_ipv6_addr = None
                                                    self.repair_label = None
                                                    self.repair_element_type = None
                                                    self.repair_strict_spf_label = None
                                                    self._segment_path = lambda: "uloop-explicit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class Nnh(Entity):
                                                """
                                                Next next hops
                                                
                                                .. attribute:: link_id_set
                                                
                                                	If link\_id is given
                                                	**type**\: bool
                                                
                                                .. attribute:: ipv4_set
                                                
                                                	If ipv4 address is given
                                                	**type**\: bool
                                                
                                                .. attribute:: link_id
                                                
                                                	link ID of the next next hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	Ipv4 address of the next next hop
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.Nnh, self).__init__()

                                                    self.yang_name = "nnh"
                                                    self.yang_parent_name = "multicast-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                        ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                        ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ])
                                                    self.link_id_set = None
                                                    self.ipv4_set = None
                                                    self.link_id = None
                                                    self.ipv4_address = None
                                                    self._segment_path = lambda: "nnh"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastPath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                        class SrtePath(Entity):
                                            """
                                            SR\-TE native first hops toward the prefix
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\: str
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit>`
                                            
                                            .. attribute:: nnh
                                            
                                            	Next next hops
                                            	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.Nnh>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath, self).__init__()

                                                self.yang_name = "srte-path"
                                                self.yang_parent_name = "backup"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.Nnh))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.tunnel_interface = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"

                                                self.uloop_explicit = YList(self)
                                                self.nnh = YList(self)
                                                self._segment_path = lambda: "srte-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "srte-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "srte-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                        ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                        ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                        ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                        ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                        ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                    ])
                                                    self.repair_element_node_id = None
                                                    self.repair_ipv4_addr = None
                                                    self.repair_ipv6_addr = None
                                                    self.repair_label = None
                                                    self.repair_element_type = None
                                                    self.repair_strict_spf_label = None
                                                    self._segment_path = lambda: "uloop-explicit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class Nnh(Entity):
                                                """
                                                Next next hops
                                                
                                                .. attribute:: link_id_set
                                                
                                                	If link\_id is given
                                                	**type**\: bool
                                                
                                                .. attribute:: ipv4_set
                                                
                                                	If ipv4 address is given
                                                	**type**\: bool
                                                
                                                .. attribute:: link_id
                                                
                                                	link ID of the next next hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	Ipv4 address of the next next hop
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.Nnh, self).__init__()

                                                    self.yang_name = "nnh"
                                                    self.yang_parent_name = "srte-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                        ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                        ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ])
                                                    self.link_id_set = None
                                                    self.ipv4_set = None
                                                    self.link_id = None
                                                    self.ipv4_address = None
                                                    self._segment_path = lambda: "nnh"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.SrtePath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                        class ExplicitPath(Entity):
                                            """
                                            SR microloop avoidance paths
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\: str
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit>`
                                            
                                            .. attribute:: nnh
                                            
                                            	Next next hops
                                            	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.Nnh>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath, self).__init__()

                                                self.yang_name = "explicit-path"
                                                self.yang_parent_name = "backup"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.Nnh))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.tunnel_interface = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"

                                                self.uloop_explicit = YList(self)
                                                self.nnh = YList(self)
                                                self._segment_path = lambda: "explicit-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "explicit-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "explicit-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                        ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                        ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                        ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                        ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                        ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                    ])
                                                    self.repair_element_node_id = None
                                                    self.repair_ipv4_addr = None
                                                    self.repair_ipv6_addr = None
                                                    self.repair_label = None
                                                    self.repair_element_type = None
                                                    self.repair_strict_spf_label = None
                                                    self._segment_path = lambda: "uloop-explicit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class Nnh(Entity):
                                                """
                                                Next next hops
                                                
                                                .. attribute:: link_id_set
                                                
                                                	If link\_id is given
                                                	**type**\: bool
                                                
                                                .. attribute:: ipv4_set
                                                
                                                	If ipv4 address is given
                                                	**type**\: bool
                                                
                                                .. attribute:: link_id
                                                
                                                	link ID of the next next hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	Ipv4 address of the next next hop
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.Nnh, self).__init__()

                                                    self.yang_name = "nnh"
                                                    self.yang_parent_name = "explicit-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                        ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                        ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ])
                                                    self.link_id_set = None
                                                    self.ipv4_set = None
                                                    self.link_id = None
                                                    self.ipv4_address = None
                                                    self._segment_path = lambda: "nnh"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.ExplicitPath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                        class Source(Entity):
                                            """
                                            Sources advertising the prefix
                                            
                                            .. attribute:: source_lsp_id
                                            
                                            	ID of the LSP advertising the prefix
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                            
                                            .. attribute:: source_address
                                            
                                            	Source address of the IS advertising the prefix
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: tags
                                            
                                            	Tags associated with the prefix item
                                            	**type**\: list of  		 :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Source.Tags>`
                                            
                                            .. attribute:: nodal_sid
                                            
                                            	Nodal SIDs with the prefix item
                                            	**type**\: list of  		 :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Source.NodalSid>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "backup"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tags", ("tags", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Source.Tags)), ("nodal-sid", ("nodal_sid", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Source.NodalSid))])
                                                self._leafs = OrderedDict([
                                                    ('source_lsp_id', (YLeaf(YType.str, 'source-lsp-id'), ['str'])),
                                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                                ])
                                                self.source_lsp_id = None
                                                self.source_address = None

                                                self.tags = YList(self)
                                                self.nodal_sid = YList(self)
                                                self._segment_path = lambda: "source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Source, [u'source_lsp_id', u'source_address'], name, value)


                                            class Tags(Entity):
                                                """
                                                Tags associated with the prefix item
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Source.Tags, self).__init__()

                                                    self.yang_name = "tags"
                                                    self.yang_parent_name = "source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "tags"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Source.Tags, [u'entry'], name, value)


                                            class NodalSid(Entity):
                                                """
                                                Nodal SIDs with the prefix item
                                                
                                                .. attribute:: sid_value
                                                
                                                	sid value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rflag
                                                
                                                	rflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nflag
                                                
                                                	nflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pflag
                                                
                                                	pflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: eflag
                                                
                                                	eflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: vflag
                                                
                                                	vflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: lflag
                                                
                                                	lflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: algorithm
                                                
                                                	algorithm
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Source.NodalSid, self).__init__()

                                                    self.yang_name = "nodal-sid"
                                                    self.yang_parent_name = "source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('sid_value', (YLeaf(YType.uint32, 'sid-value'), ['int'])),
                                                        ('rflag', (YLeaf(YType.uint8, 'rflag'), ['int'])),
                                                        ('nflag', (YLeaf(YType.uint8, 'nflag'), ['int'])),
                                                        ('pflag', (YLeaf(YType.uint8, 'pflag'), ['int'])),
                                                        ('eflag', (YLeaf(YType.uint8, 'eflag'), ['int'])),
                                                        ('vflag', (YLeaf(YType.uint8, 'vflag'), ['int'])),
                                                        ('lflag', (YLeaf(YType.uint8, 'lflag'), ['int'])),
                                                        ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                                    ])
                                                    self.sid_value = None
                                                    self.rflag = None
                                                    self.nflag = None
                                                    self.pflag = None
                                                    self.eflag = None
                                                    self.vflag = None
                                                    self.lflag = None
                                                    self.algorithm = None
                                                    self._segment_path = lambda: "nodal-sid"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.Source.NodalSid, [u'sid_value', u'rflag', u'nflag', u'pflag', u'eflag', u'vflag', u'lflag', u'algorithm'], name, value)


                                        class MulticastSource(Entity):
                                            """
                                            Multicast\-intact sources advertising the prefix
                                            
                                            .. attribute:: source_lsp_id
                                            
                                            	ID of the LSP advertising the prefix
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                            
                                            .. attribute:: source_address
                                            
                                            	Source address of the IS advertising the prefix
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: tags
                                            
                                            	Tags associated with the prefix item
                                            	**type**\: list of  		 :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastSource.Tags>`
                                            
                                            .. attribute:: nodal_sid
                                            
                                            	Nodal SIDs with the prefix item
                                            	**type**\: list of  		 :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastSource, self).__init__()

                                                self.yang_name = "multicast-source"
                                                self.yang_parent_name = "backup"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tags", ("tags", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastSource.Tags)), ("nodal-sid", ("nodal_sid", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid))])
                                                self._leafs = OrderedDict([
                                                    ('source_lsp_id', (YLeaf(YType.str, 'source-lsp-id'), ['str'])),
                                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                                ])
                                                self.source_lsp_id = None
                                                self.source_address = None

                                                self.tags = YList(self)
                                                self.nodal_sid = YList(self)
                                                self._segment_path = lambda: "multicast-source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastSource, [u'source_lsp_id', u'source_address'], name, value)


                                            class Tags(Entity):
                                                """
                                                Tags associated with the prefix item
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastSource.Tags, self).__init__()

                                                    self.yang_name = "tags"
                                                    self.yang_parent_name = "multicast-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "tags"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastSource.Tags, [u'entry'], name, value)


                                            class NodalSid(Entity):
                                                """
                                                Nodal SIDs with the prefix item
                                                
                                                .. attribute:: sid_value
                                                
                                                	sid value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rflag
                                                
                                                	rflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nflag
                                                
                                                	nflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pflag
                                                
                                                	pflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: eflag
                                                
                                                	eflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: vflag
                                                
                                                	vflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: lflag
                                                
                                                	lflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: algorithm
                                                
                                                	algorithm
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid, self).__init__()

                                                    self.yang_name = "nodal-sid"
                                                    self.yang_parent_name = "multicast-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('sid_value', (YLeaf(YType.uint32, 'sid-value'), ['int'])),
                                                        ('rflag', (YLeaf(YType.uint8, 'rflag'), ['int'])),
                                                        ('nflag', (YLeaf(YType.uint8, 'nflag'), ['int'])),
                                                        ('pflag', (YLeaf(YType.uint8, 'pflag'), ['int'])),
                                                        ('eflag', (YLeaf(YType.uint8, 'eflag'), ['int'])),
                                                        ('vflag', (YLeaf(YType.uint8, 'vflag'), ['int'])),
                                                        ('lflag', (YLeaf(YType.uint8, 'lflag'), ['int'])),
                                                        ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                                    ])
                                                    self.sid_value = None
                                                    self.rflag = None
                                                    self.nflag = None
                                                    self.pflag = None
                                                    self.eflag = None
                                                    self.vflag = None
                                                    self.lflag = None
                                                    self.algorithm = None
                                                    self._segment_path = lambda: "nodal-sid"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid, [u'sid_value', u'rflag', u'nflag', u'pflag', u'eflag', u'vflag', u'lflag', u'algorithm'], name, value)


                            class PerLevelAdvertisingDetail(Entity):
                                """
                                Per level details of how the local system
                                advertises the prefix
                                
                                .. attribute:: summarization_status
                                
                                	Status of summarization for the prefix
                                	**type**\:  :py:class:`SummarizationStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.SummarizationStatus>`
                                
                                .. attribute:: level
                                
                                	Level in which the prefix is advertised
                                	**type**\:  :py:class:`IsisLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevel>`
                                
                                .. attribute:: advertising_origin
                                
                                	The origin of the advertisement
                                	**type**\:  :py:class:`IsisShRouteAdvOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisShRouteAdvOrigin>`
                                
                                .. attribute:: metric
                                
                                	Metric with which the prefix is advertised
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_propagated
                                
                                	Has the prefix been propagated from another level?
                                	**type**\: bool
                                
                                .. attribute:: is_external_metric
                                
                                	Is the metric an external metric?
                                	**type**\: bool
                                
                                .. attribute:: is_external_reachability
                                
                                	Is the prefix external to the IS\-IS domain?
                                	**type**\: bool
                                
                                .. attribute:: is_interarea
                                
                                	Is the up/down bit set?
                                	**type**\: bool
                                
                                .. attribute:: tags
                                
                                	Tags associated with the prefix
                                	**type**\: list of  		 :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.Tags>`
                                
                                .. attribute:: nodal_sid
                                
                                	Nodal SIDs with the prefix item
                                	**type**\: list of  		 :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.NodalSid>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail, self).__init__()

                                    self.yang_name = "per-level-advertising-detail"
                                    self.yang_parent_name = "ipv6-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("summarization-status", ("summarization_status", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.SummarizationStatus)), ("tags", ("tags", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.Tags)), ("nodal-sid", ("nodal_sid", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.NodalSid))])
                                    self._leafs = OrderedDict([
                                        ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisLevel', '')])),
                                        ('advertising_origin', (YLeaf(YType.enumeration, 'advertising-origin'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisShRouteAdvOrigin', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('is_propagated', (YLeaf(YType.boolean, 'is-propagated'), ['bool'])),
                                        ('is_external_metric', (YLeaf(YType.boolean, 'is-external-metric'), ['bool'])),
                                        ('is_external_reachability', (YLeaf(YType.boolean, 'is-external-reachability'), ['bool'])),
                                        ('is_interarea', (YLeaf(YType.boolean, 'is-interarea'), ['bool'])),
                                    ])
                                    self.level = None
                                    self.advertising_origin = None
                                    self.metric = None
                                    self.is_propagated = None
                                    self.is_external_metric = None
                                    self.is_external_reachability = None
                                    self.is_interarea = None

                                    self.summarization_status = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.SummarizationStatus()
                                    self.summarization_status.parent = self
                                    self._children_name_map["summarization_status"] = "summarization-status"

                                    self.tags = YList(self)
                                    self.nodal_sid = YList(self)
                                    self._segment_path = lambda: "per-level-advertising-detail"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail, [u'level', u'advertising_origin', u'metric', u'is_propagated', u'is_external_metric', u'is_external_reachability', u'is_interarea'], name, value)


                                class SummarizationStatus(Entity):
                                    """
                                    Status of summarization for the prefix
                                    
                                    .. attribute:: summary_prefix
                                    
                                    	Summarizing Prefix
                                    	**type**\:  :py:class:`SummaryPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	IsValid
                                    	**type**\:  :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.SummarizationStatus, self).__init__()

                                        self.yang_name = "summarization-status"
                                        self.yang_parent_name = "per-level-advertising-detail"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("summary-prefix", ("summary_prefix", Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', (YLeaf(YType.enumeration, 'is-valid'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisValid', '')])),
                                        ])
                                        self.is_valid = None

                                        self.summary_prefix = Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix()
                                        self.summary_prefix.parent = self
                                        self._children_name_map["summary_prefix"] = "summary-prefix"
                                        self._segment_path = lambda: "summarization-status"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.SummarizationStatus, [u'is_valid'], name, value)


                                    class SummaryPrefix(Entity):
                                        """
                                        Summarizing Prefix
                                        
                                        .. attribute:: prefix
                                        
                                        	prefix
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	prefix length
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix, self).__init__()

                                            self.yang_name = "summary-prefix"
                                            self.yang_parent_name = "summarization-status"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                            ])
                                            self.prefix = None
                                            self.prefix_length = None
                                            self._segment_path = lambda: "summary-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix, [u'prefix', u'prefix_length'], name, value)


                                class Tags(Entity):
                                    """
                                    Tags associated with the prefix
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.Tags, self).__init__()

                                        self.yang_name = "tags"
                                        self.yang_parent_name = "per-level-advertising-detail"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "tags"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.Tags, [u'entry'], name, value)


                                class NodalSid(Entity):
                                    """
                                    Nodal SIDs with the prefix item
                                    
                                    .. attribute:: sid_value
                                    
                                    	sid value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rflag
                                    
                                    	rflag
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: nflag
                                    
                                    	nflag
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: pflag
                                    
                                    	pflag
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: eflag
                                    
                                    	eflag
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vflag
                                    
                                    	vflag
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: lflag
                                    
                                    	lflag
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: algorithm
                                    
                                    	algorithm
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.NodalSid, self).__init__()

                                        self.yang_name = "nodal-sid"
                                        self.yang_parent_name = "per-level-advertising-detail"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('sid_value', (YLeaf(YType.uint32, 'sid-value'), ['int'])),
                                            ('rflag', (YLeaf(YType.uint8, 'rflag'), ['int'])),
                                            ('nflag', (YLeaf(YType.uint8, 'nflag'), ['int'])),
                                            ('pflag', (YLeaf(YType.uint8, 'pflag'), ['int'])),
                                            ('eflag', (YLeaf(YType.uint8, 'eflag'), ['int'])),
                                            ('vflag', (YLeaf(YType.uint8, 'vflag'), ['int'])),
                                            ('lflag', (YLeaf(YType.uint8, 'lflag'), ['int'])),
                                            ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                        ])
                                        self.sid_value = None
                                        self.rflag = None
                                        self.nflag = None
                                        self.pflag = None
                                        self.eflag = None
                                        self.vflag = None
                                        self.lflag = None
                                        self.algorithm = None
                                        self._segment_path = lambda: "nodal-sid"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6Routes.Ipv6Route.PerLevelAdvertisingDetail.NodalSid, [u'sid_value', u'rflag', u'nflag', u'pflag', u'eflag', u'vflag', u'lflag', u'algorithm'], name, value)


                    class Ipv6frrBackups(Entity):
                        """
                        IPv6 FRR table
                        
                        .. attribute:: ipv6frr_backup
                        
                        	FRR backup for an IPv6 network
                        	**type**\: list of  		 :py:class:`Ipv6frrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups, self).__init__()

                            self.yang_name = "ipv6frr-backups"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv6frr-backup", ("ipv6frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup))])
                            self._leafs = OrderedDict()

                            self.ipv6frr_backup = YList(self)
                            self._segment_path = lambda: "ipv6frr-backups"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups, [], name, value)


                        class Ipv6frrBackup(Entity):
                            """
                            FRR backup for an IPv6 network
                            
                            .. attribute:: prefix
                            
                            	Prefix
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length
                            
                            	Prefix Length
                            	**type**\: int
                            
                            	**range:** 0..128
                            
                            .. attribute:: connected_status
                            
                            	Status of IS\-IS directly connected routes to the prefix
                            	**type**\:  :py:class:`ConnectedStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.ConnectedStatus>`
                            
                            .. attribute:: redistributed_status
                            
                            	Status of other protocols' routes redistributed into IS\-IS
                            	**type**\:  :py:class:`RedistributedStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.RedistributedStatus>`
                            
                            .. attribute:: native_status
                            
                            	Status of native IS\-IS routes to the prefix
                            	**type**\:  :py:class:`NativeStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus>`
                            
                            .. attribute:: per_level_advertising_detail
                            
                            	Per level details of how the local system advertises the prefix
                            	**type**\: list of  		 :py:class:`PerLevelAdvertisingDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.PerLevelAdvertisingDetail>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup, self).__init__()

                                self.yang_name = "ipv6frr-backup"
                                self.yang_parent_name = "ipv6frr-backups"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("connected-status", ("connected_status", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.ConnectedStatus)), ("redistributed-status", ("redistributed_status", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.RedistributedStatus)), ("native-status", ("native_status", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus)), ("per-level-advertising-detail", ("per_level_advertising_detail", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.PerLevelAdvertisingDetail))])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                    ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                ])
                                self.prefix = None
                                self.prefix_length = None

                                self.connected_status = Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.ConnectedStatus()
                                self.connected_status.parent = self
                                self._children_name_map["connected_status"] = "connected-status"

                                self.redistributed_status = Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.RedistributedStatus()
                                self.redistributed_status.parent = self
                                self._children_name_map["redistributed_status"] = "redistributed-status"

                                self.native_status = Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus()
                                self.native_status.parent = self
                                self._children_name_map["native_status"] = "native-status"

                                self.per_level_advertising_detail = YList(self)
                                self._segment_path = lambda: "ipv6frr-backup"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup, ['prefix', 'prefix_length'], name, value)


                            class ConnectedStatus(Entity):
                                """
                                Status of IS\-IS directly connected routes to the
                                prefix
                                
                                .. attribute:: connected_details
                                
                                	Details of the directly connected prefix
                                	**type**\:  :py:class:`ConnectedDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.ConnectedStatus.ConnectedDetails>`
                                
                                .. attribute:: is_valid
                                
                                	IsValid
                                	**type**\:  :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.ConnectedStatus, self).__init__()

                                    self.yang_name = "connected-status"
                                    self.yang_parent_name = "ipv6frr-backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("connected-details", ("connected_details", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.ConnectedStatus.ConnectedDetails))])
                                    self._leafs = OrderedDict([
                                        ('is_valid', (YLeaf(YType.enumeration, 'is-valid'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisValid', '')])),
                                    ])
                                    self.is_valid = None

                                    self.connected_details = Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.ConnectedStatus.ConnectedDetails()
                                    self.connected_details.parent = self
                                    self._children_name_map["connected_details"] = "connected-details"
                                    self._segment_path = lambda: "connected-status"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.ConnectedStatus, [u'is_valid'], name, value)


                                class ConnectedDetails(Entity):
                                    """
                                    Details of the directly connected prefix
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.ConnectedStatus.ConnectedDetails.Interface>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.ConnectedStatus.ConnectedDetails, self).__init__()

                                        self.yang_name = "connected-details"
                                        self.yang_parent_name = "connected-status"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface", ("interface", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.ConnectedStatus.ConnectedDetails.Interface))])
                                        self._leafs = OrderedDict()

                                        self.interface = YList(self)
                                        self._segment_path = lambda: "connected-details"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.ConnectedStatus.ConnectedDetails, [], name, value)


                                    class Interface(Entity):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.ConnectedStatus.ConnectedDetails.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "connected-details"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "interface"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.ConnectedStatus.ConnectedDetails.Interface, [u'entry'], name, value)


                            class RedistributedStatus(Entity):
                                """
                                Status of other protocols' routes redistributed
                                into IS\-IS
                                
                                .. attribute:: redistribution_details
                                
                                	Per level details of the redistributed route
                                	**type**\:  :py:class:`RedistributionDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.RedistributedStatus.RedistributionDetails>`
                                
                                .. attribute:: is_valid
                                
                                	IsValid
                                	**type**\:  :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.RedistributedStatus, self).__init__()

                                    self.yang_name = "redistributed-status"
                                    self.yang_parent_name = "ipv6frr-backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("redistribution-details", ("redistribution_details", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.RedistributedStatus.RedistributionDetails))])
                                    self._leafs = OrderedDict([
                                        ('is_valid', (YLeaf(YType.enumeration, 'is-valid'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisValid', '')])),
                                    ])
                                    self.is_valid = None

                                    self.redistribution_details = Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.RedistributedStatus.RedistributionDetails()
                                    self.redistribution_details.parent = self
                                    self._children_name_map["redistribution_details"] = "redistribution-details"
                                    self._segment_path = lambda: "redistributed-status"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.RedistributedStatus, [u'is_valid'], name, value)


                                class RedistributionDetails(Entity):
                                    """
                                    Per level details of the redistributed route
                                    
                                    .. attribute:: isis_sh_route_redist_detail
                                    
                                    	isis sh route redist detail
                                    	**type**\: list of  		 :py:class:`IsisShRouteRedistDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.RedistributedStatus.RedistributionDetails, self).__init__()

                                        self.yang_name = "redistribution-details"
                                        self.yang_parent_name = "redistributed-status"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("isis-sh-route-redist-detail", ("isis_sh_route_redist_detail", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail))])
                                        self._leafs = OrderedDict()

                                        self.isis_sh_route_redist_detail = YList(self)
                                        self._segment_path = lambda: "redistribution-details"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.RedistributedStatus.RedistributionDetails, [], name, value)


                                    class IsisShRouteRedistDetail(Entity):
                                        """
                                        isis sh route redist detail
                                        
                                        .. attribute:: owner
                                        
                                        	Protocol redistributing the route
                                        	**type**\:  :py:class:`Owner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner>`
                                        
                                        .. attribute:: level
                                        
                                        	Level into which the route is redistributed
                                        	**type**\:  :py:class:`IsisLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevel>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail, self).__init__()

                                            self.yang_name = "isis-sh-route-redist-detail"
                                            self.yang_parent_name = "redistribution-details"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("owner", ("owner", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner))])
                                            self._leafs = OrderedDict([
                                                ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisLevel', '')])),
                                            ])
                                            self.level = None

                                            self.owner = Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner()
                                            self.owner.parent = self
                                            self._children_name_map["owner"] = "owner"
                                            self._segment_path = lambda: "isis-sh-route-redist-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail, [u'level'], name, value)


                                        class Owner(Entity):
                                            """
                                            Protocol redistributing the route
                                            
                                            .. attribute:: protocol
                                            
                                            	Protocol
                                            	**type**\:  :py:class:`IsisRedistProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisRedistProto>`
                                            
                                            .. attribute:: isis_instance_id
                                            
                                            	IS\-IS instance identifier
                                            	**type**\: str
                                            
                                            .. attribute:: ospf_process_id
                                            
                                            	OSPF process identifier
                                            	**type**\: str
                                            
                                            .. attribute:: ospfv3_process_id
                                            
                                            	OSPFv3 process identifier
                                            	**type**\: str
                                            
                                            .. attribute:: bgp_as_number
                                            
                                            	BGP Autonomous System number
                                            	**type**\: str
                                            
                                            .. attribute:: eigrp_as_number
                                            
                                            	EIGRP Autonomous System number
                                            	**type**\: str
                                            
                                            .. attribute:: application_name
                                            
                                            	Application Name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner, self).__init__()

                                                self.yang_name = "owner"
                                                self.yang_parent_name = "isis-sh-route-redist-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisRedistProto', '')])),
                                                    ('isis_instance_id', (YLeaf(YType.str, 'isis-instance-id'), ['str'])),
                                                    ('ospf_process_id', (YLeaf(YType.str, 'ospf-process-id'), ['str'])),
                                                    ('ospfv3_process_id', (YLeaf(YType.str, 'ospfv3-process-id'), ['str'])),
                                                    ('bgp_as_number', (YLeaf(YType.str, 'bgp-as-number'), ['str'])),
                                                    ('eigrp_as_number', (YLeaf(YType.str, 'eigrp-as-number'), ['str'])),
                                                    ('application_name', (YLeaf(YType.str, 'application-name'), ['str'])),
                                                ])
                                                self.protocol = None
                                                self.isis_instance_id = None
                                                self.ospf_process_id = None
                                                self.ospfv3_process_id = None
                                                self.bgp_as_number = None
                                                self.eigrp_as_number = None
                                                self.application_name = None
                                                self._segment_path = lambda: "owner"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner, [u'protocol', u'isis_instance_id', u'ospf_process_id', u'ospfv3_process_id', u'bgp_as_number', u'eigrp_as_number', u'application_name'], name, value)


                            class NativeStatus(Entity):
                                """
                                Status of native IS\-IS routes to the prefix
                                
                                .. attribute:: native_details
                                
                                	Details of the native route
                                	**type**\:  :py:class:`NativeDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails>`
                                
                                .. attribute:: is_valid
                                
                                	IsValid
                                	**type**\:  :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus, self).__init__()

                                    self.yang_name = "native-status"
                                    self.yang_parent_name = "ipv6frr-backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("native-details", ("native_details", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails))])
                                    self._leafs = OrderedDict([
                                        ('is_valid', (YLeaf(YType.enumeration, 'is-valid'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisValid', '')])),
                                    ])
                                    self.is_valid = None

                                    self.native_details = Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails()
                                    self.native_details.parent = self
                                    self._children_name_map["native_details"] = "native-details"
                                    self._segment_path = lambda: "native-status"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus, [u'is_valid'], name, value)


                                class NativeDetails(Entity):
                                    """
                                    Details of the native route
                                    
                                    .. attribute:: primary
                                    
                                    	Primary paths to prefix
                                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary>`
                                    
                                    .. attribute:: priority
                                    
                                    	Relative importance of the prefix
                                    	**type**\:  :py:class:`IsisPrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisPrefixPriority>`
                                    
                                    .. attribute:: backup
                                    
                                    	Backup paths to prefix
                                    	**type**\: list of  		 :py:class:`Backup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails, self).__init__()

                                        self.yang_name = "native-details"
                                        self.yang_parent_name = "native-status"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("primary", ("primary", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary)), ("backup", ("backup", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup))])
                                        self._leafs = OrderedDict([
                                            ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisPrefixPriority', '')])),
                                        ])
                                        self.priority = None

                                        self.primary = Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary()
                                        self.primary.parent = self
                                        self._children_name_map["primary"] = "primary"

                                        self.backup = YList(self)
                                        self._segment_path = lambda: "native-details"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails, [u'priority'], name, value)


                                    class Primary(Entity):
                                        """
                                        Primary paths to prefix
                                        
                                        .. attribute:: origin
                                        
                                        	Origin of route
                                        	**type**\:  :py:class:`IsisPrefixOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisPrefixOrigin>`
                                        
                                        .. attribute:: metric
                                        
                                        	Distance to network
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multicast_metric
                                        
                                        	Multicast\-intact distance to network
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_external_metric
                                        
                                        	Is the metric an external metric?
                                        	**type**\: bool
                                        
                                        .. attribute:: administrative_distance
                                        
                                        	Administrative Distance
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: paths
                                        
                                        	First hops toward the prefix
                                        	**type**\: list of  		 :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Paths>`
                                        
                                        .. attribute:: ucmp_next_hop
                                        
                                        	UCMP first hops toward the prefix
                                        	**type**\: list of  		 :py:class:`UcmpNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop>`
                                        
                                        .. attribute:: multicast_path
                                        
                                        	Multicast intact first hops toward the prefix
                                        	**type**\: list of  		 :py:class:`MulticastPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath>`
                                        
                                        .. attribute:: srte_path
                                        
                                        	SR\-TE native first hops toward the prefix
                                        	**type**\: list of  		 :py:class:`SrtePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.SrtePath>`
                                        
                                        .. attribute:: explicit_path
                                        
                                        	SR microloop avoidance paths
                                        	**type**\: list of  		 :py:class:`ExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath>`
                                        
                                        .. attribute:: source
                                        
                                        	Sources advertising the prefix
                                        	**type**\: list of  		 :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Source>`
                                        
                                        .. attribute:: multicast_source
                                        
                                        	Multicast\-intact sources advertising the prefix
                                        	**type**\: list of  		 :py:class:`MulticastSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastSource>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary, self).__init__()

                                            self.yang_name = "primary"
                                            self.yang_parent_name = "native-details"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("paths", ("paths", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Paths)), ("ucmp-next-hop", ("ucmp_next_hop", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop)), ("multicast-path", ("multicast_path", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath)), ("srte-path", ("srte_path", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.SrtePath)), ("explicit-path", ("explicit_path", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath)), ("source", ("source", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Source)), ("multicast-source", ("multicast_source", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastSource))])
                                            self._leafs = OrderedDict([
                                                ('origin', (YLeaf(YType.enumeration, 'origin'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisPrefixOrigin', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('multicast_metric', (YLeaf(YType.uint32, 'multicast-metric'), ['int'])),
                                                ('is_external_metric', (YLeaf(YType.boolean, 'is-external-metric'), ['bool'])),
                                                ('administrative_distance', (YLeaf(YType.uint16, 'administrative-distance'), ['int'])),
                                            ])
                                            self.origin = None
                                            self.metric = None
                                            self.multicast_metric = None
                                            self.is_external_metric = None
                                            self.administrative_distance = None

                                            self.paths = YList(self)
                                            self.ucmp_next_hop = YList(self)
                                            self.multicast_path = YList(self)
                                            self.srte_path = YList(self)
                                            self.explicit_path = YList(self)
                                            self.source = YList(self)
                                            self.multicast_source = YList(self)
                                            self._segment_path = lambda: "primary"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary, [u'origin', u'metric', u'multicast_metric', u'is_external_metric', u'administrative_distance'], name, value)


                                        class Paths(Entity):
                                            """
                                            First hops toward the prefix
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\: str
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit>`
                                            
                                            .. attribute:: nnh
                                            
                                            	Next next hops
                                            	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Paths.Nnh>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Paths, self).__init__()

                                                self.yang_name = "paths"
                                                self.yang_parent_name = "primary"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Paths.Nnh))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.tunnel_interface = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"

                                                self.uloop_explicit = YList(self)
                                                self.nnh = YList(self)
                                                self._segment_path = lambda: "paths"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Paths, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                        ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                        ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                        ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                        ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                        ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                    ])
                                                    self.repair_element_node_id = None
                                                    self.repair_ipv4_addr = None
                                                    self.repair_ipv6_addr = None
                                                    self.repair_label = None
                                                    self.repair_element_type = None
                                                    self.repair_strict_spf_label = None
                                                    self._segment_path = lambda: "uloop-explicit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class Nnh(Entity):
                                                """
                                                Next next hops
                                                
                                                .. attribute:: link_id_set
                                                
                                                	If link\_id is given
                                                	**type**\: bool
                                                
                                                .. attribute:: ipv4_set
                                                
                                                	If ipv4 address is given
                                                	**type**\: bool
                                                
                                                .. attribute:: link_id
                                                
                                                	link ID of the next next hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	Ipv4 address of the next next hop
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Paths.Nnh, self).__init__()

                                                    self.yang_name = "nnh"
                                                    self.yang_parent_name = "paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                        ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                        ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ])
                                                    self.link_id_set = None
                                                    self.ipv4_set = None
                                                    self.link_id = None
                                                    self.ipv4_address = None
                                                    self._segment_path = lambda: "nnh"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Paths.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                        class UcmpNextHop(Entity):
                                            """
                                            UCMP first hops toward the prefix
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: total_ucmp_distance
                                            
                                            	Distance to the network via this UCMP next hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop, self).__init__()

                                                self.yang_name = "ucmp-next-hop"
                                                self.yang_parent_name = "primary"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('total_ucmp_distance', (YLeaf(YType.uint32, 'total-ucmp-distance'), ['int'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.total_ucmp_distance = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._segment_path = lambda: "ucmp-next-hop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'total_ucmp_distance', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "ucmp-next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                        class MulticastPath(Entity):
                                            """
                                            Multicast intact first hops toward the prefix
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\: str
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit>`
                                            
                                            .. attribute:: nnh
                                            
                                            	Next next hops
                                            	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.Nnh>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath, self).__init__()

                                                self.yang_name = "multicast-path"
                                                self.yang_parent_name = "primary"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.Nnh))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.tunnel_interface = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"

                                                self.uloop_explicit = YList(self)
                                                self.nnh = YList(self)
                                                self._segment_path = lambda: "multicast-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "multicast-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "multicast-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                        ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                        ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                        ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                        ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                        ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                    ])
                                                    self.repair_element_node_id = None
                                                    self.repair_ipv4_addr = None
                                                    self.repair_ipv6_addr = None
                                                    self.repair_label = None
                                                    self.repair_element_type = None
                                                    self.repair_strict_spf_label = None
                                                    self._segment_path = lambda: "uloop-explicit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class Nnh(Entity):
                                                """
                                                Next next hops
                                                
                                                .. attribute:: link_id_set
                                                
                                                	If link\_id is given
                                                	**type**\: bool
                                                
                                                .. attribute:: ipv4_set
                                                
                                                	If ipv4 address is given
                                                	**type**\: bool
                                                
                                                .. attribute:: link_id
                                                
                                                	link ID of the next next hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	Ipv4 address of the next next hop
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.Nnh, self).__init__()

                                                    self.yang_name = "nnh"
                                                    self.yang_parent_name = "multicast-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                        ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                        ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ])
                                                    self.link_id_set = None
                                                    self.ipv4_set = None
                                                    self.link_id = None
                                                    self.ipv4_address = None
                                                    self._segment_path = lambda: "nnh"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                        class SrtePath(Entity):
                                            """
                                            SR\-TE native first hops toward the prefix
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\: str
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit>`
                                            
                                            .. attribute:: nnh
                                            
                                            	Next next hops
                                            	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.Nnh>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.SrtePath, self).__init__()

                                                self.yang_name = "srte-path"
                                                self.yang_parent_name = "primary"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.Nnh))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.tunnel_interface = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"

                                                self.uloop_explicit = YList(self)
                                                self.nnh = YList(self)
                                                self._segment_path = lambda: "srte-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.SrtePath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "srte-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "srte-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                        ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                        ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                        ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                        ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                        ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                    ])
                                                    self.repair_element_node_id = None
                                                    self.repair_ipv4_addr = None
                                                    self.repair_ipv6_addr = None
                                                    self.repair_label = None
                                                    self.repair_element_type = None
                                                    self.repair_strict_spf_label = None
                                                    self._segment_path = lambda: "uloop-explicit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class Nnh(Entity):
                                                """
                                                Next next hops
                                                
                                                .. attribute:: link_id_set
                                                
                                                	If link\_id is given
                                                	**type**\: bool
                                                
                                                .. attribute:: ipv4_set
                                                
                                                	If ipv4 address is given
                                                	**type**\: bool
                                                
                                                .. attribute:: link_id
                                                
                                                	link ID of the next next hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	Ipv4 address of the next next hop
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.Nnh, self).__init__()

                                                    self.yang_name = "nnh"
                                                    self.yang_parent_name = "srte-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                        ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                        ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ])
                                                    self.link_id_set = None
                                                    self.ipv4_set = None
                                                    self.link_id = None
                                                    self.ipv4_address = None
                                                    self._segment_path = lambda: "nnh"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                        class ExplicitPath(Entity):
                                            """
                                            SR microloop avoidance paths
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\: str
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit>`
                                            
                                            .. attribute:: nnh
                                            
                                            	Next next hops
                                            	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.Nnh>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath, self).__init__()

                                                self.yang_name = "explicit-path"
                                                self.yang_parent_name = "primary"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.Nnh))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.tunnel_interface = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"

                                                self.uloop_explicit = YList(self)
                                                self.nnh = YList(self)
                                                self._segment_path = lambda: "explicit-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "explicit-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "explicit-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                        ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                        ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                        ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                        ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                        ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                    ])
                                                    self.repair_element_node_id = None
                                                    self.repair_ipv4_addr = None
                                                    self.repair_ipv6_addr = None
                                                    self.repair_label = None
                                                    self.repair_element_type = None
                                                    self.repair_strict_spf_label = None
                                                    self._segment_path = lambda: "uloop-explicit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class Nnh(Entity):
                                                """
                                                Next next hops
                                                
                                                .. attribute:: link_id_set
                                                
                                                	If link\_id is given
                                                	**type**\: bool
                                                
                                                .. attribute:: ipv4_set
                                                
                                                	If ipv4 address is given
                                                	**type**\: bool
                                                
                                                .. attribute:: link_id
                                                
                                                	link ID of the next next hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	Ipv4 address of the next next hop
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.Nnh, self).__init__()

                                                    self.yang_name = "nnh"
                                                    self.yang_parent_name = "explicit-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                        ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                        ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ])
                                                    self.link_id_set = None
                                                    self.ipv4_set = None
                                                    self.link_id = None
                                                    self.ipv4_address = None
                                                    self._segment_path = lambda: "nnh"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                        class Source(Entity):
                                            """
                                            Sources advertising the prefix
                                            
                                            .. attribute:: source_lsp_id
                                            
                                            	ID of the LSP advertising the prefix
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                            
                                            .. attribute:: source_address
                                            
                                            	Source address of the IS advertising the prefix
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: tags
                                            
                                            	Tags associated with the prefix item
                                            	**type**\: list of  		 :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Source.Tags>`
                                            
                                            .. attribute:: nodal_sid
                                            
                                            	Nodal SIDs with the prefix item
                                            	**type**\: list of  		 :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Source.NodalSid>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "primary"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tags", ("tags", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Source.Tags)), ("nodal-sid", ("nodal_sid", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Source.NodalSid))])
                                                self._leafs = OrderedDict([
                                                    ('source_lsp_id', (YLeaf(YType.str, 'source-lsp-id'), ['str'])),
                                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                                ])
                                                self.source_lsp_id = None
                                                self.source_address = None

                                                self.tags = YList(self)
                                                self.nodal_sid = YList(self)
                                                self._segment_path = lambda: "source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Source, [u'source_lsp_id', u'source_address'], name, value)


                                            class Tags(Entity):
                                                """
                                                Tags associated with the prefix item
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Source.Tags, self).__init__()

                                                    self.yang_name = "tags"
                                                    self.yang_parent_name = "source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "tags"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Source.Tags, [u'entry'], name, value)


                                            class NodalSid(Entity):
                                                """
                                                Nodal SIDs with the prefix item
                                                
                                                .. attribute:: sid_value
                                                
                                                	sid value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rflag
                                                
                                                	rflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nflag
                                                
                                                	nflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pflag
                                                
                                                	pflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: eflag
                                                
                                                	eflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: vflag
                                                
                                                	vflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: lflag
                                                
                                                	lflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: algorithm
                                                
                                                	algorithm
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Source.NodalSid, self).__init__()

                                                    self.yang_name = "nodal-sid"
                                                    self.yang_parent_name = "source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('sid_value', (YLeaf(YType.uint32, 'sid-value'), ['int'])),
                                                        ('rflag', (YLeaf(YType.uint8, 'rflag'), ['int'])),
                                                        ('nflag', (YLeaf(YType.uint8, 'nflag'), ['int'])),
                                                        ('pflag', (YLeaf(YType.uint8, 'pflag'), ['int'])),
                                                        ('eflag', (YLeaf(YType.uint8, 'eflag'), ['int'])),
                                                        ('vflag', (YLeaf(YType.uint8, 'vflag'), ['int'])),
                                                        ('lflag', (YLeaf(YType.uint8, 'lflag'), ['int'])),
                                                        ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                                    ])
                                                    self.sid_value = None
                                                    self.rflag = None
                                                    self.nflag = None
                                                    self.pflag = None
                                                    self.eflag = None
                                                    self.vflag = None
                                                    self.lflag = None
                                                    self.algorithm = None
                                                    self._segment_path = lambda: "nodal-sid"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.Source.NodalSid, [u'sid_value', u'rflag', u'nflag', u'pflag', u'eflag', u'vflag', u'lflag', u'algorithm'], name, value)


                                        class MulticastSource(Entity):
                                            """
                                            Multicast\-intact sources advertising the prefix
                                            
                                            .. attribute:: source_lsp_id
                                            
                                            	ID of the LSP advertising the prefix
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                            
                                            .. attribute:: source_address
                                            
                                            	Source address of the IS advertising the prefix
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: tags
                                            
                                            	Tags associated with the prefix item
                                            	**type**\: list of  		 :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastSource.Tags>`
                                            
                                            .. attribute:: nodal_sid
                                            
                                            	Nodal SIDs with the prefix item
                                            	**type**\: list of  		 :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastSource, self).__init__()

                                                self.yang_name = "multicast-source"
                                                self.yang_parent_name = "primary"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tags", ("tags", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastSource.Tags)), ("nodal-sid", ("nodal_sid", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid))])
                                                self._leafs = OrderedDict([
                                                    ('source_lsp_id', (YLeaf(YType.str, 'source-lsp-id'), ['str'])),
                                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                                ])
                                                self.source_lsp_id = None
                                                self.source_address = None

                                                self.tags = YList(self)
                                                self.nodal_sid = YList(self)
                                                self._segment_path = lambda: "multicast-source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastSource, [u'source_lsp_id', u'source_address'], name, value)


                                            class Tags(Entity):
                                                """
                                                Tags associated with the prefix item
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastSource.Tags, self).__init__()

                                                    self.yang_name = "tags"
                                                    self.yang_parent_name = "multicast-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "tags"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastSource.Tags, [u'entry'], name, value)


                                            class NodalSid(Entity):
                                                """
                                                Nodal SIDs with the prefix item
                                                
                                                .. attribute:: sid_value
                                                
                                                	sid value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rflag
                                                
                                                	rflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nflag
                                                
                                                	nflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pflag
                                                
                                                	pflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: eflag
                                                
                                                	eflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: vflag
                                                
                                                	vflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: lflag
                                                
                                                	lflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: algorithm
                                                
                                                	algorithm
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid, self).__init__()

                                                    self.yang_name = "nodal-sid"
                                                    self.yang_parent_name = "multicast-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('sid_value', (YLeaf(YType.uint32, 'sid-value'), ['int'])),
                                                        ('rflag', (YLeaf(YType.uint8, 'rflag'), ['int'])),
                                                        ('nflag', (YLeaf(YType.uint8, 'nflag'), ['int'])),
                                                        ('pflag', (YLeaf(YType.uint8, 'pflag'), ['int'])),
                                                        ('eflag', (YLeaf(YType.uint8, 'eflag'), ['int'])),
                                                        ('vflag', (YLeaf(YType.uint8, 'vflag'), ['int'])),
                                                        ('lflag', (YLeaf(YType.uint8, 'lflag'), ['int'])),
                                                        ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                                    ])
                                                    self.sid_value = None
                                                    self.rflag = None
                                                    self.nflag = None
                                                    self.pflag = None
                                                    self.eflag = None
                                                    self.vflag = None
                                                    self.lflag = None
                                                    self.algorithm = None
                                                    self._segment_path = lambda: "nodal-sid"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid, [u'sid_value', u'rflag', u'nflag', u'pflag', u'eflag', u'vflag', u'lflag', u'algorithm'], name, value)


                                    class Backup(Entity):
                                        """
                                        Backup paths to prefix
                                        
                                        .. attribute:: origin
                                        
                                        	Origin of route
                                        	**type**\:  :py:class:`IsisPrefixOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisPrefixOrigin>`
                                        
                                        .. attribute:: metric
                                        
                                        	Distance to network
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multicast_metric
                                        
                                        	Multicast\-intact distance to network
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_external_metric
                                        
                                        	Is the metric an external metric?
                                        	**type**\: bool
                                        
                                        .. attribute:: administrative_distance
                                        
                                        	Administrative Distance
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: paths
                                        
                                        	First hops toward the prefix
                                        	**type**\: list of  		 :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Paths>`
                                        
                                        .. attribute:: ucmp_next_hop
                                        
                                        	UCMP first hops toward the prefix
                                        	**type**\: list of  		 :py:class:`UcmpNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop>`
                                        
                                        .. attribute:: multicast_path
                                        
                                        	Multicast intact first hops toward the prefix
                                        	**type**\: list of  		 :py:class:`MulticastPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath>`
                                        
                                        .. attribute:: srte_path
                                        
                                        	SR\-TE native first hops toward the prefix
                                        	**type**\: list of  		 :py:class:`SrtePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.SrtePath>`
                                        
                                        .. attribute:: explicit_path
                                        
                                        	SR microloop avoidance paths
                                        	**type**\: list of  		 :py:class:`ExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath>`
                                        
                                        .. attribute:: source
                                        
                                        	Sources advertising the prefix
                                        	**type**\: list of  		 :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Source>`
                                        
                                        .. attribute:: multicast_source
                                        
                                        	Multicast\-intact sources advertising the prefix
                                        	**type**\: list of  		 :py:class:`MulticastSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastSource>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup, self).__init__()

                                            self.yang_name = "backup"
                                            self.yang_parent_name = "native-details"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("paths", ("paths", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Paths)), ("ucmp-next-hop", ("ucmp_next_hop", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop)), ("multicast-path", ("multicast_path", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath)), ("srte-path", ("srte_path", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.SrtePath)), ("explicit-path", ("explicit_path", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath)), ("source", ("source", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Source)), ("multicast-source", ("multicast_source", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastSource))])
                                            self._leafs = OrderedDict([
                                                ('origin', (YLeaf(YType.enumeration, 'origin'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisPrefixOrigin', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('multicast_metric', (YLeaf(YType.uint32, 'multicast-metric'), ['int'])),
                                                ('is_external_metric', (YLeaf(YType.boolean, 'is-external-metric'), ['bool'])),
                                                ('administrative_distance', (YLeaf(YType.uint16, 'administrative-distance'), ['int'])),
                                            ])
                                            self.origin = None
                                            self.metric = None
                                            self.multicast_metric = None
                                            self.is_external_metric = None
                                            self.administrative_distance = None

                                            self.paths = YList(self)
                                            self.ucmp_next_hop = YList(self)
                                            self.multicast_path = YList(self)
                                            self.srte_path = YList(self)
                                            self.explicit_path = YList(self)
                                            self.source = YList(self)
                                            self.multicast_source = YList(self)
                                            self._segment_path = lambda: "backup"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup, [u'origin', u'metric', u'multicast_metric', u'is_external_metric', u'administrative_distance'], name, value)


                                        class Paths(Entity):
                                            """
                                            First hops toward the prefix
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\: str
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit>`
                                            
                                            .. attribute:: nnh
                                            
                                            	Next next hops
                                            	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Paths.Nnh>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Paths, self).__init__()

                                                self.yang_name = "paths"
                                                self.yang_parent_name = "backup"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Paths.Nnh))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.tunnel_interface = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"

                                                self.uloop_explicit = YList(self)
                                                self.nnh = YList(self)
                                                self._segment_path = lambda: "paths"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Paths, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                        ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                        ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                        ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                        ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                        ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                    ])
                                                    self.repair_element_node_id = None
                                                    self.repair_ipv4_addr = None
                                                    self.repair_ipv6_addr = None
                                                    self.repair_label = None
                                                    self.repair_element_type = None
                                                    self.repair_strict_spf_label = None
                                                    self._segment_path = lambda: "uloop-explicit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class Nnh(Entity):
                                                """
                                                Next next hops
                                                
                                                .. attribute:: link_id_set
                                                
                                                	If link\_id is given
                                                	**type**\: bool
                                                
                                                .. attribute:: ipv4_set
                                                
                                                	If ipv4 address is given
                                                	**type**\: bool
                                                
                                                .. attribute:: link_id
                                                
                                                	link ID of the next next hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	Ipv4 address of the next next hop
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Paths.Nnh, self).__init__()

                                                    self.yang_name = "nnh"
                                                    self.yang_parent_name = "paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                        ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                        ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ])
                                                    self.link_id_set = None
                                                    self.ipv4_set = None
                                                    self.link_id = None
                                                    self.ipv4_address = None
                                                    self._segment_path = lambda: "nnh"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Paths.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                        class UcmpNextHop(Entity):
                                            """
                                            UCMP first hops toward the prefix
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: total_ucmp_distance
                                            
                                            	Distance to the network via this UCMP next hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop, self).__init__()

                                                self.yang_name = "ucmp-next-hop"
                                                self.yang_parent_name = "backup"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('total_ucmp_distance', (YLeaf(YType.uint32, 'total-ucmp-distance'), ['int'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.total_ucmp_distance = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._segment_path = lambda: "ucmp-next-hop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'total_ucmp_distance', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "ucmp-next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                        class MulticastPath(Entity):
                                            """
                                            Multicast intact first hops toward the prefix
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\: str
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit>`
                                            
                                            .. attribute:: nnh
                                            
                                            	Next next hops
                                            	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.Nnh>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath, self).__init__()

                                                self.yang_name = "multicast-path"
                                                self.yang_parent_name = "backup"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.Nnh))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.tunnel_interface = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"

                                                self.uloop_explicit = YList(self)
                                                self.nnh = YList(self)
                                                self._segment_path = lambda: "multicast-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "multicast-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "multicast-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                        ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                        ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                        ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                        ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                        ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                    ])
                                                    self.repair_element_node_id = None
                                                    self.repair_ipv4_addr = None
                                                    self.repair_ipv6_addr = None
                                                    self.repair_label = None
                                                    self.repair_element_type = None
                                                    self.repair_strict_spf_label = None
                                                    self._segment_path = lambda: "uloop-explicit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class Nnh(Entity):
                                                """
                                                Next next hops
                                                
                                                .. attribute:: link_id_set
                                                
                                                	If link\_id is given
                                                	**type**\: bool
                                                
                                                .. attribute:: ipv4_set
                                                
                                                	If ipv4 address is given
                                                	**type**\: bool
                                                
                                                .. attribute:: link_id
                                                
                                                	link ID of the next next hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	Ipv4 address of the next next hop
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.Nnh, self).__init__()

                                                    self.yang_name = "nnh"
                                                    self.yang_parent_name = "multicast-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                        ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                        ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ])
                                                    self.link_id_set = None
                                                    self.ipv4_set = None
                                                    self.link_id = None
                                                    self.ipv4_address = None
                                                    self._segment_path = lambda: "nnh"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                        class SrtePath(Entity):
                                            """
                                            SR\-TE native first hops toward the prefix
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\: str
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit>`
                                            
                                            .. attribute:: nnh
                                            
                                            	Next next hops
                                            	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.Nnh>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.SrtePath, self).__init__()

                                                self.yang_name = "srte-path"
                                                self.yang_parent_name = "backup"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.Nnh))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.tunnel_interface = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"

                                                self.uloop_explicit = YList(self)
                                                self.nnh = YList(self)
                                                self._segment_path = lambda: "srte-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.SrtePath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "srte-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "srte-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                        ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                        ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                        ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                        ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                        ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                    ])
                                                    self.repair_element_node_id = None
                                                    self.repair_ipv4_addr = None
                                                    self.repair_ipv6_addr = None
                                                    self.repair_label = None
                                                    self.repair_element_type = None
                                                    self.repair_strict_spf_label = None
                                                    self._segment_path = lambda: "uloop-explicit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class Nnh(Entity):
                                                """
                                                Next next hops
                                                
                                                .. attribute:: link_id_set
                                                
                                                	If link\_id is given
                                                	**type**\: bool
                                                
                                                .. attribute:: ipv4_set
                                                
                                                	If ipv4 address is given
                                                	**type**\: bool
                                                
                                                .. attribute:: link_id
                                                
                                                	link ID of the next next hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	Ipv4 address of the next next hop
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.Nnh, self).__init__()

                                                    self.yang_name = "nnh"
                                                    self.yang_parent_name = "srte-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                        ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                        ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ])
                                                    self.link_id_set = None
                                                    self.ipv4_set = None
                                                    self.link_id = None
                                                    self.ipv4_address = None
                                                    self._segment_path = lambda: "nnh"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                        class ExplicitPath(Entity):
                                            """
                                            SR microloop avoidance paths
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\: str
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit>`
                                            
                                            .. attribute:: nnh
                                            
                                            	Next next hops
                                            	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.Nnh>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath, self).__init__()

                                                self.yang_name = "explicit-path"
                                                self.yang_parent_name = "backup"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.Nnh))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.tunnel_interface = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"

                                                self.uloop_explicit = YList(self)
                                                self.nnh = YList(self)
                                                self._segment_path = lambda: "explicit-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	BAckup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "explicit-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    BAckup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "explicit-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                        ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                        ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                        ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                        ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                        ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                    ])
                                                    self.repair_element_node_id = None
                                                    self.repair_ipv4_addr = None
                                                    self.repair_ipv6_addr = None
                                                    self.repair_label = None
                                                    self.repair_element_type = None
                                                    self.repair_strict_spf_label = None
                                                    self._segment_path = lambda: "uloop-explicit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class Nnh(Entity):
                                                """
                                                Next next hops
                                                
                                                .. attribute:: link_id_set
                                                
                                                	If link\_id is given
                                                	**type**\: bool
                                                
                                                .. attribute:: ipv4_set
                                                
                                                	If ipv4 address is given
                                                	**type**\: bool
                                                
                                                .. attribute:: link_id
                                                
                                                	link ID of the next next hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	Ipv4 address of the next next hop
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.Nnh, self).__init__()

                                                    self.yang_name = "nnh"
                                                    self.yang_parent_name = "explicit-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                        ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                        ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ])
                                                    self.link_id_set = None
                                                    self.ipv4_set = None
                                                    self.link_id = None
                                                    self.ipv4_address = None
                                                    self._segment_path = lambda: "nnh"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                        class Source(Entity):
                                            """
                                            Sources advertising the prefix
                                            
                                            .. attribute:: source_lsp_id
                                            
                                            	ID of the LSP advertising the prefix
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                            
                                            .. attribute:: source_address
                                            
                                            	Source address of the IS advertising the prefix
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: tags
                                            
                                            	Tags associated with the prefix item
                                            	**type**\: list of  		 :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Source.Tags>`
                                            
                                            .. attribute:: nodal_sid
                                            
                                            	Nodal SIDs with the prefix item
                                            	**type**\: list of  		 :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Source.NodalSid>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "backup"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tags", ("tags", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Source.Tags)), ("nodal-sid", ("nodal_sid", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Source.NodalSid))])
                                                self._leafs = OrderedDict([
                                                    ('source_lsp_id', (YLeaf(YType.str, 'source-lsp-id'), ['str'])),
                                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                                ])
                                                self.source_lsp_id = None
                                                self.source_address = None

                                                self.tags = YList(self)
                                                self.nodal_sid = YList(self)
                                                self._segment_path = lambda: "source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Source, [u'source_lsp_id', u'source_address'], name, value)


                                            class Tags(Entity):
                                                """
                                                Tags associated with the prefix item
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Source.Tags, self).__init__()

                                                    self.yang_name = "tags"
                                                    self.yang_parent_name = "source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "tags"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Source.Tags, [u'entry'], name, value)


                                            class NodalSid(Entity):
                                                """
                                                Nodal SIDs with the prefix item
                                                
                                                .. attribute:: sid_value
                                                
                                                	sid value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rflag
                                                
                                                	rflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nflag
                                                
                                                	nflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pflag
                                                
                                                	pflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: eflag
                                                
                                                	eflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: vflag
                                                
                                                	vflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: lflag
                                                
                                                	lflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: algorithm
                                                
                                                	algorithm
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Source.NodalSid, self).__init__()

                                                    self.yang_name = "nodal-sid"
                                                    self.yang_parent_name = "source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('sid_value', (YLeaf(YType.uint32, 'sid-value'), ['int'])),
                                                        ('rflag', (YLeaf(YType.uint8, 'rflag'), ['int'])),
                                                        ('nflag', (YLeaf(YType.uint8, 'nflag'), ['int'])),
                                                        ('pflag', (YLeaf(YType.uint8, 'pflag'), ['int'])),
                                                        ('eflag', (YLeaf(YType.uint8, 'eflag'), ['int'])),
                                                        ('vflag', (YLeaf(YType.uint8, 'vflag'), ['int'])),
                                                        ('lflag', (YLeaf(YType.uint8, 'lflag'), ['int'])),
                                                        ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                                    ])
                                                    self.sid_value = None
                                                    self.rflag = None
                                                    self.nflag = None
                                                    self.pflag = None
                                                    self.eflag = None
                                                    self.vflag = None
                                                    self.lflag = None
                                                    self.algorithm = None
                                                    self._segment_path = lambda: "nodal-sid"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.Source.NodalSid, [u'sid_value', u'rflag', u'nflag', u'pflag', u'eflag', u'vflag', u'lflag', u'algorithm'], name, value)


                                        class MulticastSource(Entity):
                                            """
                                            Multicast\-intact sources advertising the prefix
                                            
                                            .. attribute:: source_lsp_id
                                            
                                            	ID of the LSP advertising the prefix
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                            
                                            .. attribute:: source_address
                                            
                                            	Source address of the IS advertising the prefix
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: tags
                                            
                                            	Tags associated with the prefix item
                                            	**type**\: list of  		 :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastSource.Tags>`
                                            
                                            .. attribute:: nodal_sid
                                            
                                            	Nodal SIDs with the prefix item
                                            	**type**\: list of  		 :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastSource, self).__init__()

                                                self.yang_name = "multicast-source"
                                                self.yang_parent_name = "backup"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tags", ("tags", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastSource.Tags)), ("nodal-sid", ("nodal_sid", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid))])
                                                self._leafs = OrderedDict([
                                                    ('source_lsp_id', (YLeaf(YType.str, 'source-lsp-id'), ['str'])),
                                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                                ])
                                                self.source_lsp_id = None
                                                self.source_address = None

                                                self.tags = YList(self)
                                                self.nodal_sid = YList(self)
                                                self._segment_path = lambda: "multicast-source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastSource, [u'source_lsp_id', u'source_address'], name, value)


                                            class Tags(Entity):
                                                """
                                                Tags associated with the prefix item
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastSource.Tags, self).__init__()

                                                    self.yang_name = "tags"
                                                    self.yang_parent_name = "multicast-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "tags"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastSource.Tags, [u'entry'], name, value)


                                            class NodalSid(Entity):
                                                """
                                                Nodal SIDs with the prefix item
                                                
                                                .. attribute:: sid_value
                                                
                                                	sid value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rflag
                                                
                                                	rflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nflag
                                                
                                                	nflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pflag
                                                
                                                	pflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: eflag
                                                
                                                	eflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: vflag
                                                
                                                	vflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: lflag
                                                
                                                	lflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: algorithm
                                                
                                                	algorithm
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid, self).__init__()

                                                    self.yang_name = "nodal-sid"
                                                    self.yang_parent_name = "multicast-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('sid_value', (YLeaf(YType.uint32, 'sid-value'), ['int'])),
                                                        ('rflag', (YLeaf(YType.uint8, 'rflag'), ['int'])),
                                                        ('nflag', (YLeaf(YType.uint8, 'nflag'), ['int'])),
                                                        ('pflag', (YLeaf(YType.uint8, 'pflag'), ['int'])),
                                                        ('eflag', (YLeaf(YType.uint8, 'eflag'), ['int'])),
                                                        ('vflag', (YLeaf(YType.uint8, 'vflag'), ['int'])),
                                                        ('lflag', (YLeaf(YType.uint8, 'lflag'), ['int'])),
                                                        ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                                    ])
                                                    self.sid_value = None
                                                    self.rflag = None
                                                    self.nflag = None
                                                    self.pflag = None
                                                    self.eflag = None
                                                    self.vflag = None
                                                    self.lflag = None
                                                    self.algorithm = None
                                                    self._segment_path = lambda: "nodal-sid"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid, [u'sid_value', u'rflag', u'nflag', u'pflag', u'eflag', u'vflag', u'lflag', u'algorithm'], name, value)


                            class PerLevelAdvertisingDetail(Entity):
                                """
                                Per level details of how the local system
                                advertises the prefix
                                
                                .. attribute:: summarization_status
                                
                                	Status of summarization for the prefix
                                	**type**\:  :py:class:`SummarizationStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.PerLevelAdvertisingDetail.SummarizationStatus>`
                                
                                .. attribute:: level
                                
                                	Level in which the prefix is advertised
                                	**type**\:  :py:class:`IsisLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevel>`
                                
                                .. attribute:: advertising_origin
                                
                                	The origin of the advertisement
                                	**type**\:  :py:class:`IsisShRouteAdvOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisShRouteAdvOrigin>`
                                
                                .. attribute:: metric
                                
                                	Metric with which the prefix is advertised
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_propagated
                                
                                	Has the prefix been propagated from another level?
                                	**type**\: bool
                                
                                .. attribute:: is_external_metric
                                
                                	Is the metric an external metric?
                                	**type**\: bool
                                
                                .. attribute:: is_external_reachability
                                
                                	Is the prefix external to the IS\-IS domain?
                                	**type**\: bool
                                
                                .. attribute:: is_interarea
                                
                                	Is the up/down bit set?
                                	**type**\: bool
                                
                                .. attribute:: tags
                                
                                	Tags associated with the prefix
                                	**type**\: list of  		 :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.PerLevelAdvertisingDetail.Tags>`
                                
                                .. attribute:: nodal_sid
                                
                                	Nodal SIDs with the prefix item
                                	**type**\: list of  		 :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.PerLevelAdvertisingDetail.NodalSid>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.PerLevelAdvertisingDetail, self).__init__()

                                    self.yang_name = "per-level-advertising-detail"
                                    self.yang_parent_name = "ipv6frr-backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("summarization-status", ("summarization_status", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.PerLevelAdvertisingDetail.SummarizationStatus)), ("tags", ("tags", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.PerLevelAdvertisingDetail.Tags)), ("nodal-sid", ("nodal_sid", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.PerLevelAdvertisingDetail.NodalSid))])
                                    self._leafs = OrderedDict([
                                        ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisLevel', '')])),
                                        ('advertising_origin', (YLeaf(YType.enumeration, 'advertising-origin'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisShRouteAdvOrigin', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('is_propagated', (YLeaf(YType.boolean, 'is-propagated'), ['bool'])),
                                        ('is_external_metric', (YLeaf(YType.boolean, 'is-external-metric'), ['bool'])),
                                        ('is_external_reachability', (YLeaf(YType.boolean, 'is-external-reachability'), ['bool'])),
                                        ('is_interarea', (YLeaf(YType.boolean, 'is-interarea'), ['bool'])),
                                    ])
                                    self.level = None
                                    self.advertising_origin = None
                                    self.metric = None
                                    self.is_propagated = None
                                    self.is_external_metric = None
                                    self.is_external_reachability = None
                                    self.is_interarea = None

                                    self.summarization_status = Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.PerLevelAdvertisingDetail.SummarizationStatus()
                                    self.summarization_status.parent = self
                                    self._children_name_map["summarization_status"] = "summarization-status"

                                    self.tags = YList(self)
                                    self.nodal_sid = YList(self)
                                    self._segment_path = lambda: "per-level-advertising-detail"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.PerLevelAdvertisingDetail, [u'level', u'advertising_origin', u'metric', u'is_propagated', u'is_external_metric', u'is_external_reachability', u'is_interarea'], name, value)


                                class SummarizationStatus(Entity):
                                    """
                                    Status of summarization for the prefix
                                    
                                    .. attribute:: summary_prefix
                                    
                                    	Summarizing Prefix
                                    	**type**\:  :py:class:`SummaryPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	IsValid
                                    	**type**\:  :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.PerLevelAdvertisingDetail.SummarizationStatus, self).__init__()

                                        self.yang_name = "summarization-status"
                                        self.yang_parent_name = "per-level-advertising-detail"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("summary-prefix", ("summary_prefix", Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', (YLeaf(YType.enumeration, 'is-valid'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisValid', '')])),
                                        ])
                                        self.is_valid = None

                                        self.summary_prefix = Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix()
                                        self.summary_prefix.parent = self
                                        self._children_name_map["summary_prefix"] = "summary-prefix"
                                        self._segment_path = lambda: "summarization-status"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.PerLevelAdvertisingDetail.SummarizationStatus, [u'is_valid'], name, value)


                                    class SummaryPrefix(Entity):
                                        """
                                        Summarizing Prefix
                                        
                                        .. attribute:: prefix
                                        
                                        	prefix
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	prefix length
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix, self).__init__()

                                            self.yang_name = "summary-prefix"
                                            self.yang_parent_name = "summarization-status"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                            ])
                                            self.prefix = None
                                            self.prefix_length = None
                                            self._segment_path = lambda: "summary-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix, [u'prefix', u'prefix_length'], name, value)


                                class Tags(Entity):
                                    """
                                    Tags associated with the prefix
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.PerLevelAdvertisingDetail.Tags, self).__init__()

                                        self.yang_name = "tags"
                                        self.yang_parent_name = "per-level-advertising-detail"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "tags"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.PerLevelAdvertisingDetail.Tags, [u'entry'], name, value)


                                class NodalSid(Entity):
                                    """
                                    Nodal SIDs with the prefix item
                                    
                                    .. attribute:: sid_value
                                    
                                    	sid value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rflag
                                    
                                    	rflag
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: nflag
                                    
                                    	nflag
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: pflag
                                    
                                    	pflag
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: eflag
                                    
                                    	eflag
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vflag
                                    
                                    	vflag
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: lflag
                                    
                                    	lflag
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: algorithm
                                    
                                    	algorithm
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.PerLevelAdvertisingDetail.NodalSid, self).__init__()

                                        self.yang_name = "nodal-sid"
                                        self.yang_parent_name = "per-level-advertising-detail"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('sid_value', (YLeaf(YType.uint32, 'sid-value'), ['int'])),
                                            ('rflag', (YLeaf(YType.uint8, 'rflag'), ['int'])),
                                            ('nflag', (YLeaf(YType.uint8, 'nflag'), ['int'])),
                                            ('pflag', (YLeaf(YType.uint8, 'pflag'), ['int'])),
                                            ('eflag', (YLeaf(YType.uint8, 'eflag'), ['int'])),
                                            ('vflag', (YLeaf(YType.uint8, 'vflag'), ['int'])),
                                            ('lflag', (YLeaf(YType.uint8, 'lflag'), ['int'])),
                                            ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                        ])
                                        self.sid_value = None
                                        self.rflag = None
                                        self.nflag = None
                                        self.pflag = None
                                        self.eflag = None
                                        self.vflag = None
                                        self.lflag = None
                                        self.algorithm = None
                                        self._segment_path = lambda: "nodal-sid"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv6frrBackups.Ipv6frrBackup.PerLevelAdvertisingDetail.NodalSid, [u'sid_value', u'rflag', u'nflag', u'pflag', u'eflag', u'vflag', u'lflag', u'algorithm'], name, value)


                    class Ipv4frrBackups(Entity):
                        """
                        IPv4 FRR table
                        
                        .. attribute:: ipv4frr_backup
                        
                        	FRR backup for an IPv4 network
                        	**type**\: list of  		 :py:class:`Ipv4frrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups, self).__init__()

                            self.yang_name = "ipv4frr-backups"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4frr-backup", ("ipv4frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup))])
                            self._leafs = OrderedDict()

                            self.ipv4frr_backup = YList(self)
                            self._segment_path = lambda: "ipv4frr-backups"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups, [], name, value)


                        class Ipv4frrBackup(Entity):
                            """
                            FRR backup for an IPv4 network
                            
                            .. attribute:: prefix
                            
                            	Prefix
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length
                            
                            	Prefix Length
                            	**type**\: int
                            
                            	**range:** 0..32
                            
                            .. attribute:: connected_status
                            
                            	Status of IS\-IS directly connected routes to the prefix
                            	**type**\:  :py:class:`ConnectedStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.ConnectedStatus>`
                            
                            .. attribute:: redistributed_status
                            
                            	Status of other protocols' routes redistributed into IS\-IS
                            	**type**\:  :py:class:`RedistributedStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.RedistributedStatus>`
                            
                            .. attribute:: native_status
                            
                            	Status of native IS\-IS routes to the prefix
                            	**type**\:  :py:class:`NativeStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus>`
                            
                            .. attribute:: per_level_advertising_detail
                            
                            	Per level details of how the local system advertises the prefix
                            	**type**\: list of  		 :py:class:`PerLevelAdvertisingDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.PerLevelAdvertisingDetail>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup, self).__init__()

                                self.yang_name = "ipv4frr-backup"
                                self.yang_parent_name = "ipv4frr-backups"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("connected-status", ("connected_status", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.ConnectedStatus)), ("redistributed-status", ("redistributed_status", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.RedistributedStatus)), ("native-status", ("native_status", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus)), ("per-level-advertising-detail", ("per_level_advertising_detail", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.PerLevelAdvertisingDetail))])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                    ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                ])
                                self.prefix = None
                                self.prefix_length = None

                                self.connected_status = Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.ConnectedStatus()
                                self.connected_status.parent = self
                                self._children_name_map["connected_status"] = "connected-status"

                                self.redistributed_status = Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.RedistributedStatus()
                                self.redistributed_status.parent = self
                                self._children_name_map["redistributed_status"] = "redistributed-status"

                                self.native_status = Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus()
                                self.native_status.parent = self
                                self._children_name_map["native_status"] = "native-status"

                                self.per_level_advertising_detail = YList(self)
                                self._segment_path = lambda: "ipv4frr-backup"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup, ['prefix', 'prefix_length'], name, value)


                            class ConnectedStatus(Entity):
                                """
                                Status of IS\-IS directly connected routes to the
                                prefix
                                
                                .. attribute:: connected_details
                                
                                	Details of the directly connected prefix
                                	**type**\:  :py:class:`ConnectedDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.ConnectedStatus.ConnectedDetails>`
                                
                                .. attribute:: is_valid
                                
                                	IsValid
                                	**type**\:  :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.ConnectedStatus, self).__init__()

                                    self.yang_name = "connected-status"
                                    self.yang_parent_name = "ipv4frr-backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("connected-details", ("connected_details", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.ConnectedStatus.ConnectedDetails))])
                                    self._leafs = OrderedDict([
                                        ('is_valid', (YLeaf(YType.enumeration, 'is-valid'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisValid', '')])),
                                    ])
                                    self.is_valid = None

                                    self.connected_details = Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.ConnectedStatus.ConnectedDetails()
                                    self.connected_details.parent = self
                                    self._children_name_map["connected_details"] = "connected-details"
                                    self._segment_path = lambda: "connected-status"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.ConnectedStatus, [u'is_valid'], name, value)


                                class ConnectedDetails(Entity):
                                    """
                                    Details of the directly connected prefix
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.ConnectedStatus.ConnectedDetails.Interface>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.ConnectedStatus.ConnectedDetails, self).__init__()

                                        self.yang_name = "connected-details"
                                        self.yang_parent_name = "connected-status"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface", ("interface", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.ConnectedStatus.ConnectedDetails.Interface))])
                                        self._leafs = OrderedDict()

                                        self.interface = YList(self)
                                        self._segment_path = lambda: "connected-details"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.ConnectedStatus.ConnectedDetails, [], name, value)


                                    class Interface(Entity):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.ConnectedStatus.ConnectedDetails.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "connected-details"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "interface"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.ConnectedStatus.ConnectedDetails.Interface, [u'entry'], name, value)


                            class RedistributedStatus(Entity):
                                """
                                Status of other protocols' routes redistributed
                                into IS\-IS
                                
                                .. attribute:: redistribution_details
                                
                                	Per level details of the redistributed route
                                	**type**\:  :py:class:`RedistributionDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.RedistributedStatus.RedistributionDetails>`
                                
                                .. attribute:: is_valid
                                
                                	IsValid
                                	**type**\:  :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.RedistributedStatus, self).__init__()

                                    self.yang_name = "redistributed-status"
                                    self.yang_parent_name = "ipv4frr-backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("redistribution-details", ("redistribution_details", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.RedistributedStatus.RedistributionDetails))])
                                    self._leafs = OrderedDict([
                                        ('is_valid', (YLeaf(YType.enumeration, 'is-valid'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisValid', '')])),
                                    ])
                                    self.is_valid = None

                                    self.redistribution_details = Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.RedistributedStatus.RedistributionDetails()
                                    self.redistribution_details.parent = self
                                    self._children_name_map["redistribution_details"] = "redistribution-details"
                                    self._segment_path = lambda: "redistributed-status"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.RedistributedStatus, [u'is_valid'], name, value)


                                class RedistributionDetails(Entity):
                                    """
                                    Per level details of the redistributed route
                                    
                                    .. attribute:: isis_sh_route_redist_detail
                                    
                                    	isis sh route redist detail
                                    	**type**\: list of  		 :py:class:`IsisShRouteRedistDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.RedistributedStatus.RedistributionDetails, self).__init__()

                                        self.yang_name = "redistribution-details"
                                        self.yang_parent_name = "redistributed-status"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("isis-sh-route-redist-detail", ("isis_sh_route_redist_detail", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail))])
                                        self._leafs = OrderedDict()

                                        self.isis_sh_route_redist_detail = YList(self)
                                        self._segment_path = lambda: "redistribution-details"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.RedistributedStatus.RedistributionDetails, [], name, value)


                                    class IsisShRouteRedistDetail(Entity):
                                        """
                                        isis sh route redist detail
                                        
                                        .. attribute:: owner
                                        
                                        	Protocol redistributing the route
                                        	**type**\:  :py:class:`Owner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner>`
                                        
                                        .. attribute:: level
                                        
                                        	Level into which the route is redistributed
                                        	**type**\:  :py:class:`IsisLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevel>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail, self).__init__()

                                            self.yang_name = "isis-sh-route-redist-detail"
                                            self.yang_parent_name = "redistribution-details"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("owner", ("owner", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner))])
                                            self._leafs = OrderedDict([
                                                ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisLevel', '')])),
                                            ])
                                            self.level = None

                                            self.owner = Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner()
                                            self.owner.parent = self
                                            self._children_name_map["owner"] = "owner"
                                            self._segment_path = lambda: "isis-sh-route-redist-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail, [u'level'], name, value)


                                        class Owner(Entity):
                                            """
                                            Protocol redistributing the route
                                            
                                            .. attribute:: protocol
                                            
                                            	Protocol
                                            	**type**\:  :py:class:`IsisRedistProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisRedistProto>`
                                            
                                            .. attribute:: isis_instance_id
                                            
                                            	IS\-IS instance identifier
                                            	**type**\: str
                                            
                                            .. attribute:: ospf_process_id
                                            
                                            	OSPF process identifier
                                            	**type**\: str
                                            
                                            .. attribute:: ospfv3_process_id
                                            
                                            	OSPFv3 process identifier
                                            	**type**\: str
                                            
                                            .. attribute:: bgp_as_number
                                            
                                            	BGP Autonomous System number
                                            	**type**\: str
                                            
                                            .. attribute:: eigrp_as_number
                                            
                                            	EIGRP Autonomous System number
                                            	**type**\: str
                                            
                                            .. attribute:: application_name
                                            
                                            	Application Name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner, self).__init__()

                                                self.yang_name = "owner"
                                                self.yang_parent_name = "isis-sh-route-redist-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisRedistProto', '')])),
                                                    ('isis_instance_id', (YLeaf(YType.str, 'isis-instance-id'), ['str'])),
                                                    ('ospf_process_id', (YLeaf(YType.str, 'ospf-process-id'), ['str'])),
                                                    ('ospfv3_process_id', (YLeaf(YType.str, 'ospfv3-process-id'), ['str'])),
                                                    ('bgp_as_number', (YLeaf(YType.str, 'bgp-as-number'), ['str'])),
                                                    ('eigrp_as_number', (YLeaf(YType.str, 'eigrp-as-number'), ['str'])),
                                                    ('application_name', (YLeaf(YType.str, 'application-name'), ['str'])),
                                                ])
                                                self.protocol = None
                                                self.isis_instance_id = None
                                                self.ospf_process_id = None
                                                self.ospfv3_process_id = None
                                                self.bgp_as_number = None
                                                self.eigrp_as_number = None
                                                self.application_name = None
                                                self._segment_path = lambda: "owner"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner, [u'protocol', u'isis_instance_id', u'ospf_process_id', u'ospfv3_process_id', u'bgp_as_number', u'eigrp_as_number', u'application_name'], name, value)


                            class NativeStatus(Entity):
                                """
                                Status of native IS\-IS routes to the prefix
                                
                                .. attribute:: native_details
                                
                                	Details of the native route
                                	**type**\:  :py:class:`NativeDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails>`
                                
                                .. attribute:: is_valid
                                
                                	IsValid
                                	**type**\:  :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus, self).__init__()

                                    self.yang_name = "native-status"
                                    self.yang_parent_name = "ipv4frr-backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("native-details", ("native_details", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails))])
                                    self._leafs = OrderedDict([
                                        ('is_valid', (YLeaf(YType.enumeration, 'is-valid'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisValid', '')])),
                                    ])
                                    self.is_valid = None

                                    self.native_details = Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails()
                                    self.native_details.parent = self
                                    self._children_name_map["native_details"] = "native-details"
                                    self._segment_path = lambda: "native-status"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus, [u'is_valid'], name, value)


                                class NativeDetails(Entity):
                                    """
                                    Details of the native route
                                    
                                    .. attribute:: primary
                                    
                                    	Primary paths to prefix
                                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary>`
                                    
                                    .. attribute:: priority
                                    
                                    	Relative importance of the prefix
                                    	**type**\:  :py:class:`IsisPrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisPrefixPriority>`
                                    
                                    .. attribute:: backup
                                    
                                    	Backup paths to prefix
                                    	**type**\: list of  		 :py:class:`Backup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails, self).__init__()

                                        self.yang_name = "native-details"
                                        self.yang_parent_name = "native-status"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("primary", ("primary", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary)), ("backup", ("backup", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup))])
                                        self._leafs = OrderedDict([
                                            ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisPrefixPriority', '')])),
                                        ])
                                        self.priority = None

                                        self.primary = Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary()
                                        self.primary.parent = self
                                        self._children_name_map["primary"] = "primary"

                                        self.backup = YList(self)
                                        self._segment_path = lambda: "native-details"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails, [u'priority'], name, value)


                                    class Primary(Entity):
                                        """
                                        Primary paths to prefix
                                        
                                        .. attribute:: origin
                                        
                                        	Origin of route
                                        	**type**\:  :py:class:`IsisPrefixOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisPrefixOrigin>`
                                        
                                        .. attribute:: metric
                                        
                                        	Distance to network
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multicast_metric
                                        
                                        	Multicast\-intact distance to network
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_external_metric
                                        
                                        	Is the metric an external metric?
                                        	**type**\: bool
                                        
                                        .. attribute:: administrative_distance
                                        
                                        	Administrative Distance
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: paths
                                        
                                        	First hops toward the prefix
                                        	**type**\: list of  		 :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Paths>`
                                        
                                        .. attribute:: ucmp_next_hop
                                        
                                        	UCMP first hops toward the prefix
                                        	**type**\: list of  		 :py:class:`UcmpNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop>`
                                        
                                        .. attribute:: multicast_path
                                        
                                        	Multicast intact first hops toward the prefix
                                        	**type**\: list of  		 :py:class:`MulticastPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath>`
                                        
                                        .. attribute:: srte_path
                                        
                                        	SR\-TE native first hops toward the prefix
                                        	**type**\: list of  		 :py:class:`SrtePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.SrtePath>`
                                        
                                        .. attribute:: explicit_path
                                        
                                        	SR microloop avoidance paths
                                        	**type**\: list of  		 :py:class:`ExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath>`
                                        
                                        .. attribute:: source
                                        
                                        	Sources advertising the prefix
                                        	**type**\: list of  		 :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Source>`
                                        
                                        .. attribute:: multicast_source
                                        
                                        	Multicast\-intact sources advertising the prefix
                                        	**type**\: list of  		 :py:class:`MulticastSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastSource>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary, self).__init__()

                                            self.yang_name = "primary"
                                            self.yang_parent_name = "native-details"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("paths", ("paths", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Paths)), ("ucmp-next-hop", ("ucmp_next_hop", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop)), ("multicast-path", ("multicast_path", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath)), ("srte-path", ("srte_path", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.SrtePath)), ("explicit-path", ("explicit_path", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath)), ("source", ("source", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Source)), ("multicast-source", ("multicast_source", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastSource))])
                                            self._leafs = OrderedDict([
                                                ('origin', (YLeaf(YType.enumeration, 'origin'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisPrefixOrigin', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('multicast_metric', (YLeaf(YType.uint32, 'multicast-metric'), ['int'])),
                                                ('is_external_metric', (YLeaf(YType.boolean, 'is-external-metric'), ['bool'])),
                                                ('administrative_distance', (YLeaf(YType.uint16, 'administrative-distance'), ['int'])),
                                            ])
                                            self.origin = None
                                            self.metric = None
                                            self.multicast_metric = None
                                            self.is_external_metric = None
                                            self.administrative_distance = None

                                            self.paths = YList(self)
                                            self.ucmp_next_hop = YList(self)
                                            self.multicast_path = YList(self)
                                            self.srte_path = YList(self)
                                            self.explicit_path = YList(self)
                                            self.source = YList(self)
                                            self.multicast_source = YList(self)
                                            self._segment_path = lambda: "primary"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary, [u'origin', u'metric', u'multicast_metric', u'is_external_metric', u'administrative_distance'], name, value)


                                        class Paths(Entity):
                                            """
                                            First hops toward the prefix
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\: str
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit>`
                                            
                                            .. attribute:: nnh
                                            
                                            	Next next hops
                                            	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Paths.Nnh>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Paths, self).__init__()

                                                self.yang_name = "paths"
                                                self.yang_parent_name = "primary"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Paths.Nnh))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.tunnel_interface = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"

                                                self.uloop_explicit = YList(self)
                                                self.nnh = YList(self)
                                                self._segment_path = lambda: "paths"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Paths, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                        ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                        ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                        ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                        ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                        ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                    ])
                                                    self.repair_element_node_id = None
                                                    self.repair_ipv4_addr = None
                                                    self.repair_ipv6_addr = None
                                                    self.repair_label = None
                                                    self.repair_element_type = None
                                                    self.repair_strict_spf_label = None
                                                    self._segment_path = lambda: "uloop-explicit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class Nnh(Entity):
                                                """
                                                Next next hops
                                                
                                                .. attribute:: link_id_set
                                                
                                                	If link\_id is given
                                                	**type**\: bool
                                                
                                                .. attribute:: ipv4_set
                                                
                                                	If ipv4 address is given
                                                	**type**\: bool
                                                
                                                .. attribute:: link_id
                                                
                                                	link ID of the next next hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	Ipv4 address of the next next hop
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Paths.Nnh, self).__init__()

                                                    self.yang_name = "nnh"
                                                    self.yang_parent_name = "paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                        ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                        ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ])
                                                    self.link_id_set = None
                                                    self.ipv4_set = None
                                                    self.link_id = None
                                                    self.ipv4_address = None
                                                    self._segment_path = lambda: "nnh"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Paths.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                        class UcmpNextHop(Entity):
                                            """
                                            UCMP first hops toward the prefix
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: total_ucmp_distance
                                            
                                            	Distance to the network via this UCMP next hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop, self).__init__()

                                                self.yang_name = "ucmp-next-hop"
                                                self.yang_parent_name = "primary"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('total_ucmp_distance', (YLeaf(YType.uint32, 'total-ucmp-distance'), ['int'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.total_ucmp_distance = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._segment_path = lambda: "ucmp-next-hop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'total_ucmp_distance', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "ucmp-next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                        class MulticastPath(Entity):
                                            """
                                            Multicast intact first hops toward the prefix
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\: str
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit>`
                                            
                                            .. attribute:: nnh
                                            
                                            	Next next hops
                                            	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.Nnh>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath, self).__init__()

                                                self.yang_name = "multicast-path"
                                                self.yang_parent_name = "primary"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.Nnh))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.tunnel_interface = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"

                                                self.uloop_explicit = YList(self)
                                                self.nnh = YList(self)
                                                self._segment_path = lambda: "multicast-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "multicast-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "multicast-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                        ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                        ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                        ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                        ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                        ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                    ])
                                                    self.repair_element_node_id = None
                                                    self.repair_ipv4_addr = None
                                                    self.repair_ipv6_addr = None
                                                    self.repair_label = None
                                                    self.repair_element_type = None
                                                    self.repair_strict_spf_label = None
                                                    self._segment_path = lambda: "uloop-explicit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class Nnh(Entity):
                                                """
                                                Next next hops
                                                
                                                .. attribute:: link_id_set
                                                
                                                	If link\_id is given
                                                	**type**\: bool
                                                
                                                .. attribute:: ipv4_set
                                                
                                                	If ipv4 address is given
                                                	**type**\: bool
                                                
                                                .. attribute:: link_id
                                                
                                                	link ID of the next next hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	Ipv4 address of the next next hop
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.Nnh, self).__init__()

                                                    self.yang_name = "nnh"
                                                    self.yang_parent_name = "multicast-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                        ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                        ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ])
                                                    self.link_id_set = None
                                                    self.ipv4_set = None
                                                    self.link_id = None
                                                    self.ipv4_address = None
                                                    self._segment_path = lambda: "nnh"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastPath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                        class SrtePath(Entity):
                                            """
                                            SR\-TE native first hops toward the prefix
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\: str
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit>`
                                            
                                            .. attribute:: nnh
                                            
                                            	Next next hops
                                            	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.Nnh>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.SrtePath, self).__init__()

                                                self.yang_name = "srte-path"
                                                self.yang_parent_name = "primary"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.Nnh))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.tunnel_interface = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"

                                                self.uloop_explicit = YList(self)
                                                self.nnh = YList(self)
                                                self._segment_path = lambda: "srte-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.SrtePath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "srte-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "srte-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                        ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                        ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                        ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                        ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                        ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                    ])
                                                    self.repair_element_node_id = None
                                                    self.repair_ipv4_addr = None
                                                    self.repair_ipv6_addr = None
                                                    self.repair_label = None
                                                    self.repair_element_type = None
                                                    self.repair_strict_spf_label = None
                                                    self._segment_path = lambda: "uloop-explicit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class Nnh(Entity):
                                                """
                                                Next next hops
                                                
                                                .. attribute:: link_id_set
                                                
                                                	If link\_id is given
                                                	**type**\: bool
                                                
                                                .. attribute:: ipv4_set
                                                
                                                	If ipv4 address is given
                                                	**type**\: bool
                                                
                                                .. attribute:: link_id
                                                
                                                	link ID of the next next hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	Ipv4 address of the next next hop
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.Nnh, self).__init__()

                                                    self.yang_name = "nnh"
                                                    self.yang_parent_name = "srte-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                        ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                        ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ])
                                                    self.link_id_set = None
                                                    self.ipv4_set = None
                                                    self.link_id = None
                                                    self.ipv4_address = None
                                                    self._segment_path = lambda: "nnh"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.SrtePath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                        class ExplicitPath(Entity):
                                            """
                                            SR microloop avoidance paths
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\: str
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit>`
                                            
                                            .. attribute:: nnh
                                            
                                            	Next next hops
                                            	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.Nnh>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath, self).__init__()

                                                self.yang_name = "explicit-path"
                                                self.yang_parent_name = "primary"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.Nnh))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.tunnel_interface = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"

                                                self.uloop_explicit = YList(self)
                                                self.nnh = YList(self)
                                                self._segment_path = lambda: "explicit-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "explicit-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "explicit-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                        ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                        ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                        ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                        ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                        ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                    ])
                                                    self.repair_element_node_id = None
                                                    self.repair_ipv4_addr = None
                                                    self.repair_ipv6_addr = None
                                                    self.repair_label = None
                                                    self.repair_element_type = None
                                                    self.repair_strict_spf_label = None
                                                    self._segment_path = lambda: "uloop-explicit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class Nnh(Entity):
                                                """
                                                Next next hops
                                                
                                                .. attribute:: link_id_set
                                                
                                                	If link\_id is given
                                                	**type**\: bool
                                                
                                                .. attribute:: ipv4_set
                                                
                                                	If ipv4 address is given
                                                	**type**\: bool
                                                
                                                .. attribute:: link_id
                                                
                                                	link ID of the next next hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	Ipv4 address of the next next hop
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.Nnh, self).__init__()

                                                    self.yang_name = "nnh"
                                                    self.yang_parent_name = "explicit-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                        ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                        ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ])
                                                    self.link_id_set = None
                                                    self.ipv4_set = None
                                                    self.link_id = None
                                                    self.ipv4_address = None
                                                    self._segment_path = lambda: "nnh"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.ExplicitPath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                        class Source(Entity):
                                            """
                                            Sources advertising the prefix
                                            
                                            .. attribute:: source_lsp_id
                                            
                                            	ID of the LSP advertising the prefix
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                            
                                            .. attribute:: source_address
                                            
                                            	Source address of the IS advertising the prefix
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: tags
                                            
                                            	Tags associated with the prefix item
                                            	**type**\: list of  		 :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Source.Tags>`
                                            
                                            .. attribute:: nodal_sid
                                            
                                            	Nodal SIDs with the prefix item
                                            	**type**\: list of  		 :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Source.NodalSid>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "primary"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tags", ("tags", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Source.Tags)), ("nodal-sid", ("nodal_sid", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Source.NodalSid))])
                                                self._leafs = OrderedDict([
                                                    ('source_lsp_id', (YLeaf(YType.str, 'source-lsp-id'), ['str'])),
                                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                                ])
                                                self.source_lsp_id = None
                                                self.source_address = None

                                                self.tags = YList(self)
                                                self.nodal_sid = YList(self)
                                                self._segment_path = lambda: "source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Source, [u'source_lsp_id', u'source_address'], name, value)


                                            class Tags(Entity):
                                                """
                                                Tags associated with the prefix item
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Source.Tags, self).__init__()

                                                    self.yang_name = "tags"
                                                    self.yang_parent_name = "source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "tags"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Source.Tags, [u'entry'], name, value)


                                            class NodalSid(Entity):
                                                """
                                                Nodal SIDs with the prefix item
                                                
                                                .. attribute:: sid_value
                                                
                                                	sid value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rflag
                                                
                                                	rflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nflag
                                                
                                                	nflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pflag
                                                
                                                	pflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: eflag
                                                
                                                	eflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: vflag
                                                
                                                	vflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: lflag
                                                
                                                	lflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: algorithm
                                                
                                                	algorithm
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Source.NodalSid, self).__init__()

                                                    self.yang_name = "nodal-sid"
                                                    self.yang_parent_name = "source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('sid_value', (YLeaf(YType.uint32, 'sid-value'), ['int'])),
                                                        ('rflag', (YLeaf(YType.uint8, 'rflag'), ['int'])),
                                                        ('nflag', (YLeaf(YType.uint8, 'nflag'), ['int'])),
                                                        ('pflag', (YLeaf(YType.uint8, 'pflag'), ['int'])),
                                                        ('eflag', (YLeaf(YType.uint8, 'eflag'), ['int'])),
                                                        ('vflag', (YLeaf(YType.uint8, 'vflag'), ['int'])),
                                                        ('lflag', (YLeaf(YType.uint8, 'lflag'), ['int'])),
                                                        ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                                    ])
                                                    self.sid_value = None
                                                    self.rflag = None
                                                    self.nflag = None
                                                    self.pflag = None
                                                    self.eflag = None
                                                    self.vflag = None
                                                    self.lflag = None
                                                    self.algorithm = None
                                                    self._segment_path = lambda: "nodal-sid"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.Source.NodalSid, [u'sid_value', u'rflag', u'nflag', u'pflag', u'eflag', u'vflag', u'lflag', u'algorithm'], name, value)


                                        class MulticastSource(Entity):
                                            """
                                            Multicast\-intact sources advertising the prefix
                                            
                                            .. attribute:: source_lsp_id
                                            
                                            	ID of the LSP advertising the prefix
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                            
                                            .. attribute:: source_address
                                            
                                            	Source address of the IS advertising the prefix
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: tags
                                            
                                            	Tags associated with the prefix item
                                            	**type**\: list of  		 :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastSource.Tags>`
                                            
                                            .. attribute:: nodal_sid
                                            
                                            	Nodal SIDs with the prefix item
                                            	**type**\: list of  		 :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastSource, self).__init__()

                                                self.yang_name = "multicast-source"
                                                self.yang_parent_name = "primary"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tags", ("tags", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastSource.Tags)), ("nodal-sid", ("nodal_sid", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid))])
                                                self._leafs = OrderedDict([
                                                    ('source_lsp_id', (YLeaf(YType.str, 'source-lsp-id'), ['str'])),
                                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                                ])
                                                self.source_lsp_id = None
                                                self.source_address = None

                                                self.tags = YList(self)
                                                self.nodal_sid = YList(self)
                                                self._segment_path = lambda: "multicast-source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastSource, [u'source_lsp_id', u'source_address'], name, value)


                                            class Tags(Entity):
                                                """
                                                Tags associated with the prefix item
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastSource.Tags, self).__init__()

                                                    self.yang_name = "tags"
                                                    self.yang_parent_name = "multicast-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "tags"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastSource.Tags, [u'entry'], name, value)


                                            class NodalSid(Entity):
                                                """
                                                Nodal SIDs with the prefix item
                                                
                                                .. attribute:: sid_value
                                                
                                                	sid value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rflag
                                                
                                                	rflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nflag
                                                
                                                	nflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pflag
                                                
                                                	pflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: eflag
                                                
                                                	eflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: vflag
                                                
                                                	vflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: lflag
                                                
                                                	lflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: algorithm
                                                
                                                	algorithm
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid, self).__init__()

                                                    self.yang_name = "nodal-sid"
                                                    self.yang_parent_name = "multicast-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('sid_value', (YLeaf(YType.uint32, 'sid-value'), ['int'])),
                                                        ('rflag', (YLeaf(YType.uint8, 'rflag'), ['int'])),
                                                        ('nflag', (YLeaf(YType.uint8, 'nflag'), ['int'])),
                                                        ('pflag', (YLeaf(YType.uint8, 'pflag'), ['int'])),
                                                        ('eflag', (YLeaf(YType.uint8, 'eflag'), ['int'])),
                                                        ('vflag', (YLeaf(YType.uint8, 'vflag'), ['int'])),
                                                        ('lflag', (YLeaf(YType.uint8, 'lflag'), ['int'])),
                                                        ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                                    ])
                                                    self.sid_value = None
                                                    self.rflag = None
                                                    self.nflag = None
                                                    self.pflag = None
                                                    self.eflag = None
                                                    self.vflag = None
                                                    self.lflag = None
                                                    self.algorithm = None
                                                    self._segment_path = lambda: "nodal-sid"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid, [u'sid_value', u'rflag', u'nflag', u'pflag', u'eflag', u'vflag', u'lflag', u'algorithm'], name, value)


                                    class Backup(Entity):
                                        """
                                        Backup paths to prefix
                                        
                                        .. attribute:: origin
                                        
                                        	Origin of route
                                        	**type**\:  :py:class:`IsisPrefixOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisPrefixOrigin>`
                                        
                                        .. attribute:: metric
                                        
                                        	Distance to network
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multicast_metric
                                        
                                        	Multicast\-intact distance to network
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_external_metric
                                        
                                        	Is the metric an external metric?
                                        	**type**\: bool
                                        
                                        .. attribute:: administrative_distance
                                        
                                        	Administrative Distance
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: paths
                                        
                                        	First hops toward the prefix
                                        	**type**\: list of  		 :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Paths>`
                                        
                                        .. attribute:: ucmp_next_hop
                                        
                                        	UCMP first hops toward the prefix
                                        	**type**\: list of  		 :py:class:`UcmpNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop>`
                                        
                                        .. attribute:: multicast_path
                                        
                                        	Multicast intact first hops toward the prefix
                                        	**type**\: list of  		 :py:class:`MulticastPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath>`
                                        
                                        .. attribute:: srte_path
                                        
                                        	SR\-TE native first hops toward the prefix
                                        	**type**\: list of  		 :py:class:`SrtePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.SrtePath>`
                                        
                                        .. attribute:: explicit_path
                                        
                                        	SR microloop avoidance paths
                                        	**type**\: list of  		 :py:class:`ExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath>`
                                        
                                        .. attribute:: source
                                        
                                        	Sources advertising the prefix
                                        	**type**\: list of  		 :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Source>`
                                        
                                        .. attribute:: multicast_source
                                        
                                        	Multicast\-intact sources advertising the prefix
                                        	**type**\: list of  		 :py:class:`MulticastSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastSource>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup, self).__init__()

                                            self.yang_name = "backup"
                                            self.yang_parent_name = "native-details"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("paths", ("paths", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Paths)), ("ucmp-next-hop", ("ucmp_next_hop", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop)), ("multicast-path", ("multicast_path", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath)), ("srte-path", ("srte_path", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.SrtePath)), ("explicit-path", ("explicit_path", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath)), ("source", ("source", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Source)), ("multicast-source", ("multicast_source", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastSource))])
                                            self._leafs = OrderedDict([
                                                ('origin', (YLeaf(YType.enumeration, 'origin'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisPrefixOrigin', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('multicast_metric', (YLeaf(YType.uint32, 'multicast-metric'), ['int'])),
                                                ('is_external_metric', (YLeaf(YType.boolean, 'is-external-metric'), ['bool'])),
                                                ('administrative_distance', (YLeaf(YType.uint16, 'administrative-distance'), ['int'])),
                                            ])
                                            self.origin = None
                                            self.metric = None
                                            self.multicast_metric = None
                                            self.is_external_metric = None
                                            self.administrative_distance = None

                                            self.paths = YList(self)
                                            self.ucmp_next_hop = YList(self)
                                            self.multicast_path = YList(self)
                                            self.srte_path = YList(self)
                                            self.explicit_path = YList(self)
                                            self.source = YList(self)
                                            self.multicast_source = YList(self)
                                            self._segment_path = lambda: "backup"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup, [u'origin', u'metric', u'multicast_metric', u'is_external_metric', u'administrative_distance'], name, value)


                                        class Paths(Entity):
                                            """
                                            First hops toward the prefix
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\: str
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit>`
                                            
                                            .. attribute:: nnh
                                            
                                            	Next next hops
                                            	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Paths.Nnh>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Paths, self).__init__()

                                                self.yang_name = "paths"
                                                self.yang_parent_name = "backup"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Paths.Nnh))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.tunnel_interface = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"

                                                self.uloop_explicit = YList(self)
                                                self.nnh = YList(self)
                                                self._segment_path = lambda: "paths"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Paths, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                        ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                        ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                        ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                        ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                        ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                    ])
                                                    self.repair_element_node_id = None
                                                    self.repair_ipv4_addr = None
                                                    self.repair_ipv6_addr = None
                                                    self.repair_label = None
                                                    self.repair_element_type = None
                                                    self.repair_strict_spf_label = None
                                                    self._segment_path = lambda: "uloop-explicit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class Nnh(Entity):
                                                """
                                                Next next hops
                                                
                                                .. attribute:: link_id_set
                                                
                                                	If link\_id is given
                                                	**type**\: bool
                                                
                                                .. attribute:: ipv4_set
                                                
                                                	If ipv4 address is given
                                                	**type**\: bool
                                                
                                                .. attribute:: link_id
                                                
                                                	link ID of the next next hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	Ipv4 address of the next next hop
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Paths.Nnh, self).__init__()

                                                    self.yang_name = "nnh"
                                                    self.yang_parent_name = "paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                        ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                        ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ])
                                                    self.link_id_set = None
                                                    self.ipv4_set = None
                                                    self.link_id = None
                                                    self.ipv4_address = None
                                                    self._segment_path = lambda: "nnh"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Paths.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                        class UcmpNextHop(Entity):
                                            """
                                            UCMP first hops toward the prefix
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: total_ucmp_distance
                                            
                                            	Distance to the network via this UCMP next hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop, self).__init__()

                                                self.yang_name = "ucmp-next-hop"
                                                self.yang_parent_name = "backup"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('total_ucmp_distance', (YLeaf(YType.uint32, 'total-ucmp-distance'), ['int'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.total_ucmp_distance = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._segment_path = lambda: "ucmp-next-hop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'total_ucmp_distance', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "ucmp-next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                        class MulticastPath(Entity):
                                            """
                                            Multicast intact first hops toward the prefix
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\: str
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit>`
                                            
                                            .. attribute:: nnh
                                            
                                            	Next next hops
                                            	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.Nnh>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath, self).__init__()

                                                self.yang_name = "multicast-path"
                                                self.yang_parent_name = "backup"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.Nnh))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.tunnel_interface = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"

                                                self.uloop_explicit = YList(self)
                                                self.nnh = YList(self)
                                                self._segment_path = lambda: "multicast-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "multicast-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "multicast-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                        ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                        ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                        ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                        ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                        ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                    ])
                                                    self.repair_element_node_id = None
                                                    self.repair_ipv4_addr = None
                                                    self.repair_ipv6_addr = None
                                                    self.repair_label = None
                                                    self.repair_element_type = None
                                                    self.repair_strict_spf_label = None
                                                    self._segment_path = lambda: "uloop-explicit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class Nnh(Entity):
                                                """
                                                Next next hops
                                                
                                                .. attribute:: link_id_set
                                                
                                                	If link\_id is given
                                                	**type**\: bool
                                                
                                                .. attribute:: ipv4_set
                                                
                                                	If ipv4 address is given
                                                	**type**\: bool
                                                
                                                .. attribute:: link_id
                                                
                                                	link ID of the next next hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	Ipv4 address of the next next hop
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.Nnh, self).__init__()

                                                    self.yang_name = "nnh"
                                                    self.yang_parent_name = "multicast-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                        ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                        ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ])
                                                    self.link_id_set = None
                                                    self.ipv4_set = None
                                                    self.link_id = None
                                                    self.ipv4_address = None
                                                    self._segment_path = lambda: "nnh"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastPath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                        class SrtePath(Entity):
                                            """
                                            SR\-TE native first hops toward the prefix
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\: str
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit>`
                                            
                                            .. attribute:: nnh
                                            
                                            	Next next hops
                                            	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.Nnh>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.SrtePath, self).__init__()

                                                self.yang_name = "srte-path"
                                                self.yang_parent_name = "backup"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.Nnh))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.tunnel_interface = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"

                                                self.uloop_explicit = YList(self)
                                                self.nnh = YList(self)
                                                self._segment_path = lambda: "srte-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.SrtePath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "srte-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "srte-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                        ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                        ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                        ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                        ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                        ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                    ])
                                                    self.repair_element_node_id = None
                                                    self.repair_ipv4_addr = None
                                                    self.repair_ipv6_addr = None
                                                    self.repair_label = None
                                                    self.repair_element_type = None
                                                    self.repair_strict_spf_label = None
                                                    self._segment_path = lambda: "uloop-explicit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class Nnh(Entity):
                                                """
                                                Next next hops
                                                
                                                .. attribute:: link_id_set
                                                
                                                	If link\_id is given
                                                	**type**\: bool
                                                
                                                .. attribute:: ipv4_set
                                                
                                                	If ipv4 address is given
                                                	**type**\: bool
                                                
                                                .. attribute:: link_id
                                                
                                                	link ID of the next next hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	Ipv4 address of the next next hop
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.Nnh, self).__init__()

                                                    self.yang_name = "nnh"
                                                    self.yang_parent_name = "srte-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                        ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                        ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ])
                                                    self.link_id_set = None
                                                    self.ipv4_set = None
                                                    self.link_id = None
                                                    self.ipv4_address = None
                                                    self._segment_path = lambda: "nnh"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.SrtePath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                        class ExplicitPath(Entity):
                                            """
                                            SR microloop avoidance paths
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\: str
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit>`
                                            
                                            .. attribute:: nnh
                                            
                                            	Next next hops
                                            	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.Nnh>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath, self).__init__()

                                                self.yang_name = "explicit-path"
                                                self.yang_parent_name = "backup"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.Nnh))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.tunnel_interface = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"

                                                self.uloop_explicit = YList(self)
                                                self.nnh = YList(self)
                                                self._segment_path = lambda: "explicit-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "explicit-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "explicit-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                        ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                        ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                        ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                        ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                        ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                    ])
                                                    self.repair_element_node_id = None
                                                    self.repair_ipv4_addr = None
                                                    self.repair_ipv6_addr = None
                                                    self.repair_label = None
                                                    self.repair_element_type = None
                                                    self.repair_strict_spf_label = None
                                                    self._segment_path = lambda: "uloop-explicit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class Nnh(Entity):
                                                """
                                                Next next hops
                                                
                                                .. attribute:: link_id_set
                                                
                                                	If link\_id is given
                                                	**type**\: bool
                                                
                                                .. attribute:: ipv4_set
                                                
                                                	If ipv4 address is given
                                                	**type**\: bool
                                                
                                                .. attribute:: link_id
                                                
                                                	link ID of the next next hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	Ipv4 address of the next next hop
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.Nnh, self).__init__()

                                                    self.yang_name = "nnh"
                                                    self.yang_parent_name = "explicit-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                        ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                        ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ])
                                                    self.link_id_set = None
                                                    self.ipv4_set = None
                                                    self.link_id = None
                                                    self.ipv4_address = None
                                                    self._segment_path = lambda: "nnh"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.ExplicitPath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                        class Source(Entity):
                                            """
                                            Sources advertising the prefix
                                            
                                            .. attribute:: source_lsp_id
                                            
                                            	ID of the LSP advertising the prefix
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                            
                                            .. attribute:: source_address
                                            
                                            	Source address of the IS advertising the prefix
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: tags
                                            
                                            	Tags associated with the prefix item
                                            	**type**\: list of  		 :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Source.Tags>`
                                            
                                            .. attribute:: nodal_sid
                                            
                                            	Nodal SIDs with the prefix item
                                            	**type**\: list of  		 :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Source.NodalSid>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "backup"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tags", ("tags", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Source.Tags)), ("nodal-sid", ("nodal_sid", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Source.NodalSid))])
                                                self._leafs = OrderedDict([
                                                    ('source_lsp_id', (YLeaf(YType.str, 'source-lsp-id'), ['str'])),
                                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                                ])
                                                self.source_lsp_id = None
                                                self.source_address = None

                                                self.tags = YList(self)
                                                self.nodal_sid = YList(self)
                                                self._segment_path = lambda: "source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Source, [u'source_lsp_id', u'source_address'], name, value)


                                            class Tags(Entity):
                                                """
                                                Tags associated with the prefix item
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Source.Tags, self).__init__()

                                                    self.yang_name = "tags"
                                                    self.yang_parent_name = "source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "tags"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Source.Tags, [u'entry'], name, value)


                                            class NodalSid(Entity):
                                                """
                                                Nodal SIDs with the prefix item
                                                
                                                .. attribute:: sid_value
                                                
                                                	sid value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rflag
                                                
                                                	rflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nflag
                                                
                                                	nflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pflag
                                                
                                                	pflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: eflag
                                                
                                                	eflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: vflag
                                                
                                                	vflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: lflag
                                                
                                                	lflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: algorithm
                                                
                                                	algorithm
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Source.NodalSid, self).__init__()

                                                    self.yang_name = "nodal-sid"
                                                    self.yang_parent_name = "source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('sid_value', (YLeaf(YType.uint32, 'sid-value'), ['int'])),
                                                        ('rflag', (YLeaf(YType.uint8, 'rflag'), ['int'])),
                                                        ('nflag', (YLeaf(YType.uint8, 'nflag'), ['int'])),
                                                        ('pflag', (YLeaf(YType.uint8, 'pflag'), ['int'])),
                                                        ('eflag', (YLeaf(YType.uint8, 'eflag'), ['int'])),
                                                        ('vflag', (YLeaf(YType.uint8, 'vflag'), ['int'])),
                                                        ('lflag', (YLeaf(YType.uint8, 'lflag'), ['int'])),
                                                        ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                                    ])
                                                    self.sid_value = None
                                                    self.rflag = None
                                                    self.nflag = None
                                                    self.pflag = None
                                                    self.eflag = None
                                                    self.vflag = None
                                                    self.lflag = None
                                                    self.algorithm = None
                                                    self._segment_path = lambda: "nodal-sid"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.Source.NodalSid, [u'sid_value', u'rflag', u'nflag', u'pflag', u'eflag', u'vflag', u'lflag', u'algorithm'], name, value)


                                        class MulticastSource(Entity):
                                            """
                                            Multicast\-intact sources advertising the prefix
                                            
                                            .. attribute:: source_lsp_id
                                            
                                            	ID of the LSP advertising the prefix
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                            
                                            .. attribute:: source_address
                                            
                                            	Source address of the IS advertising the prefix
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: tags
                                            
                                            	Tags associated with the prefix item
                                            	**type**\: list of  		 :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastSource.Tags>`
                                            
                                            .. attribute:: nodal_sid
                                            
                                            	Nodal SIDs with the prefix item
                                            	**type**\: list of  		 :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastSource, self).__init__()

                                                self.yang_name = "multicast-source"
                                                self.yang_parent_name = "backup"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tags", ("tags", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastSource.Tags)), ("nodal-sid", ("nodal_sid", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid))])
                                                self._leafs = OrderedDict([
                                                    ('source_lsp_id', (YLeaf(YType.str, 'source-lsp-id'), ['str'])),
                                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                                ])
                                                self.source_lsp_id = None
                                                self.source_address = None

                                                self.tags = YList(self)
                                                self.nodal_sid = YList(self)
                                                self._segment_path = lambda: "multicast-source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastSource, [u'source_lsp_id', u'source_address'], name, value)


                                            class Tags(Entity):
                                                """
                                                Tags associated with the prefix item
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastSource.Tags, self).__init__()

                                                    self.yang_name = "tags"
                                                    self.yang_parent_name = "multicast-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "tags"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastSource.Tags, [u'entry'], name, value)


                                            class NodalSid(Entity):
                                                """
                                                Nodal SIDs with the prefix item
                                                
                                                .. attribute:: sid_value
                                                
                                                	sid value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rflag
                                                
                                                	rflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nflag
                                                
                                                	nflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pflag
                                                
                                                	pflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: eflag
                                                
                                                	eflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: vflag
                                                
                                                	vflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: lflag
                                                
                                                	lflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: algorithm
                                                
                                                	algorithm
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid, self).__init__()

                                                    self.yang_name = "nodal-sid"
                                                    self.yang_parent_name = "multicast-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('sid_value', (YLeaf(YType.uint32, 'sid-value'), ['int'])),
                                                        ('rflag', (YLeaf(YType.uint8, 'rflag'), ['int'])),
                                                        ('nflag', (YLeaf(YType.uint8, 'nflag'), ['int'])),
                                                        ('pflag', (YLeaf(YType.uint8, 'pflag'), ['int'])),
                                                        ('eflag', (YLeaf(YType.uint8, 'eflag'), ['int'])),
                                                        ('vflag', (YLeaf(YType.uint8, 'vflag'), ['int'])),
                                                        ('lflag', (YLeaf(YType.uint8, 'lflag'), ['int'])),
                                                        ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                                    ])
                                                    self.sid_value = None
                                                    self.rflag = None
                                                    self.nflag = None
                                                    self.pflag = None
                                                    self.eflag = None
                                                    self.vflag = None
                                                    self.lflag = None
                                                    self.algorithm = None
                                                    self._segment_path = lambda: "nodal-sid"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid, [u'sid_value', u'rflag', u'nflag', u'pflag', u'eflag', u'vflag', u'lflag', u'algorithm'], name, value)


                            class PerLevelAdvertisingDetail(Entity):
                                """
                                Per level details of how the local system
                                advertises the prefix
                                
                                .. attribute:: summarization_status
                                
                                	Status of summarization for the prefix
                                	**type**\:  :py:class:`SummarizationStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.PerLevelAdvertisingDetail.SummarizationStatus>`
                                
                                .. attribute:: level
                                
                                	Level in which the prefix is advertised
                                	**type**\:  :py:class:`IsisLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevel>`
                                
                                .. attribute:: advertising_origin
                                
                                	The origin of the advertisement
                                	**type**\:  :py:class:`IsisShRouteAdvOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisShRouteAdvOrigin>`
                                
                                .. attribute:: metric
                                
                                	Metric with which the prefix is advertised
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_propagated
                                
                                	Has the prefix been propagated from another level?
                                	**type**\: bool
                                
                                .. attribute:: is_external_metric
                                
                                	Is the metric an external metric?
                                	**type**\: bool
                                
                                .. attribute:: is_external_reachability
                                
                                	Is the prefix external to the IS\-IS domain?
                                	**type**\: bool
                                
                                .. attribute:: is_interarea
                                
                                	Is the up/down bit set?
                                	**type**\: bool
                                
                                .. attribute:: tags
                                
                                	Tags associated with the prefix
                                	**type**\: list of  		 :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.PerLevelAdvertisingDetail.Tags>`
                                
                                .. attribute:: nodal_sid
                                
                                	Nodal SIDs with the prefix item
                                	**type**\: list of  		 :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.PerLevelAdvertisingDetail.NodalSid>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.PerLevelAdvertisingDetail, self).__init__()

                                    self.yang_name = "per-level-advertising-detail"
                                    self.yang_parent_name = "ipv4frr-backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("summarization-status", ("summarization_status", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.PerLevelAdvertisingDetail.SummarizationStatus)), ("tags", ("tags", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.PerLevelAdvertisingDetail.Tags)), ("nodal-sid", ("nodal_sid", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.PerLevelAdvertisingDetail.NodalSid))])
                                    self._leafs = OrderedDict([
                                        ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisLevel', '')])),
                                        ('advertising_origin', (YLeaf(YType.enumeration, 'advertising-origin'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisShRouteAdvOrigin', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('is_propagated', (YLeaf(YType.boolean, 'is-propagated'), ['bool'])),
                                        ('is_external_metric', (YLeaf(YType.boolean, 'is-external-metric'), ['bool'])),
                                        ('is_external_reachability', (YLeaf(YType.boolean, 'is-external-reachability'), ['bool'])),
                                        ('is_interarea', (YLeaf(YType.boolean, 'is-interarea'), ['bool'])),
                                    ])
                                    self.level = None
                                    self.advertising_origin = None
                                    self.metric = None
                                    self.is_propagated = None
                                    self.is_external_metric = None
                                    self.is_external_reachability = None
                                    self.is_interarea = None

                                    self.summarization_status = Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.PerLevelAdvertisingDetail.SummarizationStatus()
                                    self.summarization_status.parent = self
                                    self._children_name_map["summarization_status"] = "summarization-status"

                                    self.tags = YList(self)
                                    self.nodal_sid = YList(self)
                                    self._segment_path = lambda: "per-level-advertising-detail"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.PerLevelAdvertisingDetail, [u'level', u'advertising_origin', u'metric', u'is_propagated', u'is_external_metric', u'is_external_reachability', u'is_interarea'], name, value)


                                class SummarizationStatus(Entity):
                                    """
                                    Status of summarization for the prefix
                                    
                                    .. attribute:: summary_prefix
                                    
                                    	Summarizing Prefix
                                    	**type**\:  :py:class:`SummaryPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	IsValid
                                    	**type**\:  :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.PerLevelAdvertisingDetail.SummarizationStatus, self).__init__()

                                        self.yang_name = "summarization-status"
                                        self.yang_parent_name = "per-level-advertising-detail"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("summary-prefix", ("summary_prefix", Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', (YLeaf(YType.enumeration, 'is-valid'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisValid', '')])),
                                        ])
                                        self.is_valid = None

                                        self.summary_prefix = Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix()
                                        self.summary_prefix.parent = self
                                        self._children_name_map["summary_prefix"] = "summary-prefix"
                                        self._segment_path = lambda: "summarization-status"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.PerLevelAdvertisingDetail.SummarizationStatus, [u'is_valid'], name, value)


                                    class SummaryPrefix(Entity):
                                        """
                                        Summarizing Prefix
                                        
                                        .. attribute:: prefix
                                        
                                        	prefix
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	prefix length
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix, self).__init__()

                                            self.yang_name = "summary-prefix"
                                            self.yang_parent_name = "summarization-status"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                            ])
                                            self.prefix = None
                                            self.prefix_length = None
                                            self._segment_path = lambda: "summary-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix, [u'prefix', u'prefix_length'], name, value)


                                class Tags(Entity):
                                    """
                                    Tags associated with the prefix
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.PerLevelAdvertisingDetail.Tags, self).__init__()

                                        self.yang_name = "tags"
                                        self.yang_parent_name = "per-level-advertising-detail"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "tags"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.PerLevelAdvertisingDetail.Tags, [u'entry'], name, value)


                                class NodalSid(Entity):
                                    """
                                    Nodal SIDs with the prefix item
                                    
                                    .. attribute:: sid_value
                                    
                                    	sid value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rflag
                                    
                                    	rflag
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: nflag
                                    
                                    	nflag
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: pflag
                                    
                                    	pflag
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: eflag
                                    
                                    	eflag
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vflag
                                    
                                    	vflag
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: lflag
                                    
                                    	lflag
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: algorithm
                                    
                                    	algorithm
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.PerLevelAdvertisingDetail.NodalSid, self).__init__()

                                        self.yang_name = "nodal-sid"
                                        self.yang_parent_name = "per-level-advertising-detail"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('sid_value', (YLeaf(YType.uint32, 'sid-value'), ['int'])),
                                            ('rflag', (YLeaf(YType.uint8, 'rflag'), ['int'])),
                                            ('nflag', (YLeaf(YType.uint8, 'nflag'), ['int'])),
                                            ('pflag', (YLeaf(YType.uint8, 'pflag'), ['int'])),
                                            ('eflag', (YLeaf(YType.uint8, 'eflag'), ['int'])),
                                            ('vflag', (YLeaf(YType.uint8, 'vflag'), ['int'])),
                                            ('lflag', (YLeaf(YType.uint8, 'lflag'), ['int'])),
                                            ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                        ])
                                        self.sid_value = None
                                        self.rflag = None
                                        self.nflag = None
                                        self.pflag = None
                                        self.eflag = None
                                        self.vflag = None
                                        self.lflag = None
                                        self.algorithm = None
                                        self._segment_path = lambda: "nodal-sid"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4frrBackups.Ipv4frrBackup.PerLevelAdvertisingDetail.NodalSid, [u'sid_value', u'rflag', u'nflag', u'pflag', u'eflag', u'vflag', u'lflag', u'algorithm'], name, value)


                    class Ipv4FlexRouteTables(Entity):
                        """
                        IPv4 Flex\-Algo local route tables
                        
                        .. attribute:: ipv4_flex_route_table
                        
                        	IPv4 Flex\-Algo local route table
                        	**type**\: list of  		 :py:class:`Ipv4FlexRouteTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables, self).__init__()

                            self.yang_name = "ipv4-flex-route-tables"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4-flex-route-table", ("ipv4_flex_route_table", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable))])
                            self._leafs = OrderedDict()

                            self.ipv4_flex_route_table = YList(self)
                            self._segment_path = lambda: "ipv4-flex-route-tables"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables, [], name, value)


                        class Ipv4FlexRouteTable(Entity):
                            """
                            IPv4 Flex\-Algo local route table
                            
                            .. attribute:: flex_alg  (key)
                            
                            	Flex Algo
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ipv4_flex_route
                            
                            	An IPv4 route known to IS\-IS
                            	**type**\: list of  		 :py:class:`Ipv4FlexRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable, self).__init__()

                                self.yang_name = "ipv4-flex-route-table"
                                self.yang_parent_name = "ipv4-flex-route-tables"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['flex_alg']
                                self._child_classes = OrderedDict([("ipv4-flex-route", ("ipv4_flex_route", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute))])
                                self._leafs = OrderedDict([
                                    ('flex_alg', (YLeaf(YType.uint32, 'flex-alg'), ['int'])),
                                ])
                                self.flex_alg = None

                                self.ipv4_flex_route = YList(self)
                                self._segment_path = lambda: "ipv4-flex-route-table" + "[flex-alg='" + str(self.flex_alg) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable, ['flex_alg'], name, value)


                            class Ipv4FlexRoute(Entity):
                                """
                                An IPv4 route known to IS\-IS
                                
                                .. attribute:: prefix
                                
                                	Prefix
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: prefix_length
                                
                                	Prefix Length
                                	**type**\: int
                                
                                	**range:** 0..32
                                
                                .. attribute:: connected_status
                                
                                	Status of IS\-IS directly connected routes to the prefix
                                	**type**\:  :py:class:`ConnectedStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.ConnectedStatus>`
                                
                                .. attribute:: redistributed_status
                                
                                	Status of other protocols' routes redistributed into IS\-IS
                                	**type**\:  :py:class:`RedistributedStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.RedistributedStatus>`
                                
                                .. attribute:: native_status
                                
                                	Status of native IS\-IS routes to the prefix
                                	**type**\:  :py:class:`NativeStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus>`
                                
                                .. attribute:: per_level_advertising_detail
                                
                                	Per level details of how the local system advertises the prefix
                                	**type**\: list of  		 :py:class:`PerLevelAdvertisingDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.PerLevelAdvertisingDetail>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute, self).__init__()

                                    self.yang_name = "ipv4-flex-route"
                                    self.yang_parent_name = "ipv4-flex-route-table"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("connected-status", ("connected_status", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.ConnectedStatus)), ("redistributed-status", ("redistributed_status", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.RedistributedStatus)), ("native-status", ("native_status", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus)), ("per-level-advertising-detail", ("per_level_advertising_detail", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.PerLevelAdvertisingDetail))])
                                    self._leafs = OrderedDict([
                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                        ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                    ])
                                    self.prefix = None
                                    self.prefix_length = None

                                    self.connected_status = Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.ConnectedStatus()
                                    self.connected_status.parent = self
                                    self._children_name_map["connected_status"] = "connected-status"

                                    self.redistributed_status = Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.RedistributedStatus()
                                    self.redistributed_status.parent = self
                                    self._children_name_map["redistributed_status"] = "redistributed-status"

                                    self.native_status = Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus()
                                    self.native_status.parent = self
                                    self._children_name_map["native_status"] = "native-status"

                                    self.per_level_advertising_detail = YList(self)
                                    self._segment_path = lambda: "ipv4-flex-route"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute, ['prefix', 'prefix_length'], name, value)


                                class ConnectedStatus(Entity):
                                    """
                                    Status of IS\-IS directly connected routes to the
                                    prefix
                                    
                                    .. attribute:: connected_details
                                    
                                    	Details of the directly connected prefix
                                    	**type**\:  :py:class:`ConnectedDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.ConnectedStatus.ConnectedDetails>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	IsValid
                                    	**type**\:  :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.ConnectedStatus, self).__init__()

                                        self.yang_name = "connected-status"
                                        self.yang_parent_name = "ipv4-flex-route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("connected-details", ("connected_details", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.ConnectedStatus.ConnectedDetails))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', (YLeaf(YType.enumeration, 'is-valid'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisValid', '')])),
                                        ])
                                        self.is_valid = None

                                        self.connected_details = Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.ConnectedStatus.ConnectedDetails()
                                        self.connected_details.parent = self
                                        self._children_name_map["connected_details"] = "connected-details"
                                        self._segment_path = lambda: "connected-status"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.ConnectedStatus, [u'is_valid'], name, value)


                                    class ConnectedDetails(Entity):
                                        """
                                        Details of the directly connected prefix
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.ConnectedStatus.ConnectedDetails.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.ConnectedStatus.ConnectedDetails, self).__init__()

                                            self.yang_name = "connected-details"
                                            self.yang_parent_name = "connected-status"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.ConnectedStatus.ConnectedDetails.Interface))])
                                            self._leafs = OrderedDict()

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "connected-details"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.ConnectedStatus.ConnectedDetails, [], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.ConnectedStatus.ConnectedDetails.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "connected-details"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "interface"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.ConnectedStatus.ConnectedDetails.Interface, [u'entry'], name, value)


                                class RedistributedStatus(Entity):
                                    """
                                    Status of other protocols' routes redistributed
                                    into IS\-IS
                                    
                                    .. attribute:: redistribution_details
                                    
                                    	Per level details of the redistributed route
                                    	**type**\:  :py:class:`RedistributionDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.RedistributedStatus.RedistributionDetails>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	IsValid
                                    	**type**\:  :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.RedistributedStatus, self).__init__()

                                        self.yang_name = "redistributed-status"
                                        self.yang_parent_name = "ipv4-flex-route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("redistribution-details", ("redistribution_details", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.RedistributedStatus.RedistributionDetails))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', (YLeaf(YType.enumeration, 'is-valid'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisValid', '')])),
                                        ])
                                        self.is_valid = None

                                        self.redistribution_details = Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.RedistributedStatus.RedistributionDetails()
                                        self.redistribution_details.parent = self
                                        self._children_name_map["redistribution_details"] = "redistribution-details"
                                        self._segment_path = lambda: "redistributed-status"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.RedistributedStatus, [u'is_valid'], name, value)


                                    class RedistributionDetails(Entity):
                                        """
                                        Per level details of the redistributed route
                                        
                                        .. attribute:: isis_sh_route_redist_detail
                                        
                                        	isis sh route redist detail
                                        	**type**\: list of  		 :py:class:`IsisShRouteRedistDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.RedistributedStatus.RedistributionDetails, self).__init__()

                                            self.yang_name = "redistribution-details"
                                            self.yang_parent_name = "redistributed-status"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("isis-sh-route-redist-detail", ("isis_sh_route_redist_detail", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail))])
                                            self._leafs = OrderedDict()

                                            self.isis_sh_route_redist_detail = YList(self)
                                            self._segment_path = lambda: "redistribution-details"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.RedistributedStatus.RedistributionDetails, [], name, value)


                                        class IsisShRouteRedistDetail(Entity):
                                            """
                                            isis sh route redist detail
                                            
                                            .. attribute:: owner
                                            
                                            	Protocol redistributing the route
                                            	**type**\:  :py:class:`Owner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner>`
                                            
                                            .. attribute:: level
                                            
                                            	Level into which the route is redistributed
                                            	**type**\:  :py:class:`IsisLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevel>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail, self).__init__()

                                                self.yang_name = "isis-sh-route-redist-detail"
                                                self.yang_parent_name = "redistribution-details"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("owner", ("owner", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner))])
                                                self._leafs = OrderedDict([
                                                    ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisLevel', '')])),
                                                ])
                                                self.level = None

                                                self.owner = Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner()
                                                self.owner.parent = self
                                                self._children_name_map["owner"] = "owner"
                                                self._segment_path = lambda: "isis-sh-route-redist-detail"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail, [u'level'], name, value)


                                            class Owner(Entity):
                                                """
                                                Protocol redistributing the route
                                                
                                                .. attribute:: protocol
                                                
                                                	Protocol
                                                	**type**\:  :py:class:`IsisRedistProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisRedistProto>`
                                                
                                                .. attribute:: isis_instance_id
                                                
                                                	IS\-IS instance identifier
                                                	**type**\: str
                                                
                                                .. attribute:: ospf_process_id
                                                
                                                	OSPF process identifier
                                                	**type**\: str
                                                
                                                .. attribute:: ospfv3_process_id
                                                
                                                	OSPFv3 process identifier
                                                	**type**\: str
                                                
                                                .. attribute:: bgp_as_number
                                                
                                                	BGP Autonomous System number
                                                	**type**\: str
                                                
                                                .. attribute:: eigrp_as_number
                                                
                                                	EIGRP Autonomous System number
                                                	**type**\: str
                                                
                                                .. attribute:: application_name
                                                
                                                	Application Name
                                                	**type**\: str
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner, self).__init__()

                                                    self.yang_name = "owner"
                                                    self.yang_parent_name = "isis-sh-route-redist-detail"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisRedistProto', '')])),
                                                        ('isis_instance_id', (YLeaf(YType.str, 'isis-instance-id'), ['str'])),
                                                        ('ospf_process_id', (YLeaf(YType.str, 'ospf-process-id'), ['str'])),
                                                        ('ospfv3_process_id', (YLeaf(YType.str, 'ospfv3-process-id'), ['str'])),
                                                        ('bgp_as_number', (YLeaf(YType.str, 'bgp-as-number'), ['str'])),
                                                        ('eigrp_as_number', (YLeaf(YType.str, 'eigrp-as-number'), ['str'])),
                                                        ('application_name', (YLeaf(YType.str, 'application-name'), ['str'])),
                                                    ])
                                                    self.protocol = None
                                                    self.isis_instance_id = None
                                                    self.ospf_process_id = None
                                                    self.ospfv3_process_id = None
                                                    self.bgp_as_number = None
                                                    self.eigrp_as_number = None
                                                    self.application_name = None
                                                    self._segment_path = lambda: "owner"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner, [u'protocol', u'isis_instance_id', u'ospf_process_id', u'ospfv3_process_id', u'bgp_as_number', u'eigrp_as_number', u'application_name'], name, value)


                                class NativeStatus(Entity):
                                    """
                                    Status of native IS\-IS routes to the prefix
                                    
                                    .. attribute:: native_details
                                    
                                    	Details of the native route
                                    	**type**\:  :py:class:`NativeDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	IsValid
                                    	**type**\:  :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus, self).__init__()

                                        self.yang_name = "native-status"
                                        self.yang_parent_name = "ipv4-flex-route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("native-details", ("native_details", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', (YLeaf(YType.enumeration, 'is-valid'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisValid', '')])),
                                        ])
                                        self.is_valid = None

                                        self.native_details = Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails()
                                        self.native_details.parent = self
                                        self._children_name_map["native_details"] = "native-details"
                                        self._segment_path = lambda: "native-status"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus, [u'is_valid'], name, value)


                                    class NativeDetails(Entity):
                                        """
                                        Details of the native route
                                        
                                        .. attribute:: primary
                                        
                                        	Primary paths to prefix
                                        	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary>`
                                        
                                        .. attribute:: priority
                                        
                                        	Relative importance of the prefix
                                        	**type**\:  :py:class:`IsisPrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisPrefixPriority>`
                                        
                                        .. attribute:: backup
                                        
                                        	Backup paths to prefix
                                        	**type**\: list of  		 :py:class:`Backup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails, self).__init__()

                                            self.yang_name = "native-details"
                                            self.yang_parent_name = "native-status"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("primary", ("primary", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary)), ("backup", ("backup", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup))])
                                            self._leafs = OrderedDict([
                                                ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisPrefixPriority', '')])),
                                            ])
                                            self.priority = None

                                            self.primary = Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary()
                                            self.primary.parent = self
                                            self._children_name_map["primary"] = "primary"

                                            self.backup = YList(self)
                                            self._segment_path = lambda: "native-details"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails, [u'priority'], name, value)


                                        class Primary(Entity):
                                            """
                                            Primary paths to prefix
                                            
                                            .. attribute:: origin
                                            
                                            	Origin of route
                                            	**type**\:  :py:class:`IsisPrefixOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisPrefixOrigin>`
                                            
                                            .. attribute:: metric
                                            
                                            	Distance to network
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: multicast_metric
                                            
                                            	Multicast\-intact distance to network
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_external_metric
                                            
                                            	Is the metric an external metric?
                                            	**type**\: bool
                                            
                                            .. attribute:: administrative_distance
                                            
                                            	Administrative Distance
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: paths
                                            
                                            	First hops toward the prefix
                                            	**type**\: list of  		 :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Paths>`
                                            
                                            .. attribute:: ucmp_next_hop
                                            
                                            	UCMP first hops toward the prefix
                                            	**type**\: list of  		 :py:class:`UcmpNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.UcmpNextHop>`
                                            
                                            .. attribute:: multicast_path
                                            
                                            	Multicast intact first hops toward the prefix
                                            	**type**\: list of  		 :py:class:`MulticastPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath>`
                                            
                                            .. attribute:: srte_path
                                            
                                            	SR\-TE native first hops toward the prefix
                                            	**type**\: list of  		 :py:class:`SrtePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath>`
                                            
                                            .. attribute:: explicit_path
                                            
                                            	SR microloop avoidance paths
                                            	**type**\: list of  		 :py:class:`ExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath>`
                                            
                                            .. attribute:: source
                                            
                                            	Sources advertising the prefix
                                            	**type**\: list of  		 :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Source>`
                                            
                                            .. attribute:: multicast_source
                                            
                                            	Multicast\-intact sources advertising the prefix
                                            	**type**\: list of  		 :py:class:`MulticastSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastSource>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary, self).__init__()

                                                self.yang_name = "primary"
                                                self.yang_parent_name = "native-details"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("paths", ("paths", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Paths)), ("ucmp-next-hop", ("ucmp_next_hop", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.UcmpNextHop)), ("multicast-path", ("multicast_path", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath)), ("srte-path", ("srte_path", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath)), ("explicit-path", ("explicit_path", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath)), ("source", ("source", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Source)), ("multicast-source", ("multicast_source", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastSource))])
                                                self._leafs = OrderedDict([
                                                    ('origin', (YLeaf(YType.enumeration, 'origin'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisPrefixOrigin', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('multicast_metric', (YLeaf(YType.uint32, 'multicast-metric'), ['int'])),
                                                    ('is_external_metric', (YLeaf(YType.boolean, 'is-external-metric'), ['bool'])),
                                                    ('administrative_distance', (YLeaf(YType.uint16, 'administrative-distance'), ['int'])),
                                                ])
                                                self.origin = None
                                                self.metric = None
                                                self.multicast_metric = None
                                                self.is_external_metric = None
                                                self.administrative_distance = None

                                                self.paths = YList(self)
                                                self.ucmp_next_hop = YList(self)
                                                self.multicast_path = YList(self)
                                                self.srte_path = YList(self)
                                                self.explicit_path = YList(self)
                                                self.source = YList(self)
                                                self.multicast_source = YList(self)
                                                self._segment_path = lambda: "primary"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary, [u'origin', u'metric', u'multicast_metric', u'is_external_metric', u'administrative_distance'], name, value)


                                            class Paths(Entity):
                                                """
                                                First hops toward the prefix
                                                
                                                .. attribute:: frr_backup
                                                
                                                	FRR backup for this path
                                                	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Paths.FrrBackup>`
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: tag
                                                
                                                	Tag associated with the path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_interface
                                                
                                                	Explicit path tunnel interface
                                                	**type**\: str
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_te_tunnel_interface
                                                
                                                	Is path via a TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: is_sr_exclude_tunnel_interface
                                                
                                                	Is path via an SR\-exclude TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: uloop_explicit
                                                
                                                	Uloop Explicit List
                                                	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit>`
                                                
                                                .. attribute:: nnh
                                                
                                                	Next next hops
                                                	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Paths.Nnh>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Paths, self).__init__()

                                                    self.yang_name = "paths"
                                                    self.yang_parent_name = "primary"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Paths.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Paths.Nnh))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                        ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.neighbor_snpa = None
                                                    self.tag = None
                                                    self.tunnel_interface = None
                                                    self.segment_routing_sid_value = None
                                                    self.weight = None
                                                    self.is_te_tunnel_interface = None
                                                    self.is_sr_exclude_tunnel_interface = None

                                                    self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Paths.FrrBackup()
                                                    self.frr_backup.parent = self
                                                    self._children_name_map["frr_backup"] = "frr-backup"

                                                    self.uloop_explicit = YList(self)
                                                    self.nnh = YList(self)
                                                    self._segment_path = lambda: "paths"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Paths, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                                class FrrBackup(Entity):
                                                    """
                                                    FRR backup for this path
                                                    
                                                    .. attribute:: neighbor_id
                                                    
                                                    	Next hop neighbor ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: egress_interface
                                                    
                                                    	Interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Next hop neighbor's forwarding address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: tunnel_egress_interface
                                                    
                                                    	Tunnel Interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_snpa
                                                    
                                                    	Next hop neighbor's SNPA
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_system_id
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_id
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: remote_lfa_system_pid
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_pid
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: total_backup_distance
                                                    
                                                    	Distance to the network via this backup path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value
                                                    
                                                    	Segment routing sid value received from first hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: num_sid
                                                    
                                                    	Number of SIDs in TI\-LFA/rLFA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_repair_list_size
                                                    
                                                    	Backup Repair List Size
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tilfa_computation
                                                    
                                                    	Ti LFA computation which provided backup path
                                                    	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                    
                                                    .. attribute:: prefix_source_node_id
                                                    
                                                    	PrefixSourceNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: is_downstream
                                                    
                                                    	Is the backup path via downstream node?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_lc_disjoint
                                                    
                                                    	Is the backup path line card disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_node_protecting
                                                    
                                                    	Is the backup path node protecting?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_primary_path
                                                    
                                                    	Is the backup path an ECMP to the network?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_srlg_disjoint
                                                    
                                                    	Is the backup path SRLG disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_remote_lfa
                                                    
                                                    	Is the backup path via a Remote LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_epcfrr_lfa
                                                    
                                                    	Is the backup path via a TI\-LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_strict_spflfa
                                                    
                                                    	Is the backup path TI\-LFA strict SPF?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_requested
                                                    
                                                    	Is SR TE tunnel requested
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight configured on the interface
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value_entry
                                                    
                                                    	Segment routing sid values for TI\-LFA/rLFA
                                                    	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry>`
                                                    
                                                    .. attribute:: backup_repair
                                                    
                                                    	Backup Repair List
                                                    	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Paths.FrrBackup, self).__init__()

                                                        self.yang_name = "frr-backup"
                                                        self.yang_parent_name = "paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair))])
                                                        self._leafs = OrderedDict([
                                                            ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                            ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                            ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                            ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                            ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                            ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                            ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                            ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                            ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                            ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                            ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                            ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                            ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                            ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                            ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                            ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                            ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                            ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                            ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                            ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                            ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                            ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                            ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                            ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ])
                                                        self.neighbor_id = None
                                                        self.egress_interface = None
                                                        self.neighbor_address = None
                                                        self.tunnel_egress_interface = None
                                                        self.neighbor_snpa = None
                                                        self.remote_lfa_system_id = None
                                                        self.remote_lfa_router_id = None
                                                        self.remote_lfa_system_pid = None
                                                        self.remote_lfa_router_pid = None
                                                        self.total_backup_distance = None
                                                        self.segment_routing_sid_value = None
                                                        self.num_sid = None
                                                        self.backup_repair_list_size = None
                                                        self.tilfa_computation = None
                                                        self.prefix_source_node_id = None
                                                        self.is_downstream = None
                                                        self.is_lc_disjoint = None
                                                        self.is_node_protecting = None
                                                        self.is_primary_path = None
                                                        self.is_srlg_disjoint = None
                                                        self.is_remote_lfa = None
                                                        self.is_epcfrr_lfa = None
                                                        self.is_strict_spflfa = None
                                                        self.is_tunnel_requested = None
                                                        self.weight = None

                                                        self.segment_routing_sid_value_entry = YList(self)
                                                        self.backup_repair = YList(self)
                                                        self._segment_path = lambda: "frr-backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Paths.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                    class SegmentRoutingSidValueEntry(Entity):
                                                        """
                                                        Segment routing sid values for TI\-LFA/rLFA
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                            self.yang_name = "segment-routing-sid-value-entry"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                    class BackupRepair(Entity):
                                                        """
                                                        Backup Repair List
                                                        
                                                        .. attribute:: repair_element_node_id
                                                        
                                                        	RepairElementNodeID
                                                        	**type**\: str
                                                        
                                                        .. attribute:: repair_ipv4_addr
                                                        
                                                        	RepairIPv4Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_ipv6_addr
                                                        
                                                        	RepairIPv6Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_label
                                                        
                                                        	Repair Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_element_type
                                                        
                                                        	Repair Element Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_strict_spf_label
                                                        
                                                        	Repair Strict SPF Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair, self).__init__()

                                                            self.yang_name = "backup-repair"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                                ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                                ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                                ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                                ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                                ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                            ])
                                                            self.repair_element_node_id = None
                                                            self.repair_ipv4_addr = None
                                                            self.repair_ipv6_addr = None
                                                            self.repair_label = None
                                                            self.repair_element_type = None
                                                            self.repair_strict_spf_label = None
                                                            self._segment_path = lambda: "backup-repair"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class UloopExplicit(Entity):
                                                    """
                                                    Uloop Explicit List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit, self).__init__()

                                                        self.yang_name = "uloop-explicit"
                                                        self.yang_parent_name = "paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "uloop-explicit"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class Nnh(Entity):
                                                    """
                                                    Next next hops
                                                    
                                                    .. attribute:: link_id_set
                                                    
                                                    	If link\_id is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ipv4_set
                                                    
                                                    	If ipv4 address is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: link_id
                                                    
                                                    	link ID of the next next hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	Ipv4 address of the next next hop
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Paths.Nnh, self).__init__()

                                                        self.yang_name = "nnh"
                                                        self.yang_parent_name = "paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                            ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                            ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ])
                                                        self.link_id_set = None
                                                        self.ipv4_set = None
                                                        self.link_id = None
                                                        self.ipv4_address = None
                                                        self._segment_path = lambda: "nnh"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Paths.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                            class UcmpNextHop(Entity):
                                                """
                                                UCMP first hops toward the prefix
                                                
                                                .. attribute:: frr_backup
                                                
                                                	FRR backup for this path
                                                	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup>`
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: tag
                                                
                                                	Tag associated with the path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: total_ucmp_distance
                                                
                                                	Distance to the network via this UCMP next hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_te_tunnel_interface
                                                
                                                	Is path via a TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: is_sr_exclude_tunnel_interface
                                                
                                                	Is path via an SR\-exclude TE tunnel
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.UcmpNextHop, self).__init__()

                                                    self.yang_name = "ucmp-next-hop"
                                                    self.yang_parent_name = "primary"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('total_ucmp_distance', (YLeaf(YType.uint32, 'total-ucmp-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                        ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.neighbor_snpa = None
                                                    self.tag = None
                                                    self.total_ucmp_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.weight = None
                                                    self.is_te_tunnel_interface = None
                                                    self.is_sr_exclude_tunnel_interface = None

                                                    self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup()
                                                    self.frr_backup.parent = self
                                                    self._children_name_map["frr_backup"] = "frr-backup"
                                                    self._segment_path = lambda: "ucmp-next-hop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.UcmpNextHop, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'total_ucmp_distance', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                                class FrrBackup(Entity):
                                                    """
                                                    FRR backup for this path
                                                    
                                                    .. attribute:: neighbor_id
                                                    
                                                    	Next hop neighbor ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: egress_interface
                                                    
                                                    	Interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Next hop neighbor's forwarding address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: tunnel_egress_interface
                                                    
                                                    	Tunnel Interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_snpa
                                                    
                                                    	Next hop neighbor's SNPA
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_system_id
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_id
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: remote_lfa_system_pid
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_pid
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: total_backup_distance
                                                    
                                                    	Distance to the network via this backup path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value
                                                    
                                                    	Segment routing sid value received from first hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: num_sid
                                                    
                                                    	Number of SIDs in TI\-LFA/rLFA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_repair_list_size
                                                    
                                                    	Backup Repair List Size
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tilfa_computation
                                                    
                                                    	Ti LFA computation which provided backup path
                                                    	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                    
                                                    .. attribute:: prefix_source_node_id
                                                    
                                                    	PrefixSourceNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: is_downstream
                                                    
                                                    	Is the backup path via downstream node?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_lc_disjoint
                                                    
                                                    	Is the backup path line card disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_node_protecting
                                                    
                                                    	Is the backup path node protecting?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_primary_path
                                                    
                                                    	Is the backup path an ECMP to the network?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_srlg_disjoint
                                                    
                                                    	Is the backup path SRLG disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_remote_lfa
                                                    
                                                    	Is the backup path via a Remote LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_epcfrr_lfa
                                                    
                                                    	Is the backup path via a TI\-LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_strict_spflfa
                                                    
                                                    	Is the backup path TI\-LFA strict SPF?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_requested
                                                    
                                                    	Is SR TE tunnel requested
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight configured on the interface
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value_entry
                                                    
                                                    	Segment routing sid values for TI\-LFA/rLFA
                                                    	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry>`
                                                    
                                                    .. attribute:: backup_repair
                                                    
                                                    	Backup Repair List
                                                    	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup, self).__init__()

                                                        self.yang_name = "frr-backup"
                                                        self.yang_parent_name = "ucmp-next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair))])
                                                        self._leafs = OrderedDict([
                                                            ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                            ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                            ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                            ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                            ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                            ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                            ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                            ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                            ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                            ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                            ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                            ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                            ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                            ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                            ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                            ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                            ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                            ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                            ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                            ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                            ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                            ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                            ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                            ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ])
                                                        self.neighbor_id = None
                                                        self.egress_interface = None
                                                        self.neighbor_address = None
                                                        self.tunnel_egress_interface = None
                                                        self.neighbor_snpa = None
                                                        self.remote_lfa_system_id = None
                                                        self.remote_lfa_router_id = None
                                                        self.remote_lfa_system_pid = None
                                                        self.remote_lfa_router_pid = None
                                                        self.total_backup_distance = None
                                                        self.segment_routing_sid_value = None
                                                        self.num_sid = None
                                                        self.backup_repair_list_size = None
                                                        self.tilfa_computation = None
                                                        self.prefix_source_node_id = None
                                                        self.is_downstream = None
                                                        self.is_lc_disjoint = None
                                                        self.is_node_protecting = None
                                                        self.is_primary_path = None
                                                        self.is_srlg_disjoint = None
                                                        self.is_remote_lfa = None
                                                        self.is_epcfrr_lfa = None
                                                        self.is_strict_spflfa = None
                                                        self.is_tunnel_requested = None
                                                        self.weight = None

                                                        self.segment_routing_sid_value_entry = YList(self)
                                                        self.backup_repair = YList(self)
                                                        self._segment_path = lambda: "frr-backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                    class SegmentRoutingSidValueEntry(Entity):
                                                        """
                                                        Segment routing sid values for TI\-LFA/rLFA
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                            self.yang_name = "segment-routing-sid-value-entry"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                    class BackupRepair(Entity):
                                                        """
                                                        Backup Repair List
                                                        
                                                        .. attribute:: repair_element_node_id
                                                        
                                                        	RepairElementNodeID
                                                        	**type**\: str
                                                        
                                                        .. attribute:: repair_ipv4_addr
                                                        
                                                        	RepairIPv4Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_ipv6_addr
                                                        
                                                        	RepairIPv6Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_label
                                                        
                                                        	Repair Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_element_type
                                                        
                                                        	Repair Element Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_strict_spf_label
                                                        
                                                        	Repair Strict SPF Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair, self).__init__()

                                                            self.yang_name = "backup-repair"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                                ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                                ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                                ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                                ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                                ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                            ])
                                                            self.repair_element_node_id = None
                                                            self.repair_ipv4_addr = None
                                                            self.repair_ipv6_addr = None
                                                            self.repair_label = None
                                                            self.repair_element_type = None
                                                            self.repair_strict_spf_label = None
                                                            self._segment_path = lambda: "backup-repair"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class MulticastPath(Entity):
                                                """
                                                Multicast intact first hops toward the prefix
                                                
                                                .. attribute:: frr_backup
                                                
                                                	FRR backup for this path
                                                	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup>`
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: tag
                                                
                                                	Tag associated with the path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_interface
                                                
                                                	Explicit path tunnel interface
                                                	**type**\: str
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_te_tunnel_interface
                                                
                                                	Is path via a TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: is_sr_exclude_tunnel_interface
                                                
                                                	Is path via an SR\-exclude TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: uloop_explicit
                                                
                                                	Uloop Explicit List
                                                	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit>`
                                                
                                                .. attribute:: nnh
                                                
                                                	Next next hops
                                                	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.Nnh>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath, self).__init__()

                                                    self.yang_name = "multicast-path"
                                                    self.yang_parent_name = "primary"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.Nnh))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                        ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.neighbor_snpa = None
                                                    self.tag = None
                                                    self.tunnel_interface = None
                                                    self.segment_routing_sid_value = None
                                                    self.weight = None
                                                    self.is_te_tunnel_interface = None
                                                    self.is_sr_exclude_tunnel_interface = None

                                                    self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup()
                                                    self.frr_backup.parent = self
                                                    self._children_name_map["frr_backup"] = "frr-backup"

                                                    self.uloop_explicit = YList(self)
                                                    self.nnh = YList(self)
                                                    self._segment_path = lambda: "multicast-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                                class FrrBackup(Entity):
                                                    """
                                                    FRR backup for this path
                                                    
                                                    .. attribute:: neighbor_id
                                                    
                                                    	Next hop neighbor ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: egress_interface
                                                    
                                                    	Interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Next hop neighbor's forwarding address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: tunnel_egress_interface
                                                    
                                                    	Tunnel Interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_snpa
                                                    
                                                    	Next hop neighbor's SNPA
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_system_id
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_id
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: remote_lfa_system_pid
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_pid
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: total_backup_distance
                                                    
                                                    	Distance to the network via this backup path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value
                                                    
                                                    	Segment routing sid value received from first hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: num_sid
                                                    
                                                    	Number of SIDs in TI\-LFA/rLFA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_repair_list_size
                                                    
                                                    	Backup Repair List Size
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tilfa_computation
                                                    
                                                    	Ti LFA computation which provided backup path
                                                    	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                    
                                                    .. attribute:: prefix_source_node_id
                                                    
                                                    	PrefixSourceNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: is_downstream
                                                    
                                                    	Is the backup path via downstream node?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_lc_disjoint
                                                    
                                                    	Is the backup path line card disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_node_protecting
                                                    
                                                    	Is the backup path node protecting?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_primary_path
                                                    
                                                    	Is the backup path an ECMP to the network?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_srlg_disjoint
                                                    
                                                    	Is the backup path SRLG disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_remote_lfa
                                                    
                                                    	Is the backup path via a Remote LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_epcfrr_lfa
                                                    
                                                    	Is the backup path via a TI\-LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_strict_spflfa
                                                    
                                                    	Is the backup path TI\-LFA strict SPF?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_requested
                                                    
                                                    	Is SR TE tunnel requested
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight configured on the interface
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value_entry
                                                    
                                                    	Segment routing sid values for TI\-LFA/rLFA
                                                    	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                    
                                                    .. attribute:: backup_repair
                                                    
                                                    	Backup Repair List
                                                    	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup, self).__init__()

                                                        self.yang_name = "frr-backup"
                                                        self.yang_parent_name = "multicast-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair))])
                                                        self._leafs = OrderedDict([
                                                            ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                            ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                            ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                            ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                            ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                            ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                            ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                            ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                            ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                            ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                            ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                            ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                            ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                            ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                            ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                            ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                            ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                            ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                            ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                            ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                            ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                            ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                            ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                            ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ])
                                                        self.neighbor_id = None
                                                        self.egress_interface = None
                                                        self.neighbor_address = None
                                                        self.tunnel_egress_interface = None
                                                        self.neighbor_snpa = None
                                                        self.remote_lfa_system_id = None
                                                        self.remote_lfa_router_id = None
                                                        self.remote_lfa_system_pid = None
                                                        self.remote_lfa_router_pid = None
                                                        self.total_backup_distance = None
                                                        self.segment_routing_sid_value = None
                                                        self.num_sid = None
                                                        self.backup_repair_list_size = None
                                                        self.tilfa_computation = None
                                                        self.prefix_source_node_id = None
                                                        self.is_downstream = None
                                                        self.is_lc_disjoint = None
                                                        self.is_node_protecting = None
                                                        self.is_primary_path = None
                                                        self.is_srlg_disjoint = None
                                                        self.is_remote_lfa = None
                                                        self.is_epcfrr_lfa = None
                                                        self.is_strict_spflfa = None
                                                        self.is_tunnel_requested = None
                                                        self.weight = None

                                                        self.segment_routing_sid_value_entry = YList(self)
                                                        self.backup_repair = YList(self)
                                                        self._segment_path = lambda: "frr-backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                    class SegmentRoutingSidValueEntry(Entity):
                                                        """
                                                        Segment routing sid values for TI\-LFA/rLFA
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                            self.yang_name = "segment-routing-sid-value-entry"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                    class BackupRepair(Entity):
                                                        """
                                                        Backup Repair List
                                                        
                                                        .. attribute:: repair_element_node_id
                                                        
                                                        	RepairElementNodeID
                                                        	**type**\: str
                                                        
                                                        .. attribute:: repair_ipv4_addr
                                                        
                                                        	RepairIPv4Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_ipv6_addr
                                                        
                                                        	RepairIPv6Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_label
                                                        
                                                        	Repair Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_element_type
                                                        
                                                        	Repair Element Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_strict_spf_label
                                                        
                                                        	Repair Strict SPF Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair, self).__init__()

                                                            self.yang_name = "backup-repair"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                                ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                                ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                                ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                                ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                                ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                            ])
                                                            self.repair_element_node_id = None
                                                            self.repair_ipv4_addr = None
                                                            self.repair_ipv6_addr = None
                                                            self.repair_label = None
                                                            self.repair_element_type = None
                                                            self.repair_strict_spf_label = None
                                                            self._segment_path = lambda: "backup-repair"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class UloopExplicit(Entity):
                                                    """
                                                    Uloop Explicit List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit, self).__init__()

                                                        self.yang_name = "uloop-explicit"
                                                        self.yang_parent_name = "multicast-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "uloop-explicit"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class Nnh(Entity):
                                                    """
                                                    Next next hops
                                                    
                                                    .. attribute:: link_id_set
                                                    
                                                    	If link\_id is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ipv4_set
                                                    
                                                    	If ipv4 address is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: link_id
                                                    
                                                    	link ID of the next next hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	Ipv4 address of the next next hop
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.Nnh, self).__init__()

                                                        self.yang_name = "nnh"
                                                        self.yang_parent_name = "multicast-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                            ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                            ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ])
                                                        self.link_id_set = None
                                                        self.ipv4_set = None
                                                        self.link_id = None
                                                        self.ipv4_address = None
                                                        self._segment_path = lambda: "nnh"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastPath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                            class SrtePath(Entity):
                                                """
                                                SR\-TE native first hops toward the prefix
                                                
                                                .. attribute:: frr_backup
                                                
                                                	FRR backup for this path
                                                	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup>`
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: tag
                                                
                                                	Tag associated with the path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_interface
                                                
                                                	Explicit path tunnel interface
                                                	**type**\: str
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_te_tunnel_interface
                                                
                                                	Is path via a TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: is_sr_exclude_tunnel_interface
                                                
                                                	Is path via an SR\-exclude TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: uloop_explicit
                                                
                                                	Uloop Explicit List
                                                	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit>`
                                                
                                                .. attribute:: nnh
                                                
                                                	Next next hops
                                                	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.Nnh>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath, self).__init__()

                                                    self.yang_name = "srte-path"
                                                    self.yang_parent_name = "primary"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.Nnh))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                        ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.neighbor_snpa = None
                                                    self.tag = None
                                                    self.tunnel_interface = None
                                                    self.segment_routing_sid_value = None
                                                    self.weight = None
                                                    self.is_te_tunnel_interface = None
                                                    self.is_sr_exclude_tunnel_interface = None

                                                    self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup()
                                                    self.frr_backup.parent = self
                                                    self._children_name_map["frr_backup"] = "frr-backup"

                                                    self.uloop_explicit = YList(self)
                                                    self.nnh = YList(self)
                                                    self._segment_path = lambda: "srte-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                                class FrrBackup(Entity):
                                                    """
                                                    FRR backup for this path
                                                    
                                                    .. attribute:: neighbor_id
                                                    
                                                    	Next hop neighbor ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: egress_interface
                                                    
                                                    	Interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Next hop neighbor's forwarding address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: tunnel_egress_interface
                                                    
                                                    	Tunnel Interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_snpa
                                                    
                                                    	Next hop neighbor's SNPA
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_system_id
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_id
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: remote_lfa_system_pid
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_pid
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: total_backup_distance
                                                    
                                                    	Distance to the network via this backup path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value
                                                    
                                                    	Segment routing sid value received from first hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: num_sid
                                                    
                                                    	Number of SIDs in TI\-LFA/rLFA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_repair_list_size
                                                    
                                                    	Backup Repair List Size
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tilfa_computation
                                                    
                                                    	Ti LFA computation which provided backup path
                                                    	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                    
                                                    .. attribute:: prefix_source_node_id
                                                    
                                                    	PrefixSourceNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: is_downstream
                                                    
                                                    	Is the backup path via downstream node?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_lc_disjoint
                                                    
                                                    	Is the backup path line card disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_node_protecting
                                                    
                                                    	Is the backup path node protecting?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_primary_path
                                                    
                                                    	Is the backup path an ECMP to the network?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_srlg_disjoint
                                                    
                                                    	Is the backup path SRLG disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_remote_lfa
                                                    
                                                    	Is the backup path via a Remote LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_epcfrr_lfa
                                                    
                                                    	Is the backup path via a TI\-LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_strict_spflfa
                                                    
                                                    	Is the backup path TI\-LFA strict SPF?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_requested
                                                    
                                                    	Is SR TE tunnel requested
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight configured on the interface
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value_entry
                                                    
                                                    	Segment routing sid values for TI\-LFA/rLFA
                                                    	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                    
                                                    .. attribute:: backup_repair
                                                    
                                                    	Backup Repair List
                                                    	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup, self).__init__()

                                                        self.yang_name = "frr-backup"
                                                        self.yang_parent_name = "srte-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair))])
                                                        self._leafs = OrderedDict([
                                                            ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                            ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                            ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                            ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                            ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                            ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                            ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                            ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                            ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                            ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                            ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                            ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                            ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                            ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                            ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                            ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                            ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                            ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                            ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                            ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                            ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                            ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                            ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                            ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ])
                                                        self.neighbor_id = None
                                                        self.egress_interface = None
                                                        self.neighbor_address = None
                                                        self.tunnel_egress_interface = None
                                                        self.neighbor_snpa = None
                                                        self.remote_lfa_system_id = None
                                                        self.remote_lfa_router_id = None
                                                        self.remote_lfa_system_pid = None
                                                        self.remote_lfa_router_pid = None
                                                        self.total_backup_distance = None
                                                        self.segment_routing_sid_value = None
                                                        self.num_sid = None
                                                        self.backup_repair_list_size = None
                                                        self.tilfa_computation = None
                                                        self.prefix_source_node_id = None
                                                        self.is_downstream = None
                                                        self.is_lc_disjoint = None
                                                        self.is_node_protecting = None
                                                        self.is_primary_path = None
                                                        self.is_srlg_disjoint = None
                                                        self.is_remote_lfa = None
                                                        self.is_epcfrr_lfa = None
                                                        self.is_strict_spflfa = None
                                                        self.is_tunnel_requested = None
                                                        self.weight = None

                                                        self.segment_routing_sid_value_entry = YList(self)
                                                        self.backup_repair = YList(self)
                                                        self._segment_path = lambda: "frr-backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                    class SegmentRoutingSidValueEntry(Entity):
                                                        """
                                                        Segment routing sid values for TI\-LFA/rLFA
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                            self.yang_name = "segment-routing-sid-value-entry"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                    class BackupRepair(Entity):
                                                        """
                                                        Backup Repair List
                                                        
                                                        .. attribute:: repair_element_node_id
                                                        
                                                        	RepairElementNodeID
                                                        	**type**\: str
                                                        
                                                        .. attribute:: repair_ipv4_addr
                                                        
                                                        	RepairIPv4Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_ipv6_addr
                                                        
                                                        	RepairIPv6Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_label
                                                        
                                                        	Repair Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_element_type
                                                        
                                                        	Repair Element Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_strict_spf_label
                                                        
                                                        	Repair Strict SPF Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair, self).__init__()

                                                            self.yang_name = "backup-repair"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                                ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                                ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                                ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                                ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                                ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                            ])
                                                            self.repair_element_node_id = None
                                                            self.repair_ipv4_addr = None
                                                            self.repair_ipv6_addr = None
                                                            self.repair_label = None
                                                            self.repair_element_type = None
                                                            self.repair_strict_spf_label = None
                                                            self._segment_path = lambda: "backup-repair"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class UloopExplicit(Entity):
                                                    """
                                                    Uloop Explicit List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit, self).__init__()

                                                        self.yang_name = "uloop-explicit"
                                                        self.yang_parent_name = "srte-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "uloop-explicit"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class Nnh(Entity):
                                                    """
                                                    Next next hops
                                                    
                                                    .. attribute:: link_id_set
                                                    
                                                    	If link\_id is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ipv4_set
                                                    
                                                    	If ipv4 address is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: link_id
                                                    
                                                    	link ID of the next next hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	Ipv4 address of the next next hop
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.Nnh, self).__init__()

                                                        self.yang_name = "nnh"
                                                        self.yang_parent_name = "srte-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                            ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                            ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ])
                                                        self.link_id_set = None
                                                        self.ipv4_set = None
                                                        self.link_id = None
                                                        self.ipv4_address = None
                                                        self._segment_path = lambda: "nnh"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.SrtePath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                            class ExplicitPath(Entity):
                                                """
                                                SR microloop avoidance paths
                                                
                                                .. attribute:: frr_backup
                                                
                                                	FRR backup for this path
                                                	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup>`
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: tag
                                                
                                                	Tag associated with the path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_interface
                                                
                                                	Explicit path tunnel interface
                                                	**type**\: str
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_te_tunnel_interface
                                                
                                                	Is path via a TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: is_sr_exclude_tunnel_interface
                                                
                                                	Is path via an SR\-exclude TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: uloop_explicit
                                                
                                                	Uloop Explicit List
                                                	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit>`
                                                
                                                .. attribute:: nnh
                                                
                                                	Next next hops
                                                	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.Nnh>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath, self).__init__()

                                                    self.yang_name = "explicit-path"
                                                    self.yang_parent_name = "primary"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.Nnh))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                        ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.neighbor_snpa = None
                                                    self.tag = None
                                                    self.tunnel_interface = None
                                                    self.segment_routing_sid_value = None
                                                    self.weight = None
                                                    self.is_te_tunnel_interface = None
                                                    self.is_sr_exclude_tunnel_interface = None

                                                    self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup()
                                                    self.frr_backup.parent = self
                                                    self._children_name_map["frr_backup"] = "frr-backup"

                                                    self.uloop_explicit = YList(self)
                                                    self.nnh = YList(self)
                                                    self._segment_path = lambda: "explicit-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                                class FrrBackup(Entity):
                                                    """
                                                    FRR backup for this path
                                                    
                                                    .. attribute:: neighbor_id
                                                    
                                                    	Next hop neighbor ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: egress_interface
                                                    
                                                    	Interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Next hop neighbor's forwarding address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: tunnel_egress_interface
                                                    
                                                    	Tunnel Interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_snpa
                                                    
                                                    	Next hop neighbor's SNPA
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_system_id
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_id
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: remote_lfa_system_pid
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_pid
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: total_backup_distance
                                                    
                                                    	Distance to the network via this backup path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value
                                                    
                                                    	Segment routing sid value received from first hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: num_sid
                                                    
                                                    	Number of SIDs in TI\-LFA/rLFA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_repair_list_size
                                                    
                                                    	Backup Repair List Size
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tilfa_computation
                                                    
                                                    	Ti LFA computation which provided backup path
                                                    	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                    
                                                    .. attribute:: prefix_source_node_id
                                                    
                                                    	PrefixSourceNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: is_downstream
                                                    
                                                    	Is the backup path via downstream node?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_lc_disjoint
                                                    
                                                    	Is the backup path line card disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_node_protecting
                                                    
                                                    	Is the backup path node protecting?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_primary_path
                                                    
                                                    	Is the backup path an ECMP to the network?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_srlg_disjoint
                                                    
                                                    	Is the backup path SRLG disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_remote_lfa
                                                    
                                                    	Is the backup path via a Remote LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_epcfrr_lfa
                                                    
                                                    	Is the backup path via a TI\-LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_strict_spflfa
                                                    
                                                    	Is the backup path TI\-LFA strict SPF?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_requested
                                                    
                                                    	Is SR TE tunnel requested
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight configured on the interface
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value_entry
                                                    
                                                    	Segment routing sid values for TI\-LFA/rLFA
                                                    	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                    
                                                    .. attribute:: backup_repair
                                                    
                                                    	Backup Repair List
                                                    	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup, self).__init__()

                                                        self.yang_name = "frr-backup"
                                                        self.yang_parent_name = "explicit-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair))])
                                                        self._leafs = OrderedDict([
                                                            ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                            ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                            ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                            ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                            ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                            ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                            ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                            ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                            ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                            ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                            ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                            ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                            ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                            ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                            ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                            ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                            ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                            ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                            ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                            ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                            ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                            ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                            ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                            ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ])
                                                        self.neighbor_id = None
                                                        self.egress_interface = None
                                                        self.neighbor_address = None
                                                        self.tunnel_egress_interface = None
                                                        self.neighbor_snpa = None
                                                        self.remote_lfa_system_id = None
                                                        self.remote_lfa_router_id = None
                                                        self.remote_lfa_system_pid = None
                                                        self.remote_lfa_router_pid = None
                                                        self.total_backup_distance = None
                                                        self.segment_routing_sid_value = None
                                                        self.num_sid = None
                                                        self.backup_repair_list_size = None
                                                        self.tilfa_computation = None
                                                        self.prefix_source_node_id = None
                                                        self.is_downstream = None
                                                        self.is_lc_disjoint = None
                                                        self.is_node_protecting = None
                                                        self.is_primary_path = None
                                                        self.is_srlg_disjoint = None
                                                        self.is_remote_lfa = None
                                                        self.is_epcfrr_lfa = None
                                                        self.is_strict_spflfa = None
                                                        self.is_tunnel_requested = None
                                                        self.weight = None

                                                        self.segment_routing_sid_value_entry = YList(self)
                                                        self.backup_repair = YList(self)
                                                        self._segment_path = lambda: "frr-backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                    class SegmentRoutingSidValueEntry(Entity):
                                                        """
                                                        Segment routing sid values for TI\-LFA/rLFA
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                            self.yang_name = "segment-routing-sid-value-entry"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                    class BackupRepair(Entity):
                                                        """
                                                        Backup Repair List
                                                        
                                                        .. attribute:: repair_element_node_id
                                                        
                                                        	RepairElementNodeID
                                                        	**type**\: str
                                                        
                                                        .. attribute:: repair_ipv4_addr
                                                        
                                                        	RepairIPv4Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_ipv6_addr
                                                        
                                                        	RepairIPv6Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_label
                                                        
                                                        	Repair Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_element_type
                                                        
                                                        	Repair Element Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_strict_spf_label
                                                        
                                                        	Repair Strict SPF Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair, self).__init__()

                                                            self.yang_name = "backup-repair"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                                ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                                ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                                ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                                ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                                ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                            ])
                                                            self.repair_element_node_id = None
                                                            self.repair_ipv4_addr = None
                                                            self.repair_ipv6_addr = None
                                                            self.repair_label = None
                                                            self.repair_element_type = None
                                                            self.repair_strict_spf_label = None
                                                            self._segment_path = lambda: "backup-repair"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class UloopExplicit(Entity):
                                                    """
                                                    Uloop Explicit List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit, self).__init__()

                                                        self.yang_name = "uloop-explicit"
                                                        self.yang_parent_name = "explicit-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "uloop-explicit"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class Nnh(Entity):
                                                    """
                                                    Next next hops
                                                    
                                                    .. attribute:: link_id_set
                                                    
                                                    	If link\_id is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ipv4_set
                                                    
                                                    	If ipv4 address is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: link_id
                                                    
                                                    	link ID of the next next hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	Ipv4 address of the next next hop
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.Nnh, self).__init__()

                                                        self.yang_name = "nnh"
                                                        self.yang_parent_name = "explicit-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                            ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                            ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ])
                                                        self.link_id_set = None
                                                        self.ipv4_set = None
                                                        self.link_id = None
                                                        self.ipv4_address = None
                                                        self._segment_path = lambda: "nnh"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.ExplicitPath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                            class Source(Entity):
                                                """
                                                Sources advertising the prefix
                                                
                                                .. attribute:: source_lsp_id
                                                
                                                	ID of the LSP advertising the prefix
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                                
                                                .. attribute:: source_address
                                                
                                                	Source address of the IS advertising the prefix
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tags
                                                
                                                	Tags associated with the prefix item
                                                	**type**\: list of  		 :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Source.Tags>`
                                                
                                                .. attribute:: nodal_sid
                                                
                                                	Nodal SIDs with the prefix item
                                                	**type**\: list of  		 :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Source.NodalSid>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Source, self).__init__()

                                                    self.yang_name = "source"
                                                    self.yang_parent_name = "primary"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tags", ("tags", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Source.Tags)), ("nodal-sid", ("nodal_sid", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Source.NodalSid))])
                                                    self._leafs = OrderedDict([
                                                        ('source_lsp_id', (YLeaf(YType.str, 'source-lsp-id'), ['str'])),
                                                        ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                                    ])
                                                    self.source_lsp_id = None
                                                    self.source_address = None

                                                    self.tags = YList(self)
                                                    self.nodal_sid = YList(self)
                                                    self._segment_path = lambda: "source"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Source, [u'source_lsp_id', u'source_address'], name, value)


                                                class Tags(Entity):
                                                    """
                                                    Tags associated with the prefix item
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Source.Tags, self).__init__()

                                                        self.yang_name = "tags"
                                                        self.yang_parent_name = "source"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "tags"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Source.Tags, [u'entry'], name, value)


                                                class NodalSid(Entity):
                                                    """
                                                    Nodal SIDs with the prefix item
                                                    
                                                    .. attribute:: sid_value
                                                    
                                                    	sid value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rflag
                                                    
                                                    	rflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nflag
                                                    
                                                    	nflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pflag
                                                    
                                                    	pflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: eflag
                                                    
                                                    	eflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: vflag
                                                    
                                                    	vflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: lflag
                                                    
                                                    	lflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: algorithm
                                                    
                                                    	algorithm
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Source.NodalSid, self).__init__()

                                                        self.yang_name = "nodal-sid"
                                                        self.yang_parent_name = "source"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('sid_value', (YLeaf(YType.uint32, 'sid-value'), ['int'])),
                                                            ('rflag', (YLeaf(YType.uint8, 'rflag'), ['int'])),
                                                            ('nflag', (YLeaf(YType.uint8, 'nflag'), ['int'])),
                                                            ('pflag', (YLeaf(YType.uint8, 'pflag'), ['int'])),
                                                            ('eflag', (YLeaf(YType.uint8, 'eflag'), ['int'])),
                                                            ('vflag', (YLeaf(YType.uint8, 'vflag'), ['int'])),
                                                            ('lflag', (YLeaf(YType.uint8, 'lflag'), ['int'])),
                                                            ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                                        ])
                                                        self.sid_value = None
                                                        self.rflag = None
                                                        self.nflag = None
                                                        self.pflag = None
                                                        self.eflag = None
                                                        self.vflag = None
                                                        self.lflag = None
                                                        self.algorithm = None
                                                        self._segment_path = lambda: "nodal-sid"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.Source.NodalSid, [u'sid_value', u'rflag', u'nflag', u'pflag', u'eflag', u'vflag', u'lflag', u'algorithm'], name, value)


                                            class MulticastSource(Entity):
                                                """
                                                Multicast\-intact sources advertising the prefix
                                                
                                                .. attribute:: source_lsp_id
                                                
                                                	ID of the LSP advertising the prefix
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                                
                                                .. attribute:: source_address
                                                
                                                	Source address of the IS advertising the prefix
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tags
                                                
                                                	Tags associated with the prefix item
                                                	**type**\: list of  		 :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastSource.Tags>`
                                                
                                                .. attribute:: nodal_sid
                                                
                                                	Nodal SIDs with the prefix item
                                                	**type**\: list of  		 :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastSource, self).__init__()

                                                    self.yang_name = "multicast-source"
                                                    self.yang_parent_name = "primary"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tags", ("tags", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastSource.Tags)), ("nodal-sid", ("nodal_sid", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid))])
                                                    self._leafs = OrderedDict([
                                                        ('source_lsp_id', (YLeaf(YType.str, 'source-lsp-id'), ['str'])),
                                                        ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                                    ])
                                                    self.source_lsp_id = None
                                                    self.source_address = None

                                                    self.tags = YList(self)
                                                    self.nodal_sid = YList(self)
                                                    self._segment_path = lambda: "multicast-source"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastSource, [u'source_lsp_id', u'source_address'], name, value)


                                                class Tags(Entity):
                                                    """
                                                    Tags associated with the prefix item
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastSource.Tags, self).__init__()

                                                        self.yang_name = "tags"
                                                        self.yang_parent_name = "multicast-source"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "tags"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastSource.Tags, [u'entry'], name, value)


                                                class NodalSid(Entity):
                                                    """
                                                    Nodal SIDs with the prefix item
                                                    
                                                    .. attribute:: sid_value
                                                    
                                                    	sid value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rflag
                                                    
                                                    	rflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nflag
                                                    
                                                    	nflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pflag
                                                    
                                                    	pflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: eflag
                                                    
                                                    	eflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: vflag
                                                    
                                                    	vflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: lflag
                                                    
                                                    	lflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: algorithm
                                                    
                                                    	algorithm
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid, self).__init__()

                                                        self.yang_name = "nodal-sid"
                                                        self.yang_parent_name = "multicast-source"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('sid_value', (YLeaf(YType.uint32, 'sid-value'), ['int'])),
                                                            ('rflag', (YLeaf(YType.uint8, 'rflag'), ['int'])),
                                                            ('nflag', (YLeaf(YType.uint8, 'nflag'), ['int'])),
                                                            ('pflag', (YLeaf(YType.uint8, 'pflag'), ['int'])),
                                                            ('eflag', (YLeaf(YType.uint8, 'eflag'), ['int'])),
                                                            ('vflag', (YLeaf(YType.uint8, 'vflag'), ['int'])),
                                                            ('lflag', (YLeaf(YType.uint8, 'lflag'), ['int'])),
                                                            ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                                        ])
                                                        self.sid_value = None
                                                        self.rflag = None
                                                        self.nflag = None
                                                        self.pflag = None
                                                        self.eflag = None
                                                        self.vflag = None
                                                        self.lflag = None
                                                        self.algorithm = None
                                                        self._segment_path = lambda: "nodal-sid"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid, [u'sid_value', u'rflag', u'nflag', u'pflag', u'eflag', u'vflag', u'lflag', u'algorithm'], name, value)


                                        class Backup(Entity):
                                            """
                                            Backup paths to prefix
                                            
                                            .. attribute:: origin
                                            
                                            	Origin of route
                                            	**type**\:  :py:class:`IsisPrefixOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisPrefixOrigin>`
                                            
                                            .. attribute:: metric
                                            
                                            	Distance to network
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: multicast_metric
                                            
                                            	Multicast\-intact distance to network
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_external_metric
                                            
                                            	Is the metric an external metric?
                                            	**type**\: bool
                                            
                                            .. attribute:: administrative_distance
                                            
                                            	Administrative Distance
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: paths
                                            
                                            	First hops toward the prefix
                                            	**type**\: list of  		 :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Paths>`
                                            
                                            .. attribute:: ucmp_next_hop
                                            
                                            	UCMP first hops toward the prefix
                                            	**type**\: list of  		 :py:class:`UcmpNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.UcmpNextHop>`
                                            
                                            .. attribute:: multicast_path
                                            
                                            	Multicast intact first hops toward the prefix
                                            	**type**\: list of  		 :py:class:`MulticastPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath>`
                                            
                                            .. attribute:: srte_path
                                            
                                            	SR\-TE native first hops toward the prefix
                                            	**type**\: list of  		 :py:class:`SrtePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath>`
                                            
                                            .. attribute:: explicit_path
                                            
                                            	SR microloop avoidance paths
                                            	**type**\: list of  		 :py:class:`ExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath>`
                                            
                                            .. attribute:: source
                                            
                                            	Sources advertising the prefix
                                            	**type**\: list of  		 :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Source>`
                                            
                                            .. attribute:: multicast_source
                                            
                                            	Multicast\-intact sources advertising the prefix
                                            	**type**\: list of  		 :py:class:`MulticastSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastSource>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup, self).__init__()

                                                self.yang_name = "backup"
                                                self.yang_parent_name = "native-details"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("paths", ("paths", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Paths)), ("ucmp-next-hop", ("ucmp_next_hop", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.UcmpNextHop)), ("multicast-path", ("multicast_path", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath)), ("srte-path", ("srte_path", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath)), ("explicit-path", ("explicit_path", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath)), ("source", ("source", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Source)), ("multicast-source", ("multicast_source", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastSource))])
                                                self._leafs = OrderedDict([
                                                    ('origin', (YLeaf(YType.enumeration, 'origin'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisPrefixOrigin', '')])),
                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                    ('multicast_metric', (YLeaf(YType.uint32, 'multicast-metric'), ['int'])),
                                                    ('is_external_metric', (YLeaf(YType.boolean, 'is-external-metric'), ['bool'])),
                                                    ('administrative_distance', (YLeaf(YType.uint16, 'administrative-distance'), ['int'])),
                                                ])
                                                self.origin = None
                                                self.metric = None
                                                self.multicast_metric = None
                                                self.is_external_metric = None
                                                self.administrative_distance = None

                                                self.paths = YList(self)
                                                self.ucmp_next_hop = YList(self)
                                                self.multicast_path = YList(self)
                                                self.srte_path = YList(self)
                                                self.explicit_path = YList(self)
                                                self.source = YList(self)
                                                self.multicast_source = YList(self)
                                                self._segment_path = lambda: "backup"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup, [u'origin', u'metric', u'multicast_metric', u'is_external_metric', u'administrative_distance'], name, value)


                                            class Paths(Entity):
                                                """
                                                First hops toward the prefix
                                                
                                                .. attribute:: frr_backup
                                                
                                                	FRR backup for this path
                                                	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Paths.FrrBackup>`
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: tag
                                                
                                                	Tag associated with the path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_interface
                                                
                                                	Explicit path tunnel interface
                                                	**type**\: str
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_te_tunnel_interface
                                                
                                                	Is path via a TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: is_sr_exclude_tunnel_interface
                                                
                                                	Is path via an SR\-exclude TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: uloop_explicit
                                                
                                                	Uloop Explicit List
                                                	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit>`
                                                
                                                .. attribute:: nnh
                                                
                                                	Next next hops
                                                	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Paths.Nnh>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Paths, self).__init__()

                                                    self.yang_name = "paths"
                                                    self.yang_parent_name = "backup"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Paths.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Paths.Nnh))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                        ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.neighbor_snpa = None
                                                    self.tag = None
                                                    self.tunnel_interface = None
                                                    self.segment_routing_sid_value = None
                                                    self.weight = None
                                                    self.is_te_tunnel_interface = None
                                                    self.is_sr_exclude_tunnel_interface = None

                                                    self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Paths.FrrBackup()
                                                    self.frr_backup.parent = self
                                                    self._children_name_map["frr_backup"] = "frr-backup"

                                                    self.uloop_explicit = YList(self)
                                                    self.nnh = YList(self)
                                                    self._segment_path = lambda: "paths"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Paths, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                                class FrrBackup(Entity):
                                                    """
                                                    FRR backup for this path
                                                    
                                                    .. attribute:: neighbor_id
                                                    
                                                    	Next hop neighbor ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: egress_interface
                                                    
                                                    	Interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Next hop neighbor's forwarding address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: tunnel_egress_interface
                                                    
                                                    	Tunnel Interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_snpa
                                                    
                                                    	Next hop neighbor's SNPA
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_system_id
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_id
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: remote_lfa_system_pid
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_pid
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: total_backup_distance
                                                    
                                                    	Distance to the network via this backup path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value
                                                    
                                                    	Segment routing sid value received from first hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: num_sid
                                                    
                                                    	Number of SIDs in TI\-LFA/rLFA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_repair_list_size
                                                    
                                                    	Backup Repair List Size
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tilfa_computation
                                                    
                                                    	Ti LFA computation which provided backup path
                                                    	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                    
                                                    .. attribute:: prefix_source_node_id
                                                    
                                                    	PrefixSourceNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: is_downstream
                                                    
                                                    	Is the backup path via downstream node?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_lc_disjoint
                                                    
                                                    	Is the backup path line card disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_node_protecting
                                                    
                                                    	Is the backup path node protecting?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_primary_path
                                                    
                                                    	Is the backup path an ECMP to the network?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_srlg_disjoint
                                                    
                                                    	Is the backup path SRLG disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_remote_lfa
                                                    
                                                    	Is the backup path via a Remote LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_epcfrr_lfa
                                                    
                                                    	Is the backup path via a TI\-LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_strict_spflfa
                                                    
                                                    	Is the backup path TI\-LFA strict SPF?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_requested
                                                    
                                                    	Is SR TE tunnel requested
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight configured on the interface
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value_entry
                                                    
                                                    	Segment routing sid values for TI\-LFA/rLFA
                                                    	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry>`
                                                    
                                                    .. attribute:: backup_repair
                                                    
                                                    	Backup Repair List
                                                    	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Paths.FrrBackup, self).__init__()

                                                        self.yang_name = "frr-backup"
                                                        self.yang_parent_name = "paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair))])
                                                        self._leafs = OrderedDict([
                                                            ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                            ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                            ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                            ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                            ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                            ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                            ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                            ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                            ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                            ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                            ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                            ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                            ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                            ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                            ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                            ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                            ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                            ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                            ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                            ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                            ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                            ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                            ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                            ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ])
                                                        self.neighbor_id = None
                                                        self.egress_interface = None
                                                        self.neighbor_address = None
                                                        self.tunnel_egress_interface = None
                                                        self.neighbor_snpa = None
                                                        self.remote_lfa_system_id = None
                                                        self.remote_lfa_router_id = None
                                                        self.remote_lfa_system_pid = None
                                                        self.remote_lfa_router_pid = None
                                                        self.total_backup_distance = None
                                                        self.segment_routing_sid_value = None
                                                        self.num_sid = None
                                                        self.backup_repair_list_size = None
                                                        self.tilfa_computation = None
                                                        self.prefix_source_node_id = None
                                                        self.is_downstream = None
                                                        self.is_lc_disjoint = None
                                                        self.is_node_protecting = None
                                                        self.is_primary_path = None
                                                        self.is_srlg_disjoint = None
                                                        self.is_remote_lfa = None
                                                        self.is_epcfrr_lfa = None
                                                        self.is_strict_spflfa = None
                                                        self.is_tunnel_requested = None
                                                        self.weight = None

                                                        self.segment_routing_sid_value_entry = YList(self)
                                                        self.backup_repair = YList(self)
                                                        self._segment_path = lambda: "frr-backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Paths.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                    class SegmentRoutingSidValueEntry(Entity):
                                                        """
                                                        Segment routing sid values for TI\-LFA/rLFA
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                            self.yang_name = "segment-routing-sid-value-entry"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                    class BackupRepair(Entity):
                                                        """
                                                        Backup Repair List
                                                        
                                                        .. attribute:: repair_element_node_id
                                                        
                                                        	RepairElementNodeID
                                                        	**type**\: str
                                                        
                                                        .. attribute:: repair_ipv4_addr
                                                        
                                                        	RepairIPv4Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_ipv6_addr
                                                        
                                                        	RepairIPv6Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_label
                                                        
                                                        	Repair Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_element_type
                                                        
                                                        	Repair Element Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_strict_spf_label
                                                        
                                                        	Repair Strict SPF Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair, self).__init__()

                                                            self.yang_name = "backup-repair"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                                ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                                ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                                ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                                ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                                ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                            ])
                                                            self.repair_element_node_id = None
                                                            self.repair_ipv4_addr = None
                                                            self.repair_ipv6_addr = None
                                                            self.repair_label = None
                                                            self.repair_element_type = None
                                                            self.repair_strict_spf_label = None
                                                            self._segment_path = lambda: "backup-repair"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class UloopExplicit(Entity):
                                                    """
                                                    Uloop Explicit List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit, self).__init__()

                                                        self.yang_name = "uloop-explicit"
                                                        self.yang_parent_name = "paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "uloop-explicit"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class Nnh(Entity):
                                                    """
                                                    Next next hops
                                                    
                                                    .. attribute:: link_id_set
                                                    
                                                    	If link\_id is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ipv4_set
                                                    
                                                    	If ipv4 address is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: link_id
                                                    
                                                    	link ID of the next next hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	Ipv4 address of the next next hop
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Paths.Nnh, self).__init__()

                                                        self.yang_name = "nnh"
                                                        self.yang_parent_name = "paths"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                            ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                            ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ])
                                                        self.link_id_set = None
                                                        self.ipv4_set = None
                                                        self.link_id = None
                                                        self.ipv4_address = None
                                                        self._segment_path = lambda: "nnh"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Paths.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                            class UcmpNextHop(Entity):
                                                """
                                                UCMP first hops toward the prefix
                                                
                                                .. attribute:: frr_backup
                                                
                                                	FRR backup for this path
                                                	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup>`
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: tag
                                                
                                                	Tag associated with the path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: total_ucmp_distance
                                                
                                                	Distance to the network via this UCMP next hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_te_tunnel_interface
                                                
                                                	Is path via a TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: is_sr_exclude_tunnel_interface
                                                
                                                	Is path via an SR\-exclude TE tunnel
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.UcmpNextHop, self).__init__()

                                                    self.yang_name = "ucmp-next-hop"
                                                    self.yang_parent_name = "backup"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('total_ucmp_distance', (YLeaf(YType.uint32, 'total-ucmp-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                        ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.neighbor_snpa = None
                                                    self.tag = None
                                                    self.total_ucmp_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.weight = None
                                                    self.is_te_tunnel_interface = None
                                                    self.is_sr_exclude_tunnel_interface = None

                                                    self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup()
                                                    self.frr_backup.parent = self
                                                    self._children_name_map["frr_backup"] = "frr-backup"
                                                    self._segment_path = lambda: "ucmp-next-hop"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.UcmpNextHop, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'total_ucmp_distance', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                                class FrrBackup(Entity):
                                                    """
                                                    FRR backup for this path
                                                    
                                                    .. attribute:: neighbor_id
                                                    
                                                    	Next hop neighbor ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: egress_interface
                                                    
                                                    	Interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Next hop neighbor's forwarding address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: tunnel_egress_interface
                                                    
                                                    	Tunnel Interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_snpa
                                                    
                                                    	Next hop neighbor's SNPA
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_system_id
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_id
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: remote_lfa_system_pid
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_pid
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: total_backup_distance
                                                    
                                                    	Distance to the network via this backup path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value
                                                    
                                                    	Segment routing sid value received from first hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: num_sid
                                                    
                                                    	Number of SIDs in TI\-LFA/rLFA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_repair_list_size
                                                    
                                                    	Backup Repair List Size
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tilfa_computation
                                                    
                                                    	Ti LFA computation which provided backup path
                                                    	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                    
                                                    .. attribute:: prefix_source_node_id
                                                    
                                                    	PrefixSourceNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: is_downstream
                                                    
                                                    	Is the backup path via downstream node?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_lc_disjoint
                                                    
                                                    	Is the backup path line card disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_node_protecting
                                                    
                                                    	Is the backup path node protecting?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_primary_path
                                                    
                                                    	Is the backup path an ECMP to the network?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_srlg_disjoint
                                                    
                                                    	Is the backup path SRLG disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_remote_lfa
                                                    
                                                    	Is the backup path via a Remote LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_epcfrr_lfa
                                                    
                                                    	Is the backup path via a TI\-LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_strict_spflfa
                                                    
                                                    	Is the backup path TI\-LFA strict SPF?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_requested
                                                    
                                                    	Is SR TE tunnel requested
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight configured on the interface
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value_entry
                                                    
                                                    	Segment routing sid values for TI\-LFA/rLFA
                                                    	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry>`
                                                    
                                                    .. attribute:: backup_repair
                                                    
                                                    	Backup Repair List
                                                    	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup, self).__init__()

                                                        self.yang_name = "frr-backup"
                                                        self.yang_parent_name = "ucmp-next-hop"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair))])
                                                        self._leafs = OrderedDict([
                                                            ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                            ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                            ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                            ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                            ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                            ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                            ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                            ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                            ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                            ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                            ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                            ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                            ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                            ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                            ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                            ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                            ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                            ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                            ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                            ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                            ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                            ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                            ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                            ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ])
                                                        self.neighbor_id = None
                                                        self.egress_interface = None
                                                        self.neighbor_address = None
                                                        self.tunnel_egress_interface = None
                                                        self.neighbor_snpa = None
                                                        self.remote_lfa_system_id = None
                                                        self.remote_lfa_router_id = None
                                                        self.remote_lfa_system_pid = None
                                                        self.remote_lfa_router_pid = None
                                                        self.total_backup_distance = None
                                                        self.segment_routing_sid_value = None
                                                        self.num_sid = None
                                                        self.backup_repair_list_size = None
                                                        self.tilfa_computation = None
                                                        self.prefix_source_node_id = None
                                                        self.is_downstream = None
                                                        self.is_lc_disjoint = None
                                                        self.is_node_protecting = None
                                                        self.is_primary_path = None
                                                        self.is_srlg_disjoint = None
                                                        self.is_remote_lfa = None
                                                        self.is_epcfrr_lfa = None
                                                        self.is_strict_spflfa = None
                                                        self.is_tunnel_requested = None
                                                        self.weight = None

                                                        self.segment_routing_sid_value_entry = YList(self)
                                                        self.backup_repair = YList(self)
                                                        self._segment_path = lambda: "frr-backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                    class SegmentRoutingSidValueEntry(Entity):
                                                        """
                                                        Segment routing sid values for TI\-LFA/rLFA
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                            self.yang_name = "segment-routing-sid-value-entry"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                    class BackupRepair(Entity):
                                                        """
                                                        Backup Repair List
                                                        
                                                        .. attribute:: repair_element_node_id
                                                        
                                                        	RepairElementNodeID
                                                        	**type**\: str
                                                        
                                                        .. attribute:: repair_ipv4_addr
                                                        
                                                        	RepairIPv4Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_ipv6_addr
                                                        
                                                        	RepairIPv6Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_label
                                                        
                                                        	Repair Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_element_type
                                                        
                                                        	Repair Element Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_strict_spf_label
                                                        
                                                        	Repair Strict SPF Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair, self).__init__()

                                                            self.yang_name = "backup-repair"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                                ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                                ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                                ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                                ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                                ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                            ])
                                                            self.repair_element_node_id = None
                                                            self.repair_ipv4_addr = None
                                                            self.repair_ipv6_addr = None
                                                            self.repair_label = None
                                                            self.repair_element_type = None
                                                            self.repair_strict_spf_label = None
                                                            self._segment_path = lambda: "backup-repair"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class MulticastPath(Entity):
                                                """
                                                Multicast intact first hops toward the prefix
                                                
                                                .. attribute:: frr_backup
                                                
                                                	FRR backup for this path
                                                	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup>`
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: tag
                                                
                                                	Tag associated with the path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_interface
                                                
                                                	Explicit path tunnel interface
                                                	**type**\: str
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_te_tunnel_interface
                                                
                                                	Is path via a TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: is_sr_exclude_tunnel_interface
                                                
                                                	Is path via an SR\-exclude TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: uloop_explicit
                                                
                                                	Uloop Explicit List
                                                	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit>`
                                                
                                                .. attribute:: nnh
                                                
                                                	Next next hops
                                                	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.Nnh>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath, self).__init__()

                                                    self.yang_name = "multicast-path"
                                                    self.yang_parent_name = "backup"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.Nnh))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                        ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.neighbor_snpa = None
                                                    self.tag = None
                                                    self.tunnel_interface = None
                                                    self.segment_routing_sid_value = None
                                                    self.weight = None
                                                    self.is_te_tunnel_interface = None
                                                    self.is_sr_exclude_tunnel_interface = None

                                                    self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup()
                                                    self.frr_backup.parent = self
                                                    self._children_name_map["frr_backup"] = "frr-backup"

                                                    self.uloop_explicit = YList(self)
                                                    self.nnh = YList(self)
                                                    self._segment_path = lambda: "multicast-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                                class FrrBackup(Entity):
                                                    """
                                                    FRR backup for this path
                                                    
                                                    .. attribute:: neighbor_id
                                                    
                                                    	Next hop neighbor ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: egress_interface
                                                    
                                                    	Interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Next hop neighbor's forwarding address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: tunnel_egress_interface
                                                    
                                                    	Tunnel Interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_snpa
                                                    
                                                    	Next hop neighbor's SNPA
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_system_id
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_id
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: remote_lfa_system_pid
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_pid
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: total_backup_distance
                                                    
                                                    	Distance to the network via this backup path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value
                                                    
                                                    	Segment routing sid value received from first hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: num_sid
                                                    
                                                    	Number of SIDs in TI\-LFA/rLFA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_repair_list_size
                                                    
                                                    	Backup Repair List Size
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tilfa_computation
                                                    
                                                    	Ti LFA computation which provided backup path
                                                    	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                    
                                                    .. attribute:: prefix_source_node_id
                                                    
                                                    	PrefixSourceNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: is_downstream
                                                    
                                                    	Is the backup path via downstream node?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_lc_disjoint
                                                    
                                                    	Is the backup path line card disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_node_protecting
                                                    
                                                    	Is the backup path node protecting?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_primary_path
                                                    
                                                    	Is the backup path an ECMP to the network?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_srlg_disjoint
                                                    
                                                    	Is the backup path SRLG disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_remote_lfa
                                                    
                                                    	Is the backup path via a Remote LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_epcfrr_lfa
                                                    
                                                    	Is the backup path via a TI\-LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_strict_spflfa
                                                    
                                                    	Is the backup path TI\-LFA strict SPF?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_requested
                                                    
                                                    	Is SR TE tunnel requested
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight configured on the interface
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value_entry
                                                    
                                                    	Segment routing sid values for TI\-LFA/rLFA
                                                    	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                    
                                                    .. attribute:: backup_repair
                                                    
                                                    	Backup Repair List
                                                    	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup, self).__init__()

                                                        self.yang_name = "frr-backup"
                                                        self.yang_parent_name = "multicast-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair))])
                                                        self._leafs = OrderedDict([
                                                            ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                            ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                            ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                            ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                            ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                            ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                            ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                            ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                            ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                            ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                            ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                            ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                            ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                            ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                            ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                            ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                            ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                            ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                            ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                            ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                            ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                            ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                            ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                            ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ])
                                                        self.neighbor_id = None
                                                        self.egress_interface = None
                                                        self.neighbor_address = None
                                                        self.tunnel_egress_interface = None
                                                        self.neighbor_snpa = None
                                                        self.remote_lfa_system_id = None
                                                        self.remote_lfa_router_id = None
                                                        self.remote_lfa_system_pid = None
                                                        self.remote_lfa_router_pid = None
                                                        self.total_backup_distance = None
                                                        self.segment_routing_sid_value = None
                                                        self.num_sid = None
                                                        self.backup_repair_list_size = None
                                                        self.tilfa_computation = None
                                                        self.prefix_source_node_id = None
                                                        self.is_downstream = None
                                                        self.is_lc_disjoint = None
                                                        self.is_node_protecting = None
                                                        self.is_primary_path = None
                                                        self.is_srlg_disjoint = None
                                                        self.is_remote_lfa = None
                                                        self.is_epcfrr_lfa = None
                                                        self.is_strict_spflfa = None
                                                        self.is_tunnel_requested = None
                                                        self.weight = None

                                                        self.segment_routing_sid_value_entry = YList(self)
                                                        self.backup_repair = YList(self)
                                                        self._segment_path = lambda: "frr-backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                    class SegmentRoutingSidValueEntry(Entity):
                                                        """
                                                        Segment routing sid values for TI\-LFA/rLFA
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                            self.yang_name = "segment-routing-sid-value-entry"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                    class BackupRepair(Entity):
                                                        """
                                                        Backup Repair List
                                                        
                                                        .. attribute:: repair_element_node_id
                                                        
                                                        	RepairElementNodeID
                                                        	**type**\: str
                                                        
                                                        .. attribute:: repair_ipv4_addr
                                                        
                                                        	RepairIPv4Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_ipv6_addr
                                                        
                                                        	RepairIPv6Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_label
                                                        
                                                        	Repair Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_element_type
                                                        
                                                        	Repair Element Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_strict_spf_label
                                                        
                                                        	Repair Strict SPF Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair, self).__init__()

                                                            self.yang_name = "backup-repair"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                                ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                                ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                                ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                                ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                                ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                            ])
                                                            self.repair_element_node_id = None
                                                            self.repair_ipv4_addr = None
                                                            self.repair_ipv6_addr = None
                                                            self.repair_label = None
                                                            self.repair_element_type = None
                                                            self.repair_strict_spf_label = None
                                                            self._segment_path = lambda: "backup-repair"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class UloopExplicit(Entity):
                                                    """
                                                    Uloop Explicit List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit, self).__init__()

                                                        self.yang_name = "uloop-explicit"
                                                        self.yang_parent_name = "multicast-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "uloop-explicit"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class Nnh(Entity):
                                                    """
                                                    Next next hops
                                                    
                                                    .. attribute:: link_id_set
                                                    
                                                    	If link\_id is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ipv4_set
                                                    
                                                    	If ipv4 address is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: link_id
                                                    
                                                    	link ID of the next next hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	Ipv4 address of the next next hop
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.Nnh, self).__init__()

                                                        self.yang_name = "nnh"
                                                        self.yang_parent_name = "multicast-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                            ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                            ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ])
                                                        self.link_id_set = None
                                                        self.ipv4_set = None
                                                        self.link_id = None
                                                        self.ipv4_address = None
                                                        self._segment_path = lambda: "nnh"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastPath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                            class SrtePath(Entity):
                                                """
                                                SR\-TE native first hops toward the prefix
                                                
                                                .. attribute:: frr_backup
                                                
                                                	FRR backup for this path
                                                	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup>`
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: tag
                                                
                                                	Tag associated with the path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_interface
                                                
                                                	Explicit path tunnel interface
                                                	**type**\: str
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_te_tunnel_interface
                                                
                                                	Is path via a TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: is_sr_exclude_tunnel_interface
                                                
                                                	Is path via an SR\-exclude TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: uloop_explicit
                                                
                                                	Uloop Explicit List
                                                	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit>`
                                                
                                                .. attribute:: nnh
                                                
                                                	Next next hops
                                                	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.Nnh>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath, self).__init__()

                                                    self.yang_name = "srte-path"
                                                    self.yang_parent_name = "backup"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.Nnh))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                        ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.neighbor_snpa = None
                                                    self.tag = None
                                                    self.tunnel_interface = None
                                                    self.segment_routing_sid_value = None
                                                    self.weight = None
                                                    self.is_te_tunnel_interface = None
                                                    self.is_sr_exclude_tunnel_interface = None

                                                    self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup()
                                                    self.frr_backup.parent = self
                                                    self._children_name_map["frr_backup"] = "frr-backup"

                                                    self.uloop_explicit = YList(self)
                                                    self.nnh = YList(self)
                                                    self._segment_path = lambda: "srte-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                                class FrrBackup(Entity):
                                                    """
                                                    FRR backup for this path
                                                    
                                                    .. attribute:: neighbor_id
                                                    
                                                    	Next hop neighbor ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: egress_interface
                                                    
                                                    	Interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Next hop neighbor's forwarding address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: tunnel_egress_interface
                                                    
                                                    	Tunnel Interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_snpa
                                                    
                                                    	Next hop neighbor's SNPA
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_system_id
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_id
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: remote_lfa_system_pid
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_pid
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: total_backup_distance
                                                    
                                                    	Distance to the network via this backup path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value
                                                    
                                                    	Segment routing sid value received from first hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: num_sid
                                                    
                                                    	Number of SIDs in TI\-LFA/rLFA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_repair_list_size
                                                    
                                                    	Backup Repair List Size
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tilfa_computation
                                                    
                                                    	Ti LFA computation which provided backup path
                                                    	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                    
                                                    .. attribute:: prefix_source_node_id
                                                    
                                                    	PrefixSourceNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: is_downstream
                                                    
                                                    	Is the backup path via downstream node?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_lc_disjoint
                                                    
                                                    	Is the backup path line card disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_node_protecting
                                                    
                                                    	Is the backup path node protecting?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_primary_path
                                                    
                                                    	Is the backup path an ECMP to the network?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_srlg_disjoint
                                                    
                                                    	Is the backup path SRLG disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_remote_lfa
                                                    
                                                    	Is the backup path via a Remote LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_epcfrr_lfa
                                                    
                                                    	Is the backup path via a TI\-LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_strict_spflfa
                                                    
                                                    	Is the backup path TI\-LFA strict SPF?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_requested
                                                    
                                                    	Is SR TE tunnel requested
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight configured on the interface
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value_entry
                                                    
                                                    	Segment routing sid values for TI\-LFA/rLFA
                                                    	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                    
                                                    .. attribute:: backup_repair
                                                    
                                                    	Backup Repair List
                                                    	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup, self).__init__()

                                                        self.yang_name = "frr-backup"
                                                        self.yang_parent_name = "srte-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair))])
                                                        self._leafs = OrderedDict([
                                                            ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                            ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                            ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                            ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                            ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                            ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                            ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                            ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                            ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                            ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                            ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                            ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                            ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                            ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                            ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                            ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                            ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                            ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                            ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                            ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                            ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                            ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                            ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                            ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ])
                                                        self.neighbor_id = None
                                                        self.egress_interface = None
                                                        self.neighbor_address = None
                                                        self.tunnel_egress_interface = None
                                                        self.neighbor_snpa = None
                                                        self.remote_lfa_system_id = None
                                                        self.remote_lfa_router_id = None
                                                        self.remote_lfa_system_pid = None
                                                        self.remote_lfa_router_pid = None
                                                        self.total_backup_distance = None
                                                        self.segment_routing_sid_value = None
                                                        self.num_sid = None
                                                        self.backup_repair_list_size = None
                                                        self.tilfa_computation = None
                                                        self.prefix_source_node_id = None
                                                        self.is_downstream = None
                                                        self.is_lc_disjoint = None
                                                        self.is_node_protecting = None
                                                        self.is_primary_path = None
                                                        self.is_srlg_disjoint = None
                                                        self.is_remote_lfa = None
                                                        self.is_epcfrr_lfa = None
                                                        self.is_strict_spflfa = None
                                                        self.is_tunnel_requested = None
                                                        self.weight = None

                                                        self.segment_routing_sid_value_entry = YList(self)
                                                        self.backup_repair = YList(self)
                                                        self._segment_path = lambda: "frr-backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                    class SegmentRoutingSidValueEntry(Entity):
                                                        """
                                                        Segment routing sid values for TI\-LFA/rLFA
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                            self.yang_name = "segment-routing-sid-value-entry"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                    class BackupRepair(Entity):
                                                        """
                                                        Backup Repair List
                                                        
                                                        .. attribute:: repair_element_node_id
                                                        
                                                        	RepairElementNodeID
                                                        	**type**\: str
                                                        
                                                        .. attribute:: repair_ipv4_addr
                                                        
                                                        	RepairIPv4Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_ipv6_addr
                                                        
                                                        	RepairIPv6Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_label
                                                        
                                                        	Repair Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_element_type
                                                        
                                                        	Repair Element Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_strict_spf_label
                                                        
                                                        	Repair Strict SPF Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair, self).__init__()

                                                            self.yang_name = "backup-repair"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                                ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                                ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                                ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                                ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                                ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                            ])
                                                            self.repair_element_node_id = None
                                                            self.repair_ipv4_addr = None
                                                            self.repair_ipv6_addr = None
                                                            self.repair_label = None
                                                            self.repair_element_type = None
                                                            self.repair_strict_spf_label = None
                                                            self._segment_path = lambda: "backup-repair"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class UloopExplicit(Entity):
                                                    """
                                                    Uloop Explicit List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit, self).__init__()

                                                        self.yang_name = "uloop-explicit"
                                                        self.yang_parent_name = "srte-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "uloop-explicit"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class Nnh(Entity):
                                                    """
                                                    Next next hops
                                                    
                                                    .. attribute:: link_id_set
                                                    
                                                    	If link\_id is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ipv4_set
                                                    
                                                    	If ipv4 address is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: link_id
                                                    
                                                    	link ID of the next next hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	Ipv4 address of the next next hop
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.Nnh, self).__init__()

                                                        self.yang_name = "nnh"
                                                        self.yang_parent_name = "srte-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                            ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                            ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ])
                                                        self.link_id_set = None
                                                        self.ipv4_set = None
                                                        self.link_id = None
                                                        self.ipv4_address = None
                                                        self._segment_path = lambda: "nnh"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.SrtePath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                            class ExplicitPath(Entity):
                                                """
                                                SR microloop avoidance paths
                                                
                                                .. attribute:: frr_backup
                                                
                                                	FRR backup for this path
                                                	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup>`
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: tag
                                                
                                                	Tag associated with the path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tunnel_interface
                                                
                                                	Explicit path tunnel interface
                                                	**type**\: str
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: is_te_tunnel_interface
                                                
                                                	Is path via a TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: is_sr_exclude_tunnel_interface
                                                
                                                	Is path via an SR\-exclude TE tunnel
                                                	**type**\: bool
                                                
                                                .. attribute:: uloop_explicit
                                                
                                                	Uloop Explicit List
                                                	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit>`
                                                
                                                .. attribute:: nnh
                                                
                                                	Next next hops
                                                	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.Nnh>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath, self).__init__()

                                                    self.yang_name = "explicit-path"
                                                    self.yang_parent_name = "backup"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.Nnh))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                        ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                        ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.neighbor_snpa = None
                                                    self.tag = None
                                                    self.tunnel_interface = None
                                                    self.segment_routing_sid_value = None
                                                    self.weight = None
                                                    self.is_te_tunnel_interface = None
                                                    self.is_sr_exclude_tunnel_interface = None

                                                    self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup()
                                                    self.frr_backup.parent = self
                                                    self._children_name_map["frr_backup"] = "frr-backup"

                                                    self.uloop_explicit = YList(self)
                                                    self.nnh = YList(self)
                                                    self._segment_path = lambda: "explicit-path"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                                class FrrBackup(Entity):
                                                    """
                                                    FRR backup for this path
                                                    
                                                    .. attribute:: neighbor_id
                                                    
                                                    	Next hop neighbor ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: egress_interface
                                                    
                                                    	Interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_address
                                                    
                                                    	Next hop neighbor's forwarding address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: tunnel_egress_interface
                                                    
                                                    	Tunnel Interface to send the packet out of
                                                    	**type**\: str
                                                    
                                                    .. attribute:: neighbor_snpa
                                                    
                                                    	Next hop neighbor's SNPA
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_system_id
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_id
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: remote_lfa_system_pid
                                                    
                                                    	Remote LFA PQ Node's ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                    
                                                    .. attribute:: remote_lfa_router_pid
                                                    
                                                    	Remote LFA Router ID
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: total_backup_distance
                                                    
                                                    	Distance to the network via this backup path
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value
                                                    
                                                    	Segment routing sid value received from first hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: num_sid
                                                    
                                                    	Number of SIDs in TI\-LFA/rLFA
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_repair_list_size
                                                    
                                                    	Backup Repair List Size
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: tilfa_computation
                                                    
                                                    	Ti LFA computation which provided backup path
                                                    	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                    
                                                    .. attribute:: prefix_source_node_id
                                                    
                                                    	PrefixSourceNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: is_downstream
                                                    
                                                    	Is the backup path via downstream node?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_lc_disjoint
                                                    
                                                    	Is the backup path line card disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_node_protecting
                                                    
                                                    	Is the backup path node protecting?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_primary_path
                                                    
                                                    	Is the backup path an ECMP to the network?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_srlg_disjoint
                                                    
                                                    	Is the backup path SRLG disjoint with primary?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_remote_lfa
                                                    
                                                    	Is the backup path via a Remote LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_epcfrr_lfa
                                                    
                                                    	Is the backup path via a TI\-LFA?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_strict_spflfa
                                                    
                                                    	Is the backup path TI\-LFA strict SPF?
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: is_tunnel_requested
                                                    
                                                    	Is SR TE tunnel requested
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: weight
                                                    
                                                    	Weight configured on the interface
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segment_routing_sid_value_entry
                                                    
                                                    	Segment routing sid values for TI\-LFA/rLFA
                                                    	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                    
                                                    .. attribute:: backup_repair
                                                    
                                                    	Backup Repair List
                                                    	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup, self).__init__()

                                                        self.yang_name = "frr-backup"
                                                        self.yang_parent_name = "explicit-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair))])
                                                        self._leafs = OrderedDict([
                                                            ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                            ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                            ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                            ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                            ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                            ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                            ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                            ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                            ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                            ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                            ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                            ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                            ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                            ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                            ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                            ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                            ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                            ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                            ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                            ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                            ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                            ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                            ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                            ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                            ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                        ])
                                                        self.neighbor_id = None
                                                        self.egress_interface = None
                                                        self.neighbor_address = None
                                                        self.tunnel_egress_interface = None
                                                        self.neighbor_snpa = None
                                                        self.remote_lfa_system_id = None
                                                        self.remote_lfa_router_id = None
                                                        self.remote_lfa_system_pid = None
                                                        self.remote_lfa_router_pid = None
                                                        self.total_backup_distance = None
                                                        self.segment_routing_sid_value = None
                                                        self.num_sid = None
                                                        self.backup_repair_list_size = None
                                                        self.tilfa_computation = None
                                                        self.prefix_source_node_id = None
                                                        self.is_downstream = None
                                                        self.is_lc_disjoint = None
                                                        self.is_node_protecting = None
                                                        self.is_primary_path = None
                                                        self.is_srlg_disjoint = None
                                                        self.is_remote_lfa = None
                                                        self.is_epcfrr_lfa = None
                                                        self.is_strict_spflfa = None
                                                        self.is_tunnel_requested = None
                                                        self.weight = None

                                                        self.segment_routing_sid_value_entry = YList(self)
                                                        self.backup_repair = YList(self)
                                                        self._segment_path = lambda: "frr-backup"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                    class SegmentRoutingSidValueEntry(Entity):
                                                        """
                                                        Segment routing sid values for TI\-LFA/rLFA
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                            self.yang_name = "segment-routing-sid-value-entry"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                            ])
                                                            self.entry = None
                                                            self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                    class BackupRepair(Entity):
                                                        """
                                                        Backup Repair List
                                                        
                                                        .. attribute:: repair_element_node_id
                                                        
                                                        	RepairElementNodeID
                                                        	**type**\: str
                                                        
                                                        .. attribute:: repair_ipv4_addr
                                                        
                                                        	RepairIPv4Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_ipv6_addr
                                                        
                                                        	RepairIPv6Addr
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: repair_label
                                                        
                                                        	Repair Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_element_type
                                                        
                                                        	Repair Element Type
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: repair_strict_spf_label
                                                        
                                                        	Repair Strict SPF Label
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair, self).__init__()

                                                            self.yang_name = "backup-repair"
                                                            self.yang_parent_name = "frr-backup"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                                ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                                ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                                ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                                ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                                ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                            ])
                                                            self.repair_element_node_id = None
                                                            self.repair_ipv4_addr = None
                                                            self.repair_ipv6_addr = None
                                                            self.repair_label = None
                                                            self.repair_element_type = None
                                                            self.repair_strict_spf_label = None
                                                            self._segment_path = lambda: "backup-repair"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class UloopExplicit(Entity):
                                                    """
                                                    Uloop Explicit List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit, self).__init__()

                                                        self.yang_name = "uloop-explicit"
                                                        self.yang_parent_name = "explicit-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "uloop-explicit"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                                class Nnh(Entity):
                                                    """
                                                    Next next hops
                                                    
                                                    .. attribute:: link_id_set
                                                    
                                                    	If link\_id is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: ipv4_set
                                                    
                                                    	If ipv4 address is given
                                                    	**type**\: bool
                                                    
                                                    .. attribute:: link_id
                                                    
                                                    	link ID of the next next hop
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	Ipv4 address of the next next hop
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.Nnh, self).__init__()

                                                        self.yang_name = "nnh"
                                                        self.yang_parent_name = "explicit-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                            ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                            ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                            ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                        ])
                                                        self.link_id_set = None
                                                        self.ipv4_set = None
                                                        self.link_id = None
                                                        self.ipv4_address = None
                                                        self._segment_path = lambda: "nnh"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.ExplicitPath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                            class Source(Entity):
                                                """
                                                Sources advertising the prefix
                                                
                                                .. attribute:: source_lsp_id
                                                
                                                	ID of the LSP advertising the prefix
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                                
                                                .. attribute:: source_address
                                                
                                                	Source address of the IS advertising the prefix
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tags
                                                
                                                	Tags associated with the prefix item
                                                	**type**\: list of  		 :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Source.Tags>`
                                                
                                                .. attribute:: nodal_sid
                                                
                                                	Nodal SIDs with the prefix item
                                                	**type**\: list of  		 :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Source.NodalSid>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Source, self).__init__()

                                                    self.yang_name = "source"
                                                    self.yang_parent_name = "backup"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tags", ("tags", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Source.Tags)), ("nodal-sid", ("nodal_sid", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Source.NodalSid))])
                                                    self._leafs = OrderedDict([
                                                        ('source_lsp_id', (YLeaf(YType.str, 'source-lsp-id'), ['str'])),
                                                        ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                                    ])
                                                    self.source_lsp_id = None
                                                    self.source_address = None

                                                    self.tags = YList(self)
                                                    self.nodal_sid = YList(self)
                                                    self._segment_path = lambda: "source"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Source, [u'source_lsp_id', u'source_address'], name, value)


                                                class Tags(Entity):
                                                    """
                                                    Tags associated with the prefix item
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Source.Tags, self).__init__()

                                                        self.yang_name = "tags"
                                                        self.yang_parent_name = "source"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "tags"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Source.Tags, [u'entry'], name, value)


                                                class NodalSid(Entity):
                                                    """
                                                    Nodal SIDs with the prefix item
                                                    
                                                    .. attribute:: sid_value
                                                    
                                                    	sid value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rflag
                                                    
                                                    	rflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nflag
                                                    
                                                    	nflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pflag
                                                    
                                                    	pflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: eflag
                                                    
                                                    	eflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: vflag
                                                    
                                                    	vflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: lflag
                                                    
                                                    	lflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: algorithm
                                                    
                                                    	algorithm
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Source.NodalSid, self).__init__()

                                                        self.yang_name = "nodal-sid"
                                                        self.yang_parent_name = "source"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('sid_value', (YLeaf(YType.uint32, 'sid-value'), ['int'])),
                                                            ('rflag', (YLeaf(YType.uint8, 'rflag'), ['int'])),
                                                            ('nflag', (YLeaf(YType.uint8, 'nflag'), ['int'])),
                                                            ('pflag', (YLeaf(YType.uint8, 'pflag'), ['int'])),
                                                            ('eflag', (YLeaf(YType.uint8, 'eflag'), ['int'])),
                                                            ('vflag', (YLeaf(YType.uint8, 'vflag'), ['int'])),
                                                            ('lflag', (YLeaf(YType.uint8, 'lflag'), ['int'])),
                                                            ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                                        ])
                                                        self.sid_value = None
                                                        self.rflag = None
                                                        self.nflag = None
                                                        self.pflag = None
                                                        self.eflag = None
                                                        self.vflag = None
                                                        self.lflag = None
                                                        self.algorithm = None
                                                        self._segment_path = lambda: "nodal-sid"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.Source.NodalSid, [u'sid_value', u'rflag', u'nflag', u'pflag', u'eflag', u'vflag', u'lflag', u'algorithm'], name, value)


                                            class MulticastSource(Entity):
                                                """
                                                Multicast\-intact sources advertising the prefix
                                                
                                                .. attribute:: source_lsp_id
                                                
                                                	ID of the LSP advertising the prefix
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                                
                                                .. attribute:: source_address
                                                
                                                	Source address of the IS advertising the prefix
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tags
                                                
                                                	Tags associated with the prefix item
                                                	**type**\: list of  		 :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastSource.Tags>`
                                                
                                                .. attribute:: nodal_sid
                                                
                                                	Nodal SIDs with the prefix item
                                                	**type**\: list of  		 :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastSource, self).__init__()

                                                    self.yang_name = "multicast-source"
                                                    self.yang_parent_name = "backup"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tags", ("tags", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastSource.Tags)), ("nodal-sid", ("nodal_sid", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid))])
                                                    self._leafs = OrderedDict([
                                                        ('source_lsp_id', (YLeaf(YType.str, 'source-lsp-id'), ['str'])),
                                                        ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                                    ])
                                                    self.source_lsp_id = None
                                                    self.source_address = None

                                                    self.tags = YList(self)
                                                    self.nodal_sid = YList(self)
                                                    self._segment_path = lambda: "multicast-source"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastSource, [u'source_lsp_id', u'source_address'], name, value)


                                                class Tags(Entity):
                                                    """
                                                    Tags associated with the prefix item
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastSource.Tags, self).__init__()

                                                        self.yang_name = "tags"
                                                        self.yang_parent_name = "multicast-source"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "tags"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastSource.Tags, [u'entry'], name, value)


                                                class NodalSid(Entity):
                                                    """
                                                    Nodal SIDs with the prefix item
                                                    
                                                    .. attribute:: sid_value
                                                    
                                                    	sid value
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: rflag
                                                    
                                                    	rflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: nflag
                                                    
                                                    	nflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: pflag
                                                    
                                                    	pflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: eflag
                                                    
                                                    	eflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: vflag
                                                    
                                                    	vflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: lflag
                                                    
                                                    	lflag
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: algorithm
                                                    
                                                    	algorithm
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid, self).__init__()

                                                        self.yang_name = "nodal-sid"
                                                        self.yang_parent_name = "multicast-source"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('sid_value', (YLeaf(YType.uint32, 'sid-value'), ['int'])),
                                                            ('rflag', (YLeaf(YType.uint8, 'rflag'), ['int'])),
                                                            ('nflag', (YLeaf(YType.uint8, 'nflag'), ['int'])),
                                                            ('pflag', (YLeaf(YType.uint8, 'pflag'), ['int'])),
                                                            ('eflag', (YLeaf(YType.uint8, 'eflag'), ['int'])),
                                                            ('vflag', (YLeaf(YType.uint8, 'vflag'), ['int'])),
                                                            ('lflag', (YLeaf(YType.uint8, 'lflag'), ['int'])),
                                                            ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                                        ])
                                                        self.sid_value = None
                                                        self.rflag = None
                                                        self.nflag = None
                                                        self.pflag = None
                                                        self.eflag = None
                                                        self.vflag = None
                                                        self.lflag = None
                                                        self.algorithm = None
                                                        self._segment_path = lambda: "nodal-sid"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid, [u'sid_value', u'rflag', u'nflag', u'pflag', u'eflag', u'vflag', u'lflag', u'algorithm'], name, value)


                                class PerLevelAdvertisingDetail(Entity):
                                    """
                                    Per level details of how the local system
                                    advertises the prefix
                                    
                                    .. attribute:: summarization_status
                                    
                                    	Status of summarization for the prefix
                                    	**type**\:  :py:class:`SummarizationStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.PerLevelAdvertisingDetail.SummarizationStatus>`
                                    
                                    .. attribute:: level
                                    
                                    	Level in which the prefix is advertised
                                    	**type**\:  :py:class:`IsisLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevel>`
                                    
                                    .. attribute:: advertising_origin
                                    
                                    	The origin of the advertisement
                                    	**type**\:  :py:class:`IsisShRouteAdvOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisShRouteAdvOrigin>`
                                    
                                    .. attribute:: metric
                                    
                                    	Metric with which the prefix is advertised
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_propagated
                                    
                                    	Has the prefix been propagated from another level?
                                    	**type**\: bool
                                    
                                    .. attribute:: is_external_metric
                                    
                                    	Is the metric an external metric?
                                    	**type**\: bool
                                    
                                    .. attribute:: is_external_reachability
                                    
                                    	Is the prefix external to the IS\-IS domain?
                                    	**type**\: bool
                                    
                                    .. attribute:: is_interarea
                                    
                                    	Is the up/down bit set?
                                    	**type**\: bool
                                    
                                    .. attribute:: tags
                                    
                                    	Tags associated with the prefix
                                    	**type**\: list of  		 :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.PerLevelAdvertisingDetail.Tags>`
                                    
                                    .. attribute:: nodal_sid
                                    
                                    	Nodal SIDs with the prefix item
                                    	**type**\: list of  		 :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.PerLevelAdvertisingDetail.NodalSid>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.PerLevelAdvertisingDetail, self).__init__()

                                        self.yang_name = "per-level-advertising-detail"
                                        self.yang_parent_name = "ipv4-flex-route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("summarization-status", ("summarization_status", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.PerLevelAdvertisingDetail.SummarizationStatus)), ("tags", ("tags", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.PerLevelAdvertisingDetail.Tags)), ("nodal-sid", ("nodal_sid", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.PerLevelAdvertisingDetail.NodalSid))])
                                        self._leafs = OrderedDict([
                                            ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisLevel', '')])),
                                            ('advertising_origin', (YLeaf(YType.enumeration, 'advertising-origin'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisShRouteAdvOrigin', '')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('is_propagated', (YLeaf(YType.boolean, 'is-propagated'), ['bool'])),
                                            ('is_external_metric', (YLeaf(YType.boolean, 'is-external-metric'), ['bool'])),
                                            ('is_external_reachability', (YLeaf(YType.boolean, 'is-external-reachability'), ['bool'])),
                                            ('is_interarea', (YLeaf(YType.boolean, 'is-interarea'), ['bool'])),
                                        ])
                                        self.level = None
                                        self.advertising_origin = None
                                        self.metric = None
                                        self.is_propagated = None
                                        self.is_external_metric = None
                                        self.is_external_reachability = None
                                        self.is_interarea = None

                                        self.summarization_status = Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.PerLevelAdvertisingDetail.SummarizationStatus()
                                        self.summarization_status.parent = self
                                        self._children_name_map["summarization_status"] = "summarization-status"

                                        self.tags = YList(self)
                                        self.nodal_sid = YList(self)
                                        self._segment_path = lambda: "per-level-advertising-detail"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.PerLevelAdvertisingDetail, [u'level', u'advertising_origin', u'metric', u'is_propagated', u'is_external_metric', u'is_external_reachability', u'is_interarea'], name, value)


                                    class SummarizationStatus(Entity):
                                        """
                                        Status of summarization for the prefix
                                        
                                        .. attribute:: summary_prefix
                                        
                                        	Summarizing Prefix
                                        	**type**\:  :py:class:`SummaryPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	IsValid
                                        	**type**\:  :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.PerLevelAdvertisingDetail.SummarizationStatus, self).__init__()

                                            self.yang_name = "summarization-status"
                                            self.yang_parent_name = "per-level-advertising-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("summary-prefix", ("summary_prefix", Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', (YLeaf(YType.enumeration, 'is-valid'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisValid', '')])),
                                            ])
                                            self.is_valid = None

                                            self.summary_prefix = Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix()
                                            self.summary_prefix.parent = self
                                            self._children_name_map["summary_prefix"] = "summary-prefix"
                                            self._segment_path = lambda: "summarization-status"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.PerLevelAdvertisingDetail.SummarizationStatus, [u'is_valid'], name, value)


                                        class SummaryPrefix(Entity):
                                            """
                                            Summarizing Prefix
                                            
                                            .. attribute:: prefix
                                            
                                            	prefix
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	prefix length
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix, self).__init__()

                                                self.yang_name = "summary-prefix"
                                                self.yang_parent_name = "summarization-status"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                    ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                ])
                                                self.prefix = None
                                                self.prefix_length = None
                                                self._segment_path = lambda: "summary-prefix"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix, [u'prefix', u'prefix_length'], name, value)


                                    class Tags(Entity):
                                        """
                                        Tags associated with the prefix
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.PerLevelAdvertisingDetail.Tags, self).__init__()

                                            self.yang_name = "tags"
                                            self.yang_parent_name = "per-level-advertising-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "tags"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.PerLevelAdvertisingDetail.Tags, [u'entry'], name, value)


                                    class NodalSid(Entity):
                                        """
                                        Nodal SIDs with the prefix item
                                        
                                        .. attribute:: sid_value
                                        
                                        	sid value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rflag
                                        
                                        	rflag
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: nflag
                                        
                                        	nflag
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: pflag
                                        
                                        	pflag
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: eflag
                                        
                                        	eflag
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vflag
                                        
                                        	vflag
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: lflag
                                        
                                        	lflag
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: algorithm
                                        
                                        	algorithm
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.PerLevelAdvertisingDetail.NodalSid, self).__init__()

                                            self.yang_name = "nodal-sid"
                                            self.yang_parent_name = "per-level-advertising-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('sid_value', (YLeaf(YType.uint32, 'sid-value'), ['int'])),
                                                ('rflag', (YLeaf(YType.uint8, 'rflag'), ['int'])),
                                                ('nflag', (YLeaf(YType.uint8, 'nflag'), ['int'])),
                                                ('pflag', (YLeaf(YType.uint8, 'pflag'), ['int'])),
                                                ('eflag', (YLeaf(YType.uint8, 'eflag'), ['int'])),
                                                ('vflag', (YLeaf(YType.uint8, 'vflag'), ['int'])),
                                                ('lflag', (YLeaf(YType.uint8, 'lflag'), ['int'])),
                                                ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                            ])
                                            self.sid_value = None
                                            self.rflag = None
                                            self.nflag = None
                                            self.pflag = None
                                            self.eflag = None
                                            self.vflag = None
                                            self.lflag = None
                                            self.algorithm = None
                                            self._segment_path = lambda: "nodal-sid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4FlexRouteTables.Ipv4FlexRouteTable.Ipv4FlexRoute.PerLevelAdvertisingDetail.NodalSid, [u'sid_value', u'rflag', u'nflag', u'pflag', u'eflag', u'vflag', u'lflag', u'algorithm'], name, value)


                    class Ipv4Routes(Entity):
                        """
                        IPv4 local route table
                        
                        .. attribute:: ipv4_route
                        
                        	An IPv4 route known to IS\-IS
                        	**type**\: list of  		 :py:class:`Ipv4Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes, self).__init__()

                            self.yang_name = "ipv4-routes"
                            self.yang_parent_name = "topology"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ipv4-route", ("ipv4_route", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route))])
                            self._leafs = OrderedDict()

                            self.ipv4_route = YList(self)
                            self._segment_path = lambda: "ipv4-routes"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes, [], name, value)


                        class Ipv4Route(Entity):
                            """
                            An IPv4 route known to IS\-IS
                            
                            .. attribute:: prefix
                            
                            	Prefix
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: prefix_length
                            
                            	Prefix Length
                            	**type**\: int
                            
                            	**range:** 0..32
                            
                            .. attribute:: connected_status
                            
                            	Status of IS\-IS directly connected routes to the prefix
                            	**type**\:  :py:class:`ConnectedStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.ConnectedStatus>`
                            
                            .. attribute:: redistributed_status
                            
                            	Status of other protocols' routes redistributed into IS\-IS
                            	**type**\:  :py:class:`RedistributedStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus>`
                            
                            .. attribute:: native_status
                            
                            	Status of native IS\-IS routes to the prefix
                            	**type**\:  :py:class:`NativeStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus>`
                            
                            .. attribute:: per_level_advertising_detail
                            
                            	Per level details of how the local system advertises the prefix
                            	**type**\: list of  		 :py:class:`PerLevelAdvertisingDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route, self).__init__()

                                self.yang_name = "ipv4-route"
                                self.yang_parent_name = "ipv4-routes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("connected-status", ("connected_status", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.ConnectedStatus)), ("redistributed-status", ("redistributed_status", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus)), ("native-status", ("native_status", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus)), ("per-level-advertising-detail", ("per_level_advertising_detail", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail))])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                    ('prefix_length', (YLeaf(YType.uint32, 'prefix-length'), ['int'])),
                                ])
                                self.prefix = None
                                self.prefix_length = None

                                self.connected_status = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.ConnectedStatus()
                                self.connected_status.parent = self
                                self._children_name_map["connected_status"] = "connected-status"

                                self.redistributed_status = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus()
                                self.redistributed_status.parent = self
                                self._children_name_map["redistributed_status"] = "redistributed-status"

                                self.native_status = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus()
                                self.native_status.parent = self
                                self._children_name_map["native_status"] = "native-status"

                                self.per_level_advertising_detail = YList(self)
                                self._segment_path = lambda: "ipv4-route"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route, ['prefix', 'prefix_length'], name, value)


                            class ConnectedStatus(Entity):
                                """
                                Status of IS\-IS directly connected routes to the
                                prefix
                                
                                .. attribute:: connected_details
                                
                                	Details of the directly connected prefix
                                	**type**\:  :py:class:`ConnectedDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.ConnectedStatus.ConnectedDetails>`
                                
                                .. attribute:: is_valid
                                
                                	IsValid
                                	**type**\:  :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.ConnectedStatus, self).__init__()

                                    self.yang_name = "connected-status"
                                    self.yang_parent_name = "ipv4-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("connected-details", ("connected_details", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.ConnectedStatus.ConnectedDetails))])
                                    self._leafs = OrderedDict([
                                        ('is_valid', (YLeaf(YType.enumeration, 'is-valid'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisValid', '')])),
                                    ])
                                    self.is_valid = None

                                    self.connected_details = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.ConnectedStatus.ConnectedDetails()
                                    self.connected_details.parent = self
                                    self._children_name_map["connected_details"] = "connected-details"
                                    self._segment_path = lambda: "connected-status"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.ConnectedStatus, [u'is_valid'], name, value)


                                class ConnectedDetails(Entity):
                                    """
                                    Details of the directly connected prefix
                                    
                                    .. attribute:: interface
                                    
                                    	Interfaces
                                    	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.ConnectedStatus.ConnectedDetails.Interface>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.ConnectedStatus.ConnectedDetails, self).__init__()

                                        self.yang_name = "connected-details"
                                        self.yang_parent_name = "connected-status"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface", ("interface", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.ConnectedStatus.ConnectedDetails.Interface))])
                                        self._leafs = OrderedDict()

                                        self.interface = YList(self)
                                        self._segment_path = lambda: "connected-details"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.ConnectedStatus.ConnectedDetails, [], name, value)


                                    class Interface(Entity):
                                        """
                                        Interfaces
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.ConnectedStatus.ConnectedDetails.Interface, self).__init__()

                                            self.yang_name = "interface"
                                            self.yang_parent_name = "connected-details"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "interface"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.ConnectedStatus.ConnectedDetails.Interface, [u'entry'], name, value)


                            class RedistributedStatus(Entity):
                                """
                                Status of other protocols' routes redistributed
                                into IS\-IS
                                
                                .. attribute:: redistribution_details
                                
                                	Per level details of the redistributed route
                                	**type**\:  :py:class:`RedistributionDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus.RedistributionDetails>`
                                
                                .. attribute:: is_valid
                                
                                	IsValid
                                	**type**\:  :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus, self).__init__()

                                    self.yang_name = "redistributed-status"
                                    self.yang_parent_name = "ipv4-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("redistribution-details", ("redistribution_details", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus.RedistributionDetails))])
                                    self._leafs = OrderedDict([
                                        ('is_valid', (YLeaf(YType.enumeration, 'is-valid'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisValid', '')])),
                                    ])
                                    self.is_valid = None

                                    self.redistribution_details = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus.RedistributionDetails()
                                    self.redistribution_details.parent = self
                                    self._children_name_map["redistribution_details"] = "redistribution-details"
                                    self._segment_path = lambda: "redistributed-status"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus, [u'is_valid'], name, value)


                                class RedistributionDetails(Entity):
                                    """
                                    Per level details of the redistributed route
                                    
                                    .. attribute:: isis_sh_route_redist_detail
                                    
                                    	isis sh route redist detail
                                    	**type**\: list of  		 :py:class:`IsisShRouteRedistDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus.RedistributionDetails, self).__init__()

                                        self.yang_name = "redistribution-details"
                                        self.yang_parent_name = "redistributed-status"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("isis-sh-route-redist-detail", ("isis_sh_route_redist_detail", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail))])
                                        self._leafs = OrderedDict()

                                        self.isis_sh_route_redist_detail = YList(self)
                                        self._segment_path = lambda: "redistribution-details"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus.RedistributionDetails, [], name, value)


                                    class IsisShRouteRedistDetail(Entity):
                                        """
                                        isis sh route redist detail
                                        
                                        .. attribute:: owner
                                        
                                        	Protocol redistributing the route
                                        	**type**\:  :py:class:`Owner <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner>`
                                        
                                        .. attribute:: level
                                        
                                        	Level into which the route is redistributed
                                        	**type**\:  :py:class:`IsisLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevel>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail, self).__init__()

                                            self.yang_name = "isis-sh-route-redist-detail"
                                            self.yang_parent_name = "redistribution-details"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("owner", ("owner", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner))])
                                            self._leafs = OrderedDict([
                                                ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisLevel', '')])),
                                            ])
                                            self.level = None

                                            self.owner = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner()
                                            self.owner.parent = self
                                            self._children_name_map["owner"] = "owner"
                                            self._segment_path = lambda: "isis-sh-route-redist-detail"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail, [u'level'], name, value)


                                        class Owner(Entity):
                                            """
                                            Protocol redistributing the route
                                            
                                            .. attribute:: protocol
                                            
                                            	Protocol
                                            	**type**\:  :py:class:`IsisRedistProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisRedistProto>`
                                            
                                            .. attribute:: isis_instance_id
                                            
                                            	IS\-IS instance identifier
                                            	**type**\: str
                                            
                                            .. attribute:: ospf_process_id
                                            
                                            	OSPF process identifier
                                            	**type**\: str
                                            
                                            .. attribute:: ospfv3_process_id
                                            
                                            	OSPFv3 process identifier
                                            	**type**\: str
                                            
                                            .. attribute:: bgp_as_number
                                            
                                            	BGP Autonomous System number
                                            	**type**\: str
                                            
                                            .. attribute:: eigrp_as_number
                                            
                                            	EIGRP Autonomous System number
                                            	**type**\: str
                                            
                                            .. attribute:: application_name
                                            
                                            	Application Name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner, self).__init__()

                                                self.yang_name = "owner"
                                                self.yang_parent_name = "isis-sh-route-redist-detail"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisRedistProto', '')])),
                                                    ('isis_instance_id', (YLeaf(YType.str, 'isis-instance-id'), ['str'])),
                                                    ('ospf_process_id', (YLeaf(YType.str, 'ospf-process-id'), ['str'])),
                                                    ('ospfv3_process_id', (YLeaf(YType.str, 'ospfv3-process-id'), ['str'])),
                                                    ('bgp_as_number', (YLeaf(YType.str, 'bgp-as-number'), ['str'])),
                                                    ('eigrp_as_number', (YLeaf(YType.str, 'eigrp-as-number'), ['str'])),
                                                    ('application_name', (YLeaf(YType.str, 'application-name'), ['str'])),
                                                ])
                                                self.protocol = None
                                                self.isis_instance_id = None
                                                self.ospf_process_id = None
                                                self.ospfv3_process_id = None
                                                self.bgp_as_number = None
                                                self.eigrp_as_number = None
                                                self.application_name = None
                                                self._segment_path = lambda: "owner"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.RedistributedStatus.RedistributionDetails.IsisShRouteRedistDetail.Owner, [u'protocol', u'isis_instance_id', u'ospf_process_id', u'ospfv3_process_id', u'bgp_as_number', u'eigrp_as_number', u'application_name'], name, value)


                            class NativeStatus(Entity):
                                """
                                Status of native IS\-IS routes to the prefix
                                
                                .. attribute:: native_details
                                
                                	Details of the native route
                                	**type**\:  :py:class:`NativeDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails>`
                                
                                .. attribute:: is_valid
                                
                                	IsValid
                                	**type**\:  :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus, self).__init__()

                                    self.yang_name = "native-status"
                                    self.yang_parent_name = "ipv4-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("native-details", ("native_details", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails))])
                                    self._leafs = OrderedDict([
                                        ('is_valid', (YLeaf(YType.enumeration, 'is-valid'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisValid', '')])),
                                    ])
                                    self.is_valid = None

                                    self.native_details = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails()
                                    self.native_details.parent = self
                                    self._children_name_map["native_details"] = "native-details"
                                    self._segment_path = lambda: "native-status"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus, [u'is_valid'], name, value)


                                class NativeDetails(Entity):
                                    """
                                    Details of the native route
                                    
                                    .. attribute:: primary
                                    
                                    	Primary paths to prefix
                                    	**type**\:  :py:class:`Primary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary>`
                                    
                                    .. attribute:: priority
                                    
                                    	Relative importance of the prefix
                                    	**type**\:  :py:class:`IsisPrefixPriority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisPrefixPriority>`
                                    
                                    .. attribute:: backup
                                    
                                    	Backup paths to prefix
                                    	**type**\: list of  		 :py:class:`Backup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails, self).__init__()

                                        self.yang_name = "native-details"
                                        self.yang_parent_name = "native-status"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("primary", ("primary", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary)), ("backup", ("backup", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup))])
                                        self._leafs = OrderedDict([
                                            ('priority', (YLeaf(YType.enumeration, 'priority'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisPrefixPriority', '')])),
                                        ])
                                        self.priority = None

                                        self.primary = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary()
                                        self.primary.parent = self
                                        self._children_name_map["primary"] = "primary"

                                        self.backup = YList(self)
                                        self._segment_path = lambda: "native-details"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails, [u'priority'], name, value)


                                    class Primary(Entity):
                                        """
                                        Primary paths to prefix
                                        
                                        .. attribute:: origin
                                        
                                        	Origin of route
                                        	**type**\:  :py:class:`IsisPrefixOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisPrefixOrigin>`
                                        
                                        .. attribute:: metric
                                        
                                        	Distance to network
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multicast_metric
                                        
                                        	Multicast\-intact distance to network
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_external_metric
                                        
                                        	Is the metric an external metric?
                                        	**type**\: bool
                                        
                                        .. attribute:: administrative_distance
                                        
                                        	Administrative Distance
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: paths
                                        
                                        	First hops toward the prefix
                                        	**type**\: list of  		 :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths>`
                                        
                                        .. attribute:: ucmp_next_hop
                                        
                                        	UCMP first hops toward the prefix
                                        	**type**\: list of  		 :py:class:`UcmpNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop>`
                                        
                                        .. attribute:: multicast_path
                                        
                                        	Multicast intact first hops toward the prefix
                                        	**type**\: list of  		 :py:class:`MulticastPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath>`
                                        
                                        .. attribute:: srte_path
                                        
                                        	SR\-TE native first hops toward the prefix
                                        	**type**\: list of  		 :py:class:`SrtePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath>`
                                        
                                        .. attribute:: explicit_path
                                        
                                        	SR microloop avoidance paths
                                        	**type**\: list of  		 :py:class:`ExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath>`
                                        
                                        .. attribute:: source
                                        
                                        	Sources advertising the prefix
                                        	**type**\: list of  		 :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Source>`
                                        
                                        .. attribute:: multicast_source
                                        
                                        	Multicast\-intact sources advertising the prefix
                                        	**type**\: list of  		 :py:class:`MulticastSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastSource>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary, self).__init__()

                                            self.yang_name = "primary"
                                            self.yang_parent_name = "native-details"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("paths", ("paths", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths)), ("ucmp-next-hop", ("ucmp_next_hop", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop)), ("multicast-path", ("multicast_path", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath)), ("srte-path", ("srte_path", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath)), ("explicit-path", ("explicit_path", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath)), ("source", ("source", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Source)), ("multicast-source", ("multicast_source", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastSource))])
                                            self._leafs = OrderedDict([
                                                ('origin', (YLeaf(YType.enumeration, 'origin'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisPrefixOrigin', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('multicast_metric', (YLeaf(YType.uint32, 'multicast-metric'), ['int'])),
                                                ('is_external_metric', (YLeaf(YType.boolean, 'is-external-metric'), ['bool'])),
                                                ('administrative_distance', (YLeaf(YType.uint16, 'administrative-distance'), ['int'])),
                                            ])
                                            self.origin = None
                                            self.metric = None
                                            self.multicast_metric = None
                                            self.is_external_metric = None
                                            self.administrative_distance = None

                                            self.paths = YList(self)
                                            self.ucmp_next_hop = YList(self)
                                            self.multicast_path = YList(self)
                                            self.srte_path = YList(self)
                                            self.explicit_path = YList(self)
                                            self.source = YList(self)
                                            self.multicast_source = YList(self)
                                            self._segment_path = lambda: "primary"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary, [u'origin', u'metric', u'multicast_metric', u'is_external_metric', u'administrative_distance'], name, value)


                                        class Paths(Entity):
                                            """
                                            First hops toward the prefix
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\: str
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit>`
                                            
                                            .. attribute:: nnh
                                            
                                            	Next next hops
                                            	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.Nnh>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths, self).__init__()

                                                self.yang_name = "paths"
                                                self.yang_parent_name = "primary"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.Nnh))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.tunnel_interface = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"

                                                self.uloop_explicit = YList(self)
                                                self.nnh = YList(self)
                                                self._segment_path = lambda: "paths"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                        ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                        ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                        ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                        ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                        ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                    ])
                                                    self.repair_element_node_id = None
                                                    self.repair_ipv4_addr = None
                                                    self.repair_ipv6_addr = None
                                                    self.repair_label = None
                                                    self.repair_element_type = None
                                                    self.repair_strict_spf_label = None
                                                    self._segment_path = lambda: "uloop-explicit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class Nnh(Entity):
                                                """
                                                Next next hops
                                                
                                                .. attribute:: link_id_set
                                                
                                                	If link\_id is given
                                                	**type**\: bool
                                                
                                                .. attribute:: ipv4_set
                                                
                                                	If ipv4 address is given
                                                	**type**\: bool
                                                
                                                .. attribute:: link_id
                                                
                                                	link ID of the next next hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	Ipv4 address of the next next hop
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.Nnh, self).__init__()

                                                    self.yang_name = "nnh"
                                                    self.yang_parent_name = "paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                        ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                        ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ])
                                                    self.link_id_set = None
                                                    self.ipv4_set = None
                                                    self.link_id = None
                                                    self.ipv4_address = None
                                                    self._segment_path = lambda: "nnh"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Paths.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                        class UcmpNextHop(Entity):
                                            """
                                            UCMP first hops toward the prefix
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: total_ucmp_distance
                                            
                                            	Distance to the network via this UCMP next hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop, self).__init__()

                                                self.yang_name = "ucmp-next-hop"
                                                self.yang_parent_name = "primary"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('total_ucmp_distance', (YLeaf(YType.uint32, 'total-ucmp-distance'), ['int'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.total_ucmp_distance = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._segment_path = lambda: "ucmp-next-hop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'total_ucmp_distance', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "ucmp-next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.UcmpNextHop.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                        class MulticastPath(Entity):
                                            """
                                            Multicast intact first hops toward the prefix
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\: str
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit>`
                                            
                                            .. attribute:: nnh
                                            
                                            	Next next hops
                                            	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.Nnh>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath, self).__init__()

                                                self.yang_name = "multicast-path"
                                                self.yang_parent_name = "primary"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.Nnh))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.tunnel_interface = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"

                                                self.uloop_explicit = YList(self)
                                                self.nnh = YList(self)
                                                self._segment_path = lambda: "multicast-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "multicast-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "multicast-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                        ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                        ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                        ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                        ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                        ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                    ])
                                                    self.repair_element_node_id = None
                                                    self.repair_ipv4_addr = None
                                                    self.repair_ipv6_addr = None
                                                    self.repair_label = None
                                                    self.repair_element_type = None
                                                    self.repair_strict_spf_label = None
                                                    self._segment_path = lambda: "uloop-explicit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class Nnh(Entity):
                                                """
                                                Next next hops
                                                
                                                .. attribute:: link_id_set
                                                
                                                	If link\_id is given
                                                	**type**\: bool
                                                
                                                .. attribute:: ipv4_set
                                                
                                                	If ipv4 address is given
                                                	**type**\: bool
                                                
                                                .. attribute:: link_id
                                                
                                                	link ID of the next next hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	Ipv4 address of the next next hop
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.Nnh, self).__init__()

                                                    self.yang_name = "nnh"
                                                    self.yang_parent_name = "multicast-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                        ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                        ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ])
                                                    self.link_id_set = None
                                                    self.ipv4_set = None
                                                    self.link_id = None
                                                    self.ipv4_address = None
                                                    self._segment_path = lambda: "nnh"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastPath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                        class SrtePath(Entity):
                                            """
                                            SR\-TE native first hops toward the prefix
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\: str
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit>`
                                            
                                            .. attribute:: nnh
                                            
                                            	Next next hops
                                            	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.Nnh>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath, self).__init__()

                                                self.yang_name = "srte-path"
                                                self.yang_parent_name = "primary"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.Nnh))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.tunnel_interface = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"

                                                self.uloop_explicit = YList(self)
                                                self.nnh = YList(self)
                                                self._segment_path = lambda: "srte-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "srte-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "srte-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                        ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                        ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                        ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                        ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                        ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                    ])
                                                    self.repair_element_node_id = None
                                                    self.repair_ipv4_addr = None
                                                    self.repair_ipv6_addr = None
                                                    self.repair_label = None
                                                    self.repair_element_type = None
                                                    self.repair_strict_spf_label = None
                                                    self._segment_path = lambda: "uloop-explicit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class Nnh(Entity):
                                                """
                                                Next next hops
                                                
                                                .. attribute:: link_id_set
                                                
                                                	If link\_id is given
                                                	**type**\: bool
                                                
                                                .. attribute:: ipv4_set
                                                
                                                	If ipv4 address is given
                                                	**type**\: bool
                                                
                                                .. attribute:: link_id
                                                
                                                	link ID of the next next hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	Ipv4 address of the next next hop
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.Nnh, self).__init__()

                                                    self.yang_name = "nnh"
                                                    self.yang_parent_name = "srte-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                        ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                        ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ])
                                                    self.link_id_set = None
                                                    self.ipv4_set = None
                                                    self.link_id = None
                                                    self.ipv4_address = None
                                                    self._segment_path = lambda: "nnh"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.SrtePath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                        class ExplicitPath(Entity):
                                            """
                                            SR microloop avoidance paths
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\: str
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit>`
                                            
                                            .. attribute:: nnh
                                            
                                            	Next next hops
                                            	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.Nnh>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath, self).__init__()

                                                self.yang_name = "explicit-path"
                                                self.yang_parent_name = "primary"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.Nnh))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.tunnel_interface = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"

                                                self.uloop_explicit = YList(self)
                                                self.nnh = YList(self)
                                                self._segment_path = lambda: "explicit-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "explicit-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "explicit-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                        ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                        ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                        ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                        ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                        ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                    ])
                                                    self.repair_element_node_id = None
                                                    self.repair_ipv4_addr = None
                                                    self.repair_ipv6_addr = None
                                                    self.repair_label = None
                                                    self.repair_element_type = None
                                                    self.repair_strict_spf_label = None
                                                    self._segment_path = lambda: "uloop-explicit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class Nnh(Entity):
                                                """
                                                Next next hops
                                                
                                                .. attribute:: link_id_set
                                                
                                                	If link\_id is given
                                                	**type**\: bool
                                                
                                                .. attribute:: ipv4_set
                                                
                                                	If ipv4 address is given
                                                	**type**\: bool
                                                
                                                .. attribute:: link_id
                                                
                                                	link ID of the next next hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	Ipv4 address of the next next hop
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.Nnh, self).__init__()

                                                    self.yang_name = "nnh"
                                                    self.yang_parent_name = "explicit-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                        ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                        ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ])
                                                    self.link_id_set = None
                                                    self.ipv4_set = None
                                                    self.link_id = None
                                                    self.ipv4_address = None
                                                    self._segment_path = lambda: "nnh"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.ExplicitPath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                        class Source(Entity):
                                            """
                                            Sources advertising the prefix
                                            
                                            .. attribute:: source_lsp_id
                                            
                                            	ID of the LSP advertising the prefix
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                            
                                            .. attribute:: source_address
                                            
                                            	Source address of the IS advertising the prefix
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: tags
                                            
                                            	Tags associated with the prefix item
                                            	**type**\: list of  		 :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Source.Tags>`
                                            
                                            .. attribute:: nodal_sid
                                            
                                            	Nodal SIDs with the prefix item
                                            	**type**\: list of  		 :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Source.NodalSid>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "primary"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tags", ("tags", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Source.Tags)), ("nodal-sid", ("nodal_sid", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Source.NodalSid))])
                                                self._leafs = OrderedDict([
                                                    ('source_lsp_id', (YLeaf(YType.str, 'source-lsp-id'), ['str'])),
                                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                                ])
                                                self.source_lsp_id = None
                                                self.source_address = None

                                                self.tags = YList(self)
                                                self.nodal_sid = YList(self)
                                                self._segment_path = lambda: "source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Source, [u'source_lsp_id', u'source_address'], name, value)


                                            class Tags(Entity):
                                                """
                                                Tags associated with the prefix item
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Source.Tags, self).__init__()

                                                    self.yang_name = "tags"
                                                    self.yang_parent_name = "source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "tags"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Source.Tags, [u'entry'], name, value)


                                            class NodalSid(Entity):
                                                """
                                                Nodal SIDs with the prefix item
                                                
                                                .. attribute:: sid_value
                                                
                                                	sid value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rflag
                                                
                                                	rflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nflag
                                                
                                                	nflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pflag
                                                
                                                	pflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: eflag
                                                
                                                	eflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: vflag
                                                
                                                	vflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: lflag
                                                
                                                	lflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: algorithm
                                                
                                                	algorithm
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Source.NodalSid, self).__init__()

                                                    self.yang_name = "nodal-sid"
                                                    self.yang_parent_name = "source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('sid_value', (YLeaf(YType.uint32, 'sid-value'), ['int'])),
                                                        ('rflag', (YLeaf(YType.uint8, 'rflag'), ['int'])),
                                                        ('nflag', (YLeaf(YType.uint8, 'nflag'), ['int'])),
                                                        ('pflag', (YLeaf(YType.uint8, 'pflag'), ['int'])),
                                                        ('eflag', (YLeaf(YType.uint8, 'eflag'), ['int'])),
                                                        ('vflag', (YLeaf(YType.uint8, 'vflag'), ['int'])),
                                                        ('lflag', (YLeaf(YType.uint8, 'lflag'), ['int'])),
                                                        ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                                    ])
                                                    self.sid_value = None
                                                    self.rflag = None
                                                    self.nflag = None
                                                    self.pflag = None
                                                    self.eflag = None
                                                    self.vflag = None
                                                    self.lflag = None
                                                    self.algorithm = None
                                                    self._segment_path = lambda: "nodal-sid"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.Source.NodalSid, [u'sid_value', u'rflag', u'nflag', u'pflag', u'eflag', u'vflag', u'lflag', u'algorithm'], name, value)


                                        class MulticastSource(Entity):
                                            """
                                            Multicast\-intact sources advertising the prefix
                                            
                                            .. attribute:: source_lsp_id
                                            
                                            	ID of the LSP advertising the prefix
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                            
                                            .. attribute:: source_address
                                            
                                            	Source address of the IS advertising the prefix
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: tags
                                            
                                            	Tags associated with the prefix item
                                            	**type**\: list of  		 :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastSource.Tags>`
                                            
                                            .. attribute:: nodal_sid
                                            
                                            	Nodal SIDs with the prefix item
                                            	**type**\: list of  		 :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastSource, self).__init__()

                                                self.yang_name = "multicast-source"
                                                self.yang_parent_name = "primary"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tags", ("tags", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastSource.Tags)), ("nodal-sid", ("nodal_sid", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid))])
                                                self._leafs = OrderedDict([
                                                    ('source_lsp_id', (YLeaf(YType.str, 'source-lsp-id'), ['str'])),
                                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                                ])
                                                self.source_lsp_id = None
                                                self.source_address = None

                                                self.tags = YList(self)
                                                self.nodal_sid = YList(self)
                                                self._segment_path = lambda: "multicast-source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastSource, [u'source_lsp_id', u'source_address'], name, value)


                                            class Tags(Entity):
                                                """
                                                Tags associated with the prefix item
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastSource.Tags, self).__init__()

                                                    self.yang_name = "tags"
                                                    self.yang_parent_name = "multicast-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "tags"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastSource.Tags, [u'entry'], name, value)


                                            class NodalSid(Entity):
                                                """
                                                Nodal SIDs with the prefix item
                                                
                                                .. attribute:: sid_value
                                                
                                                	sid value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rflag
                                                
                                                	rflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nflag
                                                
                                                	nflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pflag
                                                
                                                	pflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: eflag
                                                
                                                	eflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: vflag
                                                
                                                	vflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: lflag
                                                
                                                	lflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: algorithm
                                                
                                                	algorithm
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid, self).__init__()

                                                    self.yang_name = "nodal-sid"
                                                    self.yang_parent_name = "multicast-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('sid_value', (YLeaf(YType.uint32, 'sid-value'), ['int'])),
                                                        ('rflag', (YLeaf(YType.uint8, 'rflag'), ['int'])),
                                                        ('nflag', (YLeaf(YType.uint8, 'nflag'), ['int'])),
                                                        ('pflag', (YLeaf(YType.uint8, 'pflag'), ['int'])),
                                                        ('eflag', (YLeaf(YType.uint8, 'eflag'), ['int'])),
                                                        ('vflag', (YLeaf(YType.uint8, 'vflag'), ['int'])),
                                                        ('lflag', (YLeaf(YType.uint8, 'lflag'), ['int'])),
                                                        ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                                    ])
                                                    self.sid_value = None
                                                    self.rflag = None
                                                    self.nflag = None
                                                    self.pflag = None
                                                    self.eflag = None
                                                    self.vflag = None
                                                    self.lflag = None
                                                    self.algorithm = None
                                                    self._segment_path = lambda: "nodal-sid"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Primary.MulticastSource.NodalSid, [u'sid_value', u'rflag', u'nflag', u'pflag', u'eflag', u'vflag', u'lflag', u'algorithm'], name, value)


                                    class Backup(Entity):
                                        """
                                        Backup paths to prefix
                                        
                                        .. attribute:: origin
                                        
                                        	Origin of route
                                        	**type**\:  :py:class:`IsisPrefixOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisPrefixOrigin>`
                                        
                                        .. attribute:: metric
                                        
                                        	Distance to network
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: multicast_metric
                                        
                                        	Multicast\-intact distance to network
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_external_metric
                                        
                                        	Is the metric an external metric?
                                        	**type**\: bool
                                        
                                        .. attribute:: administrative_distance
                                        
                                        	Administrative Distance
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: paths
                                        
                                        	First hops toward the prefix
                                        	**type**\: list of  		 :py:class:`Paths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths>`
                                        
                                        .. attribute:: ucmp_next_hop
                                        
                                        	UCMP first hops toward the prefix
                                        	**type**\: list of  		 :py:class:`UcmpNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop>`
                                        
                                        .. attribute:: multicast_path
                                        
                                        	Multicast intact first hops toward the prefix
                                        	**type**\: list of  		 :py:class:`MulticastPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath>`
                                        
                                        .. attribute:: srte_path
                                        
                                        	SR\-TE native first hops toward the prefix
                                        	**type**\: list of  		 :py:class:`SrtePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath>`
                                        
                                        .. attribute:: explicit_path
                                        
                                        	SR microloop avoidance paths
                                        	**type**\: list of  		 :py:class:`ExplicitPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath>`
                                        
                                        .. attribute:: source
                                        
                                        	Sources advertising the prefix
                                        	**type**\: list of  		 :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Source>`
                                        
                                        .. attribute:: multicast_source
                                        
                                        	Multicast\-intact sources advertising the prefix
                                        	**type**\: list of  		 :py:class:`MulticastSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastSource>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup, self).__init__()

                                            self.yang_name = "backup"
                                            self.yang_parent_name = "native-details"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("paths", ("paths", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths)), ("ucmp-next-hop", ("ucmp_next_hop", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop)), ("multicast-path", ("multicast_path", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath)), ("srte-path", ("srte_path", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath)), ("explicit-path", ("explicit_path", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath)), ("source", ("source", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Source)), ("multicast-source", ("multicast_source", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastSource))])
                                            self._leafs = OrderedDict([
                                                ('origin', (YLeaf(YType.enumeration, 'origin'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisPrefixOrigin', '')])),
                                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                ('multicast_metric', (YLeaf(YType.uint32, 'multicast-metric'), ['int'])),
                                                ('is_external_metric', (YLeaf(YType.boolean, 'is-external-metric'), ['bool'])),
                                                ('administrative_distance', (YLeaf(YType.uint16, 'administrative-distance'), ['int'])),
                                            ])
                                            self.origin = None
                                            self.metric = None
                                            self.multicast_metric = None
                                            self.is_external_metric = None
                                            self.administrative_distance = None

                                            self.paths = YList(self)
                                            self.ucmp_next_hop = YList(self)
                                            self.multicast_path = YList(self)
                                            self.srte_path = YList(self)
                                            self.explicit_path = YList(self)
                                            self.source = YList(self)
                                            self.multicast_source = YList(self)
                                            self._segment_path = lambda: "backup"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup, [u'origin', u'metric', u'multicast_metric', u'is_external_metric', u'administrative_distance'], name, value)


                                        class Paths(Entity):
                                            """
                                            First hops toward the prefix
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\: str
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit>`
                                            
                                            .. attribute:: nnh
                                            
                                            	Next next hops
                                            	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.Nnh>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths, self).__init__()

                                                self.yang_name = "paths"
                                                self.yang_parent_name = "backup"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.Nnh))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.tunnel_interface = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"

                                                self.uloop_explicit = YList(self)
                                                self.nnh = YList(self)
                                                self._segment_path = lambda: "paths"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                        ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                        ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                        ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                        ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                        ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                    ])
                                                    self.repair_element_node_id = None
                                                    self.repair_ipv4_addr = None
                                                    self.repair_ipv6_addr = None
                                                    self.repair_label = None
                                                    self.repair_element_type = None
                                                    self.repair_strict_spf_label = None
                                                    self._segment_path = lambda: "uloop-explicit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class Nnh(Entity):
                                                """
                                                Next next hops
                                                
                                                .. attribute:: link_id_set
                                                
                                                	If link\_id is given
                                                	**type**\: bool
                                                
                                                .. attribute:: ipv4_set
                                                
                                                	If ipv4 address is given
                                                	**type**\: bool
                                                
                                                .. attribute:: link_id
                                                
                                                	link ID of the next next hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	Ipv4 address of the next next hop
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.Nnh, self).__init__()

                                                    self.yang_name = "nnh"
                                                    self.yang_parent_name = "paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                        ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                        ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ])
                                                    self.link_id_set = None
                                                    self.ipv4_set = None
                                                    self.link_id = None
                                                    self.ipv4_address = None
                                                    self._segment_path = lambda: "nnh"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Paths.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                        class UcmpNextHop(Entity):
                                            """
                                            UCMP first hops toward the prefix
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: total_ucmp_distance
                                            
                                            	Distance to the network via this UCMP next hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop, self).__init__()

                                                self.yang_name = "ucmp-next-hop"
                                                self.yang_parent_name = "backup"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('total_ucmp_distance', (YLeaf(YType.uint32, 'total-ucmp-distance'), ['int'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.total_ucmp_distance = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"
                                                self._segment_path = lambda: "ucmp-next-hop"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'total_ucmp_distance', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "ucmp-next-hop"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.UcmpNextHop.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                        class MulticastPath(Entity):
                                            """
                                            Multicast intact first hops toward the prefix
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\: str
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit>`
                                            
                                            .. attribute:: nnh
                                            
                                            	Next next hops
                                            	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.Nnh>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath, self).__init__()

                                                self.yang_name = "multicast-path"
                                                self.yang_parent_name = "backup"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.Nnh))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.tunnel_interface = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"

                                                self.uloop_explicit = YList(self)
                                                self.nnh = YList(self)
                                                self._segment_path = lambda: "multicast-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "multicast-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "multicast-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                        ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                        ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                        ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                        ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                        ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                    ])
                                                    self.repair_element_node_id = None
                                                    self.repair_ipv4_addr = None
                                                    self.repair_ipv6_addr = None
                                                    self.repair_label = None
                                                    self.repair_element_type = None
                                                    self.repair_strict_spf_label = None
                                                    self._segment_path = lambda: "uloop-explicit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class Nnh(Entity):
                                                """
                                                Next next hops
                                                
                                                .. attribute:: link_id_set
                                                
                                                	If link\_id is given
                                                	**type**\: bool
                                                
                                                .. attribute:: ipv4_set
                                                
                                                	If ipv4 address is given
                                                	**type**\: bool
                                                
                                                .. attribute:: link_id
                                                
                                                	link ID of the next next hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	Ipv4 address of the next next hop
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.Nnh, self).__init__()

                                                    self.yang_name = "nnh"
                                                    self.yang_parent_name = "multicast-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                        ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                        ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ])
                                                    self.link_id_set = None
                                                    self.ipv4_set = None
                                                    self.link_id = None
                                                    self.ipv4_address = None
                                                    self._segment_path = lambda: "nnh"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastPath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                        class SrtePath(Entity):
                                            """
                                            SR\-TE native first hops toward the prefix
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\: str
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit>`
                                            
                                            .. attribute:: nnh
                                            
                                            	Next next hops
                                            	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.Nnh>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath, self).__init__()

                                                self.yang_name = "srte-path"
                                                self.yang_parent_name = "backup"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.Nnh))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.tunnel_interface = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"

                                                self.uloop_explicit = YList(self)
                                                self.nnh = YList(self)
                                                self._segment_path = lambda: "srte-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "srte-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "srte-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                        ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                        ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                        ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                        ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                        ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                    ])
                                                    self.repair_element_node_id = None
                                                    self.repair_ipv4_addr = None
                                                    self.repair_ipv6_addr = None
                                                    self.repair_label = None
                                                    self.repair_element_type = None
                                                    self.repair_strict_spf_label = None
                                                    self._segment_path = lambda: "uloop-explicit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class Nnh(Entity):
                                                """
                                                Next next hops
                                                
                                                .. attribute:: link_id_set
                                                
                                                	If link\_id is given
                                                	**type**\: bool
                                                
                                                .. attribute:: ipv4_set
                                                
                                                	If ipv4 address is given
                                                	**type**\: bool
                                                
                                                .. attribute:: link_id
                                                
                                                	link ID of the next next hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	Ipv4 address of the next next hop
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.Nnh, self).__init__()

                                                    self.yang_name = "nnh"
                                                    self.yang_parent_name = "srte-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                        ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                        ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ])
                                                    self.link_id_set = None
                                                    self.ipv4_set = None
                                                    self.link_id = None
                                                    self.ipv4_address = None
                                                    self._segment_path = lambda: "nnh"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.SrtePath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                        class ExplicitPath(Entity):
                                            """
                                            SR microloop avoidance paths
                                            
                                            .. attribute:: frr_backup
                                            
                                            	FRR backup for this path
                                            	**type**\:  :py:class:`FrrBackup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup>`
                                            
                                            .. attribute:: neighbor_id
                                            
                                            	Next hop neighbor ID
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: egress_interface
                                            
                                            	Interface to send the packet out of
                                            	**type**\: str
                                            
                                            .. attribute:: neighbor_address
                                            
                                            	Next hop neighbor's forwarding address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: neighbor_snpa
                                            
                                            	Next hop neighbor's SNPA
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                            
                                            .. attribute:: tag
                                            
                                            	Tag associated with the path
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tunnel_interface
                                            
                                            	Explicit path tunnel interface
                                            	**type**\: str
                                            
                                            .. attribute:: segment_routing_sid_value
                                            
                                            	Segment routing sid value received from first hop
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: weight
                                            
                                            	Weight configured on the interface
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_te_tunnel_interface
                                            
                                            	Is path via a TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: is_sr_exclude_tunnel_interface
                                            
                                            	Is path via an SR\-exclude TE tunnel
                                            	**type**\: bool
                                            
                                            .. attribute:: uloop_explicit
                                            
                                            	Uloop Explicit List
                                            	**type**\: list of  		 :py:class:`UloopExplicit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit>`
                                            
                                            .. attribute:: nnh
                                            
                                            	Next next hops
                                            	**type**\: list of  		 :py:class:`Nnh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.Nnh>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath, self).__init__()

                                                self.yang_name = "explicit-path"
                                                self.yang_parent_name = "backup"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-backup", ("frr_backup", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup)), ("uloop-explicit", ("uloop_explicit", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit)), ("nnh", ("nnh", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.Nnh))])
                                                self._leafs = OrderedDict([
                                                    ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                    ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                    ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                    ('tag', (YLeaf(YType.uint32, 'tag'), ['int'])),
                                                    ('tunnel_interface', (YLeaf(YType.str, 'tunnel-interface'), ['str'])),
                                                    ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                    ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ('is_te_tunnel_interface', (YLeaf(YType.boolean, 'is-te-tunnel-interface'), ['bool'])),
                                                    ('is_sr_exclude_tunnel_interface', (YLeaf(YType.boolean, 'is-sr-exclude-tunnel-interface'), ['bool'])),
                                                ])
                                                self.neighbor_id = None
                                                self.egress_interface = None
                                                self.neighbor_address = None
                                                self.neighbor_snpa = None
                                                self.tag = None
                                                self.tunnel_interface = None
                                                self.segment_routing_sid_value = None
                                                self.weight = None
                                                self.is_te_tunnel_interface = None
                                                self.is_sr_exclude_tunnel_interface = None

                                                self.frr_backup = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup()
                                                self.frr_backup.parent = self
                                                self._children_name_map["frr_backup"] = "frr-backup"

                                                self.uloop_explicit = YList(self)
                                                self.nnh = YList(self)
                                                self._segment_path = lambda: "explicit-path"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'neighbor_snpa', u'tag', u'tunnel_interface', u'segment_routing_sid_value', u'weight', u'is_te_tunnel_interface', u'is_sr_exclude_tunnel_interface'], name, value)


                                            class FrrBackup(Entity):
                                                """
                                                FRR backup for this path
                                                
                                                .. attribute:: neighbor_id
                                                
                                                	Next hop neighbor ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: egress_interface
                                                
                                                	Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_address
                                                
                                                	Next hop neighbor's forwarding address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: tunnel_egress_interface
                                                
                                                	Tunnel Interface to send the packet out of
                                                	**type**\: str
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                	Next hop neighbor's SNPA
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_system_id
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_id
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: remote_lfa_system_pid
                                                
                                                	Remote LFA PQ Node's ID
                                                	**type**\: str
                                                
                                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                                
                                                .. attribute:: remote_lfa_router_pid
                                                
                                                	Remote LFA Router ID
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: total_backup_distance
                                                
                                                	Distance to the network via this backup path
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value
                                                
                                                	Segment routing sid value received from first hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: num_sid
                                                
                                                	Number of SIDs in TI\-LFA/rLFA
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: backup_repair_list_size
                                                
                                                	Backup Repair List Size
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tilfa_computation
                                                
                                                	Ti LFA computation which provided backup path
                                                	**type**\:  :py:class:`IsisTilfaComputation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisTilfaComputation>`
                                                
                                                .. attribute:: prefix_source_node_id
                                                
                                                	PrefixSourceNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: is_downstream
                                                
                                                	Is the backup path via downstream node?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_lc_disjoint
                                                
                                                	Is the backup path line card disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_node_protecting
                                                
                                                	Is the backup path node protecting?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_primary_path
                                                
                                                	Is the backup path an ECMP to the network?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_srlg_disjoint
                                                
                                                	Is the backup path SRLG disjoint with primary?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_remote_lfa
                                                
                                                	Is the backup path via a Remote LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_epcfrr_lfa
                                                
                                                	Is the backup path via a TI\-LFA?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_strict_spflfa
                                                
                                                	Is the backup path TI\-LFA strict SPF?
                                                	**type**\: bool
                                                
                                                .. attribute:: is_tunnel_requested
                                                
                                                	Is SR TE tunnel requested
                                                	**type**\: bool
                                                
                                                .. attribute:: weight
                                                
                                                	Weight configured on the interface
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: segment_routing_sid_value_entry
                                                
                                                	Segment routing sid values for TI\-LFA/rLFA
                                                	**type**\: list of  		 :py:class:`SegmentRoutingSidValueEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry>`
                                                
                                                .. attribute:: backup_repair
                                                
                                                	Backup Repair List
                                                	**type**\: list of  		 :py:class:`BackupRepair <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup, self).__init__()

                                                    self.yang_name = "frr-backup"
                                                    self.yang_parent_name = "explicit-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("segment-routing-sid-value-entry", ("segment_routing_sid_value_entry", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry)), ("backup-repair", ("backup_repair", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair))])
                                                    self._leafs = OrderedDict([
                                                        ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                        ('egress_interface', (YLeaf(YType.str, 'egress-interface'), ['str'])),
                                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                                        ('tunnel_egress_interface', (YLeaf(YType.str, 'tunnel-egress-interface'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('remote_lfa_system_id', (YLeaf(YType.str, 'remote-lfa-system-id'), ['str'])),
                                                        ('remote_lfa_router_id', (YLeaf(YType.str, 'remote-lfa-router-id'), ['str'])),
                                                        ('remote_lfa_system_pid', (YLeaf(YType.str, 'remote-lfa-system-pid'), ['str'])),
                                                        ('remote_lfa_router_pid', (YLeaf(YType.str, 'remote-lfa-router-pid'), ['str'])),
                                                        ('total_backup_distance', (YLeaf(YType.uint32, 'total-backup-distance'), ['int'])),
                                                        ('segment_routing_sid_value', (YLeaf(YType.uint32, 'segment-routing-sid-value'), ['int'])),
                                                        ('num_sid', (YLeaf(YType.uint32, 'num-sid'), ['int'])),
                                                        ('backup_repair_list_size', (YLeaf(YType.uint32, 'backup-repair-list-size'), ['int'])),
                                                        ('tilfa_computation', (YLeaf(YType.enumeration, 'tilfa-computation'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisTilfaComputation', '')])),
                                                        ('prefix_source_node_id', (YLeaf(YType.str, 'prefix-source-node-id'), ['str'])),
                                                        ('is_downstream', (YLeaf(YType.boolean, 'is-downstream'), ['bool'])),
                                                        ('is_lc_disjoint', (YLeaf(YType.boolean, 'is-lc-disjoint'), ['bool'])),
                                                        ('is_node_protecting', (YLeaf(YType.boolean, 'is-node-protecting'), ['bool'])),
                                                        ('is_primary_path', (YLeaf(YType.boolean, 'is-primary-path'), ['bool'])),
                                                        ('is_srlg_disjoint', (YLeaf(YType.boolean, 'is-srlg-disjoint'), ['bool'])),
                                                        ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                        ('is_epcfrr_lfa', (YLeaf(YType.boolean, 'is-epcfrr-lfa'), ['bool'])),
                                                        ('is_strict_spflfa', (YLeaf(YType.boolean, 'is-strict-spflfa'), ['bool'])),
                                                        ('is_tunnel_requested', (YLeaf(YType.boolean, 'is-tunnel-requested'), ['bool'])),
                                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                                    ])
                                                    self.neighbor_id = None
                                                    self.egress_interface = None
                                                    self.neighbor_address = None
                                                    self.tunnel_egress_interface = None
                                                    self.neighbor_snpa = None
                                                    self.remote_lfa_system_id = None
                                                    self.remote_lfa_router_id = None
                                                    self.remote_lfa_system_pid = None
                                                    self.remote_lfa_router_pid = None
                                                    self.total_backup_distance = None
                                                    self.segment_routing_sid_value = None
                                                    self.num_sid = None
                                                    self.backup_repair_list_size = None
                                                    self.tilfa_computation = None
                                                    self.prefix_source_node_id = None
                                                    self.is_downstream = None
                                                    self.is_lc_disjoint = None
                                                    self.is_node_protecting = None
                                                    self.is_primary_path = None
                                                    self.is_srlg_disjoint = None
                                                    self.is_remote_lfa = None
                                                    self.is_epcfrr_lfa = None
                                                    self.is_strict_spflfa = None
                                                    self.is_tunnel_requested = None
                                                    self.weight = None

                                                    self.segment_routing_sid_value_entry = YList(self)
                                                    self.backup_repair = YList(self)
                                                    self._segment_path = lambda: "frr-backup"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup, [u'neighbor_id', u'egress_interface', u'neighbor_address', u'tunnel_egress_interface', u'neighbor_snpa', u'remote_lfa_system_id', u'remote_lfa_router_id', u'remote_lfa_system_pid', u'remote_lfa_router_pid', u'total_backup_distance', u'segment_routing_sid_value', u'num_sid', u'backup_repair_list_size', u'tilfa_computation', u'prefix_source_node_id', u'is_downstream', u'is_lc_disjoint', u'is_node_protecting', u'is_primary_path', u'is_srlg_disjoint', u'is_remote_lfa', u'is_epcfrr_lfa', u'is_strict_spflfa', u'is_tunnel_requested', u'weight'], name, value)


                                                class SegmentRoutingSidValueEntry(Entity):
                                                    """
                                                    Segment routing sid values for TI\-LFA/rLFA
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, self).__init__()

                                                        self.yang_name = "segment-routing-sid-value-entry"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "segment-routing-sid-value-entry"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.SegmentRoutingSidValueEntry, [u'entry'], name, value)


                                                class BackupRepair(Entity):
                                                    """
                                                    Backup Repair List
                                                    
                                                    .. attribute:: repair_element_node_id
                                                    
                                                    	RepairElementNodeID
                                                    	**type**\: str
                                                    
                                                    .. attribute:: repair_ipv4_addr
                                                    
                                                    	RepairIPv4Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_ipv6_addr
                                                    
                                                    	RepairIPv6Addr
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: repair_label
                                                    
                                                    	Repair Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_element_type
                                                    
                                                    	Repair Element Type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: repair_strict_spf_label
                                                    
                                                    	Repair Strict SPF Label
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair, self).__init__()

                                                        self.yang_name = "backup-repair"
                                                        self.yang_parent_name = "frr-backup"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                            ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                            ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                            ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                            ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                            ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                        ])
                                                        self.repair_element_node_id = None
                                                        self.repair_ipv4_addr = None
                                                        self.repair_ipv6_addr = None
                                                        self.repair_label = None
                                                        self.repair_element_type = None
                                                        self.repair_strict_spf_label = None
                                                        self._segment_path = lambda: "backup-repair"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.FrrBackup.BackupRepair, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class UloopExplicit(Entity):
                                                """
                                                Uloop Explicit List
                                                
                                                .. attribute:: repair_element_node_id
                                                
                                                	RepairElementNodeID
                                                	**type**\: str
                                                
                                                .. attribute:: repair_ipv4_addr
                                                
                                                	RepairIPv4Addr
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_ipv6_addr
                                                
                                                	RepairIPv6Addr
                                                	**type**\: str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: repair_label
                                                
                                                	Repair Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_element_type
                                                
                                                	Repair Element Type
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: repair_strict_spf_label
                                                
                                                	Repair Strict SPF Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit, self).__init__()

                                                    self.yang_name = "uloop-explicit"
                                                    self.yang_parent_name = "explicit-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('repair_element_node_id', (YLeaf(YType.str, 'repair-element-node-id'), ['str'])),
                                                        ('repair_ipv4_addr', (YLeaf(YType.str, 'repair-ipv4-addr'), ['str'])),
                                                        ('repair_ipv6_addr', (YLeaf(YType.str, 'repair-ipv6-addr'), ['str'])),
                                                        ('repair_label', (YLeaf(YType.uint32, 'repair-label'), ['int'])),
                                                        ('repair_element_type', (YLeaf(YType.uint32, 'repair-element-type'), ['int'])),
                                                        ('repair_strict_spf_label', (YLeaf(YType.uint32, 'repair-strict-spf-label'), ['int'])),
                                                    ])
                                                    self.repair_element_node_id = None
                                                    self.repair_ipv4_addr = None
                                                    self.repair_ipv6_addr = None
                                                    self.repair_label = None
                                                    self.repair_element_type = None
                                                    self.repair_strict_spf_label = None
                                                    self._segment_path = lambda: "uloop-explicit"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.UloopExplicit, [u'repair_element_node_id', u'repair_ipv4_addr', u'repair_ipv6_addr', u'repair_label', u'repair_element_type', u'repair_strict_spf_label'], name, value)


                                            class Nnh(Entity):
                                                """
                                                Next next hops
                                                
                                                .. attribute:: link_id_set
                                                
                                                	If link\_id is given
                                                	**type**\: bool
                                                
                                                .. attribute:: ipv4_set
                                                
                                                	If ipv4 address is given
                                                	**type**\: bool
                                                
                                                .. attribute:: link_id
                                                
                                                	link ID of the next next hop
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	Ipv4 address of the next next hop
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.Nnh, self).__init__()

                                                    self.yang_name = "nnh"
                                                    self.yang_parent_name = "explicit-path"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('link_id_set', (YLeaf(YType.boolean, 'link-id-set'), ['bool'])),
                                                        ('ipv4_set', (YLeaf(YType.boolean, 'ipv4-set'), ['bool'])),
                                                        ('link_id', (YLeaf(YType.uint32, 'link-id'), ['int'])),
                                                        ('ipv4_address', (YLeaf(YType.str, 'ipv4-address'), ['str'])),
                                                    ])
                                                    self.link_id_set = None
                                                    self.ipv4_set = None
                                                    self.link_id = None
                                                    self.ipv4_address = None
                                                    self._segment_path = lambda: "nnh"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.ExplicitPath.Nnh, [u'link_id_set', u'ipv4_set', u'link_id', u'ipv4_address'], name, value)


                                        class Source(Entity):
                                            """
                                            Sources advertising the prefix
                                            
                                            .. attribute:: source_lsp_id
                                            
                                            	ID of the LSP advertising the prefix
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                            
                                            .. attribute:: source_address
                                            
                                            	Source address of the IS advertising the prefix
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: tags
                                            
                                            	Tags associated with the prefix item
                                            	**type**\: list of  		 :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Source.Tags>`
                                            
                                            .. attribute:: nodal_sid
                                            
                                            	Nodal SIDs with the prefix item
                                            	**type**\: list of  		 :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Source.NodalSid>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Source, self).__init__()

                                                self.yang_name = "source"
                                                self.yang_parent_name = "backup"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tags", ("tags", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Source.Tags)), ("nodal-sid", ("nodal_sid", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Source.NodalSid))])
                                                self._leafs = OrderedDict([
                                                    ('source_lsp_id', (YLeaf(YType.str, 'source-lsp-id'), ['str'])),
                                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                                ])
                                                self.source_lsp_id = None
                                                self.source_address = None

                                                self.tags = YList(self)
                                                self.nodal_sid = YList(self)
                                                self._segment_path = lambda: "source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Source, [u'source_lsp_id', u'source_address'], name, value)


                                            class Tags(Entity):
                                                """
                                                Tags associated with the prefix item
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Source.Tags, self).__init__()

                                                    self.yang_name = "tags"
                                                    self.yang_parent_name = "source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "tags"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Source.Tags, [u'entry'], name, value)


                                            class NodalSid(Entity):
                                                """
                                                Nodal SIDs with the prefix item
                                                
                                                .. attribute:: sid_value
                                                
                                                	sid value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rflag
                                                
                                                	rflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nflag
                                                
                                                	nflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pflag
                                                
                                                	pflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: eflag
                                                
                                                	eflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: vflag
                                                
                                                	vflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: lflag
                                                
                                                	lflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: algorithm
                                                
                                                	algorithm
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Source.NodalSid, self).__init__()

                                                    self.yang_name = "nodal-sid"
                                                    self.yang_parent_name = "source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('sid_value', (YLeaf(YType.uint32, 'sid-value'), ['int'])),
                                                        ('rflag', (YLeaf(YType.uint8, 'rflag'), ['int'])),
                                                        ('nflag', (YLeaf(YType.uint8, 'nflag'), ['int'])),
                                                        ('pflag', (YLeaf(YType.uint8, 'pflag'), ['int'])),
                                                        ('eflag', (YLeaf(YType.uint8, 'eflag'), ['int'])),
                                                        ('vflag', (YLeaf(YType.uint8, 'vflag'), ['int'])),
                                                        ('lflag', (YLeaf(YType.uint8, 'lflag'), ['int'])),
                                                        ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                                    ])
                                                    self.sid_value = None
                                                    self.rflag = None
                                                    self.nflag = None
                                                    self.pflag = None
                                                    self.eflag = None
                                                    self.vflag = None
                                                    self.lflag = None
                                                    self.algorithm = None
                                                    self._segment_path = lambda: "nodal-sid"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.Source.NodalSid, [u'sid_value', u'rflag', u'nflag', u'pflag', u'eflag', u'vflag', u'lflag', u'algorithm'], name, value)


                                        class MulticastSource(Entity):
                                            """
                                            Multicast\-intact sources advertising the prefix
                                            
                                            .. attribute:: source_lsp_id
                                            
                                            	ID of the LSP advertising the prefix
                                            	**type**\: str
                                            
                                            	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                            
                                            .. attribute:: source_address
                                            
                                            	Source address of the IS advertising the prefix
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: tags
                                            
                                            	Tags associated with the prefix item
                                            	**type**\: list of  		 :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastSource.Tags>`
                                            
                                            .. attribute:: nodal_sid
                                            
                                            	Nodal SIDs with the prefix item
                                            	**type**\: list of  		 :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastSource, self).__init__()

                                                self.yang_name = "multicast-source"
                                                self.yang_parent_name = "backup"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tags", ("tags", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastSource.Tags)), ("nodal-sid", ("nodal_sid", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid))])
                                                self._leafs = OrderedDict([
                                                    ('source_lsp_id', (YLeaf(YType.str, 'source-lsp-id'), ['str'])),
                                                    ('source_address', (YLeaf(YType.str, 'source-address'), ['str'])),
                                                ])
                                                self.source_lsp_id = None
                                                self.source_address = None

                                                self.tags = YList(self)
                                                self.nodal_sid = YList(self)
                                                self._segment_path = lambda: "multicast-source"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastSource, [u'source_lsp_id', u'source_address'], name, value)


                                            class Tags(Entity):
                                                """
                                                Tags associated with the prefix item
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastSource.Tags, self).__init__()

                                                    self.yang_name = "tags"
                                                    self.yang_parent_name = "multicast-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "tags"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastSource.Tags, [u'entry'], name, value)


                                            class NodalSid(Entity):
                                                """
                                                Nodal SIDs with the prefix item
                                                
                                                .. attribute:: sid_value
                                                
                                                	sid value
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: rflag
                                                
                                                	rflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: nflag
                                                
                                                	nflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: pflag
                                                
                                                	pflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: eflag
                                                
                                                	eflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: vflag
                                                
                                                	vflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: lflag
                                                
                                                	lflag
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: algorithm
                                                
                                                	algorithm
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid, self).__init__()

                                                    self.yang_name = "nodal-sid"
                                                    self.yang_parent_name = "multicast-source"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('sid_value', (YLeaf(YType.uint32, 'sid-value'), ['int'])),
                                                        ('rflag', (YLeaf(YType.uint8, 'rflag'), ['int'])),
                                                        ('nflag', (YLeaf(YType.uint8, 'nflag'), ['int'])),
                                                        ('pflag', (YLeaf(YType.uint8, 'pflag'), ['int'])),
                                                        ('eflag', (YLeaf(YType.uint8, 'eflag'), ['int'])),
                                                        ('vflag', (YLeaf(YType.uint8, 'vflag'), ['int'])),
                                                        ('lflag', (YLeaf(YType.uint8, 'lflag'), ['int'])),
                                                        ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                                    ])
                                                    self.sid_value = None
                                                    self.rflag = None
                                                    self.nflag = None
                                                    self.pflag = None
                                                    self.eflag = None
                                                    self.vflag = None
                                                    self.lflag = None
                                                    self.algorithm = None
                                                    self._segment_path = lambda: "nodal-sid"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.NativeStatus.NativeDetails.Backup.MulticastSource.NodalSid, [u'sid_value', u'rflag', u'nflag', u'pflag', u'eflag', u'vflag', u'lflag', u'algorithm'], name, value)


                            class PerLevelAdvertisingDetail(Entity):
                                """
                                Per level details of how the local system
                                advertises the prefix
                                
                                .. attribute:: summarization_status
                                
                                	Status of summarization for the prefix
                                	**type**\:  :py:class:`SummarizationStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.SummarizationStatus>`
                                
                                .. attribute:: level
                                
                                	Level in which the prefix is advertised
                                	**type**\:  :py:class:`IsisLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevel>`
                                
                                .. attribute:: advertising_origin
                                
                                	The origin of the advertisement
                                	**type**\:  :py:class:`IsisShRouteAdvOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisShRouteAdvOrigin>`
                                
                                .. attribute:: metric
                                
                                	Metric with which the prefix is advertised
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_propagated
                                
                                	Has the prefix been propagated from another level?
                                	**type**\: bool
                                
                                .. attribute:: is_external_metric
                                
                                	Is the metric an external metric?
                                	**type**\: bool
                                
                                .. attribute:: is_external_reachability
                                
                                	Is the prefix external to the IS\-IS domain?
                                	**type**\: bool
                                
                                .. attribute:: is_interarea
                                
                                	Is the up/down bit set?
                                	**type**\: bool
                                
                                .. attribute:: tags
                                
                                	Tags associated with the prefix
                                	**type**\: list of  		 :py:class:`Tags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.Tags>`
                                
                                .. attribute:: nodal_sid
                                
                                	Nodal SIDs with the prefix item
                                	**type**\: list of  		 :py:class:`NodalSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.NodalSid>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail, self).__init__()

                                    self.yang_name = "per-level-advertising-detail"
                                    self.yang_parent_name = "ipv4-route"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("summarization-status", ("summarization_status", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.SummarizationStatus)), ("tags", ("tags", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.Tags)), ("nodal-sid", ("nodal_sid", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.NodalSid))])
                                    self._leafs = OrderedDict([
                                        ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisLevel', '')])),
                                        ('advertising_origin', (YLeaf(YType.enumeration, 'advertising-origin'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisShRouteAdvOrigin', '')])),
                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                        ('is_propagated', (YLeaf(YType.boolean, 'is-propagated'), ['bool'])),
                                        ('is_external_metric', (YLeaf(YType.boolean, 'is-external-metric'), ['bool'])),
                                        ('is_external_reachability', (YLeaf(YType.boolean, 'is-external-reachability'), ['bool'])),
                                        ('is_interarea', (YLeaf(YType.boolean, 'is-interarea'), ['bool'])),
                                    ])
                                    self.level = None
                                    self.advertising_origin = None
                                    self.metric = None
                                    self.is_propagated = None
                                    self.is_external_metric = None
                                    self.is_external_reachability = None
                                    self.is_interarea = None

                                    self.summarization_status = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.SummarizationStatus()
                                    self.summarization_status.parent = self
                                    self._children_name_map["summarization_status"] = "summarization-status"

                                    self.tags = YList(self)
                                    self.nodal_sid = YList(self)
                                    self._segment_path = lambda: "per-level-advertising-detail"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail, [u'level', u'advertising_origin', u'metric', u'is_propagated', u'is_external_metric', u'is_external_reachability', u'is_interarea'], name, value)


                                class SummarizationStatus(Entity):
                                    """
                                    Status of summarization for the prefix
                                    
                                    .. attribute:: summary_prefix
                                    
                                    	Summarizing Prefix
                                    	**type**\:  :py:class:`SummaryPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	IsValid
                                    	**type**\:  :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.SummarizationStatus, self).__init__()

                                        self.yang_name = "summarization-status"
                                        self.yang_parent_name = "per-level-advertising-detail"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("summary-prefix", ("summary_prefix", Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', (YLeaf(YType.enumeration, 'is-valid'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisValid', '')])),
                                        ])
                                        self.is_valid = None

                                        self.summary_prefix = Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix()
                                        self.summary_prefix.parent = self
                                        self._children_name_map["summary_prefix"] = "summary-prefix"
                                        self._segment_path = lambda: "summarization-status"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.SummarizationStatus, [u'is_valid'], name, value)


                                    class SummaryPrefix(Entity):
                                        """
                                        Summarizing Prefix
                                        
                                        .. attribute:: prefix
                                        
                                        	prefix
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: prefix_length
                                        
                                        	prefix length
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix, self).__init__()

                                            self.yang_name = "summary-prefix"
                                            self.yang_parent_name = "summarization-status"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                            ])
                                            self.prefix = None
                                            self.prefix_length = None
                                            self._segment_path = lambda: "summary-prefix"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.SummarizationStatus.SummaryPrefix, [u'prefix', u'prefix_length'], name, value)


                                class Tags(Entity):
                                    """
                                    Tags associated with the prefix
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.Tags, self).__init__()

                                        self.yang_name = "tags"
                                        self.yang_parent_name = "per-level-advertising-detail"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "tags"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.Tags, [u'entry'], name, value)


                                class NodalSid(Entity):
                                    """
                                    Nodal SIDs with the prefix item
                                    
                                    .. attribute:: sid_value
                                    
                                    	sid value
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rflag
                                    
                                    	rflag
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: nflag
                                    
                                    	nflag
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: pflag
                                    
                                    	pflag
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: eflag
                                    
                                    	eflag
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vflag
                                    
                                    	vflag
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: lflag
                                    
                                    	lflag
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: algorithm
                                    
                                    	algorithm
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.NodalSid, self).__init__()

                                        self.yang_name = "nodal-sid"
                                        self.yang_parent_name = "per-level-advertising-detail"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('sid_value', (YLeaf(YType.uint32, 'sid-value'), ['int'])),
                                            ('rflag', (YLeaf(YType.uint8, 'rflag'), ['int'])),
                                            ('nflag', (YLeaf(YType.uint8, 'nflag'), ['int'])),
                                            ('pflag', (YLeaf(YType.uint8, 'pflag'), ['int'])),
                                            ('eflag', (YLeaf(YType.uint8, 'eflag'), ['int'])),
                                            ('vflag', (YLeaf(YType.uint8, 'vflag'), ['int'])),
                                            ('lflag', (YLeaf(YType.uint8, 'lflag'), ['int'])),
                                            ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                        ])
                                        self.sid_value = None
                                        self.rflag = None
                                        self.nflag = None
                                        self.pflag = None
                                        self.eflag = None
                                        self.vflag = None
                                        self.lflag = None
                                        self.algorithm = None
                                        self._segment_path = lambda: "nodal-sid"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Topologies.Topology.Ipv4Routes.Ipv4Route.PerLevelAdvertisingDetail.NodalSid, [u'sid_value', u'rflag', u'nflag', u'pflag', u'eflag', u'vflag', u'lflag', u'algorithm'], name, value)


            class NsrStatus(Entity):
                """
                NSR Status information
                
                .. attribute:: isis_nsr_peer
                
                	ISIS NSR PEER STATUS
                	**type**\:  :py:class:`IsisNsrPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrPeer>`
                
                .. attribute:: isis_nsr_infra
                
                	ISIS NSR Infra
                	**type**\:  :py:class:`IsisNsrInfra <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra>`
                
                .. attribute:: isis_vm_state
                
                	ISIS VM STATE
                	**type**\: int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2018-04-07'

                def __init__(self):
                    super(Isis.Instances.Instance.NsrStatus, self).__init__()

                    self.yang_name = "nsr-status"
                    self.yang_parent_name = "instance"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("isis-nsr-peer", ("isis_nsr_peer", Isis.Instances.Instance.NsrStatus.IsisNsrPeer)), ("isis-nsr-infra", ("isis_nsr_infra", Isis.Instances.Instance.NsrStatus.IsisNsrInfra))])
                    self._leafs = OrderedDict([
                        ('isis_vm_state', (YLeaf(YType.uint16, 'isis-vm-state'), ['int'])),
                    ])
                    self.isis_vm_state = None

                    self.isis_nsr_peer = Isis.Instances.Instance.NsrStatus.IsisNsrPeer()
                    self.isis_nsr_peer.parent = self
                    self._children_name_map["isis_nsr_peer"] = "isis-nsr-peer"

                    self.isis_nsr_infra = Isis.Instances.Instance.NsrStatus.IsisNsrInfra()
                    self.isis_nsr_infra.parent = self
                    self._children_name_map["isis_nsr_infra"] = "isis-nsr-infra"
                    self._segment_path = lambda: "nsr-status"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Isis.Instances.Instance.NsrStatus, [u'isis_vm_state'], name, value)


                class IsisNsrPeer(Entity):
                    """
                    ISIS NSR PEER STATUS
                    
                    .. attribute:: full_sync_achieved
                    
                    	full sync achieved
                    	**type**\: list of  		 :py:class:`FullSyncAchieved <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrPeer.FullSyncAchieved>`
                    
                    .. attribute:: man_sync_count
                    
                    	man sync count
                    	**type**\: list of  		 :py:class:`ManSyncCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrPeer.ManSyncCount>`
                    
                    .. attribute:: nsr_chg_count
                    
                    	nsr chg count
                    	**type**\: list of  		 :py:class:`NsrChgCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrPeer.NsrChgCount>`
                    
                    .. attribute:: uptime
                    
                    	uptime
                    	**type**\: list of  		 :py:class:`Uptime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrPeer.Uptime>`
                    
                    .. attribute:: uptime_valid
                    
                    	uptime valid
                    	**type**\: list of  		 :py:class:`UptimeValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrPeer.UptimeValid>`
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2018-04-07'

                    def __init__(self):
                        super(Isis.Instances.Instance.NsrStatus.IsisNsrPeer, self).__init__()

                        self.yang_name = "isis-nsr-peer"
                        self.yang_parent_name = "nsr-status"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("full-sync-achieved", ("full_sync_achieved", Isis.Instances.Instance.NsrStatus.IsisNsrPeer.FullSyncAchieved)), ("man-sync-count", ("man_sync_count", Isis.Instances.Instance.NsrStatus.IsisNsrPeer.ManSyncCount)), ("nsr-chg-count", ("nsr_chg_count", Isis.Instances.Instance.NsrStatus.IsisNsrPeer.NsrChgCount)), ("uptime", ("uptime", Isis.Instances.Instance.NsrStatus.IsisNsrPeer.Uptime)), ("uptime-valid", ("uptime_valid", Isis.Instances.Instance.NsrStatus.IsisNsrPeer.UptimeValid))])
                        self._leafs = OrderedDict()

                        self.full_sync_achieved = YList(self)
                        self.man_sync_count = YList(self)
                        self.nsr_chg_count = YList(self)
                        self.uptime = YList(self)
                        self.uptime_valid = YList(self)
                        self._segment_path = lambda: "isis-nsr-peer"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Isis.Instances.Instance.NsrStatus.IsisNsrPeer, [], name, value)


                    class FullSyncAchieved(Entity):
                        """
                        full sync achieved
                        
                        .. attribute:: entry
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.NsrStatus.IsisNsrPeer.FullSyncAchieved, self).__init__()

                            self.yang_name = "full-sync-achieved"
                            self.yang_parent_name = "isis-nsr-peer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                            ])
                            self.entry = None
                            self._segment_path = lambda: "full-sync-achieved"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.NsrStatus.IsisNsrPeer.FullSyncAchieved, [u'entry'], name, value)


                    class ManSyncCount(Entity):
                        """
                        man sync count
                        
                        .. attribute:: entry
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.NsrStatus.IsisNsrPeer.ManSyncCount, self).__init__()

                            self.yang_name = "man-sync-count"
                            self.yang_parent_name = "isis-nsr-peer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                            ])
                            self.entry = None
                            self._segment_path = lambda: "man-sync-count"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.NsrStatus.IsisNsrPeer.ManSyncCount, [u'entry'], name, value)


                    class NsrChgCount(Entity):
                        """
                        nsr chg count
                        
                        .. attribute:: entry
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.NsrStatus.IsisNsrPeer.NsrChgCount, self).__init__()

                            self.yang_name = "nsr-chg-count"
                            self.yang_parent_name = "isis-nsr-peer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                            ])
                            self.entry = None
                            self._segment_path = lambda: "nsr-chg-count"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.NsrStatus.IsisNsrPeer.NsrChgCount, [u'entry'], name, value)


                    class Uptime(Entity):
                        """
                        uptime
                        
                        .. attribute:: entry
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.NsrStatus.IsisNsrPeer.Uptime, self).__init__()

                            self.yang_name = "uptime"
                            self.yang_parent_name = "isis-nsr-peer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('entry', (YLeaf(YType.uint32, 'entry'), ['int'])),
                            ])
                            self.entry = None
                            self._segment_path = lambda: "uptime"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.NsrStatus.IsisNsrPeer.Uptime, [u'entry'], name, value)


                    class UptimeValid(Entity):
                        """
                        uptime valid
                        
                        .. attribute:: entry
                        
                        	Array entry
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.NsrStatus.IsisNsrPeer.UptimeValid, self).__init__()

                            self.yang_name = "uptime-valid"
                            self.yang_parent_name = "isis-nsr-peer"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('entry', (YLeaf(YType.boolean, 'entry'), ['bool'])),
                            ])
                            self.entry = None
                            self._segment_path = lambda: "uptime-valid"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.NsrStatus.IsisNsrPeer.UptimeValid, [u'entry'], name, value)


                class IsisNsrInfra(Entity):
                    """
                    ISIS NSR Infra
                    
                    .. attribute:: gen
                    
                    	gen
                    	**type**\:  :py:class:`Gen <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Gen>`
                    
                    .. attribute:: pm
                    
                    	pm
                    	**type**\:  :py:class:`Pm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Pm>`
                    
                    .. attribute:: ds
                    
                    	ds
                    	**type**\:  :py:class:`Ds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds>`
                    
                    .. attribute:: te
                    
                    	te
                    	**type**\:  :py:class:`Te <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Te>`
                    
                    .. attribute:: ncd
                    
                    	ncd
                    	**type**\: list of  		 :py:class:`Ncd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ncd>`
                    
                    .. attribute:: nii_idb
                    
                    	nii idb
                    	**type**\: list of  		 :py:class:`NiiIdb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.NiiIdb>`
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2018-04-07'

                    def __init__(self):
                        super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra, self).__init__()

                        self.yang_name = "isis-nsr-infra"
                        self.yang_parent_name = "nsr-status"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("gen", ("gen", Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Gen)), ("pm", ("pm", Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Pm)), ("ds", ("ds", Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds)), ("te", ("te", Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Te)), ("ncd", ("ncd", Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ncd)), ("nii-idb", ("nii_idb", Isis.Instances.Instance.NsrStatus.IsisNsrInfra.NiiIdb))])
                        self._leafs = OrderedDict()

                        self.gen = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Gen()
                        self.gen.parent = self
                        self._children_name_map["gen"] = "gen"

                        self.pm = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Pm()
                        self.pm.parent = self
                        self._children_name_map["pm"] = "pm"

                        self.ds = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds()
                        self.ds.parent = self
                        self._children_name_map["ds"] = "ds"

                        self.te = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Te()
                        self.te.parent = self
                        self._children_name_map["te"] = "te"

                        self.ncd = YList(self)
                        self.nii_idb = YList(self)
                        self._segment_path = lambda: "isis-nsr-infra"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Isis.Instances.Instance.NsrStatus.IsisNsrInfra, [], name, value)


                    class Gen(Entity):
                        """
                        gen
                        
                        .. attribute:: my_nodeid
                        
                        	my nodeid
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: my_process_id
                        
                        	my process id
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pm_issu_role
                        
                        	pm issu role
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: pm_ha_role
                        
                        	pm ha role
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: sysmgr_ha_role
                        
                        	sysmgr ha role
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: nsr_send_ready
                        
                        	nsr send ready
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: nsr_send_unready
                        
                        	nsr send unready
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: nsr_send_err
                        
                        	nsr send err
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_recv_err
                        
                        	nsr recv err
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: retry_flag
                        
                        	retry flag
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nsr_enabled
                        
                        	nsr enabled
                        	**type**\: bool
                        
                        .. attribute:: nsr_configured
                        
                        	nsr configured
                        	**type**\: bool
                        
                        .. attribute:: nsf_configured
                        
                        	nsf configured
                        	**type**\: bool
                        
                        .. attribute:: failover
                        
                        	failover
                        	**type**\: bool
                        
                        .. attribute:: lanid_req_needed
                        
                        	lanid req needed
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Gen, self).__init__()

                            self.yang_name = "gen"
                            self.yang_parent_name = "isis-nsr-infra"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('my_nodeid', (YLeaf(YType.uint32, 'my-nodeid'), ['int'])),
                                ('my_process_id', (YLeaf(YType.uint32, 'my-process-id'), ['int'])),
                                ('pm_issu_role', (YLeaf(YType.uint8, 'pm-issu-role'), ['int'])),
                                ('pm_ha_role', (YLeaf(YType.uint8, 'pm-ha-role'), ['int'])),
                                ('sysmgr_ha_role', (YLeaf(YType.uint8, 'sysmgr-ha-role'), ['int'])),
                                ('nsr_send_ready', (YLeaf(YType.uint8, 'nsr-send-ready'), ['int'])),
                                ('nsr_send_unready', (YLeaf(YType.uint8, 'nsr-send-unready'), ['int'])),
                                ('nsr_send_err', (YLeaf(YType.uint32, 'nsr-send-err'), ['int'])),
                                ('nsr_recv_err', (YLeaf(YType.uint32, 'nsr-recv-err'), ['int'])),
                                ('retry_flag', (YLeaf(YType.uint32, 'retry-flag'), ['int'])),
                                ('nsr_enabled', (YLeaf(YType.boolean, 'nsr-enabled'), ['bool'])),
                                ('nsr_configured', (YLeaf(YType.boolean, 'nsr-configured'), ['bool'])),
                                ('nsf_configured', (YLeaf(YType.boolean, 'nsf-configured'), ['bool'])),
                                ('failover', (YLeaf(YType.boolean, 'failover'), ['bool'])),
                                ('lanid_req_needed', (YLeaf(YType.boolean, 'lanid-req-needed'), ['bool'])),
                            ])
                            self.my_nodeid = None
                            self.my_process_id = None
                            self.pm_issu_role = None
                            self.pm_ha_role = None
                            self.sysmgr_ha_role = None
                            self.nsr_send_ready = None
                            self.nsr_send_unready = None
                            self.nsr_send_err = None
                            self.nsr_recv_err = None
                            self.retry_flag = None
                            self.nsr_enabled = None
                            self.nsr_configured = None
                            self.nsf_configured = None
                            self.failover = None
                            self.lanid_req_needed = None
                            self._segment_path = lambda: "gen"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Gen, [u'my_nodeid', u'my_process_id', u'pm_issu_role', u'pm_ha_role', u'sysmgr_ha_role', u'nsr_send_ready', u'nsr_send_unready', u'nsr_send_err', u'nsr_recv_err', u'retry_flag', u'nsr_enabled', u'nsr_configured', u'nsf_configured', u'failover', u'lanid_req_needed'], name, value)


                    class Pm(Entity):
                        """
                        pm
                        
                        .. attribute:: reg
                        
                        	reg
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: conn_cb
                        
                        	conn cb
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: disconn_cb
                        
                        	disconn cb
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: conn_status
                        
                        	conn status
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Pm, self).__init__()

                            self.yang_name = "pm"
                            self.yang_parent_name = "isis-nsr-infra"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('reg', (YLeaf(YType.uint8, 'reg'), ['int'])),
                                ('conn_cb', (YLeaf(YType.uint8, 'conn-cb'), ['int'])),
                                ('disconn_cb', (YLeaf(YType.uint8, 'disconn-cb'), ['int'])),
                                ('conn_status', (YLeaf(YType.boolean, 'conn-status'), ['bool'])),
                            ])
                            self.reg = None
                            self.conn_cb = None
                            self.disconn_cb = None
                            self.conn_status = None
                            self._segment_path = lambda: "pm"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Pm, [u'reg', u'conn_cb', u'disconn_cb', u'conn_status'], name, value)


                    class Ds(Entity):
                        """
                        ds
                        
                        .. attribute:: conn_ts
                        
                        	conn ts
                        	**type**\:  :py:class:`ConnTs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.ConnTs>`
                        
                        .. attribute:: conn_cb_ts
                        
                        	conn cb ts
                        	**type**\:  :py:class:`ConnCbTs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.ConnCbTs>`
                        
                        .. attribute:: pub_ts
                        
                        	pub ts
                        	**type**\:  :py:class:`PubTs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.PubTs>`
                        
                        .. attribute:: pub_cb_ts
                        
                        	pub cb ts
                        	**type**\:  :py:class:`PubCbTs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.PubCbTs>`
                        
                        .. attribute:: reg_ts
                        
                        	reg ts
                        	**type**\:  :py:class:`RegTs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.RegTs>`
                        
                        .. attribute:: reg_cb_ts
                        
                        	reg cb ts
                        	**type**\:  :py:class:`RegCbTs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.RegCbTs>`
                        
                        .. attribute:: unreg_ts
                        
                        	unreg ts
                        	**type**\:  :py:class:`UnregTs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.UnregTs>`
                        
                        .. attribute:: unreg_cb_ts
                        
                        	unreg cb ts
                        	**type**\:  :py:class:`UnregCbTs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.UnregCbTs>`
                        
                        .. attribute:: disconn_cb_ts
                        
                        	disconn cb ts
                        	**type**\:  :py:class:`DisconnCbTs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.DisconnCbTs>`
                        
                        .. attribute:: notify_cb_ts
                        
                        	notify cb ts
                        	**type**\:  :py:class:`NotifyCbTs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.NotifyCbTs>`
                        
                        .. attribute:: del_cb_ts
                        
                        	del cb ts
                        	**type**\:  :py:class:`DelCbTs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.DelCbTs>`
                        
                        .. attribute:: remove_srv_ts
                        
                        	remove srv ts
                        	**type**\:  :py:class:`RemoveSrvTs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.RemoveSrvTs>`
                        
                        .. attribute:: conn_status_ts
                        
                        	conn status ts
                        	**type**\:  :py:class:`ConnStatusTs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.ConnStatusTs>`
                        
                        .. attribute:: conn
                        
                        	conn
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: conn_cb
                        
                        	conn cb
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: pub
                        
                        	pub
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: pub_cb
                        
                        	pub cb
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: reg
                        
                        	reg
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: reg_cb
                        
                        	reg cb
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: unreg
                        
                        	unreg
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: unreg_cb
                        
                        	unreg cb
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: disconn_cb
                        
                        	disconn cb
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: notify_cb
                        
                        	notify cb
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: notify_peer_xr
                        
                        	notify peer xr
                        	**type**\: str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        .. attribute:: del_cb
                        
                        	del cb
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: remove_srv
                        
                        	remove srv
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: conn_status
                        
                        	conn status
                        	**type**\: bool
                        
                        .. attribute:: notify_peer
                        
                        	notify peer
                        	**type**\: list of  		 :py:class:`NotifyPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.NotifyPeer>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds, self).__init__()

                            self.yang_name = "ds"
                            self.yang_parent_name = "isis-nsr-infra"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("conn-ts", ("conn_ts", Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.ConnTs)), ("conn-cb-ts", ("conn_cb_ts", Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.ConnCbTs)), ("pub-ts", ("pub_ts", Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.PubTs)), ("pub-cb-ts", ("pub_cb_ts", Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.PubCbTs)), ("reg-ts", ("reg_ts", Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.RegTs)), ("reg-cb-ts", ("reg_cb_ts", Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.RegCbTs)), ("unreg-ts", ("unreg_ts", Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.UnregTs)), ("unreg-cb-ts", ("unreg_cb_ts", Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.UnregCbTs)), ("disconn-cb-ts", ("disconn_cb_ts", Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.DisconnCbTs)), ("notify-cb-ts", ("notify_cb_ts", Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.NotifyCbTs)), ("del-cb-ts", ("del_cb_ts", Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.DelCbTs)), ("remove-srv-ts", ("remove_srv_ts", Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.RemoveSrvTs)), ("conn-status-ts", ("conn_status_ts", Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.ConnStatusTs)), ("notify-peer", ("notify_peer", Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.NotifyPeer))])
                            self._leafs = OrderedDict([
                                ('conn', (YLeaf(YType.uint8, 'conn'), ['int'])),
                                ('conn_cb', (YLeaf(YType.uint8, 'conn-cb'), ['int'])),
                                ('pub', (YLeaf(YType.uint8, 'pub'), ['int'])),
                                ('pub_cb', (YLeaf(YType.uint8, 'pub-cb'), ['int'])),
                                ('reg', (YLeaf(YType.uint8, 'reg'), ['int'])),
                                ('reg_cb', (YLeaf(YType.uint8, 'reg-cb'), ['int'])),
                                ('unreg', (YLeaf(YType.uint8, 'unreg'), ['int'])),
                                ('unreg_cb', (YLeaf(YType.uint8, 'unreg-cb'), ['int'])),
                                ('disconn_cb', (YLeaf(YType.uint8, 'disconn-cb'), ['int'])),
                                ('notify_cb', (YLeaf(YType.uint8, 'notify-cb'), ['int'])),
                                ('notify_peer_xr', (YLeaf(YType.str, 'notify-peer-xr'), ['str'])),
                                ('del_cb', (YLeaf(YType.uint8, 'del-cb'), ['int'])),
                                ('remove_srv', (YLeaf(YType.uint8, 'remove-srv'), ['int'])),
                                ('conn_status', (YLeaf(YType.boolean, 'conn-status'), ['bool'])),
                            ])
                            self.conn = None
                            self.conn_cb = None
                            self.pub = None
                            self.pub_cb = None
                            self.reg = None
                            self.reg_cb = None
                            self.unreg = None
                            self.unreg_cb = None
                            self.disconn_cb = None
                            self.notify_cb = None
                            self.notify_peer_xr = None
                            self.del_cb = None
                            self.remove_srv = None
                            self.conn_status = None

                            self.conn_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.ConnTs()
                            self.conn_ts.parent = self
                            self._children_name_map["conn_ts"] = "conn-ts"

                            self.conn_cb_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.ConnCbTs()
                            self.conn_cb_ts.parent = self
                            self._children_name_map["conn_cb_ts"] = "conn-cb-ts"

                            self.pub_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.PubTs()
                            self.pub_ts.parent = self
                            self._children_name_map["pub_ts"] = "pub-ts"

                            self.pub_cb_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.PubCbTs()
                            self.pub_cb_ts.parent = self
                            self._children_name_map["pub_cb_ts"] = "pub-cb-ts"

                            self.reg_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.RegTs()
                            self.reg_ts.parent = self
                            self._children_name_map["reg_ts"] = "reg-ts"

                            self.reg_cb_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.RegCbTs()
                            self.reg_cb_ts.parent = self
                            self._children_name_map["reg_cb_ts"] = "reg-cb-ts"

                            self.unreg_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.UnregTs()
                            self.unreg_ts.parent = self
                            self._children_name_map["unreg_ts"] = "unreg-ts"

                            self.unreg_cb_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.UnregCbTs()
                            self.unreg_cb_ts.parent = self
                            self._children_name_map["unreg_cb_ts"] = "unreg-cb-ts"

                            self.disconn_cb_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.DisconnCbTs()
                            self.disconn_cb_ts.parent = self
                            self._children_name_map["disconn_cb_ts"] = "disconn-cb-ts"

                            self.notify_cb_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.NotifyCbTs()
                            self.notify_cb_ts.parent = self
                            self._children_name_map["notify_cb_ts"] = "notify-cb-ts"

                            self.del_cb_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.DelCbTs()
                            self.del_cb_ts.parent = self
                            self._children_name_map["del_cb_ts"] = "del-cb-ts"

                            self.remove_srv_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.RemoveSrvTs()
                            self.remove_srv_ts.parent = self
                            self._children_name_map["remove_srv_ts"] = "remove-srv-ts"

                            self.conn_status_ts = Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.ConnStatusTs()
                            self.conn_status_ts.parent = self
                            self._children_name_map["conn_status_ts"] = "conn-status-ts"

                            self.notify_peer = YList(self)
                            self._segment_path = lambda: "ds"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds, [u'conn', u'conn_cb', u'pub', u'pub_cb', u'reg', u'reg_cb', u'unreg', u'unreg_cb', u'disconn_cb', u'notify_cb', u'notify_peer_xr', u'del_cb', u'remove_srv', u'conn_status'], name, value)


                        class ConnTs(Entity):
                            """
                            conn ts
                            
                            .. attribute:: seconds
                            
                            	Timestamp value (seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nano_seconds
                            
                            	Timestamp value (nanoseconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.ConnTs, self).__init__()

                                self.yang_name = "conn-ts"
                                self.yang_parent_name = "ds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                    ('nano_seconds', (YLeaf(YType.uint32, 'nano-seconds'), ['int'])),
                                ])
                                self.seconds = None
                                self.nano_seconds = None
                                self._segment_path = lambda: "conn-ts"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.ConnTs, [u'seconds', u'nano_seconds'], name, value)


                        class ConnCbTs(Entity):
                            """
                            conn cb ts
                            
                            .. attribute:: seconds
                            
                            	Timestamp value (seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nano_seconds
                            
                            	Timestamp value (nanoseconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.ConnCbTs, self).__init__()

                                self.yang_name = "conn-cb-ts"
                                self.yang_parent_name = "ds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                    ('nano_seconds', (YLeaf(YType.uint32, 'nano-seconds'), ['int'])),
                                ])
                                self.seconds = None
                                self.nano_seconds = None
                                self._segment_path = lambda: "conn-cb-ts"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.ConnCbTs, [u'seconds', u'nano_seconds'], name, value)


                        class PubTs(Entity):
                            """
                            pub ts
                            
                            .. attribute:: seconds
                            
                            	Timestamp value (seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nano_seconds
                            
                            	Timestamp value (nanoseconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.PubTs, self).__init__()

                                self.yang_name = "pub-ts"
                                self.yang_parent_name = "ds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                    ('nano_seconds', (YLeaf(YType.uint32, 'nano-seconds'), ['int'])),
                                ])
                                self.seconds = None
                                self.nano_seconds = None
                                self._segment_path = lambda: "pub-ts"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.PubTs, [u'seconds', u'nano_seconds'], name, value)


                        class PubCbTs(Entity):
                            """
                            pub cb ts
                            
                            .. attribute:: seconds
                            
                            	Timestamp value (seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nano_seconds
                            
                            	Timestamp value (nanoseconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.PubCbTs, self).__init__()

                                self.yang_name = "pub-cb-ts"
                                self.yang_parent_name = "ds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                    ('nano_seconds', (YLeaf(YType.uint32, 'nano-seconds'), ['int'])),
                                ])
                                self.seconds = None
                                self.nano_seconds = None
                                self._segment_path = lambda: "pub-cb-ts"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.PubCbTs, [u'seconds', u'nano_seconds'], name, value)


                        class RegTs(Entity):
                            """
                            reg ts
                            
                            .. attribute:: seconds
                            
                            	Timestamp value (seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nano_seconds
                            
                            	Timestamp value (nanoseconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.RegTs, self).__init__()

                                self.yang_name = "reg-ts"
                                self.yang_parent_name = "ds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                    ('nano_seconds', (YLeaf(YType.uint32, 'nano-seconds'), ['int'])),
                                ])
                                self.seconds = None
                                self.nano_seconds = None
                                self._segment_path = lambda: "reg-ts"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.RegTs, [u'seconds', u'nano_seconds'], name, value)


                        class RegCbTs(Entity):
                            """
                            reg cb ts
                            
                            .. attribute:: seconds
                            
                            	Timestamp value (seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nano_seconds
                            
                            	Timestamp value (nanoseconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.RegCbTs, self).__init__()

                                self.yang_name = "reg-cb-ts"
                                self.yang_parent_name = "ds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                    ('nano_seconds', (YLeaf(YType.uint32, 'nano-seconds'), ['int'])),
                                ])
                                self.seconds = None
                                self.nano_seconds = None
                                self._segment_path = lambda: "reg-cb-ts"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.RegCbTs, [u'seconds', u'nano_seconds'], name, value)


                        class UnregTs(Entity):
                            """
                            unreg ts
                            
                            .. attribute:: seconds
                            
                            	Timestamp value (seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nano_seconds
                            
                            	Timestamp value (nanoseconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.UnregTs, self).__init__()

                                self.yang_name = "unreg-ts"
                                self.yang_parent_name = "ds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                    ('nano_seconds', (YLeaf(YType.uint32, 'nano-seconds'), ['int'])),
                                ])
                                self.seconds = None
                                self.nano_seconds = None
                                self._segment_path = lambda: "unreg-ts"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.UnregTs, [u'seconds', u'nano_seconds'], name, value)


                        class UnregCbTs(Entity):
                            """
                            unreg cb ts
                            
                            .. attribute:: seconds
                            
                            	Timestamp value (seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nano_seconds
                            
                            	Timestamp value (nanoseconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.UnregCbTs, self).__init__()

                                self.yang_name = "unreg-cb-ts"
                                self.yang_parent_name = "ds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                    ('nano_seconds', (YLeaf(YType.uint32, 'nano-seconds'), ['int'])),
                                ])
                                self.seconds = None
                                self.nano_seconds = None
                                self._segment_path = lambda: "unreg-cb-ts"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.UnregCbTs, [u'seconds', u'nano_seconds'], name, value)


                        class DisconnCbTs(Entity):
                            """
                            disconn cb ts
                            
                            .. attribute:: seconds
                            
                            	Timestamp value (seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nano_seconds
                            
                            	Timestamp value (nanoseconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.DisconnCbTs, self).__init__()

                                self.yang_name = "disconn-cb-ts"
                                self.yang_parent_name = "ds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                    ('nano_seconds', (YLeaf(YType.uint32, 'nano-seconds'), ['int'])),
                                ])
                                self.seconds = None
                                self.nano_seconds = None
                                self._segment_path = lambda: "disconn-cb-ts"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.DisconnCbTs, [u'seconds', u'nano_seconds'], name, value)


                        class NotifyCbTs(Entity):
                            """
                            notify cb ts
                            
                            .. attribute:: seconds
                            
                            	Timestamp value (seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nano_seconds
                            
                            	Timestamp value (nanoseconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.NotifyCbTs, self).__init__()

                                self.yang_name = "notify-cb-ts"
                                self.yang_parent_name = "ds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                    ('nano_seconds', (YLeaf(YType.uint32, 'nano-seconds'), ['int'])),
                                ])
                                self.seconds = None
                                self.nano_seconds = None
                                self._segment_path = lambda: "notify-cb-ts"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.NotifyCbTs, [u'seconds', u'nano_seconds'], name, value)


                        class DelCbTs(Entity):
                            """
                            del cb ts
                            
                            .. attribute:: seconds
                            
                            	Timestamp value (seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nano_seconds
                            
                            	Timestamp value (nanoseconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.DelCbTs, self).__init__()

                                self.yang_name = "del-cb-ts"
                                self.yang_parent_name = "ds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                    ('nano_seconds', (YLeaf(YType.uint32, 'nano-seconds'), ['int'])),
                                ])
                                self.seconds = None
                                self.nano_seconds = None
                                self._segment_path = lambda: "del-cb-ts"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.DelCbTs, [u'seconds', u'nano_seconds'], name, value)


                        class RemoveSrvTs(Entity):
                            """
                            remove srv ts
                            
                            .. attribute:: seconds
                            
                            	Timestamp value (seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nano_seconds
                            
                            	Timestamp value (nanoseconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.RemoveSrvTs, self).__init__()

                                self.yang_name = "remove-srv-ts"
                                self.yang_parent_name = "ds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                    ('nano_seconds', (YLeaf(YType.uint32, 'nano-seconds'), ['int'])),
                                ])
                                self.seconds = None
                                self.nano_seconds = None
                                self._segment_path = lambda: "remove-srv-ts"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.RemoveSrvTs, [u'seconds', u'nano_seconds'], name, value)


                        class ConnStatusTs(Entity):
                            """
                            conn status ts
                            
                            .. attribute:: seconds
                            
                            	Timestamp value (seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nano_seconds
                            
                            	Timestamp value (nanoseconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.ConnStatusTs, self).__init__()

                                self.yang_name = "conn-status-ts"
                                self.yang_parent_name = "ds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                    ('nano_seconds', (YLeaf(YType.uint32, 'nano-seconds'), ['int'])),
                                ])
                                self.seconds = None
                                self.nano_seconds = None
                                self._segment_path = lambda: "conn-status-ts"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.ConnStatusTs, [u'seconds', u'nano_seconds'], name, value)


                        class NotifyPeer(Entity):
                            """
                            notify peer
                            
                            .. attribute:: seconds
                            
                            	Timestamp value (seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nano_seconds
                            
                            	Timestamp value (nanoseconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.NotifyPeer, self).__init__()

                                self.yang_name = "notify-peer"
                                self.yang_parent_name = "ds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                    ('nano_seconds', (YLeaf(YType.uint32, 'nano-seconds'), ['int'])),
                                ])
                                self.seconds = None
                                self.nano_seconds = None
                                self._segment_path = lambda: "notify-peer"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ds.NotifyPeer, [u'seconds', u'nano_seconds'], name, value)


                    class Te(Entity):
                        """
                        te
                        
                        .. attribute:: enabled
                        
                        	enabled
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: conn_up
                        
                        	conn up
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: te_link_cb
                        
                        	te link cb
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: te_tunnel_cb
                        
                        	te tunnel cb
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: adv_sync_data
                        
                        	adv sync data
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: link_purge_time_on
                        
                        	link purge time on
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: tunnel_purge_time_on
                        
                        	tunnel purge time on
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: has_info_from_te
                        
                        	has info from te
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Te, self).__init__()

                            self.yang_name = "te"
                            self.yang_parent_name = "isis-nsr-infra"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('enabled', (YLeaf(YType.uint8, 'enabled'), ['int'])),
                                ('conn_up', (YLeaf(YType.uint8, 'conn-up'), ['int'])),
                                ('te_link_cb', (YLeaf(YType.uint8, 'te-link-cb'), ['int'])),
                                ('te_tunnel_cb', (YLeaf(YType.uint8, 'te-tunnel-cb'), ['int'])),
                                ('adv_sync_data', (YLeaf(YType.uint8, 'adv-sync-data'), ['int'])),
                                ('link_purge_time_on', (YLeaf(YType.uint8, 'link-purge-time-on'), ['int'])),
                                ('tunnel_purge_time_on', (YLeaf(YType.uint8, 'tunnel-purge-time-on'), ['int'])),
                                ('has_info_from_te', (YLeaf(YType.uint8, 'has-info-from-te'), ['int'])),
                            ])
                            self.enabled = None
                            self.conn_up = None
                            self.te_link_cb = None
                            self.te_tunnel_cb = None
                            self.adv_sync_data = None
                            self.link_purge_time_on = None
                            self.tunnel_purge_time_on = None
                            self.has_info_from_te = None
                            self._segment_path = lambda: "te"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Te, [u'enabled', u'conn_up', u'te_link_cb', u'te_tunnel_cb', u'adv_sync_data', u'link_purge_time_on', u'tunnel_purge_time_on', u'has_info_from_te'], name, value)


                    class Ncd(Entity):
                        """
                        ncd
                        
                        .. attribute:: vm_idx
                        
                        	vm idx
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: conn_up
                        
                        	conn up
                        	**type**\: bool
                        
                        .. attribute:: endp_hdl
                        
                        	endp hdl
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: chksum
                        
                        	chksum
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: send_seqnum
                        
                        	send seqnum
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: recv_cnt
                        
                        	recv cnt
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ncd, self).__init__()

                            self.yang_name = "ncd"
                            self.yang_parent_name = "isis-nsr-infra"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('vm_idx', (YLeaf(YType.uint8, 'vm-idx'), ['int'])),
                                ('conn_up', (YLeaf(YType.boolean, 'conn-up'), ['bool'])),
                                ('endp_hdl', (YLeaf(YType.uint8, 'endp-hdl'), ['int'])),
                                ('chksum', (YLeaf(YType.uint16, 'chksum'), ['int'])),
                                ('send_seqnum', (YLeaf(YType.uint32, 'send-seqnum'), ['int'])),
                                ('recv_cnt', (YLeaf(YType.uint32, 'recv-cnt'), ['int'])),
                            ])
                            self.vm_idx = None
                            self.conn_up = None
                            self.endp_hdl = None
                            self.chksum = None
                            self.send_seqnum = None
                            self.recv_cnt = None
                            self._segment_path = lambda: "ncd"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.Ncd, [u'vm_idx', u'conn_up', u'endp_hdl', u'chksum', u'send_seqnum', u'recv_cnt'], name, value)


                    class NiiIdb(Entity):
                        """
                        nii idb
                        
                        .. attribute:: exist
                        
                        	exist
                        	**type**\: bool
                        
                        .. attribute:: brought_up
                        
                        	brought up
                        	**type**\: bool
                        
                        .. attribute:: retry_timer
                        
                        	retry timer
                        	**type**\: bool
                        
                        .. attribute:: running
                        
                        	running
                        	**type**\: bool
                        
                        .. attribute:: has_adj
                        
                        	has adj
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.NiiIdb, self).__init__()

                            self.yang_name = "nii-idb"
                            self.yang_parent_name = "isis-nsr-infra"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('exist', (YLeaf(YType.boolean, 'exist'), ['bool'])),
                                ('brought_up', (YLeaf(YType.boolean, 'brought-up'), ['bool'])),
                                ('retry_timer', (YLeaf(YType.boolean, 'retry-timer'), ['bool'])),
                                ('running', (YLeaf(YType.boolean, 'running'), ['bool'])),
                                ('has_adj', (YLeaf(YType.boolean, 'has-adj'), ['bool'])),
                            ])
                            self.exist = None
                            self.brought_up = None
                            self.retry_timer = None
                            self.running = None
                            self.has_adj = None
                            self._segment_path = lambda: "nii-idb"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.NsrStatus.IsisNsrInfra.NiiIdb, [u'exist', u'brought_up', u'retry_timer', u'running', u'has_adj'], name, value)


            class Interfaces(Entity):
                """
                Interface table
                
                .. attribute:: interface
                
                	Information about one IS\-IS interface
                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface>`
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2018-04-07'

                def __init__(self):
                    super(Isis.Instances.Instance.Interfaces, self).__init__()

                    self.yang_name = "interfaces"
                    self.yang_parent_name = "instance"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("interface", ("interface", Isis.Instances.Instance.Interfaces.Interface))])
                    self._leafs = OrderedDict()

                    self.interface = YList(self)
                    self._segment_path = lambda: "interfaces"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Isis.Instances.Instance.Interfaces, [], name, value)


                class Interface(Entity):
                    """
                    Information about one IS\-IS interface
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: configured_status
                    
                    	Configured interface status
                    	**type**\:  :py:class:`ConfiguredStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.ConfiguredStatus>`
                    
                    .. attribute:: interface_status_and_data
                    
                    	Information about the interface status and its data
                    	**type**\:  :py:class:`InterfaceStatusAndData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData>`
                    
                    .. attribute:: configured_circuit_type
                    
                    	Configured circuit type for the interface
                    	**type**\:  :py:class:`IsisLevels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevels>`
                    
                    .. attribute:: mesh_group
                    
                    	Interface mesh group
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_type
                    
                    	IS\-type of the router
                    	**type**\:  :py:class:`IsisLevels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevels>`
                    
                    .. attribute:: nsr_intf
                    
                    	ISIS NSR Interface
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2018-04-07'

                    def __init__(self):
                        super(Isis.Instances.Instance.Interfaces.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "interfaces"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([("configured-status", ("configured_status", Isis.Instances.Instance.Interfaces.Interface.ConfiguredStatus)), ("interface-status-and-data", ("interface_status_and_data", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData))])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('configured_circuit_type', (YLeaf(YType.enumeration, 'configured-circuit-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisLevels', '')])),
                            ('mesh_group', (YLeaf(YType.uint32, 'mesh-group'), ['int'])),
                            ('is_type', (YLeaf(YType.enumeration, 'is-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisLevels', '')])),
                            ('nsr_intf', (YLeaf(YType.boolean, 'nsr-intf'), ['bool'])),
                        ])
                        self.interface_name = None
                        self.configured_circuit_type = None
                        self.mesh_group = None
                        self.is_type = None
                        self.nsr_intf = None

                        self.configured_status = Isis.Instances.Instance.Interfaces.Interface.ConfiguredStatus()
                        self.configured_status.parent = self
                        self._children_name_map["configured_status"] = "configured-status"

                        self.interface_status_and_data = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData()
                        self.interface_status_and_data.parent = self
                        self._children_name_map["interface_status_and_data"] = "interface-status-and-data"
                        self._segment_path = lambda: "interface" + "[interface-name='" + str(self.interface_name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface, ['interface_name', u'configured_circuit_type', u'mesh_group', u'is_type', u'nsr_intf'], name, value)


                    class ConfiguredStatus(Entity):
                        """
                        Configured interface status
                        
                        .. attribute:: adjacency_form_status
                        
                        	Configured adjacency formation status
                        	**type**\: bool
                        
                        .. attribute:: adv_prefix_status
                        
                        	Configured prefix advertisement status
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.Interfaces.Interface.ConfiguredStatus, self).__init__()

                            self.yang_name = "configured-status"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('adjacency_form_status', (YLeaf(YType.boolean, 'adjacency-form-status'), ['bool'])),
                                ('adv_prefix_status', (YLeaf(YType.boolean, 'adv-prefix-status'), ['bool'])),
                            ])
                            self.adjacency_form_status = None
                            self.adv_prefix_status = None
                            self._segment_path = lambda: "configured-status"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.ConfiguredStatus, [u'adjacency_form_status', u'adv_prefix_status'], name, value)


                    class InterfaceStatusAndData(Entity):
                        """
                        Information about the interface status and its
                        data
                        
                        .. attribute:: disabled
                        
                        	The interface state if disabled
                        	**type**\:  :py:class:`Disabled <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Disabled>`
                        
                        .. attribute:: enabled
                        
                        	The interface state if enabled
                        	**type**\:  :py:class:`Enabled <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled>`
                        
                        .. attribute:: status
                        
                        	Status
                        	**type**\:  :py:class:`IsisEnabled <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisEnabled>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData, self).__init__()

                            self.yang_name = "interface-status-and-data"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("disabled", ("disabled", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Disabled)), ("enabled", ("enabled", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled))])
                            self._leafs = OrderedDict([
                                ('status', (YLeaf(YType.enumeration, 'status'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisEnabled', '')])),
                            ])
                            self.status = None

                            self.disabled = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Disabled()
                            self.disabled.parent = self
                            self._children_name_map["disabled"] = "disabled"

                            self.enabled = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled()
                            self.enabled.parent = self
                            self._children_name_map["enabled"] = "enabled"
                            self._segment_path = lambda: "interface-status-and-data"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData, [u'status'], name, value)


                        class Disabled(Entity):
                            """
                            The interface state if disabled
                            
                            .. attribute:: reason_code
                            
                            	Reason why the interface is disabled
                            	**type**\:  :py:class:`IsisIfDisabledReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisIfDisabledReason>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Disabled, self).__init__()

                                self.yang_name = "disabled"
                                self.yang_parent_name = "interface-status-and-data"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('reason_code', (YLeaf(YType.enumeration, 'reason-code'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisIfDisabledReason', '')])),
                                ])
                                self.reason_code = None
                                self._segment_path = lambda: "disabled"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Disabled, [u'reason_code'], name, value)


                        class Enabled(Entity):
                            """
                            The interface state if enabled
                            
                            .. attribute:: adjacency_form_status
                            
                            	Interface's Adjacency Formation status
                            	**type**\:  :py:class:`AdjacencyFormStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdjacencyFormStatus>`
                            
                            .. attribute:: adv_prefix_status
                            
                            	Interface's Prefix Advertisement status
                            	**type**\:  :py:class:`AdvPrefixStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdvPrefixStatus>`
                            
                            .. attribute:: p2p_data
                            
                            	Data for an active P2P interface, NULL if not active or P2P
                            	**type**\:  :py:class:`P2pData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.P2pData>`
                            
                            .. attribute:: bfd_data
                            
                            	The BFD data for the given interface
                            	**type**\:  :py:class:`BfdData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.BfdData>`
                            
                            .. attribute:: clns_data
                            
                            	Interface data specific to CLNS I/O services
                            	**type**\:  :py:class:`ClnsData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData>`
                            
                            .. attribute:: interface_media_type
                            
                            	Media type of the interface
                            	**type**\:  :py:class:`IsisMediaClass <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisMediaClass>`
                            
                            .. attribute:: enabled_circuit_type
                            
                            	Enabled Circuit type of the interface
                            	**type**\:  :py:class:`IsisLevels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevels>`
                            
                            .. attribute:: local_circuit_number
                            
                            	Local Circuit Number of the interface
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: rsi_srlg_registered
                            
                            	Rsi Srlg Registered
                            	**type**\: bool
                            
                            .. attribute:: bandwidth
                            
                            	Bandwidth of the interface
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: underlying_interface
                            
                            	Underlying interface list for bundle interfaces
                            	**type**\: list of  		 :py:class:`UnderlyingInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.UnderlyingInterface>`
                            
                            .. attribute:: per_area_data
                            
                            	Array of area information for an active interface
                            	**type**\: list of  		 :py:class:`PerAreaData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAreaData>`
                            
                            .. attribute:: per_topology_data
                            
                            	Array of topology information
                            	**type**\: list of  		 :py:class:`PerTopologyData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData>`
                            
                            .. attribute:: per_address_family_data
                            
                            	Array of address family information
                            	**type**\: list of  		 :py:class:`PerAddressFamilyData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled, self).__init__()

                                self.yang_name = "enabled"
                                self.yang_parent_name = "interface-status-and-data"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("adjacency-form-status", ("adjacency_form_status", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdjacencyFormStatus)), ("adv-prefix-status", ("adv_prefix_status", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdvPrefixStatus)), ("p2p-data", ("p2p_data", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.P2pData)), ("bfd-data", ("bfd_data", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.BfdData)), ("clns-data", ("clns_data", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData)), ("underlying-interface", ("underlying_interface", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.UnderlyingInterface)), ("per-area-data", ("per_area_data", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAreaData)), ("per-topology-data", ("per_topology_data", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData)), ("per-address-family-data", ("per_address_family_data", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData))])
                                self._leafs = OrderedDict([
                                    ('interface_media_type', (YLeaf(YType.enumeration, 'interface-media-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisMediaClass', '')])),
                                    ('enabled_circuit_type', (YLeaf(YType.enumeration, 'enabled-circuit-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisLevels', '')])),
                                    ('local_circuit_number', (YLeaf(YType.uint8, 'local-circuit-number'), ['int'])),
                                    ('rsi_srlg_registered', (YLeaf(YType.boolean, 'rsi-srlg-registered'), ['bool'])),
                                    ('bandwidth', (YLeaf(YType.uint32, 'bandwidth'), ['int'])),
                                ])
                                self.interface_media_type = None
                                self.enabled_circuit_type = None
                                self.local_circuit_number = None
                                self.rsi_srlg_registered = None
                                self.bandwidth = None

                                self.adjacency_form_status = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdjacencyFormStatus()
                                self.adjacency_form_status.parent = self
                                self._children_name_map["adjacency_form_status"] = "adjacency-form-status"

                                self.adv_prefix_status = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdvPrefixStatus()
                                self.adv_prefix_status.parent = self
                                self._children_name_map["adv_prefix_status"] = "adv-prefix-status"

                                self.p2p_data = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.P2pData()
                                self.p2p_data.parent = self
                                self._children_name_map["p2p_data"] = "p2p-data"

                                self.bfd_data = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.BfdData()
                                self.bfd_data.parent = self
                                self._children_name_map["bfd_data"] = "bfd-data"

                                self.clns_data = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData()
                                self.clns_data.parent = self
                                self._children_name_map["clns_data"] = "clns-data"

                                self.underlying_interface = YList(self)
                                self.per_area_data = YList(self)
                                self.per_topology_data = YList(self)
                                self.per_address_family_data = YList(self)
                                self._segment_path = lambda: "enabled"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled, [u'interface_media_type', u'enabled_circuit_type', u'local_circuit_number', u'rsi_srlg_registered', u'bandwidth'], name, value)


                            class AdjacencyFormStatus(Entity):
                                """
                                Interface's Adjacency Formation status
                                
                                .. attribute:: disabled
                                
                                	Disabled info for the adjacency formation status
                                	**type**\:  :py:class:`Disabled <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdjacencyFormStatus.Disabled>`
                                
                                .. attribute:: status
                                
                                	Status
                                	**type**\:  :py:class:`IsisEnabled <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisEnabled>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdjacencyFormStatus, self).__init__()

                                    self.yang_name = "adjacency-form-status"
                                    self.yang_parent_name = "enabled"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("disabled", ("disabled", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdjacencyFormStatus.Disabled))])
                                    self._leafs = OrderedDict([
                                        ('status', (YLeaf(YType.enumeration, 'status'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisEnabled', '')])),
                                    ])
                                    self.status = None

                                    self.disabled = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdjacencyFormStatus.Disabled()
                                    self.disabled.parent = self
                                    self._children_name_map["disabled"] = "disabled"
                                    self._segment_path = lambda: "adjacency-form-status"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdjacencyFormStatus, [u'status'], name, value)


                                class Disabled(Entity):
                                    """
                                    Disabled info for the adjacency formation status
                                    
                                    .. attribute:: reason_code
                                    
                                    	Reason why the interface is not able to form adjacencies
                                    	**type**\:  :py:class:`IsisIfAdjFormDisabledReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisIfAdjFormDisabledReason>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdjacencyFormStatus.Disabled, self).__init__()

                                        self.yang_name = "disabled"
                                        self.yang_parent_name = "adjacency-form-status"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('reason_code', (YLeaf(YType.enumeration, 'reason-code'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisIfAdjFormDisabledReason', '')])),
                                        ])
                                        self.reason_code = None
                                        self._segment_path = lambda: "disabled"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdjacencyFormStatus.Disabled, [u'reason_code'], name, value)


                            class AdvPrefixStatus(Entity):
                                """
                                Interface's Prefix Advertisement status
                                
                                .. attribute:: disabled
                                
                                	Disabled info for the prefix advertisement status
                                	**type**\:  :py:class:`Disabled <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdvPrefixStatus.Disabled>`
                                
                                .. attribute:: status
                                
                                	Status
                                	**type**\:  :py:class:`IsisEnabled <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisEnabled>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdvPrefixStatus, self).__init__()

                                    self.yang_name = "adv-prefix-status"
                                    self.yang_parent_name = "enabled"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("disabled", ("disabled", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdvPrefixStatus.Disabled))])
                                    self._leafs = OrderedDict([
                                        ('status', (YLeaf(YType.enumeration, 'status'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisEnabled', '')])),
                                    ])
                                    self.status = None

                                    self.disabled = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdvPrefixStatus.Disabled()
                                    self.disabled.parent = self
                                    self._children_name_map["disabled"] = "disabled"
                                    self._segment_path = lambda: "adv-prefix-status"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdvPrefixStatus, [u'status'], name, value)


                                class Disabled(Entity):
                                    """
                                    Disabled info for the prefix advertisement
                                    status
                                    
                                    .. attribute:: reason_code
                                    
                                    	Reason why the interface is not able to advertise prefixes
                                    	**type**\:  :py:class:`IsisIfAdvPrefixDisabledReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisIfAdvPrefixDisabledReason>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdvPrefixStatus.Disabled, self).__init__()

                                        self.yang_name = "disabled"
                                        self.yang_parent_name = "adv-prefix-status"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('reason_code', (YLeaf(YType.enumeration, 'reason-code'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisIfAdvPrefixDisabledReason', '')])),
                                        ])
                                        self.reason_code = None
                                        self._segment_path = lambda: "disabled"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.AdvPrefixStatus.Disabled, [u'reason_code'], name, value)


                            class P2pData(Entity):
                                """
                                Data for an active P2P interface, NULL if not
                                active or P2P
                                
                                .. attribute:: time_until_next_iih
                                
                                	Time in ms before the next IIH can be sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: retransmit_lsp_queue_size
                                
                                	No. of LSPs queued to be retransmitted
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: retransmit_lsp_interval
                                
                                	Time in ms until the next scheduled LSP is retransmitted
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: extended_circuit_number
                                
                                	Extended Circuit Number valid for a P2P interface
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.P2pData, self).__init__()

                                    self.yang_name = "p2p-data"
                                    self.yang_parent_name = "enabled"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('time_until_next_iih', (YLeaf(YType.uint32, 'time-until-next-iih'), ['int'])),
                                        ('retransmit_lsp_queue_size', (YLeaf(YType.uint32, 'retransmit-lsp-queue-size'), ['int'])),
                                        ('retransmit_lsp_interval', (YLeaf(YType.uint32, 'retransmit-lsp-interval'), ['int'])),
                                        ('extended_circuit_number', (YLeaf(YType.uint32, 'extended-circuit-number'), ['int'])),
                                    ])
                                    self.time_until_next_iih = None
                                    self.retransmit_lsp_queue_size = None
                                    self.retransmit_lsp_interval = None
                                    self.extended_circuit_number = None
                                    self._segment_path = lambda: "p2p-data"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.P2pData, [u'time_until_next_iih', u'retransmit_lsp_queue_size', u'retransmit_lsp_interval', u'extended_circuit_number'], name, value)


                            class BfdData(Entity):
                                """
                                The BFD data for the given interface
                                
                                .. attribute:: enabled
                                
                                	IPv4 BFD enabled status
                                	**type**\: bool
                                
                                .. attribute:: ipv6_enabled
                                
                                	IPv6 BFD enabled status
                                	**type**\: bool
                                
                                .. attribute:: interval
                                
                                	BFD hello minimum interval in milliseconds
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: multiplier
                                
                                	BFD hello multiplier
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.BfdData, self).__init__()

                                    self.yang_name = "bfd-data"
                                    self.yang_parent_name = "enabled"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                        ('ipv6_enabled', (YLeaf(YType.boolean, 'ipv6-enabled'), ['bool'])),
                                        ('interval', (YLeaf(YType.uint32, 'interval'), ['int'])),
                                        ('multiplier', (YLeaf(YType.uint32, 'multiplier'), ['int'])),
                                    ])
                                    self.enabled = None
                                    self.ipv6_enabled = None
                                    self.interval = None
                                    self.multiplier = None
                                    self._segment_path = lambda: "bfd-data"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.BfdData, [u'enabled', u'ipv6_enabled', u'interval', u'multiplier'], name, value)


                            class ClnsData(Entity):
                                """
                                Interface data specific to CLNS I/O services
                                
                                .. attribute:: clns_status
                                
                                	Is CLNS protcol up or if not, the reason why it is not up
                                	**type**\:  :py:class:`ClnsStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.ClnsStatus>`
                                
                                .. attribute:: mtu_info
                                
                                	A valid MTU or the reason for the MTU being invalid
                                	**type**\:  :py:class:`MtuInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MtuInfo>`
                                
                                .. attribute:: snpa_state
                                
                                	SNPA state
                                	**type**\:  :py:class:`SnpaState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.SnpaState>`
                                
                                .. attribute:: media_specific_state
                                
                                	Media Specific CLNS state
                                	**type**\:  :py:class:`MediaSpecificState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState>`
                                
                                .. attribute:: time_until_next_lsp
                                
                                	Time until next LSP may be sent (ms)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsp_transmit_requested_flag
                                
                                	TRUE if an LSP transmission has been requested
                                	**type**\: bool
                                
                                .. attribute:: lsp_transmitted_flag
                                
                                	TRUE if an LSP transmission has been sent, indicates LastLSPLevelTransmitted and LastLSP\_IDTransmitted valid
                                	**type**\: bool
                                
                                .. attribute:: lsp_txmitd_b2b_limit
                                
                                	Number of LSPs that can be sent back to back in the current window without exceeding the pacing limit
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsp_txmt_b2b_msecs
                                
                                	Time im msecs indicating the end of the window in which the 'back to back lsps to be sent' counter applies
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                .. attribute:: last_lsp_level_transmitted
                                
                                	Level of the Last LSP Transmitted
                                	**type**\:  :py:class:`IsisLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevel>`
                                
                                .. attribute:: last_lsp_id_transmitted
                                
                                	Last LSP ID Transmitted
                                	**type**\: str
                                
                                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData, self).__init__()

                                    self.yang_name = "clns-data"
                                    self.yang_parent_name = "enabled"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("clns-status", ("clns_status", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.ClnsStatus)), ("mtu-info", ("mtu_info", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MtuInfo)), ("snpa-state", ("snpa_state", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.SnpaState)), ("media-specific-state", ("media_specific_state", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState))])
                                    self._leafs = OrderedDict([
                                        ('time_until_next_lsp', (YLeaf(YType.uint32, 'time-until-next-lsp'), ['int'])),
                                        ('lsp_transmit_requested_flag', (YLeaf(YType.boolean, 'lsp-transmit-requested-flag'), ['bool'])),
                                        ('lsp_transmitted_flag', (YLeaf(YType.boolean, 'lsp-transmitted-flag'), ['bool'])),
                                        ('lsp_txmitd_b2b_limit', (YLeaf(YType.uint32, 'lsp-txmitd-b2b-limit'), ['int'])),
                                        ('lsp_txmt_b2b_msecs', (YLeaf(YType.uint32, 'lsp-txmt-b2b-msecs'), ['int'])),
                                        ('last_lsp_level_transmitted', (YLeaf(YType.enumeration, 'last-lsp-level-transmitted'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisLevel', '')])),
                                        ('last_lsp_id_transmitted', (YLeaf(YType.str, 'last-lsp-id-transmitted'), ['str'])),
                                    ])
                                    self.time_until_next_lsp = None
                                    self.lsp_transmit_requested_flag = None
                                    self.lsp_transmitted_flag = None
                                    self.lsp_txmitd_b2b_limit = None
                                    self.lsp_txmt_b2b_msecs = None
                                    self.last_lsp_level_transmitted = None
                                    self.last_lsp_id_transmitted = None

                                    self.clns_status = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.ClnsStatus()
                                    self.clns_status.parent = self
                                    self._children_name_map["clns_status"] = "clns-status"

                                    self.mtu_info = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MtuInfo()
                                    self.mtu_info.parent = self
                                    self._children_name_map["mtu_info"] = "mtu-info"

                                    self.snpa_state = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.SnpaState()
                                    self.snpa_state.parent = self
                                    self._children_name_map["snpa_state"] = "snpa-state"

                                    self.media_specific_state = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState()
                                    self.media_specific_state.parent = self
                                    self._children_name_map["media_specific_state"] = "media-specific-state"
                                    self._segment_path = lambda: "clns-data"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData, [u'time_until_next_lsp', u'lsp_transmit_requested_flag', u'lsp_transmitted_flag', u'lsp_txmitd_b2b_limit', u'lsp_txmt_b2b_msecs', u'last_lsp_level_transmitted', u'last_lsp_id_transmitted'], name, value)


                                class ClnsStatus(Entity):
                                    """
                                    Is CLNS protcol up or if not, the reason why it
                                    is not up
                                    
                                    .. attribute:: clns_down_info
                                    
                                    	State describing why CLNS is down
                                    	**type**\:  :py:class:`ClnsDownInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.ClnsStatus.ClnsDownInfo>`
                                    
                                    .. attribute:: status
                                    
                                    	Status
                                    	**type**\:  :py:class:`IsisUp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisUp>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.ClnsStatus, self).__init__()

                                        self.yang_name = "clns-status"
                                        self.yang_parent_name = "clns-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("clns-down-info", ("clns_down_info", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.ClnsStatus.ClnsDownInfo))])
                                        self._leafs = OrderedDict([
                                            ('status', (YLeaf(YType.enumeration, 'status'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisUp', '')])),
                                        ])
                                        self.status = None

                                        self.clns_down_info = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.ClnsStatus.ClnsDownInfo()
                                        self.clns_down_info.parent = self
                                        self._children_name_map["clns_down_info"] = "clns-down-info"
                                        self._segment_path = lambda: "clns-status"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.ClnsStatus, [u'status'], name, value)


                                    class ClnsDownInfo(Entity):
                                        """
                                        State describing why CLNS is down
                                        
                                        .. attribute:: reason_code
                                        
                                        	Reason why CLNS is down
                                        	**type**\:  :py:class:`IsisIfClnsProtoDownReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisIfClnsProtoDownReason>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.ClnsStatus.ClnsDownInfo, self).__init__()

                                            self.yang_name = "clns-down-info"
                                            self.yang_parent_name = "clns-status"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('reason_code', (YLeaf(YType.enumeration, 'reason-code'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisIfClnsProtoDownReason', '')])),
                                            ])
                                            self.reason_code = None
                                            self._segment_path = lambda: "clns-down-info"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.ClnsStatus.ClnsDownInfo, [u'reason_code'], name, value)


                                class MtuInfo(Entity):
                                    """
                                    A valid MTU or the reason for the MTU being
                                    invalid
                                    
                                    .. attribute:: invalid
                                    
                                    	Information pertaining to the invalid CLNS MTU
                                    	**type**\:  :py:class:`Invalid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MtuInfo.Invalid>`
                                    
                                    .. attribute:: status
                                    
                                    	Status
                                    	**type**\:  :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                    
                                    .. attribute:: mtu
                                    
                                    	Valid MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MtuInfo, self).__init__()

                                        self.yang_name = "mtu-info"
                                        self.yang_parent_name = "clns-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("invalid", ("invalid", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MtuInfo.Invalid))])
                                        self._leafs = OrderedDict([
                                            ('status', (YLeaf(YType.enumeration, 'status'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisValid', '')])),
                                            ('mtu', (YLeaf(YType.uint32, 'mtu'), ['int'])),
                                        ])
                                        self.status = None
                                        self.mtu = None

                                        self.invalid = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MtuInfo.Invalid()
                                        self.invalid.parent = self
                                        self._children_name_map["invalid"] = "invalid"
                                        self._segment_path = lambda: "mtu-info"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MtuInfo, [u'status', u'mtu'], name, value)


                                    class Invalid(Entity):
                                        """
                                        Information pertaining to the invalid CLNS MTU
                                        
                                        .. attribute:: reason_code
                                        
                                        	Reason why the MTU is invalid
                                        	**type**\:  :py:class:`IsisIfClnsMtuInvalidReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisIfClnsMtuInvalidReason>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MtuInfo.Invalid, self).__init__()

                                            self.yang_name = "invalid"
                                            self.yang_parent_name = "mtu-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('reason_code', (YLeaf(YType.enumeration, 'reason-code'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisIfClnsMtuInvalidReason', '')])),
                                            ])
                                            self.reason_code = None
                                            self._segment_path = lambda: "invalid"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MtuInfo.Invalid, [u'reason_code'], name, value)


                                class SnpaState(Entity):
                                    """
                                    SNPA state
                                    
                                    .. attribute:: unknown
                                    
                                    	Information pertaining to the unknown SNPA state
                                    	**type**\:  :py:class:`Unknown <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.SnpaState.Unknown>`
                                    
                                    .. attribute:: known
                                    
                                    	Information pertaining to the known SNPA state
                                    	**type**\:  :py:class:`Known <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.SnpaState.Known>`
                                    
                                    .. attribute:: status
                                    
                                    	Status
                                    	**type**\:  :py:class:`IsisKnown <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisKnown>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.SnpaState, self).__init__()

                                        self.yang_name = "snpa-state"
                                        self.yang_parent_name = "clns-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("unknown", ("unknown", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.SnpaState.Unknown)), ("known", ("known", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.SnpaState.Known))])
                                        self._leafs = OrderedDict([
                                            ('status', (YLeaf(YType.enumeration, 'status'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisKnown', '')])),
                                        ])
                                        self.status = None

                                        self.unknown = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.SnpaState.Unknown()
                                        self.unknown.parent = self
                                        self._children_name_map["unknown"] = "unknown"

                                        self.known = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.SnpaState.Known()
                                        self.known.parent = self
                                        self._children_name_map["known"] = "known"
                                        self._segment_path = lambda: "snpa-state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.SnpaState, [u'status'], name, value)


                                    class Unknown(Entity):
                                        """
                                        Information pertaining to the unknown SNPA state
                                        
                                        .. attribute:: reason_code
                                        
                                        	Reason why the SNPA is unknown
                                        	**type**\:  :py:class:`IsisIfClnsSnpaUnknownReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisIfClnsSnpaUnknownReason>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.SnpaState.Unknown, self).__init__()

                                            self.yang_name = "unknown"
                                            self.yang_parent_name = "snpa-state"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('reason_code', (YLeaf(YType.enumeration, 'reason-code'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisIfClnsSnpaUnknownReason', '')])),
                                            ])
                                            self.reason_code = None
                                            self._segment_path = lambda: "unknown"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.SnpaState.Unknown, [u'reason_code'], name, value)


                                    class Known(Entity):
                                        """
                                        Information pertaining to the known SNPA state
                                        
                                        .. attribute:: snpa
                                        
                                        	Valid SNPA
                                        	**type**\: str
                                        
                                        	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.SnpaState.Known, self).__init__()

                                            self.yang_name = "known"
                                            self.yang_parent_name = "snpa-state"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('snpa', (YLeaf(YType.str, 'snpa'), ['str'])),
                                            ])
                                            self.snpa = None
                                            self._segment_path = lambda: "known"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.SnpaState.Known, [u'snpa'], name, value)


                                class MediaSpecificState(Entity):
                                    """
                                    Media Specific CLNS state
                                    
                                    .. attribute:: clns_lan_data
                                    
                                    	LAN state
                                    	**type**\:  :py:class:`ClnsLanData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData>`
                                    
                                    .. attribute:: clns_p2p_data
                                    
                                    	Point\-to\-point state
                                    	**type**\:  :py:class:`ClnsP2pData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2pData>`
                                    
                                    .. attribute:: clns_media_type
                                    
                                    	CLNSMediaType
                                    	**type**\:  :py:class:`IsisMediaClass <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisMediaClass>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState, self).__init__()

                                        self.yang_name = "media-specific-state"
                                        self.yang_parent_name = "clns-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("clns-lan-data", ("clns_lan_data", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData)), ("clns-p2p-data", ("clns_p2p_data", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2pData))])
                                        self._leafs = OrderedDict([
                                            ('clns_media_type', (YLeaf(YType.enumeration, 'clns-media-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisMediaClass', '')])),
                                        ])
                                        self.clns_media_type = None

                                        self.clns_lan_data = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData()
                                        self.clns_lan_data.parent = self
                                        self._children_name_map["clns_lan_data"] = "clns-lan-data"

                                        self.clns_p2p_data = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2pData()
                                        self.clns_p2p_data.parent = self
                                        self._children_name_map["clns_p2p_data"] = "clns-p2p-data"
                                        self._segment_path = lambda: "media-specific-state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState, [u'clns_media_type'], name, value)


                                    class ClnsLanData(Entity):
                                        """
                                        LAN state
                                        
                                        .. attribute:: per_area_data
                                        
                                        	Array of per area CLNS data
                                        	**type**\: list of  		 :py:class:`PerAreaData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData.PerAreaData>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData, self).__init__()

                                            self.yang_name = "clns-lan-data"
                                            self.yang_parent_name = "media-specific-state"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("per-area-data", ("per_area_data", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData.PerAreaData))])
                                            self._leafs = OrderedDict()

                                            self.per_area_data = YList(self)
                                            self._segment_path = lambda: "clns-lan-data"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData, [], name, value)


                                        class PerAreaData(Entity):
                                            """
                                            Array of per area CLNS data
                                            
                                            .. attribute:: multicast_status
                                            
                                            	Multicast group membership status
                                            	**type**\:  :py:class:`MulticastStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData.PerAreaData.MulticastStatus>`
                                            
                                            .. attribute:: level
                                            
                                            	Level of the area
                                            	**type**\:  :py:class:`IsisLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevel>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData.PerAreaData, self).__init__()

                                                self.yang_name = "per-area-data"
                                                self.yang_parent_name = "clns-lan-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("multicast-status", ("multicast_status", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData.PerAreaData.MulticastStatus))])
                                                self._leafs = OrderedDict([
                                                    ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisLevel', '')])),
                                                ])
                                                self.level = None

                                                self.multicast_status = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData.PerAreaData.MulticastStatus()
                                                self.multicast_status.parent = self
                                                self._children_name_map["multicast_status"] = "multicast-status"
                                                self._segment_path = lambda: "per-area-data"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData.PerAreaData, [u'level'], name, value)


                                            class MulticastStatus(Entity):
                                                """
                                                Multicast group membership status
                                                
                                                .. attribute:: invalid
                                                
                                                	Information pertaining to the invalid multicast status
                                                	**type**\:  :py:class:`Invalid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData.PerAreaData.MulticastStatus.Invalid>`
                                                
                                                .. attribute:: status
                                                
                                                	Status
                                                	**type**\:  :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData.PerAreaData.MulticastStatus, self).__init__()

                                                    self.yang_name = "multicast-status"
                                                    self.yang_parent_name = "per-area-data"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("invalid", ("invalid", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData.PerAreaData.MulticastStatus.Invalid))])
                                                    self._leafs = OrderedDict([
                                                        ('status', (YLeaf(YType.enumeration, 'status'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisValid', '')])),
                                                    ])
                                                    self.status = None

                                                    self.invalid = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData.PerAreaData.MulticastStatus.Invalid()
                                                    self.invalid.parent = self
                                                    self._children_name_map["invalid"] = "invalid"
                                                    self._segment_path = lambda: "multicast-status"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData.PerAreaData.MulticastStatus, [u'status'], name, value)


                                                class Invalid(Entity):
                                                    """
                                                    Information pertaining to the invalid multicast
                                                    status
                                                    
                                                    .. attribute:: reason_code
                                                    
                                                    	Reason why the multicast status is invalid
                                                    	**type**\:  :py:class:`IsisIfMcastInvalidReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisIfMcastInvalidReason>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData.PerAreaData.MulticastStatus.Invalid, self).__init__()

                                                        self.yang_name = "invalid"
                                                        self.yang_parent_name = "multicast-status"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('reason_code', (YLeaf(YType.enumeration, 'reason-code'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisIfMcastInvalidReason', '')])),
                                                        ])
                                                        self.reason_code = None
                                                        self._segment_path = lambda: "invalid"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsLanData.PerAreaData.MulticastStatus.Invalid, [u'reason_code'], name, value)


                                    class ClnsP2pData(Entity):
                                        """
                                        Point\-to\-point state
                                        
                                        .. attribute:: p2p_over_lan_data
                                        
                                        	Point\-to\-point over LAN data
                                        	**type**\:  :py:class:`P2pOverLanData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2pData.P2pOverLanData>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2pData, self).__init__()

                                            self.yang_name = "clns-p2p-data"
                                            self.yang_parent_name = "media-specific-state"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("p2p-over-lan-data", ("p2p_over_lan_data", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2pData.P2pOverLanData))])
                                            self._leafs = OrderedDict()

                                            self.p2p_over_lan_data = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2pData.P2pOverLanData()
                                            self.p2p_over_lan_data.parent = self
                                            self._children_name_map["p2p_over_lan_data"] = "p2p-over-lan-data"
                                            self._segment_path = lambda: "clns-p2p-data"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2pData, [], name, value)


                                        class P2pOverLanData(Entity):
                                            """
                                            Point\-to\-point over LAN data
                                            
                                            .. attribute:: multicast_status
                                            
                                            	Multicast group membership status
                                            	**type**\:  :py:class:`MulticastStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2pData.P2pOverLanData.MulticastStatus>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2pData.P2pOverLanData, self).__init__()

                                                self.yang_name = "p2p-over-lan-data"
                                                self.yang_parent_name = "clns-p2p-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("multicast-status", ("multicast_status", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2pData.P2pOverLanData.MulticastStatus))])
                                                self._leafs = OrderedDict()

                                                self.multicast_status = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2pData.P2pOverLanData.MulticastStatus()
                                                self.multicast_status.parent = self
                                                self._children_name_map["multicast_status"] = "multicast-status"
                                                self._segment_path = lambda: "p2p-over-lan-data"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2pData.P2pOverLanData, [], name, value)


                                            class MulticastStatus(Entity):
                                                """
                                                Multicast group membership status
                                                
                                                .. attribute:: invalid
                                                
                                                	Information pertaining to the invalid multicast status
                                                	**type**\:  :py:class:`Invalid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2pData.P2pOverLanData.MulticastStatus.Invalid>`
                                                
                                                .. attribute:: status
                                                
                                                	Status
                                                	**type**\:  :py:class:`IsisValid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisValid>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2pData.P2pOverLanData.MulticastStatus, self).__init__()

                                                    self.yang_name = "multicast-status"
                                                    self.yang_parent_name = "p2p-over-lan-data"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("invalid", ("invalid", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2pData.P2pOverLanData.MulticastStatus.Invalid))])
                                                    self._leafs = OrderedDict([
                                                        ('status', (YLeaf(YType.enumeration, 'status'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisValid', '')])),
                                                    ])
                                                    self.status = None

                                                    self.invalid = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2pData.P2pOverLanData.MulticastStatus.Invalid()
                                                    self.invalid.parent = self
                                                    self._children_name_map["invalid"] = "invalid"
                                                    self._segment_path = lambda: "multicast-status"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2pData.P2pOverLanData.MulticastStatus, [u'status'], name, value)


                                                class Invalid(Entity):
                                                    """
                                                    Information pertaining to the invalid multicast
                                                    status
                                                    
                                                    .. attribute:: reason_code
                                                    
                                                    	Reason why the multicast status is invalid
                                                    	**type**\:  :py:class:`IsisIfMcastInvalidReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisIfMcastInvalidReason>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2pData.P2pOverLanData.MulticastStatus.Invalid, self).__init__()

                                                        self.yang_name = "invalid"
                                                        self.yang_parent_name = "multicast-status"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('reason_code', (YLeaf(YType.enumeration, 'reason-code'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisIfMcastInvalidReason', '')])),
                                                        ])
                                                        self.reason_code = None
                                                        self._segment_path = lambda: "invalid"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.ClnsData.MediaSpecificState.ClnsP2pData.P2pOverLanData.MulticastStatus.Invalid, [u'reason_code'], name, value)


                            class UnderlyingInterface(Entity):
                                """
                                Underlying interface list for bundle interfaces
                                
                                .. attribute:: interface_index
                                
                                	Local interface handle
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.UnderlyingInterface, self).__init__()

                                    self.yang_name = "underlying-interface"
                                    self.yang_parent_name = "enabled"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interface_index', (YLeaf(YType.uint32, 'interface-index'), ['int'])),
                                        ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                                    ])
                                    self.interface_index = None
                                    self.interface_name = None
                                    self._segment_path = lambda: "underlying-interface"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.UnderlyingInterface, [u'interface_index', u'interface_name'], name, value)


                            class PerAreaData(Entity):
                                """
                                Array of area information for an active
                                interface
                                
                                .. attribute:: lan_data
                                
                                	LAN data, NULL iff interface has non\-LAN media type
                                	**type**\:  :py:class:`LanData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAreaData.LanData>`
                                
                                .. attribute:: level
                                
                                	Level of the area
                                	**type**\:  :py:class:`IsisLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevel>`
                                
                                .. attribute:: adjacency_count
                                
                                	Number of adjacencies
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: lsp_pacing_interval
                                
                                	LSP pacing time period (ms)
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: psnp_transmit_queue_size
                                
                                	No. of SNP entries queued to be transmitted
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: hello_interval
                                
                                	Hello interval
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: hello_multiplier
                                
                                	Hello Multiplier
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAreaData, self).__init__()

                                    self.yang_name = "per-area-data"
                                    self.yang_parent_name = "enabled"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("lan-data", ("lan_data", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAreaData.LanData))])
                                    self._leafs = OrderedDict([
                                        ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisLevel', '')])),
                                        ('adjacency_count', (YLeaf(YType.uint32, 'adjacency-count'), ['int'])),
                                        ('lsp_pacing_interval', (YLeaf(YType.uint32, 'lsp-pacing-interval'), ['int'])),
                                        ('psnp_transmit_queue_size', (YLeaf(YType.uint32, 'psnp-transmit-queue-size'), ['int'])),
                                        ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                                        ('hello_multiplier', (YLeaf(YType.uint32, 'hello-multiplier'), ['int'])),
                                    ])
                                    self.level = None
                                    self.adjacency_count = None
                                    self.lsp_pacing_interval = None
                                    self.psnp_transmit_queue_size = None
                                    self.hello_interval = None
                                    self.hello_multiplier = None

                                    self.lan_data = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAreaData.LanData()
                                    self.lan_data.parent = self
                                    self._children_name_map["lan_data"] = "lan-data"
                                    self._segment_path = lambda: "per-area-data"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAreaData, [u'level', u'adjacency_count', u'lsp_pacing_interval', u'psnp_transmit_queue_size', u'hello_interval', u'hello_multiplier'], name, value)


                                class LanData(Entity):
                                    """
                                    LAN data, NULL iff interface has non\-LAN media
                                    type
                                    
                                    .. attribute:: circuit_lan_id
                                    
                                    	Circuit LAN ID
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: time_until_next_iih
                                    
                                    	Time (ms) until next IIH
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: interface_priority
                                    
                                    	Interface's DIS\-election priority
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: dispriority
                                    
                                    	Priority of current DIS on this LAN
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: are_we_dis
                                    
                                    	Flag indicating if this LAN circuit is the DIS
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAreaData.LanData, self).__init__()

                                        self.yang_name = "lan-data"
                                        self.yang_parent_name = "per-area-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('circuit_lan_id', (YLeaf(YType.str, 'circuit-lan-id'), ['str'])),
                                            ('time_until_next_iih', (YLeaf(YType.uint32, 'time-until-next-iih'), ['int'])),
                                            ('interface_priority', (YLeaf(YType.uint8, 'interface-priority'), ['int'])),
                                            ('dispriority', (YLeaf(YType.uint8, 'dispriority'), ['int'])),
                                            ('are_we_dis', (YLeaf(YType.boolean, 'are-we-dis'), ['bool'])),
                                        ])
                                        self.circuit_lan_id = None
                                        self.time_until_next_iih = None
                                        self.interface_priority = None
                                        self.dispriority = None
                                        self.are_we_dis = None
                                        self._segment_path = lambda: "lan-data"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAreaData.LanData, [u'circuit_lan_id', u'time_until_next_iih', u'interface_priority', u'dispriority', u'are_we_dis'], name, value)


                            class PerTopologyData(Entity):
                                """
                                Array of topology information
                                
                                .. attribute:: topology_id
                                
                                	Topology identifier
                                	**type**\:  :py:class:`TopologyId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.TopologyId>`
                                
                                .. attribute:: status
                                
                                	Status of the topology
                                	**type**\:  :py:class:`Status <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData, self).__init__()

                                    self.yang_name = "per-topology-data"
                                    self.yang_parent_name = "enabled"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("topology-id", ("topology_id", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.TopologyId)), ("status", ("status", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status))])
                                    self._leafs = OrderedDict()

                                    self.topology_id = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.TopologyId()
                                    self.topology_id.parent = self
                                    self._children_name_map["topology_id"] = "topology-id"

                                    self.status = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status()
                                    self.status.parent = self
                                    self._children_name_map["status"] = "status"
                                    self._segment_path = lambda: "per-topology-data"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData, [], name, value)


                                class TopologyId(Entity):
                                    """
                                    Topology identifier
                                    
                                    .. attribute:: af_name
                                    
                                    	AF name
                                    	**type**\:  :py:class:`IsisAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAfId>`
                                    
                                    .. attribute:: saf_name
                                    
                                    	Sub\-AF name
                                    	**type**\:  :py:class:`IsisSubAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisSubAfId>`
                                    
                                    .. attribute:: vrf_name
                                    
                                    	VRF Name
                                    	**type**\: str
                                    
                                    .. attribute:: topology_name
                                    
                                    	Topology Name
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.TopologyId, self).__init__()

                                        self.yang_name = "topology-id"
                                        self.yang_parent_name = "per-topology-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisAfId', '')])),
                                            ('saf_name', (YLeaf(YType.enumeration, 'saf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisSubAfId', '')])),
                                            ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                            ('topology_name', (YLeaf(YType.str, 'topology-name'), ['str'])),
                                        ])
                                        self.af_name = None
                                        self.saf_name = None
                                        self.vrf_name = None
                                        self.topology_name = None
                                        self._segment_path = lambda: "topology-id"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.TopologyId, [u'af_name', u'saf_name', u'vrf_name', u'topology_name'], name, value)


                                class Status(Entity):
                                    """
                                    Status of the topology
                                    
                                    .. attribute:: disabled
                                    
                                    	Disabled information of a topology
                                    	**type**\:  :py:class:`Disabled <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Disabled>`
                                    
                                    .. attribute:: enabled
                                    
                                    	Enabled information of a topology
                                    	**type**\:  :py:class:`Enabled_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_>`
                                    
                                    .. attribute:: status
                                    
                                    	Status
                                    	**type**\:  :py:class:`IsisEnabled <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisEnabled>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status, self).__init__()

                                        self.yang_name = "status"
                                        self.yang_parent_name = "per-topology-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("disabled", ("disabled", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Disabled)), ("enabled", ("enabled", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_))])
                                        self._leafs = OrderedDict([
                                            ('status', (YLeaf(YType.enumeration, 'status'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisEnabled', '')])),
                                        ])
                                        self.status = None

                                        self.disabled = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Disabled()
                                        self.disabled.parent = self
                                        self._children_name_map["disabled"] = "disabled"

                                        self.enabled = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_()
                                        self.enabled.parent = self
                                        self._children_name_map["enabled"] = "enabled"
                                        self._segment_path = lambda: "status"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status, [u'status'], name, value)


                                    class Disabled(Entity):
                                        """
                                        Disabled information of a topology
                                        
                                        .. attribute:: reason_code
                                        
                                        	Reason why the topology is disabled
                                        	**type**\:  :py:class:`IsisIfTopoDisabledReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisIfTopoDisabledReason>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Disabled, self).__init__()

                                            self.yang_name = "disabled"
                                            self.yang_parent_name = "status"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('reason_code', (YLeaf(YType.enumeration, 'reason-code'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisIfTopoDisabledReason', '')])),
                                            ])
                                            self.reason_code = None
                                            self._segment_path = lambda: "disabled"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Disabled, [u'reason_code'], name, value)


                                    class Enabled_(Entity):
                                        """
                                        Enabled information of a topology
                                        
                                        .. attribute:: adjacency_form_status
                                        
                                        	Adjacency formation status of a topology
                                        	**type**\:  :py:class:`AdjacencyFormStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.AdjacencyFormStatus>`
                                        
                                        .. attribute:: adv_prefix_status
                                        
                                        	Prefix advertisement status of a topology
                                        	**type**\:  :py:class:`AdvPrefixStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.AdvPrefixStatus>`
                                        
                                        .. attribute:: level1_frr
                                        
                                        	Level1 FRR information
                                        	**type**\:  :py:class:`Level1Frr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.Level1Frr>`
                                        
                                        .. attribute:: level2_frr
                                        
                                        	Level2 FRR information
                                        	**type**\:  :py:class:`Level2Frr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.Level2Frr>`
                                        
                                        .. attribute:: level1_metric
                                        
                                        	L1 metric for this topology
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: level2_metric
                                        
                                        	L2 metric for this topology
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: level1_weight
                                        
                                        	L1 metric for this topology
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: level2_weight
                                        
                                        	L2 metric for this topology
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: max_label_supported
                                        
                                        	MPLS maximum number of pri labels supported
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: max_bkp_label_supported
                                        
                                        	MPLS maximum number of backup labels supported
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: max_srte_label_supported
                                        
                                        	MPLS maximum number of srte labels supported
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: level1ldp_sync_enabled
                                        
                                        	MPLS LDP sync enabled status for L1
                                        	**type**\: bool
                                        
                                        .. attribute:: level2ldp_sync_enabled
                                        
                                        	MPLS LDP sync enabled status for L2
                                        	**type**\: bool
                                        
                                        .. attribute:: ldp_sync_status
                                        
                                        	Status of MPLS LDP synchronization
                                        	**type**\: bool
                                        
                                        .. attribute:: ld_pv6_sync_status
                                        
                                        	Status of MPLS LDPv6 synchronization
                                        	**type**\: bool
                                        
                                        .. attribute:: level1_offset_metric
                                        
                                        	L1 metric\-offset for this topology
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: level2_offset_metric
                                        
                                        	L2 metric\-offset for this topology
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: level1_lkgp_configured
                                        
                                        	Link\-Group configure status for L1
                                        	**type**\: bool
                                        
                                        .. attribute:: level2_lkgp_configured
                                        
                                        	Link\-Group configure status for L2
                                        	**type**\: bool
                                        
                                        .. attribute:: level1pp_metric
                                        
                                        	L1 PP\-metric for this topology
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: level2pp_metric
                                        
                                        	L2 PP\-metric for this topology
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: level1pp_configured
                                        
                                        	PP configure status for L1
                                        	**type**\: bool
                                        
                                        .. attribute:: level2pp_configured
                                        
                                        	PP configure status for L2
                                        	**type**\: bool
                                        
                                        .. attribute:: manual_adj_sid
                                        
                                        	Array of Manual Adjacency SIDs
                                        	**type**\: list of  		 :py:class:`ManualAdjSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.ManualAdjSid>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_, self).__init__()

                                            self.yang_name = "enabled"
                                            self.yang_parent_name = "status"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("adjacency-form-status", ("adjacency_form_status", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.AdjacencyFormStatus)), ("adv-prefix-status", ("adv_prefix_status", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.AdvPrefixStatus)), ("level1-frr", ("level1_frr", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.Level1Frr)), ("level2-frr", ("level2_frr", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.Level2Frr)), ("manual-adj-sid", ("manual_adj_sid", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.ManualAdjSid))])
                                            self._leafs = OrderedDict([
                                                ('level1_metric', (YLeaf(YType.uint32, 'level1-metric'), ['int'])),
                                                ('level2_metric', (YLeaf(YType.uint32, 'level2-metric'), ['int'])),
                                                ('level1_weight', (YLeaf(YType.uint32, 'level1-weight'), ['int'])),
                                                ('level2_weight', (YLeaf(YType.uint32, 'level2-weight'), ['int'])),
                                                ('max_label_supported', (YLeaf(YType.uint8, 'max-label-supported'), ['int'])),
                                                ('max_bkp_label_supported', (YLeaf(YType.uint8, 'max-bkp-label-supported'), ['int'])),
                                                ('max_srte_label_supported', (YLeaf(YType.uint8, 'max-srte-label-supported'), ['int'])),
                                                ('level1ldp_sync_enabled', (YLeaf(YType.boolean, 'level1ldp-sync-enabled'), ['bool'])),
                                                ('level2ldp_sync_enabled', (YLeaf(YType.boolean, 'level2ldp-sync-enabled'), ['bool'])),
                                                ('ldp_sync_status', (YLeaf(YType.boolean, 'ldp-sync-status'), ['bool'])),
                                                ('ld_pv6_sync_status', (YLeaf(YType.boolean, 'ld-pv6-sync-status'), ['bool'])),
                                                ('level1_offset_metric', (YLeaf(YType.uint32, 'level1-offset-metric'), ['int'])),
                                                ('level2_offset_metric', (YLeaf(YType.uint32, 'level2-offset-metric'), ['int'])),
                                                ('level1_lkgp_configured', (YLeaf(YType.boolean, 'level1-lkgp-configured'), ['bool'])),
                                                ('level2_lkgp_configured', (YLeaf(YType.boolean, 'level2-lkgp-configured'), ['bool'])),
                                                ('level1pp_metric', (YLeaf(YType.uint32, 'level1pp-metric'), ['int'])),
                                                ('level2pp_metric', (YLeaf(YType.uint32, 'level2pp-metric'), ['int'])),
                                                ('level1pp_configured', (YLeaf(YType.boolean, 'level1pp-configured'), ['bool'])),
                                                ('level2pp_configured', (YLeaf(YType.boolean, 'level2pp-configured'), ['bool'])),
                                            ])
                                            self.level1_metric = None
                                            self.level2_metric = None
                                            self.level1_weight = None
                                            self.level2_weight = None
                                            self.max_label_supported = None
                                            self.max_bkp_label_supported = None
                                            self.max_srte_label_supported = None
                                            self.level1ldp_sync_enabled = None
                                            self.level2ldp_sync_enabled = None
                                            self.ldp_sync_status = None
                                            self.ld_pv6_sync_status = None
                                            self.level1_offset_metric = None
                                            self.level2_offset_metric = None
                                            self.level1_lkgp_configured = None
                                            self.level2_lkgp_configured = None
                                            self.level1pp_metric = None
                                            self.level2pp_metric = None
                                            self.level1pp_configured = None
                                            self.level2pp_configured = None

                                            self.adjacency_form_status = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.AdjacencyFormStatus()
                                            self.adjacency_form_status.parent = self
                                            self._children_name_map["adjacency_form_status"] = "adjacency-form-status"

                                            self.adv_prefix_status = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.AdvPrefixStatus()
                                            self.adv_prefix_status.parent = self
                                            self._children_name_map["adv_prefix_status"] = "adv-prefix-status"

                                            self.level1_frr = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.Level1Frr()
                                            self.level1_frr.parent = self
                                            self._children_name_map["level1_frr"] = "level1-frr"

                                            self.level2_frr = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.Level2Frr()
                                            self.level2_frr.parent = self
                                            self._children_name_map["level2_frr"] = "level2-frr"

                                            self.manual_adj_sid = YList(self)
                                            self._segment_path = lambda: "enabled"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_, [u'level1_metric', u'level2_metric', u'level1_weight', u'level2_weight', u'max_label_supported', u'max_bkp_label_supported', u'max_srte_label_supported', u'level1ldp_sync_enabled', u'level2ldp_sync_enabled', u'ldp_sync_status', u'ld_pv6_sync_status', u'level1_offset_metric', u'level2_offset_metric', u'level1_lkgp_configured', u'level2_lkgp_configured', u'level1pp_metric', u'level2pp_metric', u'level1pp_configured', u'level2pp_configured'], name, value)


                                        class AdjacencyFormStatus(Entity):
                                            """
                                            Adjacency formation status of a topology
                                            
                                            .. attribute:: disabled
                                            
                                            	Disabled state for the adjacency formation status of a topology
                                            	**type**\:  :py:class:`Disabled <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.AdjacencyFormStatus.Disabled>`
                                            
                                            .. attribute:: status
                                            
                                            	Status
                                            	**type**\:  :py:class:`IsisEnabled <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisEnabled>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.AdjacencyFormStatus, self).__init__()

                                                self.yang_name = "adjacency-form-status"
                                                self.yang_parent_name = "enabled"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("disabled", ("disabled", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.AdjacencyFormStatus.Disabled))])
                                                self._leafs = OrderedDict([
                                                    ('status', (YLeaf(YType.enumeration, 'status'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisEnabled', '')])),
                                                ])
                                                self.status = None

                                                self.disabled = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.AdjacencyFormStatus.Disabled()
                                                self.disabled.parent = self
                                                self._children_name_map["disabled"] = "disabled"
                                                self._segment_path = lambda: "adjacency-form-status"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.AdjacencyFormStatus, [u'status'], name, value)


                                            class Disabled(Entity):
                                                """
                                                Disabled state for the adjacency formation
                                                status of a topology
                                                
                                                .. attribute:: reason_code
                                                
                                                	Reason why the adjacency formation status of a topology is disabled
                                                	**type**\:  :py:class:`IsisIfTopoAdjFormDisabledReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisIfTopoAdjFormDisabledReason>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.AdjacencyFormStatus.Disabled, self).__init__()

                                                    self.yang_name = "disabled"
                                                    self.yang_parent_name = "adjacency-form-status"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('reason_code', (YLeaf(YType.enumeration, 'reason-code'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisIfTopoAdjFormDisabledReason', '')])),
                                                    ])
                                                    self.reason_code = None
                                                    self._segment_path = lambda: "disabled"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.AdjacencyFormStatus.Disabled, [u'reason_code'], name, value)


                                        class AdvPrefixStatus(Entity):
                                            """
                                            Prefix advertisement status of a topology
                                            
                                            .. attribute:: disabled
                                            
                                            	Disabled state for the prefix advertisement status of a topology
                                            	**type**\:  :py:class:`Disabled <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.AdvPrefixStatus.Disabled>`
                                            
                                            .. attribute:: status
                                            
                                            	Status
                                            	**type**\:  :py:class:`IsisEnabled <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisEnabled>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.AdvPrefixStatus, self).__init__()

                                                self.yang_name = "adv-prefix-status"
                                                self.yang_parent_name = "enabled"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("disabled", ("disabled", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.AdvPrefixStatus.Disabled))])
                                                self._leafs = OrderedDict([
                                                    ('status', (YLeaf(YType.enumeration, 'status'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisEnabled', '')])),
                                                ])
                                                self.status = None

                                                self.disabled = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.AdvPrefixStatus.Disabled()
                                                self.disabled.parent = self
                                                self._children_name_map["disabled"] = "disabled"
                                                self._segment_path = lambda: "adv-prefix-status"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.AdvPrefixStatus, [u'status'], name, value)


                                            class Disabled(Entity):
                                                """
                                                Disabled state for the prefix advertisement
                                                status of a topology
                                                
                                                .. attribute:: reason_code
                                                
                                                	Reason why the prefix advertisement status of a topology is disabled
                                                	**type**\:  :py:class:`IsisIfTopoAdvPrefixDisabledReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisIfTopoAdvPrefixDisabledReason>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.AdvPrefixStatus.Disabled, self).__init__()

                                                    self.yang_name = "disabled"
                                                    self.yang_parent_name = "adv-prefix-status"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('reason_code', (YLeaf(YType.enumeration, 'reason-code'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisIfTopoAdvPrefixDisabledReason', '')])),
                                                    ])
                                                    self.reason_code = None
                                                    self._segment_path = lambda: "disabled"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.AdvPrefixStatus.Disabled, [u'reason_code'], name, value)


                                        class Level1Frr(Entity):
                                            """
                                            Level1 FRR information
                                            
                                            .. attribute:: frr_type
                                            
                                            	FRR type configured per level for this interface
                                            	**type**\:  :py:class:`IsisFrr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisFrr>`
                                            
                                            .. attribute:: is_frr
                                            
                                            	Is FRR enabled per level on this interface
                                            	**type**\: bool
                                            
                                            .. attribute:: is_remote_lfa
                                            
                                            	Is FRR Remote LFA enabled per level for this interface
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ti_lfa
                                            
                                            	Is FRR TI LFA enabled per level for this interface
                                            	**type**\: bool
                                            
                                            .. attribute:: ti_lfa_node_tie_breaker_index
                                            
                                            	TI LFA node\-protecting Tie breaker index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ti_lfa_srlg_tie_breaker
                                            
                                            	TI LFA srlg Tie breaker index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_tie_breakers_configured
                                            
                                            	Is Tiebreaker configured per level for this interface
                                            	**type**\: bool
                                            
                                            .. attribute:: frr_tie_breaker
                                            
                                            	FRR TieBreakers array per level for this interface
                                            	**type**\: list of  		 :py:class:`FrrTieBreaker <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.Level1Frr.FrrTieBreaker>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.Level1Frr, self).__init__()

                                                self.yang_name = "level1-frr"
                                                self.yang_parent_name = "enabled"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-tie-breaker", ("frr_tie_breaker", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.Level1Frr.FrrTieBreaker))])
                                                self._leafs = OrderedDict([
                                                    ('frr_type', (YLeaf(YType.enumeration, 'frr-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisFrr', '')])),
                                                    ('is_frr', (YLeaf(YType.boolean, 'is-frr'), ['bool'])),
                                                    ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                    ('is_ti_lfa', (YLeaf(YType.boolean, 'is-ti-lfa'), ['bool'])),
                                                    ('ti_lfa_node_tie_breaker_index', (YLeaf(YType.uint8, 'ti-lfa-node-tie-breaker-index'), ['int'])),
                                                    ('ti_lfa_srlg_tie_breaker', (YLeaf(YType.uint8, 'ti-lfa-srlg-tie-breaker'), ['int'])),
                                                    ('is_tie_breakers_configured', (YLeaf(YType.boolean, 'is-tie-breakers-configured'), ['bool'])),
                                                ])
                                                self.frr_type = None
                                                self.is_frr = None
                                                self.is_remote_lfa = None
                                                self.is_ti_lfa = None
                                                self.ti_lfa_node_tie_breaker_index = None
                                                self.ti_lfa_srlg_tie_breaker = None
                                                self.is_tie_breakers_configured = None

                                                self.frr_tie_breaker = YList(self)
                                                self._segment_path = lambda: "level1-frr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.Level1Frr, [u'frr_type', u'is_frr', u'is_remote_lfa', u'is_ti_lfa', u'ti_lfa_node_tie_breaker_index', u'ti_lfa_srlg_tie_breaker', u'is_tie_breakers_configured'], name, value)


                                            class FrrTieBreaker(Entity):
                                                """
                                                FRR TieBreakers array per level for this
                                                interface
                                                
                                                .. attribute:: tie_breaker
                                                
                                                	Tie Breaker Type
                                                	**type**\:  :py:class:`IsisFrrTiebreaker <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisFrrTiebreaker>`
                                                
                                                .. attribute:: index
                                                
                                                	Tie Breaker Index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.Level1Frr.FrrTieBreaker, self).__init__()

                                                    self.yang_name = "frr-tie-breaker"
                                                    self.yang_parent_name = "level1-frr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('tie_breaker', (YLeaf(YType.enumeration, 'tie-breaker'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisFrrTiebreaker', '')])),
                                                        ('index', (YLeaf(YType.uint8, 'index'), ['int'])),
                                                    ])
                                                    self.tie_breaker = None
                                                    self.index = None
                                                    self._segment_path = lambda: "frr-tie-breaker"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.Level1Frr.FrrTieBreaker, [u'tie_breaker', u'index'], name, value)


                                        class Level2Frr(Entity):
                                            """
                                            Level2 FRR information
                                            
                                            .. attribute:: frr_type
                                            
                                            	FRR type configured per level for this interface
                                            	**type**\:  :py:class:`IsisFrr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisFrr>`
                                            
                                            .. attribute:: is_frr
                                            
                                            	Is FRR enabled per level on this interface
                                            	**type**\: bool
                                            
                                            .. attribute:: is_remote_lfa
                                            
                                            	Is FRR Remote LFA enabled per level for this interface
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ti_lfa
                                            
                                            	Is FRR TI LFA enabled per level for this interface
                                            	**type**\: bool
                                            
                                            .. attribute:: ti_lfa_node_tie_breaker_index
                                            
                                            	TI LFA node\-protecting Tie breaker index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ti_lfa_srlg_tie_breaker
                                            
                                            	TI LFA srlg Tie breaker index
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: is_tie_breakers_configured
                                            
                                            	Is Tiebreaker configured per level for this interface
                                            	**type**\: bool
                                            
                                            .. attribute:: frr_tie_breaker
                                            
                                            	FRR TieBreakers array per level for this interface
                                            	**type**\: list of  		 :py:class:`FrrTieBreaker <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.Level2Frr.FrrTieBreaker>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.Level2Frr, self).__init__()

                                                self.yang_name = "level2-frr"
                                                self.yang_parent_name = "enabled"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("frr-tie-breaker", ("frr_tie_breaker", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.Level2Frr.FrrTieBreaker))])
                                                self._leafs = OrderedDict([
                                                    ('frr_type', (YLeaf(YType.enumeration, 'frr-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisFrr', '')])),
                                                    ('is_frr', (YLeaf(YType.boolean, 'is-frr'), ['bool'])),
                                                    ('is_remote_lfa', (YLeaf(YType.boolean, 'is-remote-lfa'), ['bool'])),
                                                    ('is_ti_lfa', (YLeaf(YType.boolean, 'is-ti-lfa'), ['bool'])),
                                                    ('ti_lfa_node_tie_breaker_index', (YLeaf(YType.uint8, 'ti-lfa-node-tie-breaker-index'), ['int'])),
                                                    ('ti_lfa_srlg_tie_breaker', (YLeaf(YType.uint8, 'ti-lfa-srlg-tie-breaker'), ['int'])),
                                                    ('is_tie_breakers_configured', (YLeaf(YType.boolean, 'is-tie-breakers-configured'), ['bool'])),
                                                ])
                                                self.frr_type = None
                                                self.is_frr = None
                                                self.is_remote_lfa = None
                                                self.is_ti_lfa = None
                                                self.ti_lfa_node_tie_breaker_index = None
                                                self.ti_lfa_srlg_tie_breaker = None
                                                self.is_tie_breakers_configured = None

                                                self.frr_tie_breaker = YList(self)
                                                self._segment_path = lambda: "level2-frr"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.Level2Frr, [u'frr_type', u'is_frr', u'is_remote_lfa', u'is_ti_lfa', u'ti_lfa_node_tie_breaker_index', u'ti_lfa_srlg_tie_breaker', u'is_tie_breakers_configured'], name, value)


                                            class FrrTieBreaker(Entity):
                                                """
                                                FRR TieBreakers array per level for this
                                                interface
                                                
                                                .. attribute:: tie_breaker
                                                
                                                	Tie Breaker Type
                                                	**type**\:  :py:class:`IsisFrrTiebreaker <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisFrrTiebreaker>`
                                                
                                                .. attribute:: index
                                                
                                                	Tie Breaker Index
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.Level2Frr.FrrTieBreaker, self).__init__()

                                                    self.yang_name = "frr-tie-breaker"
                                                    self.yang_parent_name = "level2-frr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('tie_breaker', (YLeaf(YType.enumeration, 'tie-breaker'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisFrrTiebreaker', '')])),
                                                        ('index', (YLeaf(YType.uint8, 'index'), ['int'])),
                                                    ])
                                                    self.tie_breaker = None
                                                    self.index = None
                                                    self._segment_path = lambda: "frr-tie-breaker"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.Level2Frr.FrrTieBreaker, [u'tie_breaker', u'index'], name, value)


                                        class ManualAdjSid(Entity):
                                            """
                                            Array of Manual Adjacency SIDs
                                            
                                            .. attribute:: manual_adjacency_sid_label
                                            
                                            	Manual Adjacency SID Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: manual_adjacency_sid_index
                                            
                                            	Manual Adjacency SID Index (if configured as index)
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: manual_adjacency_sid_type
                                            
                                            	Manual Adjacency SID Type (Absolute or Index)
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: sid_protected
                                            
                                            	SID configured as protected by backup path
                                            	**type**\: bool
                                            
                                            .. attribute:: sid_active
                                            
                                            	SID is in use
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.ManualAdjSid, self).__init__()

                                                self.yang_name = "manual-adj-sid"
                                                self.yang_parent_name = "enabled"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('manual_adjacency_sid_label', (YLeaf(YType.uint32, 'manual-adjacency-sid-label'), ['int'])),
                                                    ('manual_adjacency_sid_index', (YLeaf(YType.uint32, 'manual-adjacency-sid-index'), ['int'])),
                                                    ('manual_adjacency_sid_type', (YLeaf(YType.uint8, 'manual-adjacency-sid-type'), ['int'])),
                                                    ('sid_protected', (YLeaf(YType.boolean, 'sid-protected'), ['bool'])),
                                                    ('sid_active', (YLeaf(YType.boolean, 'sid-active'), ['bool'])),
                                                ])
                                                self.manual_adjacency_sid_label = None
                                                self.manual_adjacency_sid_index = None
                                                self.manual_adjacency_sid_type = None
                                                self.sid_protected = None
                                                self.sid_active = None
                                                self._segment_path = lambda: "manual-adj-sid"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerTopologyData.Status.Enabled_.ManualAdjSid, [u'manual_adjacency_sid_label', u'manual_adjacency_sid_index', u'manual_adjacency_sid_type', u'sid_protected', u'sid_active'], name, value)


                            class PerAddressFamilyData(Entity):
                                """
                                Array of address family information
                                
                                .. attribute:: af_status
                                
                                	Address Family status of the interface
                                	**type**\:  :py:class:`AfStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus>`
                                
                                .. attribute:: af_name
                                
                                	Address Family Identifier of the interface
                                	**type**\:  :py:class:`IsisAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAfId>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData, self).__init__()

                                    self.yang_name = "per-address-family-data"
                                    self.yang_parent_name = "enabled"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("af-status", ("af_status", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus))])
                                    self._leafs = OrderedDict([
                                        ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisAfId', '')])),
                                    ])
                                    self.af_name = None

                                    self.af_status = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus()
                                    self.af_status.parent = self
                                    self._children_name_map["af_status"] = "af-status"
                                    self._segment_path = lambda: "per-address-family-data"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData, [u'af_name'], name, value)


                                class AfStatus(Entity):
                                    """
                                    Address Family status of the interface
                                    
                                    .. attribute:: disabled
                                    
                                    	Disabled info for the AF of an interface
                                    	**type**\:  :py:class:`Disabled <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.Disabled>`
                                    
                                    .. attribute:: af_data
                                    
                                    	Enabled data for the AF of an interface
                                    	**type**\:  :py:class:`AfData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData>`
                                    
                                    .. attribute:: status
                                    
                                    	Status
                                    	**type**\:  :py:class:`IsisEnabled <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisEnabled>`
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus, self).__init__()

                                        self.yang_name = "af-status"
                                        self.yang_parent_name = "per-address-family-data"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("disabled", ("disabled", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.Disabled)), ("af-data", ("af_data", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData))])
                                        self._leafs = OrderedDict([
                                            ('status', (YLeaf(YType.enumeration, 'status'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisEnabled', '')])),
                                        ])
                                        self.status = None

                                        self.disabled = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.Disabled()
                                        self.disabled.parent = self
                                        self._children_name_map["disabled"] = "disabled"

                                        self.af_data = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData()
                                        self.af_data.parent = self
                                        self._children_name_map["af_data"] = "af-data"
                                        self._segment_path = lambda: "af-status"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus, [u'status'], name, value)


                                    class Disabled(Entity):
                                        """
                                        Disabled info for the AF of an interface
                                        
                                        .. attribute:: reason_code
                                        
                                        	Reason why the Address Family is disabled
                                        	**type**\:  :py:class:`IsisIfAfDisabledReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisIfAfDisabledReason>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.Disabled, self).__init__()

                                            self.yang_name = "disabled"
                                            self.yang_parent_name = "af-status"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('reason_code', (YLeaf(YType.enumeration, 'reason-code'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisIfAfDisabledReason', '')])),
                                            ])
                                            self.reason_code = None
                                            self._segment_path = lambda: "disabled"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.Disabled, [u'reason_code'], name, value)


                                    class AfData(Entity):
                                        """
                                        Enabled data for the AF of an interface
                                        
                                        .. attribute:: protocol_status
                                        
                                        	Protocol status of the AF
                                        	**type**\:  :py:class:`ProtocolStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ProtocolStatus>`
                                        
                                        .. attribute:: forwarding_address_status
                                        
                                        	Forwarding status of the AF
                                        	**type**\:  :py:class:`ForwardingAddressStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus>`
                                        
                                        .. attribute:: prefix_status
                                        
                                        	Prefix status of the AF
                                        	**type**\:  :py:class:`PrefixStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus>`
                                        
                                        

                                        """

                                        _prefix = 'clns-isis-oper'
                                        _revision = '2018-04-07'

                                        def __init__(self):
                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData, self).__init__()

                                            self.yang_name = "af-data"
                                            self.yang_parent_name = "af-status"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("protocol-status", ("protocol_status", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ProtocolStatus)), ("forwarding-address-status", ("forwarding_address_status", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus)), ("prefix-status", ("prefix_status", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus))])
                                            self._leafs = OrderedDict()

                                            self.protocol_status = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ProtocolStatus()
                                            self.protocol_status.parent = self
                                            self._children_name_map["protocol_status"] = "protocol-status"

                                            self.forwarding_address_status = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus()
                                            self.forwarding_address_status.parent = self
                                            self._children_name_map["forwarding_address_status"] = "forwarding-address-status"

                                            self.prefix_status = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus()
                                            self.prefix_status.parent = self
                                            self._children_name_map["prefix_status"] = "prefix-status"
                                            self._segment_path = lambda: "af-data"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData, [], name, value)


                                        class ProtocolStatus(Entity):
                                            """
                                            Protocol status of the AF
                                            
                                            .. attribute:: disabled
                                            
                                            	Disabled state of the Address Family protocol
                                            	**type**\:  :py:class:`Disabled <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ProtocolStatus.Disabled>`
                                            
                                            .. attribute:: status
                                            
                                            	Status
                                            	**type**\:  :py:class:`IsisUp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisUp>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ProtocolStatus, self).__init__()

                                                self.yang_name = "protocol-status"
                                                self.yang_parent_name = "af-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("disabled", ("disabled", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ProtocolStatus.Disabled))])
                                                self._leafs = OrderedDict([
                                                    ('status', (YLeaf(YType.enumeration, 'status'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisUp', '')])),
                                                ])
                                                self.status = None

                                                self.disabled = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ProtocolStatus.Disabled()
                                                self.disabled.parent = self
                                                self._children_name_map["disabled"] = "disabled"
                                                self._segment_path = lambda: "protocol-status"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ProtocolStatus, [u'status'], name, value)


                                            class Disabled(Entity):
                                                """
                                                Disabled state of the Address Family protocol
                                                
                                                .. attribute:: reason_code
                                                
                                                	Reason why the Address Family protocol status is down
                                                	**type**\:  :py:class:`IsisIfAfProtoDownReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisIfAfProtoDownReason>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ProtocolStatus.Disabled, self).__init__()

                                                    self.yang_name = "disabled"
                                                    self.yang_parent_name = "protocol-status"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('reason_code', (YLeaf(YType.enumeration, 'reason-code'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisIfAfProtoDownReason', '')])),
                                                    ])
                                                    self.reason_code = None
                                                    self._segment_path = lambda: "disabled"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ProtocolStatus.Disabled, [u'reason_code'], name, value)


                                        class ForwardingAddressStatus(Entity):
                                            """
                                            Forwarding status of the AF
                                            
                                            .. attribute:: unknown
                                            
                                            	Unknown forwarding address data
                                            	**type**\:  :py:class:`Unknown <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus.Unknown>`
                                            
                                            .. attribute:: forwarding_address_data
                                            
                                            	Known Forwarding address data
                                            	**type**\:  :py:class:`ForwardingAddressData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus.ForwardingAddressData>`
                                            
                                            .. attribute:: status
                                            
                                            	Status
                                            	**type**\:  :py:class:`IsisKnown <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisKnown>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus, self).__init__()

                                                self.yang_name = "forwarding-address-status"
                                                self.yang_parent_name = "af-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("unknown", ("unknown", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus.Unknown)), ("forwarding-address-data", ("forwarding_address_data", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus.ForwardingAddressData))])
                                                self._leafs = OrderedDict([
                                                    ('status', (YLeaf(YType.enumeration, 'status'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisKnown', '')])),
                                                ])
                                                self.status = None

                                                self.unknown = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus.Unknown()
                                                self.unknown.parent = self
                                                self._children_name_map["unknown"] = "unknown"

                                                self.forwarding_address_data = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus.ForwardingAddressData()
                                                self.forwarding_address_data.parent = self
                                                self._children_name_map["forwarding_address_data"] = "forwarding-address-data"
                                                self._segment_path = lambda: "forwarding-address-status"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus, [u'status'], name, value)


                                            class Unknown(Entity):
                                                """
                                                Unknown forwarding address data
                                                
                                                .. attribute:: reason_code
                                                
                                                	Reason why the forwarding address(es) of an AF is(are) unknown
                                                	**type**\:  :py:class:`IsisIfAfFwdAddrUnknownReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisIfAfFwdAddrUnknownReason>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus.Unknown, self).__init__()

                                                    self.yang_name = "unknown"
                                                    self.yang_parent_name = "forwarding-address-status"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('reason_code', (YLeaf(YType.enumeration, 'reason-code'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisIfAfFwdAddrUnknownReason', '')])),
                                                    ])
                                                    self.reason_code = None
                                                    self._segment_path = lambda: "unknown"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus.Unknown, [u'reason_code'], name, value)


                                            class ForwardingAddressData(Entity):
                                                """
                                                Known Forwarding address data
                                                
                                                .. attribute:: unnumbered_interface_name
                                                
                                                	If the interface is unnumbered, then its name, else NULL
                                                	**type**\: str
                                                
                                                .. attribute:: forwarding_address
                                                
                                                	Array of forwarding addresses
                                                	**type**\: list of  		 :py:class:`ForwardingAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus.ForwardingAddressData.ForwardingAddress>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus.ForwardingAddressData, self).__init__()

                                                    self.yang_name = "forwarding-address-data"
                                                    self.yang_parent_name = "forwarding-address-status"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("forwarding-address", ("forwarding_address", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus.ForwardingAddressData.ForwardingAddress))])
                                                    self._leafs = OrderedDict([
                                                        ('unnumbered_interface_name', (YLeaf(YType.str, 'unnumbered-interface-name'), ['str'])),
                                                    ])
                                                    self.unnumbered_interface_name = None

                                                    self.forwarding_address = YList(self)
                                                    self._segment_path = lambda: "forwarding-address-data"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus.ForwardingAddressData, [u'unnumbered_interface_name'], name, value)


                                                class ForwardingAddress(Entity):
                                                    """
                                                    Array of forwarding addresses
                                                    
                                                    .. attribute:: af_name
                                                    
                                                    	AFName
                                                    	**type**\:  :py:class:`IsisAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAfId>`
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	IPV4 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	IPV6 address type
                                                    	**type**\: str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus.ForwardingAddressData.ForwardingAddress, self).__init__()

                                                        self.yang_name = "forwarding-address"
                                                        self.yang_parent_name = "forwarding-address-data"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisAfId', '')])),
                                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                                        ])
                                                        self.af_name = None
                                                        self.ipv4 = None
                                                        self.ipv6 = None
                                                        self._segment_path = lambda: "forwarding-address"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.ForwardingAddressStatus.ForwardingAddressData.ForwardingAddress, [u'af_name', u'ipv4', u'ipv6'], name, value)


                                        class PrefixStatus(Entity):
                                            """
                                            Prefix status of the AF
                                            
                                            .. attribute:: unknown
                                            
                                            	Unknown state for the global prefixes
                                            	**type**\:  :py:class:`Unknown <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.Unknown>`
                                            
                                            .. attribute:: prefix_data
                                            
                                            	Global prefix data for the Address Family
                                            	**type**\:  :py:class:`PrefixData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData>`
                                            
                                            .. attribute:: status
                                            
                                            	Status
                                            	**type**\:  :py:class:`IsisKnown <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisKnown>`
                                            
                                            

                                            """

                                            _prefix = 'clns-isis-oper'
                                            _revision = '2018-04-07'

                                            def __init__(self):
                                                super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus, self).__init__()

                                                self.yang_name = "prefix-status"
                                                self.yang_parent_name = "af-data"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("unknown", ("unknown", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.Unknown)), ("prefix-data", ("prefix_data", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData))])
                                                self._leafs = OrderedDict([
                                                    ('status', (YLeaf(YType.enumeration, 'status'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisKnown', '')])),
                                                ])
                                                self.status = None

                                                self.unknown = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.Unknown()
                                                self.unknown.parent = self
                                                self._children_name_map["unknown"] = "unknown"

                                                self.prefix_data = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData()
                                                self.prefix_data.parent = self
                                                self._children_name_map["prefix_data"] = "prefix-data"
                                                self._segment_path = lambda: "prefix-status"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus, [u'status'], name, value)


                                            class Unknown(Entity):
                                                """
                                                Unknown state for the global prefixes
                                                
                                                .. attribute:: reason_code
                                                
                                                	Reason why the global prefix(es) is(are) unknown
                                                	**type**\:  :py:class:`IsisIfAfPrefixUnknownReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisIfAfPrefixUnknownReason>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.Unknown, self).__init__()

                                                    self.yang_name = "unknown"
                                                    self.yang_parent_name = "prefix-status"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('reason_code', (YLeaf(YType.enumeration, 'reason-code'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisIfAfPrefixUnknownReason', '')])),
                                                    ])
                                                    self.reason_code = None
                                                    self._segment_path = lambda: "unknown"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.Unknown, [u'reason_code'], name, value)


                                            class PrefixData(Entity):
                                                """
                                                Global prefix data for the Address Family
                                                
                                                .. attribute:: is_unnumbered
                                                
                                                	Is the interface unnumbered
                                                	**type**\: bool
                                                
                                                .. attribute:: prefix
                                                
                                                	Array of global prefixes
                                                	**type**\: list of  		 :py:class:`Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData.Prefix>`
                                                
                                                

                                                """

                                                _prefix = 'clns-isis-oper'
                                                _revision = '2018-04-07'

                                                def __init__(self):
                                                    super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData, self).__init__()

                                                    self.yang_name = "prefix-data"
                                                    self.yang_parent_name = "prefix-status"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix", ("prefix", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData.Prefix))])
                                                    self._leafs = OrderedDict([
                                                        ('is_unnumbered', (YLeaf(YType.boolean, 'is-unnumbered'), ['bool'])),
                                                    ])
                                                    self.is_unnumbered = None

                                                    self.prefix = YList(self)
                                                    self._segment_path = lambda: "prefix-data"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData, [u'is_unnumbered'], name, value)


                                                class Prefix(Entity):
                                                    """
                                                    Array of global prefixes
                                                    
                                                    .. attribute:: ipv4
                                                    
                                                    	ipv4
                                                    	**type**\:  :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData.Prefix.Ipv4>`
                                                    
                                                    .. attribute:: ipv6
                                                    
                                                    	ipv6
                                                    	**type**\:  :py:class:`Ipv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData.Prefix.Ipv6>`
                                                    
                                                    .. attribute:: af_name
                                                    
                                                    	AFName
                                                    	**type**\:  :py:class:`IsisAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAfId>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'clns-isis-oper'
                                                    _revision = '2018-04-07'

                                                    def __init__(self):
                                                        super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData.Prefix, self).__init__()

                                                        self.yang_name = "prefix"
                                                        self.yang_parent_name = "prefix-data"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("ipv4", ("ipv4", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData.Prefix.Ipv4)), ("ipv6", ("ipv6", Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData.Prefix.Ipv6))])
                                                        self._leafs = OrderedDict([
                                                            ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisAfId', '')])),
                                                        ])
                                                        self.af_name = None

                                                        self.ipv4 = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData.Prefix.Ipv4()
                                                        self.ipv4.parent = self
                                                        self._children_name_map["ipv4"] = "ipv4"

                                                        self.ipv6 = Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData.Prefix.Ipv6()
                                                        self.ipv6.parent = self
                                                        self._children_name_map["ipv6"] = "ipv6"
                                                        self._segment_path = lambda: "prefix"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData.Prefix, [u'af_name'], name, value)


                                                    class Ipv4(Entity):
                                                        """
                                                        ipv4
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	prefix
                                                        	**type**\: str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	prefix length
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData.Prefix.Ipv4, self).__init__()

                                                            self.yang_name = "ipv4"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                            ])
                                                            self.prefix = None
                                                            self.prefix_length = None
                                                            self._segment_path = lambda: "ipv4"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData.Prefix.Ipv4, [u'prefix', u'prefix_length'], name, value)


                                                    class Ipv6(Entity):
                                                        """
                                                        ipv6
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	prefix
                                                        	**type**\: str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	prefix length
                                                        	**type**\: int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        

                                                        """

                                                        _prefix = 'clns-isis-oper'
                                                        _revision = '2018-04-07'

                                                        def __init__(self):
                                                            super(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData.Prefix.Ipv6, self).__init__()

                                                            self.yang_name = "ipv6"
                                                            self.yang_parent_name = "prefix"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ('prefix_length', (YLeaf(YType.uint8, 'prefix-length'), ['int'])),
                                                            ])
                                                            self.prefix = None
                                                            self.prefix_length = None
                                                            self._segment_path = lambda: "ipv6"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Isis.Instances.Instance.Interfaces.Interface.InterfaceStatusAndData.Enabled.PerAddressFamilyData.AfStatus.AfData.PrefixStatus.PrefixData.Prefix.Ipv6, [u'prefix', u'prefix_length'], name, value)


            class CheckpointAdjacencies(Entity):
                """
                Checkpointed adjacency table
                
                .. attribute:: checkpoint_adjacency
                
                	A checkpointed IS\-IS adjacency
                	**type**\: list of  		 :py:class:`CheckpointAdjacency <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.CheckpointAdjacencies.CheckpointAdjacency>`
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2018-04-07'

                def __init__(self):
                    super(Isis.Instances.Instance.CheckpointAdjacencies, self).__init__()

                    self.yang_name = "checkpoint-adjacencies"
                    self.yang_parent_name = "instance"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("checkpoint-adjacency", ("checkpoint_adjacency", Isis.Instances.Instance.CheckpointAdjacencies.CheckpointAdjacency))])
                    self._leafs = OrderedDict()

                    self.checkpoint_adjacency = YList(self)
                    self._segment_path = lambda: "checkpoint-adjacencies"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Isis.Instances.Instance.CheckpointAdjacencies, [], name, value)


                class CheckpointAdjacency(Entity):
                    """
                    A checkpointed IS\-IS adjacency
                    
                    .. attribute:: level
                    
                    	Level
                    	**type**\:  :py:class:`IsisInternalLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_datatypes.IsisInternalLevel>`
                    
                    .. attribute:: system_id
                    
                    	System ID
                    	**type**\: str
                    
                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: checkpoint_adjacency_object_id
                    
                    	Checkpoint object ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: checkpoint_adjacency_system_id
                    
                    	Neighbor system ID
                    	**type**\: str
                    
                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                    
                    .. attribute:: checkpoint_adjacency_snpa
                    
                    	Neighbor SNPA
                    	**type**\: str
                    
                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                    
                    .. attribute:: checkpoint_adjacency_interface
                    
                    	Local interface
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: checkpoint_adjacency_level
                    
                    	Adjacency level
                    	**type**\:  :py:class:`IsisLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevel>`
                    
                    .. attribute:: checkpoint_adjacency_holdtime
                    
                    	Adjacency holdtime (s)
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: checkpoint_adjacency_lan_priority
                    
                    	Adjacency LAN priority
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: checkpoint_adjacency_circuit_number
                    
                    	Neighbor circuit number
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: checkpoint_adjacency_per_address_family_next_hop
                    
                    	Per address family next hops
                    	**type**\: list of  		 :py:class:`CheckpointAdjacencyPerAddressFamilyNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.CheckpointAdjacencies.CheckpointAdjacency.CheckpointAdjacencyPerAddressFamilyNextHop>`
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2018-04-07'

                    def __init__(self):
                        super(Isis.Instances.Instance.CheckpointAdjacencies.CheckpointAdjacency, self).__init__()

                        self.yang_name = "checkpoint-adjacency"
                        self.yang_parent_name = "checkpoint-adjacencies"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("checkpoint-adjacency-per-address-family-next-hop", ("checkpoint_adjacency_per_address_family_next_hop", Isis.Instances.Instance.CheckpointAdjacencies.CheckpointAdjacency.CheckpointAdjacencyPerAddressFamilyNextHop))])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_datatypes', 'IsisInternalLevel', '')])),
                            ('system_id', (YLeaf(YType.str, 'system-id'), ['str'])),
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('checkpoint_adjacency_object_id', (YLeaf(YType.uint32, 'checkpoint-adjacency-object-id'), ['int'])),
                            ('checkpoint_adjacency_system_id', (YLeaf(YType.str, 'checkpoint-adjacency-system-id'), ['str'])),
                            ('checkpoint_adjacency_snpa', (YLeaf(YType.str, 'checkpoint-adjacency-snpa'), ['str'])),
                            ('checkpoint_adjacency_interface', (YLeaf(YType.str, 'checkpoint-adjacency-interface'), ['str'])),
                            ('checkpoint_adjacency_level', (YLeaf(YType.enumeration, 'checkpoint-adjacency-level'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisLevel', '')])),
                            ('checkpoint_adjacency_holdtime', (YLeaf(YType.uint16, 'checkpoint-adjacency-holdtime'), ['int'])),
                            ('checkpoint_adjacency_lan_priority', (YLeaf(YType.uint8, 'checkpoint-adjacency-lan-priority'), ['int'])),
                            ('checkpoint_adjacency_circuit_number', (YLeaf(YType.uint8, 'checkpoint-adjacency-circuit-number'), ['int'])),
                        ])
                        self.level = None
                        self.system_id = None
                        self.interface_name = None
                        self.checkpoint_adjacency_object_id = None
                        self.checkpoint_adjacency_system_id = None
                        self.checkpoint_adjacency_snpa = None
                        self.checkpoint_adjacency_interface = None
                        self.checkpoint_adjacency_level = None
                        self.checkpoint_adjacency_holdtime = None
                        self.checkpoint_adjacency_lan_priority = None
                        self.checkpoint_adjacency_circuit_number = None

                        self.checkpoint_adjacency_per_address_family_next_hop = YList(self)
                        self._segment_path = lambda: "checkpoint-adjacency"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Isis.Instances.Instance.CheckpointAdjacencies.CheckpointAdjacency, ['level', 'system_id', 'interface_name', u'checkpoint_adjacency_object_id', u'checkpoint_adjacency_system_id', u'checkpoint_adjacency_snpa', u'checkpoint_adjacency_interface', u'checkpoint_adjacency_level', u'checkpoint_adjacency_holdtime', u'checkpoint_adjacency_lan_priority', u'checkpoint_adjacency_circuit_number'], name, value)


                    class CheckpointAdjacencyPerAddressFamilyNextHop(Entity):
                        """
                        Per address family next hops
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:  :py:class:`IsisAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAfId>`
                        
                        .. attribute:: ipv4
                        
                        	IPV4 address type
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6
                        
                        	IPV6 address type
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.CheckpointAdjacencies.CheckpointAdjacency.CheckpointAdjacencyPerAddressFamilyNextHop, self).__init__()

                            self.yang_name = "checkpoint-adjacency-per-address-family-next-hop"
                            self.yang_parent_name = "checkpoint-adjacency"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisAfId', '')])),
                                ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                            ])
                            self.af_name = None
                            self.ipv4 = None
                            self.ipv6 = None
                            self._segment_path = lambda: "checkpoint-adjacency-per-address-family-next-hop"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.CheckpointAdjacencies.CheckpointAdjacency.CheckpointAdjacencyPerAddressFamilyNextHop, [u'af_name', u'ipv4', u'ipv6'], name, value)


            class FlexAlgos(Entity):
                """
                Flex\-Algo Table
                
                .. attribute:: flex_algo
                
                	Flex\-Algo Definition Data
                	**type**\: list of  		 :py:class:`FlexAlgo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.FlexAlgos.FlexAlgo>`
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2018-04-07'

                def __init__(self):
                    super(Isis.Instances.Instance.FlexAlgos, self).__init__()

                    self.yang_name = "flex-algos"
                    self.yang_parent_name = "instance"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("flex-algo", ("flex_algo", Isis.Instances.Instance.FlexAlgos.FlexAlgo))])
                    self._leafs = OrderedDict()

                    self.flex_algo = YList(self)
                    self._segment_path = lambda: "flex-algos"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Isis.Instances.Instance.FlexAlgos, [], name, value)


                class FlexAlgo(Entity):
                    """
                    Flex\-Algo Definition Data
                    
                    .. attribute:: flex_alg  (key)
                    
                    	Flex Algo
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number
                    
                    	Flex\-Algo Number
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: local_priority
                    
                    	Flex\_algo Local Priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: disabled
                    
                    	Flex\-Algo Disabled
                    	**type**\: bool
                    
                    .. attribute:: definition_prioroty
                    
                    	Flex\-Algo Definition Priority
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: definition_local
                    
                    	Flex\-Algo Definition Is Local
                    	**type**\: bool
                    
                    .. attribute:: definition_equal_local
                    
                    	Flex\-Algo Definition Is Equal To Local
                    	**type**\: bool
                    
                    .. attribute:: definiion_node_id
                    
                    	Flex\-Algo Definition Node\-ID
                    	**type**\: str
                    
                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2018-04-07'

                    def __init__(self):
                        super(Isis.Instances.Instance.FlexAlgos.FlexAlgo, self).__init__()

                        self.yang_name = "flex-algo"
                        self.yang_parent_name = "flex-algos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['flex_alg']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('flex_alg', (YLeaf(YType.uint32, 'flex-alg'), ['int'])),
                            ('number', (YLeaf(YType.uint32, 'number'), ['int'])),
                            ('local_priority', (YLeaf(YType.uint32, 'local-priority'), ['int'])),
                            ('disabled', (YLeaf(YType.boolean, 'disabled'), ['bool'])),
                            ('definition_prioroty', (YLeaf(YType.uint32, 'definition-prioroty'), ['int'])),
                            ('definition_local', (YLeaf(YType.boolean, 'definition-local'), ['bool'])),
                            ('definition_equal_local', (YLeaf(YType.boolean, 'definition-equal-local'), ['bool'])),
                            ('definiion_node_id', (YLeaf(YType.str, 'definiion-node-id'), ['str'])),
                        ])
                        self.flex_alg = None
                        self.number = None
                        self.local_priority = None
                        self.disabled = None
                        self.definition_prioroty = None
                        self.definition_local = None
                        self.definition_equal_local = None
                        self.definiion_node_id = None
                        self._segment_path = lambda: "flex-algo" + "[flex-alg='" + str(self.flex_alg) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Isis.Instances.Instance.FlexAlgos.FlexAlgo, ['flex_alg', u'number', u'local_priority', u'disabled', u'definition_prioroty', u'definition_local', u'definition_equal_local', u'definiion_node_id'], name, value)


            class Srms(Entity):
                """
                Segment Routing Mapping Server operational
                data
                
                .. attribute:: policy
                
                	Policy operational data
                	**type**\:  :py:class:`Policy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Srms.Policy>`
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2018-04-07'

                def __init__(self):
                    super(Isis.Instances.Instance.Srms, self).__init__()

                    self.yang_name = "srms"
                    self.yang_parent_name = "instance"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("policy", ("policy", Isis.Instances.Instance.Srms.Policy))])
                    self._leafs = OrderedDict()

                    self.policy = Isis.Instances.Instance.Srms.Policy()
                    self.policy.parent = self
                    self._children_name_map["policy"] = "policy"
                    self._segment_path = lambda: "srms"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Isis.Instances.Instance.Srms, [], name, value)


                class Policy(Entity):
                    """
                    Policy operational data
                    
                    .. attribute:: policy_ipv4
                    
                    	IPv4 policy operational data
                    	**type**\:  :py:class:`PolicyIpv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Srms.Policy.PolicyIpv4>`
                    
                    .. attribute:: policy_ipv6
                    
                    	IPv6 policy operational data
                    	**type**\:  :py:class:`PolicyIpv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Srms.Policy.PolicyIpv6>`
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2018-04-07'

                    def __init__(self):
                        super(Isis.Instances.Instance.Srms.Policy, self).__init__()

                        self.yang_name = "policy"
                        self.yang_parent_name = "srms"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("policy-ipv4", ("policy_ipv4", Isis.Instances.Instance.Srms.Policy.PolicyIpv4)), ("policy-ipv6", ("policy_ipv6", Isis.Instances.Instance.Srms.Policy.PolicyIpv6))])
                        self._leafs = OrderedDict()

                        self.policy_ipv4 = Isis.Instances.Instance.Srms.Policy.PolicyIpv4()
                        self.policy_ipv4.parent = self
                        self._children_name_map["policy_ipv4"] = "policy-ipv4"

                        self.policy_ipv6 = Isis.Instances.Instance.Srms.Policy.PolicyIpv6()
                        self.policy_ipv6.parent = self
                        self._children_name_map["policy_ipv6"] = "policy-ipv6"
                        self._segment_path = lambda: "policy"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Isis.Instances.Instance.Srms.Policy, [], name, value)


                    class PolicyIpv4(Entity):
                        """
                        IPv4 policy operational data
                        
                        .. attribute:: policy_ipv4_active
                        
                        	IPv4 active policy operational data
                        	**type**\:  :py:class:`PolicyIpv4Active <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Active>`
                        
                        .. attribute:: policy_ipv4_backup
                        
                        	IPv4 backup policy operational data
                        	**type**\:  :py:class:`PolicyIpv4Backup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Backup>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.Srms.Policy.PolicyIpv4, self).__init__()

                            self.yang_name = "policy-ipv4"
                            self.yang_parent_name = "policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("policy-ipv4-active", ("policy_ipv4_active", Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Active)), ("policy-ipv4-backup", ("policy_ipv4_backup", Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Backup))])
                            self._leafs = OrderedDict()

                            self.policy_ipv4_active = Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Active()
                            self.policy_ipv4_active.parent = self
                            self._children_name_map["policy_ipv4_active"] = "policy-ipv4-active"

                            self.policy_ipv4_backup = Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Backup()
                            self.policy_ipv4_backup.parent = self
                            self._children_name_map["policy_ipv4_backup"] = "policy-ipv4-backup"
                            self._segment_path = lambda: "policy-ipv4"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.Srms.Policy.PolicyIpv4, [], name, value)


                        class PolicyIpv4Active(Entity):
                            """
                            IPv4 active policy operational data
                            
                            .. attribute:: policy_mi
                            
                            	Mapping Item
                            	**type**\: list of  		 :py:class:`PolicyMi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Active, self).__init__()

                                self.yang_name = "policy-ipv4-active"
                                self.yang_parent_name = "policy-ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("policy-mi", ("policy_mi", Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi))])
                                self._leafs = OrderedDict()

                                self.policy_mi = YList(self)
                                self._segment_path = lambda: "policy-ipv4-active"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Active, [], name, value)


                            class PolicyMi(Entity):
                                """
                                Mapping Item
                                
                                .. attribute:: mi_id  (key)
                                
                                	Mapping Item ID (0, 1, 2, ...)
                                	**type**\: str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: addr
                                
                                	addr
                                	**type**\:  :py:class:`Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi.Addr>`
                                
                                .. attribute:: src
                                
                                	src
                                	**type**\:  :py:class:`SrmsMiSrcEB <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.SrmsMiSrcEB>`
                                
                                .. attribute:: router
                                
                                	Router ID
                                	**type**\: str
                                
                                	**length:** 0..30
                                
                                .. attribute:: area
                                
                                	Area (OSPF) or Level (ISIS)
                                	**type**\: str
                                
                                	**length:** 0..30
                                
                                .. attribute:: prefix
                                
                                	Prefix length
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: sid_start
                                
                                	Starting SID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sid_count
                                
                                	SID range
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_prefix
                                
                                	Last IP Prefix
                                	**type**\: str
                                
                                	**length:** 0..50
                                
                                .. attribute:: last_sid_index
                                
                                	Last SID Index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: flag_attached
                                
                                	Attached flag
                                	**type**\:  :py:class:`SrmsMiFlagEB <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.SrmsMiFlagEB>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi, self).__init__()

                                    self.yang_name = "policy-mi"
                                    self.yang_parent_name = "policy-ipv4-active"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['mi_id']
                                    self._child_classes = OrderedDict([("addr", ("addr", Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi.Addr))])
                                    self._leafs = OrderedDict([
                                        ('mi_id', (YLeaf(YType.str, 'mi-id'), ['str'])),
                                        ('src', (YLeaf(YType.enumeration, 'src'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'SrmsMiSrcEB', '')])),
                                        ('router', (YLeaf(YType.str, 'router'), ['str'])),
                                        ('area', (YLeaf(YType.str, 'area'), ['str'])),
                                        ('prefix', (YLeaf(YType.uint8, 'prefix'), ['int'])),
                                        ('sid_start', (YLeaf(YType.uint32, 'sid-start'), ['int'])),
                                        ('sid_count', (YLeaf(YType.uint32, 'sid-count'), ['int'])),
                                        ('last_prefix', (YLeaf(YType.str, 'last-prefix'), ['str'])),
                                        ('last_sid_index', (YLeaf(YType.uint32, 'last-sid-index'), ['int'])),
                                        ('flag_attached', (YLeaf(YType.enumeration, 'flag-attached'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'SrmsMiFlagEB', '')])),
                                    ])
                                    self.mi_id = None
                                    self.src = None
                                    self.router = None
                                    self.area = None
                                    self.prefix = None
                                    self.sid_start = None
                                    self.sid_count = None
                                    self.last_prefix = None
                                    self.last_sid_index = None
                                    self.flag_attached = None

                                    self.addr = Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi.Addr()
                                    self.addr.parent = self
                                    self._children_name_map["addr"] = "addr"
                                    self._segment_path = lambda: "policy-mi" + "[mi-id='" + str(self.mi_id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi, ['mi_id', 'src', 'router', 'area', 'prefix', 'sid_start', 'sid_count', 'last_prefix', 'last_sid_index', 'flag_attached'], name, value)


                                class Addr(Entity):
                                    """
                                    addr
                                    
                                    .. attribute:: af
                                    
                                    	AF
                                    	**type**\:  :py:class:`SrmsMiAfEB <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.SrmsMiAfEB>`
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi.Addr, self).__init__()

                                        self.yang_name = "addr"
                                        self.yang_parent_name = "policy-mi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af', (YLeaf(YType.enumeration, 'af'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'SrmsMiAfEB', '')])),
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                        ])
                                        self.af = None
                                        self.ipv4 = None
                                        self.ipv6 = None
                                        self._segment_path = lambda: "addr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Active.PolicyMi.Addr, ['af', 'ipv4', 'ipv6'], name, value)


                        class PolicyIpv4Backup(Entity):
                            """
                            IPv4 backup policy operational data
                            
                            .. attribute:: policy_mi
                            
                            	Mapping Item
                            	**type**\: list of  		 :py:class:`PolicyMi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Backup, self).__init__()

                                self.yang_name = "policy-ipv4-backup"
                                self.yang_parent_name = "policy-ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("policy-mi", ("policy_mi", Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi))])
                                self._leafs = OrderedDict()

                                self.policy_mi = YList(self)
                                self._segment_path = lambda: "policy-ipv4-backup"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Backup, [], name, value)


                            class PolicyMi(Entity):
                                """
                                Mapping Item
                                
                                .. attribute:: mi_id  (key)
                                
                                	Mapping Item ID (0, 1, 2, ...)
                                	**type**\: str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: addr
                                
                                	addr
                                	**type**\:  :py:class:`Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi.Addr>`
                                
                                .. attribute:: src
                                
                                	src
                                	**type**\:  :py:class:`SrmsMiSrcEB <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.SrmsMiSrcEB>`
                                
                                .. attribute:: router
                                
                                	Router ID
                                	**type**\: str
                                
                                	**length:** 0..30
                                
                                .. attribute:: area
                                
                                	Area (OSPF) or Level (ISIS)
                                	**type**\: str
                                
                                	**length:** 0..30
                                
                                .. attribute:: prefix
                                
                                	Prefix length
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: sid_start
                                
                                	Starting SID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sid_count
                                
                                	SID range
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_prefix
                                
                                	Last IP Prefix
                                	**type**\: str
                                
                                	**length:** 0..50
                                
                                .. attribute:: last_sid_index
                                
                                	Last SID Index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: flag_attached
                                
                                	Attached flag
                                	**type**\:  :py:class:`SrmsMiFlagEB <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.SrmsMiFlagEB>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi, self).__init__()

                                    self.yang_name = "policy-mi"
                                    self.yang_parent_name = "policy-ipv4-backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['mi_id']
                                    self._child_classes = OrderedDict([("addr", ("addr", Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi.Addr))])
                                    self._leafs = OrderedDict([
                                        ('mi_id', (YLeaf(YType.str, 'mi-id'), ['str'])),
                                        ('src', (YLeaf(YType.enumeration, 'src'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'SrmsMiSrcEB', '')])),
                                        ('router', (YLeaf(YType.str, 'router'), ['str'])),
                                        ('area', (YLeaf(YType.str, 'area'), ['str'])),
                                        ('prefix', (YLeaf(YType.uint8, 'prefix'), ['int'])),
                                        ('sid_start', (YLeaf(YType.uint32, 'sid-start'), ['int'])),
                                        ('sid_count', (YLeaf(YType.uint32, 'sid-count'), ['int'])),
                                        ('last_prefix', (YLeaf(YType.str, 'last-prefix'), ['str'])),
                                        ('last_sid_index', (YLeaf(YType.uint32, 'last-sid-index'), ['int'])),
                                        ('flag_attached', (YLeaf(YType.enumeration, 'flag-attached'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'SrmsMiFlagEB', '')])),
                                    ])
                                    self.mi_id = None
                                    self.src = None
                                    self.router = None
                                    self.area = None
                                    self.prefix = None
                                    self.sid_start = None
                                    self.sid_count = None
                                    self.last_prefix = None
                                    self.last_sid_index = None
                                    self.flag_attached = None

                                    self.addr = Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi.Addr()
                                    self.addr.parent = self
                                    self._children_name_map["addr"] = "addr"
                                    self._segment_path = lambda: "policy-mi" + "[mi-id='" + str(self.mi_id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi, ['mi_id', 'src', 'router', 'area', 'prefix', 'sid_start', 'sid_count', 'last_prefix', 'last_sid_index', 'flag_attached'], name, value)


                                class Addr(Entity):
                                    """
                                    addr
                                    
                                    .. attribute:: af
                                    
                                    	AF
                                    	**type**\:  :py:class:`SrmsMiAfEB <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.SrmsMiAfEB>`
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi.Addr, self).__init__()

                                        self.yang_name = "addr"
                                        self.yang_parent_name = "policy-mi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af', (YLeaf(YType.enumeration, 'af'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'SrmsMiAfEB', '')])),
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                        ])
                                        self.af = None
                                        self.ipv4 = None
                                        self.ipv6 = None
                                        self._segment_path = lambda: "addr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Srms.Policy.PolicyIpv4.PolicyIpv4Backup.PolicyMi.Addr, ['af', 'ipv4', 'ipv6'], name, value)


                    class PolicyIpv6(Entity):
                        """
                        IPv6 policy operational data
                        
                        .. attribute:: policy_ipv6_backup
                        
                        	IPv6 backup policy operational data
                        	**type**\:  :py:class:`PolicyIpv6Backup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Backup>`
                        
                        .. attribute:: policy_ipv6_active
                        
                        	IPv6 active policy operational data
                        	**type**\:  :py:class:`PolicyIpv6Active <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Active>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.Srms.Policy.PolicyIpv6, self).__init__()

                            self.yang_name = "policy-ipv6"
                            self.yang_parent_name = "policy"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("policy-ipv6-backup", ("policy_ipv6_backup", Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Backup)), ("policy-ipv6-active", ("policy_ipv6_active", Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Active))])
                            self._leafs = OrderedDict()

                            self.policy_ipv6_backup = Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Backup()
                            self.policy_ipv6_backup.parent = self
                            self._children_name_map["policy_ipv6_backup"] = "policy-ipv6-backup"

                            self.policy_ipv6_active = Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Active()
                            self.policy_ipv6_active.parent = self
                            self._children_name_map["policy_ipv6_active"] = "policy-ipv6-active"
                            self._segment_path = lambda: "policy-ipv6"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.Srms.Policy.PolicyIpv6, [], name, value)


                        class PolicyIpv6Backup(Entity):
                            """
                            IPv6 backup policy operational data
                            
                            .. attribute:: policy_mi
                            
                            	Mapping Item
                            	**type**\: list of  		 :py:class:`PolicyMi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Backup.PolicyMi>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Backup, self).__init__()

                                self.yang_name = "policy-ipv6-backup"
                                self.yang_parent_name = "policy-ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("policy-mi", ("policy_mi", Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Backup.PolicyMi))])
                                self._leafs = OrderedDict()

                                self.policy_mi = YList(self)
                                self._segment_path = lambda: "policy-ipv6-backup"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Backup, [], name, value)


                            class PolicyMi(Entity):
                                """
                                Mapping Item
                                
                                .. attribute:: mi_id  (key)
                                
                                	Mapping Item ID (0, 1, 2, ...)
                                	**type**\: str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: addr
                                
                                	addr
                                	**type**\:  :py:class:`Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Backup.PolicyMi.Addr>`
                                
                                .. attribute:: src
                                
                                	src
                                	**type**\:  :py:class:`SrmsMiSrcEB <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.SrmsMiSrcEB>`
                                
                                .. attribute:: router
                                
                                	Router ID
                                	**type**\: str
                                
                                	**length:** 0..30
                                
                                .. attribute:: area
                                
                                	Area (OSPF) or Level (ISIS)
                                	**type**\: str
                                
                                	**length:** 0..30
                                
                                .. attribute:: prefix
                                
                                	Prefix length
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: sid_start
                                
                                	Starting SID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sid_count
                                
                                	SID range
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_prefix
                                
                                	Last IP Prefix
                                	**type**\: str
                                
                                	**length:** 0..50
                                
                                .. attribute:: last_sid_index
                                
                                	Last SID Index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: flag_attached
                                
                                	Attached flag
                                	**type**\:  :py:class:`SrmsMiFlagEB <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.SrmsMiFlagEB>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Backup.PolicyMi, self).__init__()

                                    self.yang_name = "policy-mi"
                                    self.yang_parent_name = "policy-ipv6-backup"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['mi_id']
                                    self._child_classes = OrderedDict([("addr", ("addr", Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Backup.PolicyMi.Addr))])
                                    self._leafs = OrderedDict([
                                        ('mi_id', (YLeaf(YType.str, 'mi-id'), ['str'])),
                                        ('src', (YLeaf(YType.enumeration, 'src'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'SrmsMiSrcEB', '')])),
                                        ('router', (YLeaf(YType.str, 'router'), ['str'])),
                                        ('area', (YLeaf(YType.str, 'area'), ['str'])),
                                        ('prefix', (YLeaf(YType.uint8, 'prefix'), ['int'])),
                                        ('sid_start', (YLeaf(YType.uint32, 'sid-start'), ['int'])),
                                        ('sid_count', (YLeaf(YType.uint32, 'sid-count'), ['int'])),
                                        ('last_prefix', (YLeaf(YType.str, 'last-prefix'), ['str'])),
                                        ('last_sid_index', (YLeaf(YType.uint32, 'last-sid-index'), ['int'])),
                                        ('flag_attached', (YLeaf(YType.enumeration, 'flag-attached'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'SrmsMiFlagEB', '')])),
                                    ])
                                    self.mi_id = None
                                    self.src = None
                                    self.router = None
                                    self.area = None
                                    self.prefix = None
                                    self.sid_start = None
                                    self.sid_count = None
                                    self.last_prefix = None
                                    self.last_sid_index = None
                                    self.flag_attached = None

                                    self.addr = Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Backup.PolicyMi.Addr()
                                    self.addr.parent = self
                                    self._children_name_map["addr"] = "addr"
                                    self._segment_path = lambda: "policy-mi" + "[mi-id='" + str(self.mi_id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Backup.PolicyMi, ['mi_id', 'src', 'router', 'area', 'prefix', 'sid_start', 'sid_count', 'last_prefix', 'last_sid_index', 'flag_attached'], name, value)


                                class Addr(Entity):
                                    """
                                    addr
                                    
                                    .. attribute:: af
                                    
                                    	AF
                                    	**type**\:  :py:class:`SrmsMiAfEB <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.SrmsMiAfEB>`
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Backup.PolicyMi.Addr, self).__init__()

                                        self.yang_name = "addr"
                                        self.yang_parent_name = "policy-mi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af', (YLeaf(YType.enumeration, 'af'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'SrmsMiAfEB', '')])),
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                        ])
                                        self.af = None
                                        self.ipv4 = None
                                        self.ipv6 = None
                                        self._segment_path = lambda: "addr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Backup.PolicyMi.Addr, ['af', 'ipv4', 'ipv6'], name, value)


                        class PolicyIpv6Active(Entity):
                            """
                            IPv6 active policy operational data
                            
                            .. attribute:: policy_mi
                            
                            	Mapping Item
                            	**type**\: list of  		 :py:class:`PolicyMi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Active.PolicyMi>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Active, self).__init__()

                                self.yang_name = "policy-ipv6-active"
                                self.yang_parent_name = "policy-ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("policy-mi", ("policy_mi", Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Active.PolicyMi))])
                                self._leafs = OrderedDict()

                                self.policy_mi = YList(self)
                                self._segment_path = lambda: "policy-ipv6-active"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Active, [], name, value)


                            class PolicyMi(Entity):
                                """
                                Mapping Item
                                
                                .. attribute:: mi_id  (key)
                                
                                	Mapping Item ID (0, 1, 2, ...)
                                	**type**\: str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: addr
                                
                                	addr
                                	**type**\:  :py:class:`Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Active.PolicyMi.Addr>`
                                
                                .. attribute:: src
                                
                                	src
                                	**type**\:  :py:class:`SrmsMiSrcEB <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.SrmsMiSrcEB>`
                                
                                .. attribute:: router
                                
                                	Router ID
                                	**type**\: str
                                
                                	**length:** 0..30
                                
                                .. attribute:: area
                                
                                	Area (OSPF) or Level (ISIS)
                                	**type**\: str
                                
                                	**length:** 0..30
                                
                                .. attribute:: prefix
                                
                                	Prefix length
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: sid_start
                                
                                	Starting SID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sid_count
                                
                                	SID range
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: last_prefix
                                
                                	Last IP Prefix
                                	**type**\: str
                                
                                	**length:** 0..50
                                
                                .. attribute:: last_sid_index
                                
                                	Last SID Index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: flag_attached
                                
                                	Attached flag
                                	**type**\:  :py:class:`SrmsMiFlagEB <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.SrmsMiFlagEB>`
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Active.PolicyMi, self).__init__()

                                    self.yang_name = "policy-mi"
                                    self.yang_parent_name = "policy-ipv6-active"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['mi_id']
                                    self._child_classes = OrderedDict([("addr", ("addr", Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Active.PolicyMi.Addr))])
                                    self._leafs = OrderedDict([
                                        ('mi_id', (YLeaf(YType.str, 'mi-id'), ['str'])),
                                        ('src', (YLeaf(YType.enumeration, 'src'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'SrmsMiSrcEB', '')])),
                                        ('router', (YLeaf(YType.str, 'router'), ['str'])),
                                        ('area', (YLeaf(YType.str, 'area'), ['str'])),
                                        ('prefix', (YLeaf(YType.uint8, 'prefix'), ['int'])),
                                        ('sid_start', (YLeaf(YType.uint32, 'sid-start'), ['int'])),
                                        ('sid_count', (YLeaf(YType.uint32, 'sid-count'), ['int'])),
                                        ('last_prefix', (YLeaf(YType.str, 'last-prefix'), ['str'])),
                                        ('last_sid_index', (YLeaf(YType.uint32, 'last-sid-index'), ['int'])),
                                        ('flag_attached', (YLeaf(YType.enumeration, 'flag-attached'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'SrmsMiFlagEB', '')])),
                                    ])
                                    self.mi_id = None
                                    self.src = None
                                    self.router = None
                                    self.area = None
                                    self.prefix = None
                                    self.sid_start = None
                                    self.sid_count = None
                                    self.last_prefix = None
                                    self.last_sid_index = None
                                    self.flag_attached = None

                                    self.addr = Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Active.PolicyMi.Addr()
                                    self.addr.parent = self
                                    self._children_name_map["addr"] = "addr"
                                    self._segment_path = lambda: "policy-mi" + "[mi-id='" + str(self.mi_id) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Active.PolicyMi, ['mi_id', 'src', 'router', 'area', 'prefix', 'sid_start', 'sid_count', 'last_prefix', 'last_sid_index', 'flag_attached'], name, value)


                                class Addr(Entity):
                                    """
                                    addr
                                    
                                    .. attribute:: af
                                    
                                    	AF
                                    	**type**\:  :py:class:`SrmsMiAfEB <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.SrmsMiAfEB>`
                                    
                                    .. attribute:: ipv4
                                    
                                    	IPv4
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6
                                    
                                    	IPv6
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'clns-isis-oper'
                                    _revision = '2018-04-07'

                                    def __init__(self):
                                        super(Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Active.PolicyMi.Addr, self).__init__()

                                        self.yang_name = "addr"
                                        self.yang_parent_name = "policy-mi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('af', (YLeaf(YType.enumeration, 'af'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'SrmsMiAfEB', '')])),
                                            ('ipv4', (YLeaf(YType.str, 'ipv4'), ['str'])),
                                            ('ipv6', (YLeaf(YType.str, 'ipv6'), ['str'])),
                                        ])
                                        self.af = None
                                        self.ipv4 = None
                                        self.ipv6 = None
                                        self._segment_path = lambda: "addr"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Isis.Instances.Instance.Srms.Policy.PolicyIpv6.PolicyIpv6Active.PolicyMi.Addr, ['af', 'ipv4', 'ipv6'], name, value)


            class ErrorLog(Entity):
                """
                Log of errors and warnings
                
                .. attribute:: log_entry
                
                	Error Log entries
                	**type**\: list of  		 :py:class:`LogEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.ErrorLog.LogEntry>`
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2018-04-07'

                def __init__(self):
                    super(Isis.Instances.Instance.ErrorLog, self).__init__()

                    self.yang_name = "error-log"
                    self.yang_parent_name = "instance"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("log-entry", ("log_entry", Isis.Instances.Instance.ErrorLog.LogEntry))])
                    self._leafs = OrderedDict()

                    self.log_entry = YList(self)
                    self._segment_path = lambda: "error-log"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Isis.Instances.Instance.ErrorLog, [], name, value)


                class LogEntry(Entity):
                    """
                    Error Log entries
                    
                    .. attribute:: generic_data
                    
                    	Generic entry data
                    	**type**\:  :py:class:`GenericData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.ErrorLog.LogEntry.GenericData>`
                    
                    .. attribute:: error_log_level
                    
                    	Logging level
                    	**type**\:  :py:class:`IsisErrLogLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisErrLogLevel>`
                    
                    .. attribute:: error_code
                    
                    	Error code
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: error_reason
                    
                    	Error details
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2018-04-07'

                    def __init__(self):
                        super(Isis.Instances.Instance.ErrorLog.LogEntry, self).__init__()

                        self.yang_name = "log-entry"
                        self.yang_parent_name = "error-log"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("generic-data", ("generic_data", Isis.Instances.Instance.ErrorLog.LogEntry.GenericData))])
                        self._leafs = OrderedDict([
                            ('error_log_level', (YLeaf(YType.enumeration, 'error-log-level'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisErrLogLevel', '')])),
                            ('error_code', (YLeaf(YType.uint32, 'error-code'), ['int'])),
                            ('error_reason', (YLeaf(YType.str, 'error-reason'), ['str'])),
                        ])
                        self.error_log_level = None
                        self.error_code = None
                        self.error_reason = None

                        self.generic_data = Isis.Instances.Instance.ErrorLog.LogEntry.GenericData()
                        self.generic_data.parent = self
                        self._children_name_map["generic_data"] = "generic-data"
                        self._segment_path = lambda: "log-entry"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Isis.Instances.Instance.ErrorLog.LogEntry, [u'error_log_level', u'error_code', u'error_reason'], name, value)


                    class GenericData(Entity):
                        """
                        Generic entry data
                        
                        .. attribute:: timestamp
                        
                        	Time in UTC relative to Jan 1st, 1970
                        	**type**\:  :py:class:`Timestamp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.ErrorLog.LogEntry.GenericData.Timestamp>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.ErrorLog.LogEntry.GenericData, self).__init__()

                            self.yang_name = "generic-data"
                            self.yang_parent_name = "log-entry"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("timestamp", ("timestamp", Isis.Instances.Instance.ErrorLog.LogEntry.GenericData.Timestamp))])
                            self._leafs = OrderedDict()

                            self.timestamp = Isis.Instances.Instance.ErrorLog.LogEntry.GenericData.Timestamp()
                            self.timestamp.parent = self
                            self._children_name_map["timestamp"] = "timestamp"
                            self._segment_path = lambda: "generic-data"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.ErrorLog.LogEntry.GenericData, [], name, value)


                        class Timestamp(Entity):
                            """
                            Time in UTC relative to Jan 1st, 1970
                            
                            .. attribute:: seconds
                            
                            	Timestamp value (seconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: nano_seconds
                            
                            	Timestamp value (nanoseconds)
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: nanosecond
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.ErrorLog.LogEntry.GenericData.Timestamp, self).__init__()

                                self.yang_name = "timestamp"
                                self.yang_parent_name = "generic-data"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('seconds', (YLeaf(YType.uint32, 'seconds'), ['int'])),
                                    ('nano_seconds', (YLeaf(YType.uint32, 'nano-seconds'), ['int'])),
                                ])
                                self.seconds = None
                                self.nano_seconds = None
                                self._segment_path = lambda: "timestamp"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.ErrorLog.LogEntry.GenericData.Timestamp, [u'seconds', u'nano_seconds'], name, value)


            class CheckpointInterfaces(Entity):
                """
                Checkpointed interface table
                
                .. attribute:: checkpoint_interface
                
                	Checkpointed information about one IS\-IS interface
                	**type**\: list of  		 :py:class:`CheckpointInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.CheckpointInterfaces.CheckpointInterface>`
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2018-04-07'

                def __init__(self):
                    super(Isis.Instances.Instance.CheckpointInterfaces, self).__init__()

                    self.yang_name = "checkpoint-interfaces"
                    self.yang_parent_name = "instance"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("checkpoint-interface", ("checkpoint_interface", Isis.Instances.Instance.CheckpointInterfaces.CheckpointInterface))])
                    self._leafs = OrderedDict()

                    self.checkpoint_interface = YList(self)
                    self._segment_path = lambda: "checkpoint-interfaces"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Isis.Instances.Instance.CheckpointInterfaces, [], name, value)


                class CheckpointInterface(Entity):
                    """
                    Checkpointed information about one IS\-IS
                    interface
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: checkpoint_object_id
                    
                    	Checkpoint object ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface name
                    	**type**\: str
                    
                    .. attribute:: checkpoint_interface_handle
                    
                    	Local interface handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: local_circuit_number
                    
                    	Local circuit number
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: dis_areas
                    
                    	Areas in which this system is DIS
                    	**type**\:  :py:class:`IsisLevels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevels>`
                    
                    .. attribute:: has_adjacency
                    
                    	TRUE if there is an adjacency on this interface
                    	**type**\: bool
                    
                    .. attribute:: local_snpa
                    
                    	SNPA of this interface
                    	**type**\: str
                    
                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                    
                    .. attribute:: has_joined_mcast_group
                    
                    	TRUE if multicast group registration succeeded on this interface
                    	**type**\: bool
                    
                    .. attribute:: has_achieved_ldp_sync
                    
                    	MPLS LDP sync status
                    	**type**\: bool
                    
                    .. attribute:: has_achieved_ld_pv6_sync
                    
                    	MPLS LDPv6 sync status
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2018-04-07'

                    def __init__(self):
                        super(Isis.Instances.Instance.CheckpointInterfaces.CheckpointInterface, self).__init__()

                        self.yang_name = "checkpoint-interface"
                        self.yang_parent_name = "checkpoint-interfaces"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('checkpoint_object_id', (YLeaf(YType.uint32, 'checkpoint-object-id'), ['int'])),
                            ('interface_name_xr', (YLeaf(YType.str, 'interface-name-xr'), ['str'])),
                            ('checkpoint_interface_handle', (YLeaf(YType.str, 'checkpoint-interface-handle'), ['str'])),
                            ('local_circuit_number', (YLeaf(YType.uint8, 'local-circuit-number'), ['int'])),
                            ('dis_areas', (YLeaf(YType.enumeration, 'dis-areas'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisLevels', '')])),
                            ('has_adjacency', (YLeaf(YType.boolean, 'has-adjacency'), ['bool'])),
                            ('local_snpa', (YLeaf(YType.str, 'local-snpa'), ['str'])),
                            ('has_joined_mcast_group', (YLeaf(YType.boolean, 'has-joined-mcast-group'), ['bool'])),
                            ('has_achieved_ldp_sync', (YLeaf(YType.boolean, 'has-achieved-ldp-sync'), ['bool'])),
                            ('has_achieved_ld_pv6_sync', (YLeaf(YType.boolean, 'has-achieved-ld-pv6-sync'), ['bool'])),
                        ])
                        self.interface_name = None
                        self.checkpoint_object_id = None
                        self.interface_name_xr = None
                        self.checkpoint_interface_handle = None
                        self.local_circuit_number = None
                        self.dis_areas = None
                        self.has_adjacency = None
                        self.local_snpa = None
                        self.has_joined_mcast_group = None
                        self.has_achieved_ldp_sync = None
                        self.has_achieved_ld_pv6_sync = None
                        self._segment_path = lambda: "checkpoint-interface" + "[interface-name='" + str(self.interface_name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Isis.Instances.Instance.CheckpointInterfaces.CheckpointInterface, ['interface_name', u'checkpoint_object_id', u'interface_name_xr', u'checkpoint_interface_handle', u'local_circuit_number', u'dis_areas', u'has_adjacency', u'local_snpa', u'has_joined_mcast_group', u'has_achieved_ldp_sync', u'has_achieved_ld_pv6_sync'], name, value)


            class InterfaceStatistics(Entity):
                """
                Interface statistics table
                
                .. attribute:: interface_statistic
                
                	Statistics data for one IS\-IS interface
                	**type**\: list of  		 :py:class:`InterfaceStatistic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic>`
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2018-04-07'

                def __init__(self):
                    super(Isis.Instances.Instance.InterfaceStatistics, self).__init__()

                    self.yang_name = "interface-statistics"
                    self.yang_parent_name = "instance"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("interface-statistic", ("interface_statistic", Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic))])
                    self._leafs = OrderedDict()

                    self.interface_statistic = YList(self)
                    self._segment_path = lambda: "interface-statistics"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Isis.Instances.Instance.InterfaceStatistics, [], name, value)


                class InterfaceStatistic(Entity):
                    """
                    Statistics data for one IS\-IS interface
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: p2p_statistics
                    
                    	P2P interface statistics. NULL for non\-P2P interfaces
                    	**type**\:  :py:class:`P2pStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.P2pStatistics>`
                    
                    .. attribute:: traffic_interface
                    
                    	Interface to which traffic statistics apply
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: interface_media_type
                    
                    	Interface media class
                    	**type**\:  :py:class:`IsisMediaClass <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisMediaClass>`
                    
                    .. attribute:: per_area_data
                    
                    	Per\-area data
                    	**type**\: list of  		 :py:class:`PerAreaData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData>`
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2018-04-07'

                    def __init__(self):
                        super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic, self).__init__()

                        self.yang_name = "interface-statistic"
                        self.yang_parent_name = "interface-statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([("p2p-statistics", ("p2p_statistics", Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.P2pStatistics)), ("per-area-data", ("per_area_data", Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData))])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('traffic_interface', (YLeaf(YType.str, 'traffic-interface'), ['str'])),
                            ('interface_media_type', (YLeaf(YType.enumeration, 'interface-media-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisMediaClass', '')])),
                        ])
                        self.interface_name = None
                        self.traffic_interface = None
                        self.interface_media_type = None

                        self.p2p_statistics = Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.P2pStatistics()
                        self.p2p_statistics.parent = self
                        self._children_name_map["p2p_statistics"] = "p2p-statistics"

                        self.per_area_data = YList(self)
                        self._segment_path = lambda: "interface-statistic" + "[interface-name='" + str(self.interface_name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic, ['interface_name', u'traffic_interface', u'interface_media_type'], name, value)


                    class P2pStatistics(Entity):
                        """
                        P2P interface statistics. NULL for non\-P2P
                        interfaces
                        
                        .. attribute:: iih_count
                        
                        	IIH statistics
                        	**type**\:  :py:class:`IihCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.P2pStatistics.IihCount>`
                        
                        .. attribute:: memory_exhausted_iih_count
                        
                        	IIHs not sent due to memory exhaustion
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lsp_retransmit_count
                        
                        	LSP retransmissions
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.P2pStatistics, self).__init__()

                            self.yang_name = "p2p-statistics"
                            self.yang_parent_name = "interface-statistic"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("iih-count", ("iih_count", Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.P2pStatistics.IihCount))])
                            self._leafs = OrderedDict([
                                ('memory_exhausted_iih_count', (YLeaf(YType.uint32, 'memory-exhausted-iih-count'), ['int'])),
                                ('lsp_retransmit_count', (YLeaf(YType.uint32, 'lsp-retransmit-count'), ['int'])),
                            ])
                            self.memory_exhausted_iih_count = None
                            self.lsp_retransmit_count = None

                            self.iih_count = Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.P2pStatistics.IihCount()
                            self.iih_count.parent = self
                            self._children_name_map["iih_count"] = "iih-count"
                            self._segment_path = lambda: "p2p-statistics"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.P2pStatistics, [u'memory_exhausted_iih_count', u'lsp_retransmit_count'], name, value)


                        class IihCount(Entity):
                            """
                            IIH statistics
                            
                            .. attribute:: pdu_receive_count
                            
                            	PDUs received
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pdu_send_count
                            
                            	PDUs sent
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.P2pStatistics.IihCount, self).__init__()

                                self.yang_name = "iih-count"
                                self.yang_parent_name = "p2p-statistics"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('pdu_receive_count', (YLeaf(YType.uint32, 'pdu-receive-count'), ['int'])),
                                    ('pdu_send_count', (YLeaf(YType.uint32, 'pdu-send-count'), ['int'])),
                                ])
                                self.pdu_receive_count = None
                                self.pdu_send_count = None
                                self._segment_path = lambda: "iih-count"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.P2pStatistics.IihCount, [u'pdu_receive_count', u'pdu_send_count'], name, value)


                    class PerAreaData(Entity):
                        """
                        Per\-area data
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics>`
                        
                        .. attribute:: lan_data
                        
                        	LAN interface statistics. NULL for non\-LAN interfaces
                        	**type**\:  :py:class:`LanData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.LanData>`
                        
                        .. attribute:: level
                        
                        	Level of the area this data relates to
                        	**type**\:  :py:class:`IsisLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevel>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData, self).__init__()

                            self.yang_name = "per-area-data"
                            self.yang_parent_name = "interface-statistic"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("statistics", ("statistics", Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics)), ("lan-data", ("lan_data", Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.LanData))])
                            self._leafs = OrderedDict([
                                ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisLevel', '')])),
                            ])
                            self.level = None

                            self.statistics = Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"

                            self.lan_data = Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.LanData()
                            self.lan_data.parent = self
                            self._children_name_map["lan_data"] = "lan-data"
                            self._segment_path = lambda: "per-area-data"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData, [u'level'], name, value)


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: lsp_count
                            
                            	LSP statistics
                            	**type**\:  :py:class:`LspCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics.LspCount>`
                            
                            .. attribute:: csnp_count
                            
                            	CSNP statistics
                            	**type**\:  :py:class:`CsnpCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics.CsnpCount>`
                            
                            .. attribute:: psnp_count
                            
                            	PSNP statistics
                            	**type**\:  :py:class:`PsnpCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics.PsnpCount>`
                            
                            .. attribute:: lsp_drop_count
                            
                            	Count of LSPs dropped due to minimum arrival time config
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: lsp_flooding_dup_count
                            
                            	Count of LSPs already received by neighbors and not flooded
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "per-area-data"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("lsp-count", ("lsp_count", Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics.LspCount)), ("csnp-count", ("csnp_count", Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics.CsnpCount)), ("psnp-count", ("psnp_count", Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics.PsnpCount))])
                                self._leafs = OrderedDict([
                                    ('lsp_drop_count', (YLeaf(YType.uint32, 'lsp-drop-count'), ['int'])),
                                    ('lsp_flooding_dup_count', (YLeaf(YType.uint32, 'lsp-flooding-dup-count'), ['int'])),
                                ])
                                self.lsp_drop_count = None
                                self.lsp_flooding_dup_count = None

                                self.lsp_count = Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics.LspCount()
                                self.lsp_count.parent = self
                                self._children_name_map["lsp_count"] = "lsp-count"

                                self.csnp_count = Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics.CsnpCount()
                                self.csnp_count.parent = self
                                self._children_name_map["csnp_count"] = "csnp-count"

                                self.psnp_count = Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics.PsnpCount()
                                self.psnp_count.parent = self
                                self._children_name_map["psnp_count"] = "psnp-count"
                                self._segment_path = lambda: "statistics"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics, [u'lsp_drop_count', u'lsp_flooding_dup_count'], name, value)


                            class LspCount(Entity):
                                """
                                LSP statistics
                                
                                .. attribute:: pdu_receive_count
                                
                                	PDUs received
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pdu_send_count
                                
                                	PDUs sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics.LspCount, self).__init__()

                                    self.yang_name = "lsp-count"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pdu_receive_count', (YLeaf(YType.uint32, 'pdu-receive-count'), ['int'])),
                                        ('pdu_send_count', (YLeaf(YType.uint32, 'pdu-send-count'), ['int'])),
                                    ])
                                    self.pdu_receive_count = None
                                    self.pdu_send_count = None
                                    self._segment_path = lambda: "lsp-count"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics.LspCount, [u'pdu_receive_count', u'pdu_send_count'], name, value)


                            class CsnpCount(Entity):
                                """
                                CSNP statistics
                                
                                .. attribute:: pdu_receive_count
                                
                                	PDUs received
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pdu_send_count
                                
                                	PDUs sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics.CsnpCount, self).__init__()

                                    self.yang_name = "csnp-count"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pdu_receive_count', (YLeaf(YType.uint32, 'pdu-receive-count'), ['int'])),
                                        ('pdu_send_count', (YLeaf(YType.uint32, 'pdu-send-count'), ['int'])),
                                    ])
                                    self.pdu_receive_count = None
                                    self.pdu_send_count = None
                                    self._segment_path = lambda: "csnp-count"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics.CsnpCount, [u'pdu_receive_count', u'pdu_send_count'], name, value)


                            class PsnpCount(Entity):
                                """
                                PSNP statistics
                                
                                .. attribute:: pdu_receive_count
                                
                                	PDUs received
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pdu_send_count
                                
                                	PDUs sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics.PsnpCount, self).__init__()

                                    self.yang_name = "psnp-count"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pdu_receive_count', (YLeaf(YType.uint32, 'pdu-receive-count'), ['int'])),
                                        ('pdu_send_count', (YLeaf(YType.uint32, 'pdu-send-count'), ['int'])),
                                    ])
                                    self.pdu_receive_count = None
                                    self.pdu_send_count = None
                                    self._segment_path = lambda: "psnp-count"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.Statistics.PsnpCount, [u'pdu_receive_count', u'pdu_send_count'], name, value)


                        class LanData(Entity):
                            """
                            LAN interface statistics. NULL for non\-LAN
                            interfaces
                            
                            .. attribute:: iih_count
                            
                            	IIH statistics
                            	**type**\:  :py:class:`IihCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.LanData.IihCount>`
                            
                            .. attribute:: memory_exhausted_iih_count
                            
                            	IIHs not sent due to memory exhaustion
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: dis_election_count
                            
                            	DIS elections
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.LanData, self).__init__()

                                self.yang_name = "lan-data"
                                self.yang_parent_name = "per-area-data"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("iih-count", ("iih_count", Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.LanData.IihCount))])
                                self._leafs = OrderedDict([
                                    ('memory_exhausted_iih_count', (YLeaf(YType.uint32, 'memory-exhausted-iih-count'), ['int'])),
                                    ('dis_election_count', (YLeaf(YType.uint32, 'dis-election-count'), ['int'])),
                                ])
                                self.memory_exhausted_iih_count = None
                                self.dis_election_count = None

                                self.iih_count = Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.LanData.IihCount()
                                self.iih_count.parent = self
                                self._children_name_map["iih_count"] = "iih-count"
                                self._segment_path = lambda: "lan-data"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.LanData, [u'memory_exhausted_iih_count', u'dis_election_count'], name, value)


                            class IihCount(Entity):
                                """
                                IIH statistics
                                
                                .. attribute:: pdu_receive_count
                                
                                	PDUs received
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pdu_send_count
                                
                                	PDUs sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.LanData.IihCount, self).__init__()

                                    self.yang_name = "iih-count"
                                    self.yang_parent_name = "lan-data"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pdu_receive_count', (YLeaf(YType.uint32, 'pdu-receive-count'), ['int'])),
                                        ('pdu_send_count', (YLeaf(YType.uint32, 'pdu-send-count'), ['int'])),
                                    ])
                                    self.pdu_receive_count = None
                                    self.pdu_send_count = None
                                    self._segment_path = lambda: "iih-count"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.InterfaceStatistics.InterfaceStatistic.PerAreaData.LanData.IihCount, [u'pdu_receive_count', u'pdu_send_count'], name, value)


            class Protocol(Entity):
                """
                Basic protocol information about an IS\-IS
                instance
                
                .. attribute:: vrf_context
                
                	VRF context
                	**type**\: str
                
                .. attribute:: nsap_system_id
                
                	Local system ID
                	**type**\: str
                
                	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                
                .. attribute:: valid_nsap_system_id
                
                	Indicates if system ID valid
                	**type**\: bool
                
                .. attribute:: instance_id
                
                	instance id
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: running_levels
                
                	Levels running
                	**type**\:  :py:class:`IsisLevels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevels>`
                
                .. attribute:: configured_nsf_flavor
                
                	Configured NSF type
                	**type**\:  :py:class:`IsisNsfFlavor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisNsfFlavor>`
                
                .. attribute:: last_restart_nsf_flavor
                
                	NSF type of last restart
                	**type**\:  :py:class:`IsisNsfFlavor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisNsfFlavor>`
                
                .. attribute:: last_restart_status
                
                	Last restart status
                	**type**\:  :py:class:`IsisStartupStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisStartupStatus>`
                
                .. attribute:: te_connection
                
                	TE connection
                	**type**\:  :py:class:`IsisUp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisUp>`
                
                .. attribute:: remaining_time_for_next_nsf_restart
                
                	Time remaining until the next NSF restart may be attempted
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: adj_form_count
                
                	Adj Forming count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: adj_full_count
                
                	Adj Full count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: adj_stagger_enabled
                
                	Adjacency Stagger Enabled
                	**type**\: bool
                
                .. attribute:: adj_stagger_init
                
                	Adjacency Stagger Initiall Number of Forming Neighbors Allowed
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: adj_stagger_max
                
                	Adjacency Stagger Max Number of Forming Neighbors Allowed
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: srgb_allocated
                
                	Is SRGB allocated ?
                	**type**\: bool
                
                .. attribute:: srgb_start
                
                	First label in SRGB
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: srgb_end
                
                	Last label in SRGB
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: srlb_allocated
                
                	Is SRLB allocated ?
                	**type**\: bool
                
                .. attribute:: srlb_start
                
                	First label in SRLB
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: srlb_end
                
                	Last label in SRLB
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: manual_area_address
                
                	Manual area addresses
                	**type**\: list of  		 :py:class:`ManualAreaAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Protocol.ManualAreaAddress>`
                
                .. attribute:: active_area_address
                
                	Active area addresses
                	**type**\: list of  		 :py:class:`ActiveAreaAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Protocol.ActiveAreaAddress>`
                
                .. attribute:: per_topo_data
                
                	Per\-topology data
                	**type**\: list of  		 :py:class:`PerTopoData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Protocol.PerTopoData>`
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2018-04-07'

                def __init__(self):
                    super(Isis.Instances.Instance.Protocol, self).__init__()

                    self.yang_name = "protocol"
                    self.yang_parent_name = "instance"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("manual-area-address", ("manual_area_address", Isis.Instances.Instance.Protocol.ManualAreaAddress)), ("active-area-address", ("active_area_address", Isis.Instances.Instance.Protocol.ActiveAreaAddress)), ("per-topo-data", ("per_topo_data", Isis.Instances.Instance.Protocol.PerTopoData))])
                    self._leafs = OrderedDict([
                        ('vrf_context', (YLeaf(YType.str, 'vrf-context'), ['str'])),
                        ('nsap_system_id', (YLeaf(YType.str, 'nsap-system-id'), ['str'])),
                        ('valid_nsap_system_id', (YLeaf(YType.boolean, 'valid-nsap-system-id'), ['bool'])),
                        ('instance_id', (YLeaf(YType.uint16, 'instance-id'), ['int'])),
                        ('running_levels', (YLeaf(YType.enumeration, 'running-levels'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisLevels', '')])),
                        ('configured_nsf_flavor', (YLeaf(YType.enumeration, 'configured-nsf-flavor'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisNsfFlavor', '')])),
                        ('last_restart_nsf_flavor', (YLeaf(YType.enumeration, 'last-restart-nsf-flavor'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisNsfFlavor', '')])),
                        ('last_restart_status', (YLeaf(YType.enumeration, 'last-restart-status'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisStartupStatus', '')])),
                        ('te_connection', (YLeaf(YType.enumeration, 'te-connection'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisUp', '')])),
                        ('remaining_time_for_next_nsf_restart', (YLeaf(YType.uint32, 'remaining-time-for-next-nsf-restart'), ['int'])),
                        ('adj_form_count', (YLeaf(YType.uint32, 'adj-form-count'), ['int'])),
                        ('adj_full_count', (YLeaf(YType.uint32, 'adj-full-count'), ['int'])),
                        ('adj_stagger_enabled', (YLeaf(YType.boolean, 'adj-stagger-enabled'), ['bool'])),
                        ('adj_stagger_init', (YLeaf(YType.uint32, 'adj-stagger-init'), ['int'])),
                        ('adj_stagger_max', (YLeaf(YType.uint32, 'adj-stagger-max'), ['int'])),
                        ('srgb_allocated', (YLeaf(YType.boolean, 'srgb-allocated'), ['bool'])),
                        ('srgb_start', (YLeaf(YType.uint32, 'srgb-start'), ['int'])),
                        ('srgb_end', (YLeaf(YType.uint32, 'srgb-end'), ['int'])),
                        ('srlb_allocated', (YLeaf(YType.boolean, 'srlb-allocated'), ['bool'])),
                        ('srlb_start', (YLeaf(YType.uint32, 'srlb-start'), ['int'])),
                        ('srlb_end', (YLeaf(YType.uint32, 'srlb-end'), ['int'])),
                    ])
                    self.vrf_context = None
                    self.nsap_system_id = None
                    self.valid_nsap_system_id = None
                    self.instance_id = None
                    self.running_levels = None
                    self.configured_nsf_flavor = None
                    self.last_restart_nsf_flavor = None
                    self.last_restart_status = None
                    self.te_connection = None
                    self.remaining_time_for_next_nsf_restart = None
                    self.adj_form_count = None
                    self.adj_full_count = None
                    self.adj_stagger_enabled = None
                    self.adj_stagger_init = None
                    self.adj_stagger_max = None
                    self.srgb_allocated = None
                    self.srgb_start = None
                    self.srgb_end = None
                    self.srlb_allocated = None
                    self.srlb_start = None
                    self.srlb_end = None

                    self.manual_area_address = YList(self)
                    self.active_area_address = YList(self)
                    self.per_topo_data = YList(self)
                    self._segment_path = lambda: "protocol"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Isis.Instances.Instance.Protocol, [u'vrf_context', u'nsap_system_id', u'valid_nsap_system_id', u'instance_id', u'running_levels', u'configured_nsf_flavor', u'last_restart_nsf_flavor', u'last_restart_status', u'te_connection', u'remaining_time_for_next_nsf_restart', u'adj_form_count', u'adj_full_count', u'adj_stagger_enabled', u'adj_stagger_init', u'adj_stagger_max', u'srgb_allocated', u'srgb_start', u'srgb_end', u'srlb_allocated', u'srlb_start', u'srlb_end'], name, value)


                class ManualAreaAddress(Entity):
                    """
                    Manual area addresses
                    
                    .. attribute:: entry
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** [a\-fA\-F0\-9]{2}(\\.[a\-fA\-F0\-9]{4}){0,6}
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2018-04-07'

                    def __init__(self):
                        super(Isis.Instances.Instance.Protocol.ManualAreaAddress, self).__init__()

                        self.yang_name = "manual-area-address"
                        self.yang_parent_name = "protocol"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                        ])
                        self.entry = None
                        self._segment_path = lambda: "manual-area-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Isis.Instances.Instance.Protocol.ManualAreaAddress, [u'entry'], name, value)


                class ActiveAreaAddress(Entity):
                    """
                    Active area addresses
                    
                    .. attribute:: entry
                    
                    	
                    	**type**\: str
                    
                    	**pattern:** [a\-fA\-F0\-9]{2}(\\.[a\-fA\-F0\-9]{4}){0,6}
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2018-04-07'

                    def __init__(self):
                        super(Isis.Instances.Instance.Protocol.ActiveAreaAddress, self).__init__()

                        self.yang_name = "active-area-address"
                        self.yang_parent_name = "protocol"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('entry', (YLeaf(YType.str, 'entry'), ['str'])),
                        ])
                        self.entry = None
                        self._segment_path = lambda: "active-area-address"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Isis.Instances.Instance.Protocol.ActiveAreaAddress, [u'entry'], name, value)


                class PerTopoData(Entity):
                    """
                    Per\-topology data
                    
                    .. attribute:: id
                    
                    	Topology ID
                    	**type**\:  :py:class:`Id <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Protocol.PerTopoData.Id>`
                    
                    .. attribute:: redist_protocols_list
                    
                    	List of redistributed protocols
                    	**type**\:  :py:class:`RedistProtocolsList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Protocol.PerTopoData.RedistProtocolsList>`
                    
                    .. attribute:: default_admin_distance
                    
                    	Default administrative distance
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: advertise_passive_only
                    
                    	Advertise passive interface prefixes only
                    	**type**\: bool
                    
                    .. attribute:: wait_redist_complete
                    
                    	Waiting for redist complete RIB event
                    	**type**\: bool
                    
                    .. attribute:: per_area_data
                    
                    	Per\-area data
                    	**type**\: list of  		 :py:class:`PerAreaData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Protocol.PerTopoData.PerAreaData>`
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2018-04-07'

                    def __init__(self):
                        super(Isis.Instances.Instance.Protocol.PerTopoData, self).__init__()

                        self.yang_name = "per-topo-data"
                        self.yang_parent_name = "protocol"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("id", ("id", Isis.Instances.Instance.Protocol.PerTopoData.Id)), ("redist-protocols-list", ("redist_protocols_list", Isis.Instances.Instance.Protocol.PerTopoData.RedistProtocolsList)), ("per-area-data", ("per_area_data", Isis.Instances.Instance.Protocol.PerTopoData.PerAreaData))])
                        self._leafs = OrderedDict([
                            ('default_admin_distance', (YLeaf(YType.uint32, 'default-admin-distance'), ['int'])),
                            ('advertise_passive_only', (YLeaf(YType.boolean, 'advertise-passive-only'), ['bool'])),
                            ('wait_redist_complete', (YLeaf(YType.boolean, 'wait-redist-complete'), ['bool'])),
                        ])
                        self.default_admin_distance = None
                        self.advertise_passive_only = None
                        self.wait_redist_complete = None

                        self.id = Isis.Instances.Instance.Protocol.PerTopoData.Id()
                        self.id.parent = self
                        self._children_name_map["id"] = "id"

                        self.redist_protocols_list = Isis.Instances.Instance.Protocol.PerTopoData.RedistProtocolsList()
                        self.redist_protocols_list.parent = self
                        self._children_name_map["redist_protocols_list"] = "redist-protocols-list"

                        self.per_area_data = YList(self)
                        self._segment_path = lambda: "per-topo-data"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Isis.Instances.Instance.Protocol.PerTopoData, [u'default_admin_distance', u'advertise_passive_only', u'wait_redist_complete'], name, value)


                    class Id(Entity):
                        """
                        Topology ID
                        
                        .. attribute:: af_name
                        
                        	AF name
                        	**type**\:  :py:class:`IsisAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisAfId>`
                        
                        .. attribute:: saf_name
                        
                        	Sub\-AF name
                        	**type**\:  :py:class:`IsisSubAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisSubAfId>`
                        
                        .. attribute:: vrf_name
                        
                        	VRF Name
                        	**type**\: str
                        
                        .. attribute:: topology_name
                        
                        	Topology Name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.Protocol.PerTopoData.Id, self).__init__()

                            self.yang_name = "id"
                            self.yang_parent_name = "per-topo-data"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('af_name', (YLeaf(YType.enumeration, 'af-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisAfId', '')])),
                                ('saf_name', (YLeaf(YType.enumeration, 'saf-name'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisSubAfId', '')])),
                                ('vrf_name', (YLeaf(YType.str, 'vrf-name'), ['str'])),
                                ('topology_name', (YLeaf(YType.str, 'topology-name'), ['str'])),
                            ])
                            self.af_name = None
                            self.saf_name = None
                            self.vrf_name = None
                            self.topology_name = None
                            self._segment_path = lambda: "id"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.Protocol.PerTopoData.Id, [u'af_name', u'saf_name', u'vrf_name', u'topology_name'], name, value)


                    class RedistProtocolsList(Entity):
                        """
                        List of redistributed protocols
                        
                        .. attribute:: isis_sh_redist_entry
                        
                        	isis sh redist entry
                        	**type**\: list of  		 :py:class:`IsisShRedistEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Protocol.PerTopoData.RedistProtocolsList.IsisShRedistEntry>`
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.Protocol.PerTopoData.RedistProtocolsList, self).__init__()

                            self.yang_name = "redist-protocols-list"
                            self.yang_parent_name = "per-topo-data"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("isis-sh-redist-entry", ("isis_sh_redist_entry", Isis.Instances.Instance.Protocol.PerTopoData.RedistProtocolsList.IsisShRedistEntry))])
                            self._leafs = OrderedDict()

                            self.isis_sh_redist_entry = YList(self)
                            self._segment_path = lambda: "redist-protocols-list"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.Protocol.PerTopoData.RedistProtocolsList, [], name, value)


                        class IsisShRedistEntry(Entity):
                            """
                            isis sh redist entry
                            
                            .. attribute:: protocol_details
                            
                            	Relevant details of the redistributed protocol
                            	**type**\:  :py:class:`ProtocolDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.Protocol.PerTopoData.RedistProtocolsList.IsisShRedistEntry.ProtocolDetails>`
                            
                            

                            """

                            _prefix = 'clns-isis-oper'
                            _revision = '2018-04-07'

                            def __init__(self):
                                super(Isis.Instances.Instance.Protocol.PerTopoData.RedistProtocolsList.IsisShRedistEntry, self).__init__()

                                self.yang_name = "isis-sh-redist-entry"
                                self.yang_parent_name = "redist-protocols-list"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("protocol-details", ("protocol_details", Isis.Instances.Instance.Protocol.PerTopoData.RedistProtocolsList.IsisShRedistEntry.ProtocolDetails))])
                                self._leafs = OrderedDict()

                                self.protocol_details = Isis.Instances.Instance.Protocol.PerTopoData.RedistProtocolsList.IsisShRedistEntry.ProtocolDetails()
                                self.protocol_details.parent = self
                                self._children_name_map["protocol_details"] = "protocol-details"
                                self._segment_path = lambda: "isis-sh-redist-entry"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Isis.Instances.Instance.Protocol.PerTopoData.RedistProtocolsList.IsisShRedistEntry, [], name, value)


                            class ProtocolDetails(Entity):
                                """
                                Relevant details of the redistributed protocol
                                
                                .. attribute:: protocol
                                
                                	Protocol
                                	**type**\:  :py:class:`IsisRedistProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisRedistProto>`
                                
                                .. attribute:: isis_instance_id
                                
                                	IS\-IS instance identifier
                                	**type**\: str
                                
                                .. attribute:: ospf_process_id
                                
                                	OSPF process identifier
                                	**type**\: str
                                
                                .. attribute:: ospfv3_process_id
                                
                                	OSPFv3 process identifier
                                	**type**\: str
                                
                                .. attribute:: bgp_as_number
                                
                                	BGP Autonomous System number
                                	**type**\: str
                                
                                .. attribute:: eigrp_as_number
                                
                                	EIGRP Autonomous System number
                                	**type**\: str
                                
                                .. attribute:: application_name
                                
                                	Application Name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'clns-isis-oper'
                                _revision = '2018-04-07'

                                def __init__(self):
                                    super(Isis.Instances.Instance.Protocol.PerTopoData.RedistProtocolsList.IsisShRedistEntry.ProtocolDetails, self).__init__()

                                    self.yang_name = "protocol-details"
                                    self.yang_parent_name = "isis-sh-redist-entry"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('protocol', (YLeaf(YType.enumeration, 'protocol'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisRedistProto', '')])),
                                        ('isis_instance_id', (YLeaf(YType.str, 'isis-instance-id'), ['str'])),
                                        ('ospf_process_id', (YLeaf(YType.str, 'ospf-process-id'), ['str'])),
                                        ('ospfv3_process_id', (YLeaf(YType.str, 'ospfv3-process-id'), ['str'])),
                                        ('bgp_as_number', (YLeaf(YType.str, 'bgp-as-number'), ['str'])),
                                        ('eigrp_as_number', (YLeaf(YType.str, 'eigrp-as-number'), ['str'])),
                                        ('application_name', (YLeaf(YType.str, 'application-name'), ['str'])),
                                    ])
                                    self.protocol = None
                                    self.isis_instance_id = None
                                    self.ospf_process_id = None
                                    self.ospfv3_process_id = None
                                    self.bgp_as_number = None
                                    self.eigrp_as_number = None
                                    self.application_name = None
                                    self._segment_path = lambda: "protocol-details"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Isis.Instances.Instance.Protocol.PerTopoData.RedistProtocolsList.IsisShRedistEntry.ProtocolDetails, [u'protocol', u'isis_instance_id', u'ospf_process_id', u'ospfv3_process_id', u'bgp_as_number', u'eigrp_as_number', u'application_name'], name, value)


                    class PerAreaData(Entity):
                        """
                        Per\-area data
                        
                        .. attribute:: level
                        
                        	The level this data refers to
                        	**type**\:  :py:class:`IsisLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevel>`
                        
                        .. attribute:: uses_default_link_topo_flag
                        
                        	Does this topology use the default link topology
                        	**type**\: bool
                        
                        .. attribute:: generated_metric_style
                        
                        	Generate metric style
                        	**type**\:  :py:class:`IsisMetricStyle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisMetricStyle>`
                        
                        .. attribute:: accepted_metric_style
                        
                        	Accept metric style
                        	**type**\:  :py:class:`IsisMetricStyle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisMetricStyle>`
                        
                        .. attribute:: metric
                        
                        	Metric
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ispf_state
                        
                        	ISPF state
                        	**type**\:  :py:class:`IsisEnabled <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisEnabled>`
                        
                        .. attribute:: te_enabled
                        
                        	Indicates whether MPLS TE is enabled
                        	**type**\: bool
                        
                        .. attribute:: uloop_avoidance_type
                        
                        	Microloop avoidance type
                        	**type**\:  :py:class:`IsisUloopAvoidance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisUloopAvoidance>`
                        
                        .. attribute:: rib_update_delay
                        
                        	Microloop RIB update delay
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sr_uloop_is_active
                        
                        	Explicit paths installed in the RIB
                        	**type**\: bool
                        
                        .. attribute:: duration
                        
                        	SR microloop avoidance duration
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sr_uloop_event
                        
                        	SR microloop avoidance event
                        	**type**\:  :py:class:`IsisUloopEvent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisUloopEvent>`
                        
                        .. attribute:: sr_uloop_near_node_id
                        
                        	SR microloop near node
                        	**type**\: str
                        
                        	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}
                        
                        .. attribute:: sr_uloop_far_node_id
                        
                        	SR microloop far node
                        	**type**\: str
                        
                        	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.Protocol.PerTopoData.PerAreaData, self).__init__()

                            self.yang_name = "per-area-data"
                            self.yang_parent_name = "per-topo-data"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisLevel', '')])),
                                ('uses_default_link_topo_flag', (YLeaf(YType.boolean, 'uses-default-link-topo-flag'), ['bool'])),
                                ('generated_metric_style', (YLeaf(YType.enumeration, 'generated-metric-style'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisMetricStyle', '')])),
                                ('accepted_metric_style', (YLeaf(YType.enumeration, 'accepted-metric-style'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisMetricStyle', '')])),
                                ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                ('ispf_state', (YLeaf(YType.enumeration, 'ispf-state'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisEnabled', '')])),
                                ('te_enabled', (YLeaf(YType.boolean, 'te-enabled'), ['bool'])),
                                ('uloop_avoidance_type', (YLeaf(YType.enumeration, 'uloop-avoidance-type'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisUloopAvoidance', '')])),
                                ('rib_update_delay', (YLeaf(YType.uint32, 'rib-update-delay'), ['int'])),
                                ('sr_uloop_is_active', (YLeaf(YType.boolean, 'sr-uloop-is-active'), ['bool'])),
                                ('duration', (YLeaf(YType.uint32, 'duration'), ['int'])),
                                ('sr_uloop_event', (YLeaf(YType.enumeration, 'sr-uloop-event'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisUloopEvent', '')])),
                                ('sr_uloop_near_node_id', (YLeaf(YType.str, 'sr-uloop-near-node-id'), ['str'])),
                                ('sr_uloop_far_node_id', (YLeaf(YType.str, 'sr-uloop-far-node-id'), ['str'])),
                            ])
                            self.level = None
                            self.uses_default_link_topo_flag = None
                            self.generated_metric_style = None
                            self.accepted_metric_style = None
                            self.metric = None
                            self.ispf_state = None
                            self.te_enabled = None
                            self.uloop_avoidance_type = None
                            self.rib_update_delay = None
                            self.sr_uloop_is_active = None
                            self.duration = None
                            self.sr_uloop_event = None
                            self.sr_uloop_near_node_id = None
                            self.sr_uloop_far_node_id = None
                            self._segment_path = lambda: "per-area-data"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.Protocol.PerTopoData.PerAreaData, [u'level', u'uses_default_link_topo_flag', u'generated_metric_style', u'accepted_metric_style', u'metric', u'ispf_state', u'te_enabled', u'uloop_avoidance_type', u'rib_update_delay', u'sr_uloop_is_active', u'duration', u'sr_uloop_event', u'sr_uloop_near_node_id', u'sr_uloop_far_node_id'], name, value)


            class NeighborSummaries(Entity):
                """
                Neighbor\-summary table
                
                .. attribute:: neighbor_summary
                
                	Neighbor\-summary data for a single interface
                	**type**\: list of  		 :py:class:`NeighborSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NeighborSummaries.NeighborSummary>`
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2018-04-07'

                def __init__(self):
                    super(Isis.Instances.Instance.NeighborSummaries, self).__init__()

                    self.yang_name = "neighbor-summaries"
                    self.yang_parent_name = "instance"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("neighbor-summary", ("neighbor_summary", Isis.Instances.Instance.NeighborSummaries.NeighborSummary))])
                    self._leafs = OrderedDict()

                    self.neighbor_summary = YList(self)
                    self._segment_path = lambda: "neighbor-summaries"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Isis.Instances.Instance.NeighborSummaries, [], name, value)


                class NeighborSummary(Entity):
                    """
                    Neighbor\-summary data for a single interface
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: level1_neighbors
                    
                    	L1\-only neighbors
                    	**type**\:  :py:class:`Level1Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NeighborSummaries.NeighborSummary.Level1Neighbors>`
                    
                    .. attribute:: level2_neighbors
                    
                    	L2\-only neighbors
                    	**type**\:  :py:class:`Level2Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NeighborSummaries.NeighborSummary.Level2Neighbors>`
                    
                    .. attribute:: level12_neigbors
                    
                    	L12 neighbors
                    	**type**\:  :py:class:`Level12Neigbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NeighborSummaries.NeighborSummary.Level12Neigbors>`
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2018-04-07'

                    def __init__(self):
                        super(Isis.Instances.Instance.NeighborSummaries.NeighborSummary, self).__init__()

                        self.yang_name = "neighbor-summary"
                        self.yang_parent_name = "neighbor-summaries"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([("level1-neighbors", ("level1_neighbors", Isis.Instances.Instance.NeighborSummaries.NeighborSummary.Level1Neighbors)), ("level2-neighbors", ("level2_neighbors", Isis.Instances.Instance.NeighborSummaries.NeighborSummary.Level2Neighbors)), ("level12-neigbors", ("level12_neigbors", Isis.Instances.Instance.NeighborSummaries.NeighborSummary.Level12Neigbors))])
                        self._leafs = OrderedDict([
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                        ])
                        self.interface_name = None

                        self.level1_neighbors = Isis.Instances.Instance.NeighborSummaries.NeighborSummary.Level1Neighbors()
                        self.level1_neighbors.parent = self
                        self._children_name_map["level1_neighbors"] = "level1-neighbors"

                        self.level2_neighbors = Isis.Instances.Instance.NeighborSummaries.NeighborSummary.Level2Neighbors()
                        self.level2_neighbors.parent = self
                        self._children_name_map["level2_neighbors"] = "level2-neighbors"

                        self.level12_neigbors = Isis.Instances.Instance.NeighborSummaries.NeighborSummary.Level12Neigbors()
                        self.level12_neigbors.parent = self
                        self._children_name_map["level12_neigbors"] = "level12-neigbors"
                        self._segment_path = lambda: "neighbor-summary" + "[interface-name='" + str(self.interface_name) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Isis.Instances.Instance.NeighborSummaries.NeighborSummary, ['interface_name'], name, value)


                    class Level1Neighbors(Entity):
                        """
                        L1\-only neighbors
                        
                        .. attribute:: neighbor_up_count
                        
                        	Neighbors up
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: neighbor_init_count
                        
                        	Neighbors being initialized
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: neighbor_down_count
                        
                        	Neighbors down
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.NeighborSummaries.NeighborSummary.Level1Neighbors, self).__init__()

                            self.yang_name = "level1-neighbors"
                            self.yang_parent_name = "neighbor-summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('neighbor_up_count', (YLeaf(YType.uint32, 'neighbor-up-count'), ['int'])),
                                ('neighbor_init_count', (YLeaf(YType.uint32, 'neighbor-init-count'), ['int'])),
                                ('neighbor_down_count', (YLeaf(YType.uint32, 'neighbor-down-count'), ['int'])),
                            ])
                            self.neighbor_up_count = None
                            self.neighbor_init_count = None
                            self.neighbor_down_count = None
                            self._segment_path = lambda: "level1-neighbors"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.NeighborSummaries.NeighborSummary.Level1Neighbors, [u'neighbor_up_count', u'neighbor_init_count', u'neighbor_down_count'], name, value)


                    class Level2Neighbors(Entity):
                        """
                        L2\-only neighbors
                        
                        .. attribute:: neighbor_up_count
                        
                        	Neighbors up
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: neighbor_init_count
                        
                        	Neighbors being initialized
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: neighbor_down_count
                        
                        	Neighbors down
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.NeighborSummaries.NeighborSummary.Level2Neighbors, self).__init__()

                            self.yang_name = "level2-neighbors"
                            self.yang_parent_name = "neighbor-summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('neighbor_up_count', (YLeaf(YType.uint32, 'neighbor-up-count'), ['int'])),
                                ('neighbor_init_count', (YLeaf(YType.uint32, 'neighbor-init-count'), ['int'])),
                                ('neighbor_down_count', (YLeaf(YType.uint32, 'neighbor-down-count'), ['int'])),
                            ])
                            self.neighbor_up_count = None
                            self.neighbor_init_count = None
                            self.neighbor_down_count = None
                            self._segment_path = lambda: "level2-neighbors"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.NeighborSummaries.NeighborSummary.Level2Neighbors, [u'neighbor_up_count', u'neighbor_init_count', u'neighbor_down_count'], name, value)


                    class Level12Neigbors(Entity):
                        """
                        L12 neighbors
                        
                        .. attribute:: neighbor_up_count
                        
                        	Neighbors up
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: neighbor_init_count
                        
                        	Neighbors being initialized
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: neighbor_down_count
                        
                        	Neighbors down
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.NeighborSummaries.NeighborSummary.Level12Neigbors, self).__init__()

                            self.yang_name = "level12-neigbors"
                            self.yang_parent_name = "neighbor-summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('neighbor_up_count', (YLeaf(YType.uint32, 'neighbor-up-count'), ['int'])),
                                ('neighbor_init_count', (YLeaf(YType.uint32, 'neighbor-init-count'), ['int'])),
                                ('neighbor_down_count', (YLeaf(YType.uint32, 'neighbor-down-count'), ['int'])),
                            ])
                            self.neighbor_up_count = None
                            self.neighbor_init_count = None
                            self.neighbor_down_count = None
                            self._segment_path = lambda: "level12-neigbors"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.NeighborSummaries.NeighborSummary.Level12Neigbors, [u'neighbor_up_count', u'neighbor_init_count', u'neighbor_down_count'], name, value)


            class CheckpointLsps(Entity):
                """
                Checkpointed LSP table
                
                .. attribute:: checkpoint_lsp
                
                	A checkpointed IS\-IS LSP
                	**type**\: list of  		 :py:class:`CheckpointLsp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.CheckpointLsps.CheckpointLsp>`
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2018-04-07'

                def __init__(self):
                    super(Isis.Instances.Instance.CheckpointLsps, self).__init__()

                    self.yang_name = "checkpoint-lsps"
                    self.yang_parent_name = "instance"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("checkpoint-lsp", ("checkpoint_lsp", Isis.Instances.Instance.CheckpointLsps.CheckpointLsp))])
                    self._leafs = OrderedDict()

                    self.checkpoint_lsp = YList(self)
                    self._segment_path = lambda: "checkpoint-lsps"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Isis.Instances.Instance.CheckpointLsps, [], name, value)


                class CheckpointLsp(Entity):
                    """
                    A checkpointed IS\-IS LSP
                    
                    .. attribute:: level
                    
                    	Level
                    	**type**\:  :py:class:`IsisInternalLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_datatypes.IsisInternalLevel>`
                    
                    .. attribute:: lsp_id
                    
                    	LSP ID
                    	**type**\: str
                    
                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                    
                    .. attribute:: checkpoint_lsp_object_id
                    
                    	LSP Checkpoint table object ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: checkpoint_lsp_level
                    
                    	LSP level
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: checkpoint_lsp_local_flag
                    
                    	TRUE if this is a local LSP
                    	**type**\: bool
                    
                    .. attribute:: checkpoint_lsp_id
                    
                    	LSP ID
                    	**type**\: str
                    
                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}\\.[a\-fA\-F0\-9]{2}\\\-[a\-fA\-F0\-9]{2}
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2018-04-07'

                    def __init__(self):
                        super(Isis.Instances.Instance.CheckpointLsps.CheckpointLsp, self).__init__()

                        self.yang_name = "checkpoint-lsp"
                        self.yang_parent_name = "checkpoint-lsps"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_datatypes', 'IsisInternalLevel', '')])),
                            ('lsp_id', (YLeaf(YType.str, 'lsp-id'), ['str'])),
                            ('checkpoint_lsp_object_id', (YLeaf(YType.uint32, 'checkpoint-lsp-object-id'), ['int'])),
                            ('checkpoint_lsp_level', (YLeaf(YType.uint8, 'checkpoint-lsp-level'), ['int'])),
                            ('checkpoint_lsp_local_flag', (YLeaf(YType.boolean, 'checkpoint-lsp-local-flag'), ['bool'])),
                            ('checkpoint_lsp_id', (YLeaf(YType.str, 'checkpoint-lsp-id'), ['str'])),
                        ])
                        self.level = None
                        self.lsp_id = None
                        self.checkpoint_lsp_object_id = None
                        self.checkpoint_lsp_level = None
                        self.checkpoint_lsp_local_flag = None
                        self.checkpoint_lsp_id = None
                        self._segment_path = lambda: "checkpoint-lsp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Isis.Instances.Instance.CheckpointLsps.CheckpointLsp, ['level', 'lsp_id', u'checkpoint_lsp_object_id', u'checkpoint_lsp_level', u'checkpoint_lsp_local_flag', u'checkpoint_lsp_id'], name, value)


            class MeshGroups(Entity):
                """
                Mesh\-group information
                
                .. attribute:: mesh_group_configured_interface_list
                
                	List of mesh\-group\-configured interfaces
                	**type**\:  :py:class:`MeshGroupConfiguredInterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.MeshGroups.MeshGroupConfiguredInterfaceList>`
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2018-04-07'

                def __init__(self):
                    super(Isis.Instances.Instance.MeshGroups, self).__init__()

                    self.yang_name = "mesh-groups"
                    self.yang_parent_name = "instance"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mesh-group-configured-interface-list", ("mesh_group_configured_interface_list", Isis.Instances.Instance.MeshGroups.MeshGroupConfiguredInterfaceList))])
                    self._leafs = OrderedDict()

                    self.mesh_group_configured_interface_list = Isis.Instances.Instance.MeshGroups.MeshGroupConfiguredInterfaceList()
                    self.mesh_group_configured_interface_list.parent = self
                    self._children_name_map["mesh_group_configured_interface_list"] = "mesh-group-configured-interface-list"
                    self._segment_path = lambda: "mesh-groups"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Isis.Instances.Instance.MeshGroups, [], name, value)


                class MeshGroupConfiguredInterfaceList(Entity):
                    """
                    List of mesh\-group\-configured interfaces
                    
                    .. attribute:: isis_sh_mesh_entry
                    
                    	isis sh mesh entry
                    	**type**\: list of  		 :py:class:`IsisShMeshEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.MeshGroups.MeshGroupConfiguredInterfaceList.IsisShMeshEntry>`
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2018-04-07'

                    def __init__(self):
                        super(Isis.Instances.Instance.MeshGroups.MeshGroupConfiguredInterfaceList, self).__init__()

                        self.yang_name = "mesh-group-configured-interface-list"
                        self.yang_parent_name = "mesh-groups"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("isis-sh-mesh-entry", ("isis_sh_mesh_entry", Isis.Instances.Instance.MeshGroups.MeshGroupConfiguredInterfaceList.IsisShMeshEntry))])
                        self._leafs = OrderedDict()

                        self.isis_sh_mesh_entry = YList(self)
                        self._segment_path = lambda: "mesh-group-configured-interface-list"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Isis.Instances.Instance.MeshGroups.MeshGroupConfiguredInterfaceList, [], name, value)


                    class IsisShMeshEntry(Entity):
                        """
                        isis sh mesh entry
                        
                        .. attribute:: mesh_group_interface
                        
                        	This interface
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                        
                        .. attribute:: mesh_group_number
                        
                        	Mesh\-group number
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.MeshGroups.MeshGroupConfiguredInterfaceList.IsisShMeshEntry, self).__init__()

                            self.yang_name = "isis-sh-mesh-entry"
                            self.yang_parent_name = "mesh-group-configured-interface-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('mesh_group_interface', (YLeaf(YType.str, 'mesh-group-interface'), ['str'])),
                                ('mesh_group_number', (YLeaf(YType.uint32, 'mesh-group-number'), ['int'])),
                            ])
                            self.mesh_group_interface = None
                            self.mesh_group_number = None
                            self._segment_path = lambda: "isis-sh-mesh-entry"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.MeshGroups.MeshGroupConfiguredInterfaceList.IsisShMeshEntry, [u'mesh_group_interface', u'mesh_group_number'], name, value)


            class NsrStatistics(Entity):
                """
                NSR Statistics information
                
                .. attribute:: isis_nsr_stats_data
                
                	ISIS NSR STATS Data
                	**type**\:  :py:class:`IsisNsrStatsData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatistics.IsisNsrStatsData>`
                
                .. attribute:: isis_vm_state
                
                	ISIS VM STATE
                	**type**\: int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2018-04-07'

                def __init__(self):
                    super(Isis.Instances.Instance.NsrStatistics, self).__init__()

                    self.yang_name = "nsr-statistics"
                    self.yang_parent_name = "instance"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("isis-nsr-stats-data", ("isis_nsr_stats_data", Isis.Instances.Instance.NsrStatistics.IsisNsrStatsData))])
                    self._leafs = OrderedDict([
                        ('isis_vm_state', (YLeaf(YType.uint16, 'isis-vm-state'), ['int'])),
                    ])
                    self.isis_vm_state = None

                    self.isis_nsr_stats_data = Isis.Instances.Instance.NsrStatistics.IsisNsrStatsData()
                    self.isis_nsr_stats_data.parent = self
                    self._children_name_map["isis_nsr_stats_data"] = "isis-nsr-stats-data"
                    self._segment_path = lambda: "nsr-statistics"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Isis.Instances.Instance.NsrStatistics, [u'isis_vm_state'], name, value)


                class IsisNsrStatsData(Entity):
                    """
                    ISIS NSR STATS Data
                    
                    .. attribute:: self
                    
                    	self
                    	**type**\:  :py:class:`Self <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatistics.IsisNsrStatsData.Self>`
                    
                    .. attribute:: peer
                    
                    	peer
                    	**type**\: list of  		 :py:class:`Peer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.NsrStatistics.IsisNsrStatsData.Peer>`
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2018-04-07'

                    def __init__(self):
                        super(Isis.Instances.Instance.NsrStatistics.IsisNsrStatsData, self).__init__()

                        self.yang_name = "isis-nsr-stats-data"
                        self.yang_parent_name = "nsr-statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("self", ("self", Isis.Instances.Instance.NsrStatistics.IsisNsrStatsData.Self)), ("peer", ("peer", Isis.Instances.Instance.NsrStatistics.IsisNsrStatsData.Peer))])
                        self._leafs = OrderedDict()

                        self.self = Isis.Instances.Instance.NsrStatistics.IsisNsrStatsData.Self()
                        self.self.parent = self
                        self._children_name_map["self"] = "self"

                        self.peer = YList(self)
                        self._segment_path = lambda: "isis-nsr-stats-data"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Isis.Instances.Instance.NsrStatistics.IsisNsrStatsData, [], name, value)


                    class Self(Entity):
                        """
                        self
                        
                        .. attribute:: no_of_l1_lsp
                        
                        	no of l1 lsp
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: no_of_l2_lsp
                        
                        	no of l2 lsp
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: no_of_l1_adj
                        
                        	no of l1 adj
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: no_of_l2_adj
                        
                        	no of l2 adj
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: no_of_live_interface
                        
                        	no of live interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: no_of_ptp_interface
                        
                        	no of ptp interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: no_of_lan_interface
                        
                        	no of lan interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: no_of_loopback_interface
                        
                        	no of loopback interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: no_of_te_tunnels
                        
                        	no of te tunnels
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: no_of_te_links
                        
                        	no of te links
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: no_of_ipv4_routes
                        
                        	no of ipv4 routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: no_of_ipv6_routes
                        
                        	no of ipv6 routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: seqnum
                        
                        	seqnum
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.NsrStatistics.IsisNsrStatsData.Self, self).__init__()

                            self.yang_name = "self"
                            self.yang_parent_name = "isis-nsr-stats-data"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('no_of_l1_lsp', (YLeaf(YType.uint32, 'no-of-l1-lsp'), ['int'])),
                                ('no_of_l2_lsp', (YLeaf(YType.uint32, 'no-of-l2-lsp'), ['int'])),
                                ('no_of_l1_adj', (YLeaf(YType.uint16, 'no-of-l1-adj'), ['int'])),
                                ('no_of_l2_adj', (YLeaf(YType.uint16, 'no-of-l2-adj'), ['int'])),
                                ('no_of_live_interface', (YLeaf(YType.uint16, 'no-of-live-interface'), ['int'])),
                                ('no_of_ptp_interface', (YLeaf(YType.uint16, 'no-of-ptp-interface'), ['int'])),
                                ('no_of_lan_interface', (YLeaf(YType.uint16, 'no-of-lan-interface'), ['int'])),
                                ('no_of_loopback_interface', (YLeaf(YType.uint16, 'no-of-loopback-interface'), ['int'])),
                                ('no_of_te_tunnels', (YLeaf(YType.uint16, 'no-of-te-tunnels'), ['int'])),
                                ('no_of_te_links', (YLeaf(YType.uint16, 'no-of-te-links'), ['int'])),
                                ('no_of_ipv4_routes', (YLeaf(YType.uint32, 'no-of-ipv4-routes'), ['int'])),
                                ('no_of_ipv6_routes', (YLeaf(YType.uint32, 'no-of-ipv6-routes'), ['int'])),
                                ('seqnum', (YLeaf(YType.uint32, 'seqnum'), ['int'])),
                            ])
                            self.no_of_l1_lsp = None
                            self.no_of_l2_lsp = None
                            self.no_of_l1_adj = None
                            self.no_of_l2_adj = None
                            self.no_of_live_interface = None
                            self.no_of_ptp_interface = None
                            self.no_of_lan_interface = None
                            self.no_of_loopback_interface = None
                            self.no_of_te_tunnels = None
                            self.no_of_te_links = None
                            self.no_of_ipv4_routes = None
                            self.no_of_ipv6_routes = None
                            self.seqnum = None
                            self._segment_path = lambda: "self"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.NsrStatistics.IsisNsrStatsData.Self, [u'no_of_l1_lsp', u'no_of_l2_lsp', u'no_of_l1_adj', u'no_of_l2_adj', u'no_of_live_interface', u'no_of_ptp_interface', u'no_of_lan_interface', u'no_of_loopback_interface', u'no_of_te_tunnels', u'no_of_te_links', u'no_of_ipv4_routes', u'no_of_ipv6_routes', u'seqnum'], name, value)


                    class Peer(Entity):
                        """
                        peer
                        
                        .. attribute:: no_of_l1_lsp
                        
                        	no of l1 lsp
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: no_of_l2_lsp
                        
                        	no of l2 lsp
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: no_of_l1_adj
                        
                        	no of l1 adj
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: no_of_l2_adj
                        
                        	no of l2 adj
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: no_of_live_interface
                        
                        	no of live interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: no_of_ptp_interface
                        
                        	no of ptp interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: no_of_lan_interface
                        
                        	no of lan interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: no_of_loopback_interface
                        
                        	no of loopback interface
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: no_of_te_tunnels
                        
                        	no of te tunnels
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: no_of_te_links
                        
                        	no of te links
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: no_of_ipv4_routes
                        
                        	no of ipv4 routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: no_of_ipv6_routes
                        
                        	no of ipv6 routes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: seqnum
                        
                        	seqnum
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'clns-isis-oper'
                        _revision = '2018-04-07'

                        def __init__(self):
                            super(Isis.Instances.Instance.NsrStatistics.IsisNsrStatsData.Peer, self).__init__()

                            self.yang_name = "peer"
                            self.yang_parent_name = "isis-nsr-stats-data"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('no_of_l1_lsp', (YLeaf(YType.uint32, 'no-of-l1-lsp'), ['int'])),
                                ('no_of_l2_lsp', (YLeaf(YType.uint32, 'no-of-l2-lsp'), ['int'])),
                                ('no_of_l1_adj', (YLeaf(YType.uint16, 'no-of-l1-adj'), ['int'])),
                                ('no_of_l2_adj', (YLeaf(YType.uint16, 'no-of-l2-adj'), ['int'])),
                                ('no_of_live_interface', (YLeaf(YType.uint16, 'no-of-live-interface'), ['int'])),
                                ('no_of_ptp_interface', (YLeaf(YType.uint16, 'no-of-ptp-interface'), ['int'])),
                                ('no_of_lan_interface', (YLeaf(YType.uint16, 'no-of-lan-interface'), ['int'])),
                                ('no_of_loopback_interface', (YLeaf(YType.uint16, 'no-of-loopback-interface'), ['int'])),
                                ('no_of_te_tunnels', (YLeaf(YType.uint16, 'no-of-te-tunnels'), ['int'])),
                                ('no_of_te_links', (YLeaf(YType.uint16, 'no-of-te-links'), ['int'])),
                                ('no_of_ipv4_routes', (YLeaf(YType.uint32, 'no-of-ipv4-routes'), ['int'])),
                                ('no_of_ipv6_routes', (YLeaf(YType.uint32, 'no-of-ipv6-routes'), ['int'])),
                                ('seqnum', (YLeaf(YType.uint32, 'seqnum'), ['int'])),
                            ])
                            self.no_of_l1_lsp = None
                            self.no_of_l2_lsp = None
                            self.no_of_l1_adj = None
                            self.no_of_l2_adj = None
                            self.no_of_live_interface = None
                            self.no_of_ptp_interface = None
                            self.no_of_lan_interface = None
                            self.no_of_loopback_interface = None
                            self.no_of_te_tunnels = None
                            self.no_of_te_links = None
                            self.no_of_ipv4_routes = None
                            self.no_of_ipv6_routes = None
                            self.seqnum = None
                            self._segment_path = lambda: "peer"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Isis.Instances.Instance.NsrStatistics.IsisNsrStatsData.Peer, [u'no_of_l1_lsp', u'no_of_l2_lsp', u'no_of_l1_adj', u'no_of_l2_adj', u'no_of_live_interface', u'no_of_ptp_interface', u'no_of_lan_interface', u'no_of_loopback_interface', u'no_of_te_tunnels', u'no_of_te_links', u'no_of_ipv4_routes', u'no_of_ipv6_routes', u'seqnum'], name, value)


            class CheckpointTeTunnels(Entity):
                """
                Checkpointed TE tunnel table
                
                .. attribute:: checkpoint_te_tunnel
                
                	A checkpointed TE tunnel
                	**type**\: list of  		 :py:class:`CheckpointTeTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.Isis.Instances.Instance.CheckpointTeTunnels.CheckpointTeTunnel>`
                
                

                """

                _prefix = 'clns-isis-oper'
                _revision = '2018-04-07'

                def __init__(self):
                    super(Isis.Instances.Instance.CheckpointTeTunnels, self).__init__()

                    self.yang_name = "checkpoint-te-tunnels"
                    self.yang_parent_name = "instance"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("checkpoint-te-tunnel", ("checkpoint_te_tunnel", Isis.Instances.Instance.CheckpointTeTunnels.CheckpointTeTunnel))])
                    self._leafs = OrderedDict()

                    self.checkpoint_te_tunnel = YList(self)
                    self._segment_path = lambda: "checkpoint-te-tunnels"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Isis.Instances.Instance.CheckpointTeTunnels, [], name, value)


                class CheckpointTeTunnel(Entity):
                    """
                    A checkpointed TE tunnel
                    
                    .. attribute:: level
                    
                    	Level
                    	**type**\:  :py:class:`IsisInternalLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_datatypes.IsisInternalLevel>`
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: checkpoint_te_level
                    
                    	TE database level
                    	**type**\:  :py:class:`IsisLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisLevel>`
                    
                    .. attribute:: checkpoint_te_system_id
                    
                    	Destination system ID
                    	**type**\: str
                    
                    	**pattern:** [a\-fA\-F0\-9]{4}(\\.[a\-fA\-F0\-9]{4}){2}
                    
                    .. attribute:: checkpoint_te_interface
                    
                    	Tunnel interface
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9.\_/\-]+
                    
                    .. attribute:: checkpoint_te_flags
                    
                    	Tunnel flags
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: checkpoint_te_nexthop
                    
                    	Tunnel next\-hop IP address
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: checkpoint_te_metric
                    
                    	Tunnel metric
                    	**type**\: int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: checkpoint_te_metric_mode
                    
                    	Tunnel metric mode
                    	**type**\:  :py:class:`IsisMetricMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper.IsisMetricMode>`
                    
                    .. attribute:: checkpoint_te_bandwidth
                    
                    	Tunnel bandwidth
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: checkpoint_te_object_id
                    
                    	Tunnel checkpoint object ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'clns-isis-oper'
                    _revision = '2018-04-07'

                    def __init__(self):
                        super(Isis.Instances.Instance.CheckpointTeTunnels.CheckpointTeTunnel, self).__init__()

                        self.yang_name = "checkpoint-te-tunnel"
                        self.yang_parent_name = "checkpoint-te-tunnels"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('level', (YLeaf(YType.enumeration, 'level'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_datatypes', 'IsisInternalLevel', '')])),
                            ('interface_name', (YLeaf(YType.str, 'interface-name'), ['str'])),
                            ('checkpoint_te_level', (YLeaf(YType.enumeration, 'checkpoint-te-level'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisLevel', '')])),
                            ('checkpoint_te_system_id', (YLeaf(YType.str, 'checkpoint-te-system-id'), ['str'])),
                            ('checkpoint_te_interface', (YLeaf(YType.str, 'checkpoint-te-interface'), ['str'])),
                            ('checkpoint_te_flags', (YLeaf(YType.uint32, 'checkpoint-te-flags'), ['int'])),
                            ('checkpoint_te_nexthop', (YLeaf(YType.str, 'checkpoint-te-nexthop'), ['str'])),
                            ('checkpoint_te_metric', (YLeaf(YType.int32, 'checkpoint-te-metric'), ['int'])),
                            ('checkpoint_te_metric_mode', (YLeaf(YType.enumeration, 'checkpoint-te-metric-mode'), [('ydk.models.cisco_ios_xr.Cisco_IOS_XR_clns_isis_oper', 'IsisMetricMode', '')])),
                            ('checkpoint_te_bandwidth', (YLeaf(YType.uint32, 'checkpoint-te-bandwidth'), ['int'])),
                            ('checkpoint_te_object_id', (YLeaf(YType.uint32, 'checkpoint-te-object-id'), ['int'])),
                        ])
                        self.level = None
                        self.interface_name = None
                        self.checkpoint_te_level = None
                        self.checkpoint_te_system_id = None
                        self.checkpoint_te_interface = None
                        self.checkpoint_te_flags = None
                        self.checkpoint_te_nexthop = None
                        self.checkpoint_te_metric = None
                        self.checkpoint_te_metric_mode = None
                        self.checkpoint_te_bandwidth = None
                        self.checkpoint_te_object_id = None
                        self._segment_path = lambda: "checkpoint-te-tunnel"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Isis.Instances.Instance.CheckpointTeTunnels.CheckpointTeTunnel, ['level', 'interface_name', u'checkpoint_te_level', u'checkpoint_te_system_id', u'checkpoint_te_interface', u'checkpoint_te_flags', u'checkpoint_te_nexthop', u'checkpoint_te_metric', u'checkpoint_te_metric_mode', u'checkpoint_te_bandwidth', u'checkpoint_te_object_id'], name, value)

    def clone_ptr(self):
        self._top_entity = Isis()
        return self._top_entity

